(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    227902,       5691]
NotebookOptionsPosition[    215865,       5521]
NotebookOutlinePosition[    216236,       5537]
CellTagsIndexPosition[    216193,       5534]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.929254188367724*^9, 3.929254189715686*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"5eabe3ca-11f0-4ce6-8804-d967e41bc368"],

Cell[CellGroupData[{

Cell["\<\
l>=2 flux computations from circular orbits around scalar boson stars and \
parasitic black holes\
\>", "Title",
 CellChangeTimes->{{3.9292470912226987`*^9, 3.9292471260487275`*^9}, {
  3.9324693644932113`*^9, 3.932469369595629*^9}, {3.9324813322129545`*^9, 
  3.932481332791568*^9}},ExpressionUUID->"14d7fb90-fe0a-4865-b7df-\
e69fb8f5009f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"L", ">", "1"}], ",", 
     RowBox[{"Mt", ">", "0"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9293014353375697`*^9, 3.92930144433936*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"eae332e9-1963-468e-9c8a-2308583eb3a2"],

Cell["\<\
Reference: F. Duque, C. Macedo, R. Vicente and V.Cardoso. Physical Review \
Letters (in production) (2024) 2312.06767.\
\>", "Text",
 CellChangeTimes->{
  3.932481250622478*^9},ExpressionUUID->"2fe70975-9ee1-4638-a9df-\
7f1e8e2b4269"],

Cell[CellGroupData[{

Cell["Computing boson star configurations", "Section",
 CellChangeTimes->{{3.9292471315111165`*^9, 
  3.929247171885967*^9}},ExpressionUUID->"f4ea5f2e-aa29-430f-8578-\
b770ed4148e2"],

Cell[CellGroupData[{

Cell["Organizing the equations and finding the boundary conditions", \
"Subsubsection",
 CellChangeTimes->{{3.9292484189839134`*^9, 
  3.929248427679536*^9}},ExpressionUUID->"f6e5c295-8482-44a5-a551-\
5a2a76549749"],

Cell[TextData[{
 "We start by computing the background configurations. Notice that you can \
export these solutions if you wish to save some time. We consider the metric \
as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "tt"], "=", 
    RowBox[{"V", "[", "r", "]"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "47d302a8-300a-4e16-a3b2-6bef90ccd41f"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "rr"], "=", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", 
        FractionBox[
         RowBox[{"M", "[", "r", "]"}], "r"]}]}], ")"}], 
     RowBox[{"-", "1"}]]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "678f32f6-a753-4751-81f4-6a9b68815585"],
 ". Everything is in units of \[Mu]=1\n\nThe background field equations are"
}], "Text",
 CellChangeTimes->{{3.9292471734112387`*^9, 3.929247204242113*^9}, {
  3.929247242101017*^9, 
  3.9292473373567815`*^9}},ExpressionUUID->"8b4750ff-2197-4f67-9c3e-\
7a89be4400bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eq1", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"M", "[", "r", "]"}], " ", 
          RowBox[{"V", "[", "r", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Omega]", "2"], "-", 
            RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["V", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "-", 
    RowBox[{"2", " ", "r", " ", 
     RowBox[{"V", "[", "r", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]0", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "2"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq2", "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["M", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], "-", 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"r", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Omega]", "2"], "+", 
            RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
         RowBox[{"V", "[", "r", "]"}]], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]0", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}]}]}], 
   ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq3", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[Omega]", "2"]}], "+", 
          RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"V", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "r"}], "+", 
          RowBox[{"M", "[", "r", "]"}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]0", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"V", "[", "r", "]"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[Phi]0", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.929247317223193*^9, 3.929247395324712*^9}, {
  3.9292474441867228`*^9, 3.929247456710218*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"e1880841-24cc-4cae-b8e9-325b9064d94f"],

Cell["\<\
Now to improve boundary conditions at the origin we perform an expansion. \
Notice that we shall use this in the expansion for the perturbation as well. \
We also integrate using coordinates such that V[0]=1.\
\>", "Text",
 CellChangeTimes->{{3.9292474632356615`*^9, 3.9292475048624787`*^9}, {
  3.929247598297689*^9, 3.929247615681966*^9}, {3.929247706895056*^9, 
  3.929247711812069*^9}},ExpressionUUID->"a0624733-4ecc-4359-b2a6-\
601f9f46e3d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"M", ",", "V", ",", "\[Phi]0"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.929247507986782*^9, 3.929247513560466*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"f6e01616-10d4-46fe-a1c6-54f0fcc29d36"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"M", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["Mi", "i"], " ", 
      SuperscriptBox["r", 
       RowBox[{"i", "+", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["Vi", "i"], 
      SuperscriptBox["r", "i"]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]0", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Phi]0i", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Phi]0i", "0"], "\[Rule]", "\[Phi]c"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.9292475159160953`*^9, 3.9292475338163395`*^9}, {
   3.9292476202750487`*^9, 3.929247649639064*^9}, {3.929247702865054*^9, 
   3.9292477048287163`*^9}, {3.9292478840323696`*^9, 3.929247939558627*^9}, {
   3.9292479788642426`*^9, 3.929248063121293*^9}, {3.929248143487468*^9, 
   3.92924814741041*^9}, {3.9292481859052343`*^9, 3.929248196800125*^9}, {
   3.92924828964904*^9, 3.9292482924941416`*^9}, 3.9292659305015554`*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"a1c63b01-86f0-4fdb-888c-bf24235333cf"],

Cell["We solve the following equation near the origin", "Text",
 CellChangeTimes->{{3.929248254245061*^9, 
  3.9292482635819073`*^9}},ExpressionUUID->"d3be96c5-693c-470d-b376-\
544af8772911"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rubkgexp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"eq1", ",", 
           RowBox[{"eq2", " ", 
            SuperscriptBox["r", 
             RowBox[{"-", "1"}]]}], ",", 
           RowBox[{"eq3", " ", "r"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "5"}], "}"}]}], "]"}], "\[Equal]", 
       "0"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["Mi", "1"], ",", 
        SubscriptBox["Vi", "1"], ",", 
        SubscriptBox["\[Phi]0i", "1"], ",", 
        SubscriptBox["Mi", "2"], ",", 
        SubscriptBox["Vi", "2"], ",", 
        SubscriptBox["\[Phi]0i", "2"], ",", 
        SubscriptBox["Mi", "3"], ",", 
        SubscriptBox["Vi", "3"], ",", 
        SubscriptBox["\[Phi]0i", "3"], ",", 
        SubscriptBox["Mi", "4"], ",", 
        SubscriptBox["Vi", "4"], ",", 
        SubscriptBox["\[Phi]0i", "4"], ",", 
        SubscriptBox["Mi", "5"], ",", 
        SubscriptBox["Vi", "5"], ",", 
        SubscriptBox["\[Phi]0i", "5"], ",", 
        SubscriptBox["Mi", "6"], ",", 
        SubscriptBox["Vi", "6"], ",", 
        SubscriptBox["\[Phi]0i", "6"]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.9292480915563326`*^9, 3.9292481203392935`*^9}, {
  3.9292481710683517`*^9, 3.9292483320222607`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"a43dc386-a53b-4b48-be3c-ef3f91e39b17"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["Mi", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Vi", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Mi", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "+", 
        SubscriptBox["Vi", "0"]}], ")"}]}], 
     RowBox[{"3", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Vi", "2"], "\[Rule]", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SuperscriptBox["\[Phi]c", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Omega]", "2"]}], "-", 
       SubscriptBox["Vi", "0"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Omega]", "2"]}], "+", 
        SubscriptBox["Vi", "0"]}], ")"}]}], 
     RowBox[{"6", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Mi", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Vi", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Mi", "4"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Phi]c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "4"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], 
      RowBox[{"45", " ", 
       SubsuperscriptBox["Vi", "0", "2"]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["Vi", "4"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Omega]", "2"]}], "-", 
        SubscriptBox["Vi", "0"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"]}], "+", 
        SubscriptBox["Vi", "0"]}], ")"}]}], 
     RowBox[{"15", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "4"], "\[Rule]", 
    FractionBox[
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"16", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubscriptBox["Vi", "0"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"20", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], 
     RowBox[{"360", " ", 
      SubsuperscriptBox["Vi", "0", "2"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Mi", "5"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Vi", "5"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "5"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Mi", "6"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"64", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"168", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "6"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"73", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "-", 
           RowBox[{"204", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"], " ", 
         SubscriptBox["Vi", "0"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "15"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"60", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"9", "+", 
           RowBox[{"25", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "3"]}]}], ")"}]}], 
     RowBox[{"945", " ", 
      SubsuperscriptBox["Vi", "0", "3"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Vi", "6"], "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Omega]", "2"]}], "-", 
        SubscriptBox["Vi", "0"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"34", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "12"}], "+", 
           RowBox[{"37", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"180", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubscriptBox["Vi", "0"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"40", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], 
     RowBox[{"2835", " ", 
      SubsuperscriptBox["Vi", "0", "2"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "6"], "\[Rule]", 
    FractionBox[
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"9", "+", 
            RowBox[{"272", " ", 
             SuperscriptBox["\[Phi]c", "2"]}], "+", 
            RowBox[{"448", " ", 
             SuperscriptBox["\[Phi]c", "4"]}]}], ")"}]}], " ", 
         SuperscriptBox["\[Omega]", "6"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"27", "+", 
           RowBox[{"912", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"1184", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"], " ", 
         SubscriptBox["Vi", "0"]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"27", "+", 
           RowBox[{"1236", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"992", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"9", "+", 
           RowBox[{"596", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"1120", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "3"]}]}], ")"}]}], 
     RowBox[{"45360", " ", 
      SubsuperscriptBox["Vi", "0", "3"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.929248204751193*^9, 3.929248216087762*^9}, {
   3.9292482483558836`*^9, 3.9292483330902443`*^9}, 3.9292501872866626`*^9, 
   3.929253093825842*^9, 3.9292541944542603`*^9, 3.9292550943355837`*^9, 
   3.9292659351449823`*^9, 3.929302819332726*^9, 3.929332125864173*^9, 
   3.9293391563011384`*^9, 3.9293458707995768`*^9, 3.929348649040341*^9, 
   3.9293488553492527`*^9, 3.9293622341375065`*^9, 3.9293636700648518`*^9, 
   3.9293736775123625`*^9, 3.9293777937328568`*^9, 3.9293779090941286`*^9, 
   3.92937805392465*^9, 3.929378111410643*^9, 3.9294073766925755`*^9, 
   3.9295073324204803`*^9, 3.9295204231698027`*^9, 3.9296980102183175`*^9, 
   3.92972400344901*^9, 3.9297279078982787`*^9, 3.929761919066455*^9, 
   3.9297621932092752`*^9, 3.9297733027165384`*^9, 3.929783252484709*^9, {
   3.9300544837931285`*^9, 3.9300545004708014`*^9}, 3.932469004279775*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"b19aae06-5b84-401e-86e2-2bc627b3cbf0"]
}, Open  ]],

Cell["\<\
Therefore, we have the following boundary conditions for the background\
\>", "Text",
 CellChangeTimes->{{3.9292483424267063`*^9, 
  3.9292483517890263`*^9}},ExpressionUUID->"05300666-11d5-4d92-8823-\
838f19fcbccb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BOUNBKG", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"V", "[", "r", "]"}], ",", 
      RowBox[{"M", "[", "r", "]"}], ",", 
      RowBox[{"\[Phi]0", "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}]}], "}"}], "/.", 
    "rubkgexp"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9292483534932485`*^9, 3.9292483830798287`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"57ffd28c-7a55-443c-8248-3ed515c80611"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"M", ",", "V", ",", "\[Phi]0"}], "]"}]], "Input",
 CellChangeTimes->{{3.9292483875207577`*^9, 3.9292483936006165`*^9}, 
   3.9292487587731743`*^9},
 CellLabel->"In[10]:=",ExpressionUUID->"3dc87e96-66ab-4f49-9e4e-413980dc70e7"],

Cell["Finally, we can perform the background computations.", "Text",
 CellChangeTimes->{{3.929248402766037*^9, 3.9292484107695827`*^9}, 
   3.9292484440644293`*^9},ExpressionUUID->"1af02619-a71b-4478-98bf-\
849ee767fd29"]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining the integrator and the shooting", "Subsubsection",
 CellChangeTimes->{{3.929248431048627*^9, 
  3.9292484511651163`*^9}},ExpressionUUID->"6a305c5a-d0c6-4b1c-9c1f-\
c3aacc4df08e"],

Cell[TextData[{
 "Usually, one search for a solution that has a scalar field at the origin ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", "c"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f1aba4d0-035a-4424-8215-a53f3ed414da"],
 " and frequency \[Omega] in which the scalar decays to zero far from the \
center. Here we search for a solution in which the scalar decreases \
exponentially as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"exp", "[", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        RowBox[{
         SuperscriptBox["w", "2"], "/", 
         RowBox[{"V", "[", "r", "]"}]}]}]]}], 
     RowBox[{"rst", "[", "r", "]"}]}], "]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "3a681a8f-ad97-4264-8699-3fada8fbfa10"],
 ", where rst[r] is the tortoise coordinate. You can change that if you wish."
}], "Text",
 CellChangeTimes->{{3.929248454414774*^9, 
  3.9292486014469795`*^9}},ExpressionUUID->"dbc38347-e4fc-447e-8b43-\
906ba1d0ff68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BKGI", "[", 
   RowBox[{
    RowBox[{"\[Omega]0_", "?", "NumberQ"}], ",", "\[Phi]c0_", ",", "r10_", 
    ",", "r20_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"paramint", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"MaxSteps", "\[Rule]", "\[Infinity]"}], ",", 
       RowBox[{"Method", "->", "\"\<StiffnessSwitching\>\""}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "12"}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "12"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"defining", " ", "the", " ", "parameters"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"param", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Omega]", "\[Rule]", "\[Omega]0"}], ",", 
       RowBox[{"\[Phi]c", "\[Rule]", "\[Phi]c0"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "defining", " ", "equations", " ", "to", " ", "be", " ", "integrated", 
      " ", "and", " ", "boundary", " ", "conditions"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"EQS", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"eq1", "\[Equal]", "0"}], ",", 
        RowBox[{"eq2", "\[Equal]", "0"}], ",", 
        RowBox[{"eq3", "\[Equal]", "0"}]}], "}"}], "/.", "param"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"BOU", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Thread", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"V", "[", "r", "]"}], ",", 
            RowBox[{"M", "[", "r", "]"}], ",", 
            RowBox[{"\[Phi]0", "[", "r", "]"}], ",", 
            RowBox[{
             RowBox[{"\[Phi]0", "''"}], "[", "r", "]"}]}], "}"}], "\[Equal]", 
          "BOUNBKG"}], "]"}], "/.", "param"}], "/.", 
       RowBox[{
        SubscriptBox["Vi", "0"], "\[Rule]", "1"}]}], "/.", 
      RowBox[{"r", "\[Rule]", "r10"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "Integrating", " ", "the", " ", "differential", " ", "equations"}], 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{"SOLBK", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"EQS", ",", "BOU"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]0", ",", "M", ",", "V"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r10", ",", "r20"}], "}"}], ",", "paramint"}], 
       "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{
      "Computing", " ", "the", " ", "scaled", " ", "quantities", " ", "such", 
       " ", "that", " ", "V", 
       RowBox[{"(", "0", ")"}]}], "=", "1"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"sc1", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", 
         RowBox[{"2", 
          FractionBox[
           RowBox[{"M", "[", "r", "]"}], "r"]}]}], 
        RowBox[{"V", "[", "r", "]"}]], "/.", "SOLBK"}], "/.", 
      RowBox[{"r", "\[Rule]", "r20"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[Omega]s", "=", 
     RowBox[{
      SuperscriptBox["sc1", 
       RowBox[{"1", "/", "2"}]], "\[Omega]0"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"MT", "=", 
     RowBox[{
      RowBox[{"M", "[", "r20", "]"}], "/.", "SOLBK"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"RINF", "=", 
     RowBox[{"SOLBK", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"param2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Omega]", "\[Rule]", "\[Omega]s"}], ",", 
       RowBox[{"\[Phi]c", "\[Rule]", "\[Phi]c0"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "We", " ", "demand", " ", "that", " ", "the", " ", "following", " ", 
      "should", " ", "be", " ", "zero", " ", 
      RowBox[{"(", 
       RowBox[{"it", " ", "is", " ", "a", " ", "Wronskian"}], ")"}]}], "*)"}],
     "\[IndentingNewLine]", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "MT"}], "-", "r20", "-", 
           RowBox[{
            SuperscriptBox["r20", "2"], " ", 
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox[
               SuperscriptBox["\[Omega]0", "2"], 
               RowBox[{"V", "[", "r20", "]"}]]}]]}]}], ")"}], " ", 
         RowBox[{"\[Phi]0", "[", "r20", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "MT"}], "-", "r20"}], ")"}], " ", "r20", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]0", "\[Prime]",
           MultilineFunction->None], "[", "r20", "]"}]}]}], ")"}], 
      "\[Phi]c0"], "/.", "SOLBK"}]}], "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.9292486085980663`*^9, 3.9292488467621107`*^9}, {
   3.929248990670339*^9, 3.9292491202336435`*^9}, 3.9292491676546793`*^9, {
   3.9292492155534267`*^9, 3.9292493544064484`*^9}, {3.929249927160367*^9, 
   3.9292499331641264`*^9}, {3.9292659610233355`*^9, 3.929265961893789*^9}, {
   3.9292665087222977`*^9, 3.9292665509769993`*^9}, {3.92926659544553*^9, 
   3.9292666315715055`*^9}, {3.929333738399108*^9, 3.929333748825523*^9}, {
   3.9294074529344325`*^9, 3.9294074749913445`*^9}, {3.9294075722372227`*^9, 
   3.929407614381418*^9}, {3.929727958572229*^9, 3.92972799017822*^9}},
 CellLabel->"In[11]:=",ExpressionUUID->"276e9363-6de0-4957-a8a1-d2d14d5733ea"],

Cell["\<\
Now we can search for numerical background solutions. I\[CloseCurlyQuote]ll \
focus on the maximum mass configurations, but you can change that to whataver \
you want. In our case \[Phi]max=.1916\
\>", "Text",
 CellChangeTimes->{{3.929249359430789*^9, 3.9292493954370785`*^9}, {
   3.929249432021922*^9, 3.929249436534418*^9}, 
   3.929265966007163*^9},ExpressionUUID->"d96ffe01-a0c3-43ae-9d7e-\
f40613916870"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating the background equations: Boson stars", "Subsubsection",
 CellChangeTimes->{{3.9292494103901134`*^9, 3.9292494190639863`*^9}, {
  3.929250099103907*^9, 3.92925010278119*^9}, {3.932467785828891*^9, 
  3.932467790367651*^9}},ExpressionUUID->"c1edfb44-ab40-4592-b092-\
fd3dd0318b88"],

Cell["\<\
We define the maximum value for the scalar field (we know that from previous \
computations)\
\>", "Text",
 CellChangeTimes->{{3.9292495208946223`*^9, 
  3.9292495364007826`*^9}},ExpressionUUID->"93ae8fd2-b220-4935-8434-\
9dbad2689ace"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]max", "=", "0.1916"}], ";"}]], "Input",
 CellChangeTimes->{{3.929249437782932*^9, 3.9292494377849317`*^9}, {
   3.9297279096389275`*^9, 3.9297279114358788`*^9}, {3.9297280534673047`*^9, 
   3.9297280708113623`*^9}, 3.9297281065325646`*^9, {3.9297281413425937`*^9, 
   3.9297281491856146`*^9}, 3.9297621600851297`*^9, {3.9297739035333385`*^9, 
   3.9297740310960174`*^9}, {3.9297832519266415`*^9, 3.9297833240638*^9}, {
   3.92978336466422*^9, 3.9297833829313655`*^9}, {3.929783466920102*^9, 
   3.9297834763429413`*^9}, {3.930054473662819*^9, 3.9300544754327607`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"ed3798b7-7b02-432c-914b-301c44bbf0d6"],

Cell["Do the FindRoot", "Text",
 CellChangeTimes->{{3.929249540638618*^9, 3.929249542585072*^9}, {
  3.9293028255610857`*^9, 3.9293028269798717`*^9}, {3.9297279987802*^9, 
  3.9297280003135414`*^9}},ExpressionUUID->"2e6bffb1-2032-4492-ac35-\
464629041cf2"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"BKGI", "[", 
      RowBox[{"xx", ",", "\[Phi]max", ",", "0.001", ",", "30"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "1.2430593520827826`"}], "}"}]}], "]"}], ",", "xx"}],
   "]"}], "\[IndentingNewLine]", "MT"}], "Input",
 CellChangeTimes->{{3.9292494429627295`*^9, 3.92924950389202*^9}, {
   3.929249944980235*^9, 3.9292499673516393`*^9}, {3.9292664785397224`*^9, 
   3.9292664803980227`*^9}, 3.9293028300016327`*^9, 3.9293326418163033`*^9, {
   3.9293777696667614`*^9, 3.9293777794540195`*^9}, {3.9294073826716056`*^9, 
   3.9294074354014163`*^9}, {3.929407481350754*^9, 3.929407587465705*^9}, {
   3.9294076228637533`*^9, 3.929407690686348*^9}, {3.9297279240555267`*^9, 
   3.9297279497034016`*^9}, {3.929728013206674*^9, 3.9297280148428235`*^9}, {
   3.9297280493877153`*^9, 3.9297281615182443`*^9}, {3.9297621670858126`*^9, 
   3.929762286580372*^9}, {3.92977390846953*^9, 3.929774050417148*^9}, {
   3.9297832550123644`*^9, 3.9297833129400167`*^9}, {3.9297833698543925`*^9, 
   3.929783533960082*^9}, {3.9300544889202023`*^9, 3.9300545411807375`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"d0b409fa-d7fa-4c4b-9086-9a903f532ce7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"xx", "\[Rule]", "1.2430576002491154`"}], "}"}]], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295204238487635`*^9, 3.929698010720002*^9, 3.929724003898614*^9, {
   3.9297279159519415`*^9, 3.9297279502312717`*^9}, {3.929728001133248*^9, 
   3.929728019743812*^9}, {3.9297280505654383`*^9, 3.929728162035088*^9}, 
   3.929761919455723*^9, 3.929761991215452*^9, {3.9297621741234207`*^9, 
   3.9297622869779572`*^9}, 3.9297733033491187`*^9, {3.9297739096109123`*^9, 
   3.9297740508166075`*^9}, {3.9297832566005573`*^9, 
   3.9297833361721134`*^9}, {3.929783370610485*^9, 3.9297833840818205`*^9}, {
   3.929783451345046*^9, 3.929783534159384*^9}, {3.9300544905180197`*^9, 
   3.930054541653688*^9}, 3.932469004970302*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"fd14f4f5-2bc8-4bad-b63f-675e75b63994"],

Cell[BoxData["0.6330008427817497`"], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295204238487635`*^9, 3.929698010720002*^9, 3.929724003898614*^9, {
   3.9297279159519415`*^9, 3.9297279502312717`*^9}, {3.929728001133248*^9, 
   3.929728019743812*^9}, {3.9297280505654383`*^9, 3.929728162035088*^9}, 
   3.929761919455723*^9, 3.929761991215452*^9, {3.9297621741234207`*^9, 
   3.9297622869779572`*^9}, 3.9297733033491187`*^9, {3.9297739096109123`*^9, 
   3.9297740508166075`*^9}, {3.9297832566005573`*^9, 
   3.9297833361721134`*^9}, {3.929783370610485*^9, 3.9297833840818205`*^9}, {
   3.929783451345046*^9, 3.929783534159384*^9}, {3.9300544905180197`*^9, 
   3.930054541653688*^9}, 3.9324690049728107`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"261d1d53-3af3-43ca-8330-5c78da6ff627"]
}, Open  ]],

Cell["Check whether it has the required behavior", "Text",
 CellChangeTimes->{{3.9292495459155874`*^9, 
  3.9292495552133665`*^9}},ExpressionUUID->"b3a17776-7ec5-4416-aff9-\
cc0d8392fcc4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Phi]max"], "/.", "SOLBK"}], "//",
     "Abs"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.001", ",", "RINF"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9292494836639752`*^9, 3.9292495080226245`*^9}, {
   3.9292499435687823`*^9, 3.9292499693386297`*^9}, {3.9292664856166754`*^9, 
   3.929266485754013*^9}, {3.929407440147979*^9, 3.9294074407258964`*^9}, 
   3.9294075095150137`*^9, {3.929407640633501*^9, 3.9294076407509*^9}, {
   3.9294076815384417`*^9, 3.929407694341484*^9}, {3.929727952303987*^9, 
   3.929727952546246*^9}, {3.929783497276108*^9, 3.929783525018915*^9}, {
   3.9300545187342234`*^9, 3.930054519243215*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"e0479117-1ef8-49cf-ad00-1c2ddd1c1618"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVxXk8lekCAGCRKCl7HSJkj0/2pM/7WmZEWbOGkJ0wGpqswyGDpIOpkGRr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       "]]},
     Annotation[#, "Charting`Private`Tag$3015#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.001, -15.430587493520905`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0.001, 30.}, {-15.430587493520905`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }, {
    Automatic, {{-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.3978952727983707`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.4849066497880004`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.5649493574615367`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.6390573296152584`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.70805020110221, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.772588722239781, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.833213344056216, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.8903717578961645`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Output",
 CellChangeTimes->{{3.929249499414241*^9, 3.929249508236535*^9}, 
   3.929249557036867*^9, {3.929249940217453*^9, 3.929249982873658*^9}, 
   3.929250187778839*^9, 3.929253094377042*^9, 3.929254194968627*^9, 
   3.9292550948815937`*^9, 3.9292659747844057`*^9, {3.9292664818552923`*^9, 
   3.92926648611342*^9}, 3.9292665588788905`*^9, 3.9292666071786065`*^9, {
   3.9292667978789897`*^9, 3.9292668159846287`*^9}, 3.92930282023897*^9, 
   3.9293321267239904`*^9, 3.929332643894393*^9, 3.929333756545707*^9, 
   3.9293391569207497`*^9, 3.9293458718712273`*^9, 3.9293486494894686`*^9, 
   3.929348855931329*^9, 3.9293622347871356`*^9, 3.929363673009411*^9, 
   3.929364155569137*^9, 3.929373678152976*^9, {3.9293777708941693`*^9, 
   3.9293777945168324`*^9}, 3.9293779095937853`*^9, 3.9293780544818*^9, 
   3.929378112284787*^9, {3.929407393241271*^9, 3.929407441695442*^9}, {
   3.9294074788297763`*^9, 3.929407568827527*^9}, {3.92940761927335*^9, 
   3.9294076947031097`*^9}, 3.9295073328996954`*^9, 3.9295204240411444`*^9, 
   3.9296980108962393`*^9, 3.929724004083865*^9, {3.929727919177136*^9, 
   3.9297279465329943`*^9}, {3.9297280021194763`*^9, 
   3.9297280213078833`*^9}, {3.929728061775769*^9, 3.929728163284441*^9}, 
   3.929761919707611*^9, 3.9297619913412004`*^9, {3.9297621994786663`*^9, 
   3.9297622881183386`*^9}, 3.92977330372106*^9, {3.9297739103179226`*^9, 
   3.9297739279805903`*^9}, {3.9297739785564904`*^9, 
   3.9297740519772425`*^9}, {3.929783263445797*^9, 3.929783321628007*^9}, {
   3.929783371921524*^9, 3.929783385432563*^9}, {3.9297834526230135`*^9, 
   3.929783535451419*^9}, {3.930054519761766*^9, 3.930054542722932*^9}, 
   3.9324690054539537`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"9c8c7016-d004-43d2-8761-246fbd813842"]
}, Open  ]],

Cell["\<\
The mass matches Kaup\[CloseCurlyQuote]s result. We can define now a rule to \
apply this background to compute the perturbations\
\>", "Text",
 CellChangeTimes->{{3.9292495682876253`*^9, 3.9292495813126645`*^9}, {
  3.929249856357086*^9, 
  3.9292498740360937`*^9}},ExpressionUUID->"cfc2967d-602d-457b-8007-\
321396a3b4cf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rubkg", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"M", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"M", "[", "r", "]"}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"V", "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{"V", "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"V", "'"}], "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{
            RowBox[{"V", "'"}], "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Phi]0", "[", "r", "]"}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "/.", "SOLBK"}], 
         ")"}]}]}], "}"}], ",", "param2", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"scal", "\[Rule]", "sc1"}], ",", 
       RowBox[{"Mt", "\[Rule]", "MT"}], ",", 
       RowBox[{"rinf", "\[Rule]", "RINF"}], ",", 
       RowBox[{"ror", "\[Rule]", "0.001"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.92924987838093*^9, 3.929249936003543*^9}, {
   3.9292499886164703`*^9, 3.929250038820092*^9}, {3.929266001586071*^9, 
   3.929266011117361*^9}, {3.9292663967428517`*^9, 3.929266433375227*^9}, 
   3.929266563067258*^9, {3.929266639443221*^9, 3.9292667149650593`*^9}, {
   3.929302844729826*^9, 3.9293028449277954`*^9}, {3.929332674253724*^9, 
   3.9293326788328404`*^9}, {3.9293337610959473`*^9, 3.929333763125454*^9}, {
   3.929363678553999*^9, 3.9293638126658096`*^9}, {3.9293641590776215`*^9, 
   3.9293641658586626`*^9}, 3.929728006565918*^9, {3.929728178826312*^9, 
   3.9297281831630545`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"1baeed4e-bcd7-4206-af8c-ee9a78badefe"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating the background equations: Parasitic black hole ", \
"Subsubsection",
 CellChangeTimes->{{3.9292494103901134`*^9, 3.9292494190639863`*^9}, {
  3.929250099103907*^9, 3.92925010278119*^9}, {3.932467785828891*^9, 
  3.9324678030468454`*^9}, {3.932468857079599*^9, 
  3.9324688719448986`*^9}},ExpressionUUID->"55e2bc1b-a103-43d7-8b4a-\
a4ca829f07be"],

Cell["\<\
We show the case for M\[Mu]=0.1, but other cases can be computed in the same \
fashion.\
\>", "Text",
 CellChangeTimes->{{3.9292495208946223`*^9, 3.9292495364007826`*^9}, {
  3.932468942618695*^9, 
  3.9324689738119087`*^9}},ExpressionUUID->"f7c79746-a2b9-40cb-a79e-\
96b57dead4e9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]max", "=", "0.00170524"}], ";"}]], "Input",
 CellChangeTimes->{{3.929249437782932*^9, 3.9292494377849317`*^9}, {
   3.929528709895975*^9, 3.929528713717223*^9}, {3.929631106684226*^9, 
   3.929631135989314*^9}, {3.9296335086039467`*^9, 3.929633509343091*^9}, {
   3.929636560020132*^9, 3.929636560355353*^9}, 3.9296366432120285`*^9, {
   3.929636681191718*^9, 3.9296366815837603`*^9}, {3.929636711699109*^9, 
   3.929636753818775*^9}, {3.9296378009712934`*^9, 3.9296378013378153`*^9}, {
   3.9296378389336452`*^9, 3.929637852067519*^9}, {3.929637885888035*^9, 
   3.9296378864424353`*^9}, {3.9296770954719477`*^9, 
   3.9296771530219526`*^9}, {3.9296788835048976`*^9, 
   3.9296788845729437`*^9}, {3.92968097183395*^9, 3.9296810469040728`*^9}, {
   3.93246897654338*^9, 3.9324689819755163`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"9fd772ab-2d2c-4a48-8105-3123e42f6f9c"],

Cell["Do the FindRoot", "Text",
 CellChangeTimes->{{3.929249540638618*^9, 3.929249542585072*^9}, {
  3.9293028255610857`*^9, 
  3.9293028269798717`*^9}},ExpressionUUID->"9da8377d-0e89-4249-98f4-\
007d83c3d216"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"BKGI", "[", 
      RowBox[{"xx", ",", "\[Phi]max", ",", "0.001", ",", "180"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "1.0015705361986202`"}], "}"}]}], "]"}], ",", "xx"}],
   "]"}], "\[IndentingNewLine]", "MT"}], "Input",
 CellChangeTimes->{{3.9292494429627295`*^9, 3.92924950389202*^9}, {
   3.929249944980235*^9, 3.9292499673516393`*^9}, {3.9292664785397224`*^9, 
   3.9292664803980227`*^9}, 3.9293028300016327`*^9, 3.9293326418163033`*^9, {
   3.9293777696667614`*^9, 3.9293777794540195`*^9}, {3.9294073826716056`*^9, 
   3.9294074354014163`*^9}, {3.929407481350754*^9, 3.929407587465705*^9}, {
   3.9294076228637533`*^9, 3.929407690686348*^9}, {3.929528719260462*^9, 
   3.929528777411563*^9}, {3.929528828861417*^9, 3.929528927565572*^9}, {
   3.9296123761697645`*^9, 3.92961243244993*^9}, {3.9296311408706264`*^9, 
   3.9296314163667364`*^9}, {3.9296335026376605`*^9, 3.929633579773094*^9}, {
   3.92963656847721*^9, 3.9296368164917345`*^9}, {3.9296378156345344`*^9, 
   3.929637913322214*^9}, {3.929677105592987*^9, 3.929677198959568*^9}, {
   3.9296788869389677`*^9, 3.9296789472249627`*^9}, {3.929680975297878*^9, 
   3.9296810884619613`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"b482a5ec-3120-4d4d-a935-702f7be7ca7a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"xx", "\[Rule]", "1.001570537126463`"}], "}"}]], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295092810304503`*^9, 3.929510205121914*^9, 3.9295174915576053`*^9, 
   3.929517796372939*^9, 3.929519803414409*^9, 3.9295202286797314`*^9, 
   3.9295204412758026`*^9, 3.929524333168296*^9, {3.9295287362582006`*^9, 
   3.929528778039892*^9}, {3.9295288245264025`*^9, 3.929528927876172*^9}, 
   3.9295297184268875`*^9, 3.929530737931596*^9, 3.9295312654867153`*^9, 
   3.929588126249632*^9, 3.9295895330736074`*^9, 3.9296110205436034`*^9, {
   3.9296123785027204`*^9, 3.9296124329394355`*^9}, 3.9296161809661655`*^9, 
   3.9296164840669527`*^9, 3.9296167231889825`*^9, {3.9296195099903135`*^9, 
   3.9296195321260138`*^9}, 3.9296207233979654`*^9, 3.929620791215168*^9, {
   3.9296311415336065`*^9, 3.929631416663517*^9}, 3.9296315123429337`*^9, {
   3.929633512389043*^9, 3.9296335804729195`*^9}, {3.9296365642904778`*^9, 
   3.929636825783084*^9}, {3.9296378190002584`*^9, 3.929637923857246*^9}, {
   3.9296758931180577`*^9, 3.929675906733467*^9}, 3.9296759381485357`*^9, {
   3.9296759681729717`*^9, 3.9296759742895875`*^9}, {3.9296771066004086`*^9, 
   3.9296772071107635`*^9}, {3.9296788898118186`*^9, 
   3.9296789543740454`*^9}, {3.9296809765407686`*^9, 3.9296810887915015`*^9}, 
   3.9324690093273325`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"51f55431-1720-49de-ade6-7ee8aab0c487"],

Cell[BoxData["0.10076501773286792`"], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295092810304503`*^9, 3.929510205121914*^9, 3.9295174915576053`*^9, 
   3.929517796372939*^9, 3.929519803414409*^9, 3.9295202286797314`*^9, 
   3.9295204412758026`*^9, 3.929524333168296*^9, {3.9295287362582006`*^9, 
   3.929528778039892*^9}, {3.9295288245264025`*^9, 3.929528927876172*^9}, 
   3.9295297184268875`*^9, 3.929530737931596*^9, 3.9295312654867153`*^9, 
   3.929588126249632*^9, 3.9295895330736074`*^9, 3.9296110205436034`*^9, {
   3.9296123785027204`*^9, 3.9296124329394355`*^9}, 3.9296161809661655`*^9, 
   3.9296164840669527`*^9, 3.9296167231889825`*^9, {3.9296195099903135`*^9, 
   3.9296195321260138`*^9}, 3.9296207233979654`*^9, 3.929620791215168*^9, {
   3.9296311415336065`*^9, 3.929631416663517*^9}, 3.9296315123429337`*^9, {
   3.929633512389043*^9, 3.9296335804729195`*^9}, {3.9296365642904778`*^9, 
   3.929636825783084*^9}, {3.9296378190002584`*^9, 3.929637923857246*^9}, {
   3.9296758931180577`*^9, 3.929675906733467*^9}, 3.9296759381485357`*^9, {
   3.9296759681729717`*^9, 3.9296759742895875`*^9}, {3.9296771066004086`*^9, 
   3.9296772071107635`*^9}, {3.9296788898118186`*^9, 
   3.9296789543740454`*^9}, {3.9296809765407686`*^9, 3.9296810887915015`*^9}, 
   3.932469009330331*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"929578c5-97ac-47d4-817c-6e7f026a4337"]
}, Open  ]],

Cell["Check whether it has the required behavior", "Text",
 CellChangeTimes->{{3.9292495459155874`*^9, 
  3.9292495552133665`*^9}},ExpressionUUID->"df7d3653-af9a-430c-8d27-\
13999bceeb5b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Phi]max"], "/.", "SOLBK"}], "//",
     "Abs"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.001", ",", "RINF"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9292494836639752`*^9, 3.9292495080226245`*^9}, {
   3.9292499435687823`*^9, 3.9292499693386297`*^9}, {3.9292664856166754`*^9, 
   3.929266485754013*^9}, {3.929407440147979*^9, 3.9294074407258964`*^9}, 
   3.9294075095150137`*^9, {3.929407640633501*^9, 3.9294076407509*^9}, {
   3.9294076815384417`*^9, 3.929407694341484*^9}, {3.929528749288994*^9, 
   3.9295287499006157`*^9}, {3.9295287855811167`*^9, 
   3.9295287857739363`*^9}, {3.929528826317542*^9, 3.9295288265913305`*^9}, 
   3.9296312341372566`*^9},
 CellLabel->"In[20]:=",ExpressionUUID->"266335c1-1b63-4b6e-9a53-a984c82f8bb7"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVkWk8lWkfgO1Rhxw51p6yxKihZA2T5x/JFtlDlognTEM4GRlZfrbsKiVL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       "]]},
     Annotation[#, "Charting`Private`Tag$4422#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.001, -7.479048764762567},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0.001, 180.}, {-7.479048764762567, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }, {
    Automatic, {{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-8.517193191416238, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-8.111728083308073, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.824046010856292, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.600902459542082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.418580902748128, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.264430222920869, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.013115794639964, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.214608098422191, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.809142990314028, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.521460917862246, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.916290731874155, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.791759469228055, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.3978952727983707`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.4849066497880004`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Output",
 CellChangeTimes->{{3.929249499414241*^9, 3.929249508236535*^9}, 
   3.929249557036867*^9, {3.929249940217453*^9, 3.929249982873658*^9}, 
   3.929250187778839*^9, 3.929253094377042*^9, 3.929254194968627*^9, 
   3.9292550948815937`*^9, 3.9292659747844057`*^9, {3.9292664818552923`*^9, 
   3.92926648611342*^9}, 3.9292665588788905`*^9, 3.9292666071786065`*^9, {
   3.9292667978789897`*^9, 3.9292668159846287`*^9}, 3.92930282023897*^9, 
   3.9293321267239904`*^9, 3.929332643894393*^9, 3.929333756545707*^9, 
   3.9293391569207497`*^9, 3.9293458718712273`*^9, 3.9293486494894686`*^9, 
   3.929348855931329*^9, 3.9293622347871356`*^9, 3.929363673009411*^9, 
   3.929364155569137*^9, 3.929373678152976*^9, {3.9293777708941693`*^9, 
   3.9293777945168324`*^9}, 3.9293779095937853`*^9, 3.9293780544818*^9, 
   3.929378112284787*^9, {3.929407393241271*^9, 3.929407441695442*^9}, {
   3.9294074788297763`*^9, 3.929407568827527*^9}, {3.92940761927335*^9, 
   3.9294076947031097`*^9}, 3.9295073328996954`*^9, 3.9295092812085023`*^9, 
   3.9295102053240047`*^9, 3.9295174917749777`*^9, 3.9295177966841106`*^9, 
   3.9295198036165447`*^9, 3.9295202288976407`*^9, 3.929520441463235*^9, 
   3.9295243333769608`*^9, {3.9295287392003107`*^9, 3.929528779356004*^9}, {
   3.9295288269166203`*^9, 3.9295289285816364`*^9}, 3.9295297194091253`*^9, 
   3.929530737991251*^9, 3.9295312655726767`*^9, 3.9295881265296717`*^9, 
   3.9295895331791267`*^9, 3.9296110209608088`*^9, {3.929612380125873*^9, 
   3.9296124339391766`*^9}, 3.929616181073738*^9, 3.9296164841682053`*^9, 
   3.9296167235638*^9, {3.929619510226305*^9, 3.9296195325087714`*^9}, 
   3.9296207234849644`*^9, 3.9296207913036833`*^9, {3.929631228197781*^9, 
   3.9296314186699905`*^9}, 3.929631512410444*^9, {3.929633513916045*^9, 
   3.929633581517001*^9}, {3.929636580289713*^9, 3.9296368258516893`*^9}, {
   3.929637826233843*^9, 3.929637923927761*^9}, {3.9296758933402967`*^9, 
   3.929675906844017*^9}, 3.929675938252068*^9, {3.92967596826658*^9, 
   3.9296759743511424`*^9}, {3.9296771173424993`*^9, 
   3.9296771448663473`*^9}, {3.9296771882136507`*^9, 3.929677207176755*^9}, {
   3.929678890989393*^9, 3.929678954440596*^9}, {3.9296809776124973`*^9, 
   3.929681089874009*^9}, 3.932469010568404*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"f685955e-5adc-4393-b790-890e62827b80"]
}, Open  ]],

Cell["\<\
The mass matches Kaup\[CloseCurlyQuote]s result. We can define now a rule to \
apply this background to compute the perturbations\
\>", "Text",
 CellChangeTimes->{{3.9292495682876253`*^9, 3.9292495813126645`*^9}, {
  3.929249856357086*^9, 
  3.9292498740360937`*^9}},ExpressionUUID->"43f5cf93-e521-45dc-93e0-\
910d38daa684"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Mbh", "=", "0.001"}], ";"}]], "Input",
 CellChangeTimes->{{3.896769679540101*^9, 3.896769719539468*^9}, {
   3.89677000074851*^9, 3.896770004853426*^9}, 3.8975077239561586`*^9, {
   3.8975692291846333`*^9, 3.897569243511019*^9}, 3.897570230784814*^9, 
   3.89765360114114*^9, 3.897653644422191*^9, 3.8978133328717737`*^9, {
   3.898326663863903*^9, 3.8983266640077972`*^9}, {3.928003263859724*^9, 
   3.928003276678523*^9}, {3.928327682497426*^9, 3.9283276979574585`*^9}, {
   3.928327754426407*^9, 3.9283277545424523`*^9}, {3.9289985713560476`*^9, 
   3.9289985724143114`*^9}, {3.9289986129217796`*^9, 
   3.9289986137245426`*^9}, {3.9289990292391167`*^9, 
   3.9289990307852182`*^9}, {3.9290061813297663`*^9, 
   3.9290061813923674`*^9}, {3.929023106976755*^9, 3.9290231075043974`*^9}, {
   3.929025722449685*^9, 3.929025723002118*^9}, 3.92950899721614*^9, {
   3.9295291004281225`*^9, 3.929529104571277*^9}, {3.9296194871775928`*^9, 
   3.9296195064886007`*^9}, 3.9296207164656954`*^9, 3.9296207870246005`*^9, {
   3.929631425485407*^9, 3.9296314255694947`*^9}, {3.9296759245890007`*^9, 
   3.9296759283800197`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"72fd347c-eb78-4920-aa15-e0d630bc1f46"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solbh2", "=", 
   RowBox[{
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"m2", "'"}], "[", "r", "]"}], "\[Equal]", 
          RowBox[{"2", 
           SuperscriptBox["r", "2"], 
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{"\[Phi]0", "[", "r", "]"}], "]"}], "2"]}]}], "/.", 
         "SOLBK"}], ",", 
        RowBox[{
         RowBox[{"m2", "[", 
          RowBox[{"2", "Mbh"}], "]"}], "\[Equal]", "Mbh"}]}], "}"}], ",", 
      "m2", ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", 
        RowBox[{"2", "Mbh"}], ",", "RINF"}], "}"}], ",", 
      RowBox[{"PrecisionGoal", "\[Rule]", "12"}], ",", 
      RowBox[{"AccuracyGoal", "\[Rule]", "12"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.92952902825517*^9, 3.9295290337659383`*^9}, {
   3.9295291235816545`*^9, 3.929529133847395*^9}, 3.929633548865143*^9},
 CellLabel->"In[22]:=",ExpressionUUID->"06e7661e-27f7-4980-b8d9-af65a26df786"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rubh1", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"M", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"m2", "[", "r", "]"}], "/.", "solbh2"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"V", "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", 
              FractionBox["Mbh", "r"]}]}], ")"}], 
           RowBox[{"V", "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"V", "'"}], "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"V", "[", "r", "]"}], 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", " ", 
                 FractionBox["Mbh", "r"]}]}], ")"}]}], ",", "r"}], "]"}]}], "/.",
           "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", 
               FractionBox["Mbh", "r"]}]}], ")"}], 
            RowBox[{
             RowBox[{"-", "2"}], "I", " ", "Mbh"}]], 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", 
                 FractionBox["Mbh", "r"]}]}], ")"}], 
              RowBox[{
               RowBox[{"-", "2"}], "I", " ", "Mbh"}]], 
             RowBox[{"\[Phi]0", "[", "r", "]"}]}], ",", "r"}], "]"}], "/.", 
          "SOLBK"}], ")"}]}]}], "}"}], ",", "param2", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"scal", "\[Rule]", "sc1"}], ",", 
       RowBox[{
        RowBox[{"Mt", "\[Rule]", 
         RowBox[{"m2", "[", "RINF", "]"}]}], "/.", "solbh2"}], ",", 
       RowBox[{"rinf", "\[Rule]", "RINF"}], ",", 
       RowBox[{"ror", "\[Rule]", "0.001"}], ",", 
       RowBox[{"MBH", "\[Rule]", "Mbh"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.92924987838093*^9, 3.929249936003543*^9}, {
   3.9292499886164703`*^9, 3.929250038820092*^9}, {3.929266001586071*^9, 
   3.929266011117361*^9}, {3.9292663967428517`*^9, 3.929266433375227*^9}, 
   3.929266563067258*^9, {3.929266639443221*^9, 3.9292667149650593`*^9}, {
   3.929302844729826*^9, 3.9293028449277954`*^9}, {3.929332674253724*^9, 
   3.9293326788328404`*^9}, {3.9293337610959473`*^9, 3.929333763125454*^9}, {
   3.929363678553999*^9, 3.9293638126658096`*^9}, {3.9293641590776215`*^9, 
   3.9293641658586626`*^9}, {3.929510642977871*^9, 3.9295106468570724`*^9}, {
   3.9295289319688683`*^9, 3.929528944645793*^9}, {3.929529172189934*^9, 
   3.929529208287392*^9}, {3.9295293832993712`*^9, 3.929529392028884*^9}, {
   3.92952943339783*^9, 3.9295294610246577`*^9}, {3.9296125326329613`*^9, 
   3.929612535073872*^9}, 3.9296164755331097`*^9},
 CellLabel->"In[23]:=",ExpressionUUID->"1c598405-7992-4659-b426-7c1a7ebee490"],

Cell["\<\
We can select either rule depending on the situation of interest. Now we \
compute the perturbations and fluxes.\
\>", "Text",
 CellChangeTimes->{{3.929250044288864*^9, 3.9292500513422513`*^9}, {
  3.9324690164436865`*^9, 
  3.932469077210146*^9}},ExpressionUUID->"fc2541de-dac5-433c-9dfa-\
457d7601553b"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbations and fluxes: Circular orbits", "Section",
 CellChangeTimes->{{3.9292501049071674`*^9, 3.929250110446314*^9}, {
  3.9294310685810246`*^9, 
  3.9294310706097107`*^9}},ExpressionUUID->"26003b34-4475-4a22-9176-\
303559d6c86a"],

Cell[CellGroupData[{

Cell["Setting up the equations", "Subsubsection",
 CellChangeTimes->{{3.9292534082675037`*^9, 
  3.9292534115183926`*^9}},ExpressionUUID->"7b362fd0-bb14-4a49-9bdf-\
39254c4700c1"],

Cell["\<\
We define the equations describing the perturbations below (l>=2)\
\>", "Text",
 CellChangeTimes->{{3.9292501226636486`*^9, 3.9292501351978397`*^9}, {
  3.9292503881458445`*^9, 
  3.9292503914754114`*^9}},ExpressionUUID->"dfcd49d3-6bd6-4e87-bd1e-\
1a36e1343690"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqsperturbations", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "\[Pi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"Alm1p", "[", "r", "]"}], "\[Sigma]"]}], "+", 
         FractionBox[
          RowBox[{"4", " ", "r", " ", 
           RowBox[{"Flmp", "[", "r", "]"}]}], 
          SqrtBox[
           RowBox[{"L", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "-", "L", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["L", "2"]}], "+", 
              SuperscriptBox["L", "3"]}], ")"}]}]]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{"H0", "[", "r", "]"}], "r"], "+", 
      RowBox[{
       RowBox[{"H1", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "L"}], ")"}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"]}]], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
          RowBox[{"V", "[", "r", "]"}]]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["Kp", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Omega]", " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Omega]", " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "3"]}], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"r", "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{"r", "-", 
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{"V", "[", "r", "]"}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]1", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"r", " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]2", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"r", " ", "\[Sigma]"}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        SqrtBox["2"], " ", "\[Pi]", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"Blm0p", "[", "r", "]"}], 
            RowBox[{
             SqrtBox[
              RowBox[{"L", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "L"}], ")"}]}]], " ", "\[Sigma]"}]]}], "-", 
          FractionBox[
           RowBox[{"2", " ", "r", " ", 
            RowBox[{"Flmp", "[", "r", "]"}]}], 
           SqrtBox[
            RowBox[{"L", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "L", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["L", "2"]}], "+", 
               SuperscriptBox["L", "3"]}], ")"}]}]]]}], ")"}]}], 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      FractionBox[
       RowBox[{"r", " ", 
        RowBox[{"H0", "[", "r", "]"}]}], 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      FractionBox[
       RowBox[{"r", " ", 
        RowBox[{"Kp", "[", "r", "]"}]}], 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"H1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{"\[Phi]1", "[", "r", "]"}]}], 
       RowBox[{
        RowBox[{"r", " ", "\[Sigma]"}], "-", 
        RowBox[{"2", " ", "\[Sigma]", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{"\[Phi]2", "[", "r", "]"}]}], 
       RowBox[{
        RowBox[{"r", " ", "\[Sigma]"}], "-", 
        RowBox[{"2", " ", "\[Sigma]", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      RowBox[{
       SuperscriptBox["H1", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H1", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "L"}], ")"}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"]}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Sigma]", "2"], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], 
          RowBox[{"V", "[", "r", "]"}]]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["H0", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Omega]", " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "\[Sigma]"}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Omega]", " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"r", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{"r", "-", 
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{"V", "[", "r", "]"}]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "3"]}], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"r", "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{"r", "-", 
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{"V", "[", "r", "]"}]}]], "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "\[Pi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"Alm1p", "[", "r", "]"}], "\[Sigma]"]}], "-", 
         FractionBox[
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"Blmp", "[", "r", "]"}]}], 
          SqrtBox[
           RowBox[{"L", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "L"}], ")"}]}]]], "-", 
         FractionBox[
          RowBox[{"4", " ", "r", " ", 
           RowBox[{"Flmp", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"V", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Omega]", "2"], "-", 
                   RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
                 SuperscriptBox[
                  RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"V", "[", "r", "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{
           SqrtBox[
            RowBox[{"L", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "L", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["L", "2"]}], "+", 
               SuperscriptBox["L", "3"]}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{"r", "-", 
             RowBox[{"2", " ", 
              RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
           RowBox[{"V", "[", "r", "]"}]}]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]1", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"r", " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]2", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"r", " ", "\[Sigma]"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "r", " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], 
      "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]], 
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Omega]", "2"]}], "-", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Omega]", "2"], "-", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"M", "[", "r", "]"}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{"M", "[", "r", "]"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
            ")"}]}]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]], 
       RowBox[{
        RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[Omega]", "2"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"2", "-", 
                RowBox[{"8", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"L", "+", 
                SuperscriptBox["L", "2"], "+", 
                SuperscriptBox["r", "2"], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", " ", 
         SqrtBox["2"], " ", "\[Pi]", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox[
             RowBox[{"L", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "-", "L", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["L", "2"]}], "+", 
                SuperscriptBox["L", "3"]}], ")"}]}]], " ", "r", " ", 
            "\[Omega]", " ", 
            RowBox[{"Blm0p", "[", "r", "]"}], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SqrtBox[
                 RowBox[{"L", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", "L", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["L", "2"]}], "+", 
                    SuperscriptBox["L", "3"]}], ")"}]}]]}], " ", 
               RowBox[{"Blmp", "[", "r", "]"}]}], "+", 
              RowBox[{
               SqrtBox[
                RowBox[{"L", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "L"}], ")"}]}]], " ", "r", " ", 
               RowBox[{
                SuperscriptBox["Flmp", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]0", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{
            SqrtBox[
             RowBox[{"L", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "L"}], ")"}]}]], " ", 
            RowBox[{"Flmp", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"\[Sigma]", "-", 
                    RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", 
                  "\[Omega]"}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"V", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["\[Omega]", "2"]}], "+", 
                 RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"M", "[", "r", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["r", "2"], " ", 
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "L"}], ")"}]}]], " ", 
         SqrtBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "-", "L", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["L", "2"]}], "+", 
             SuperscriptBox["L", "3"]}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"V", "[", "r", "]"}], "2"]}]], 
       RowBox[{"2", " ", "\[Sigma]", " ", "\[Omega]", " ", 
        RowBox[{"H1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "3"]}], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"r", "-", 
                RowBox[{"2", " ", 
                 RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox["\[Phi]0", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{
              RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"r", "-", 
                RowBox[{
                 SuperscriptBox["r", "3"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"M", "[", "r", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                  ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]1", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      RowBox[{
       SuperscriptBox["\[Phi]1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "r", " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], 
      "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]], 
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Omega]", "2"]}], "-", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Omega]", "2"], "-", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"M", "[", "r", "]"}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{"M", "[", "r", "]"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
            ")"}]}]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]], 
       RowBox[{
        RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], "2"], 
             "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[Omega]", "2"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"2", "-", 
                RowBox[{"8", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"L", "+", 
                SuperscriptBox["L", "2"], "+", 
                SuperscriptBox["r", "2"], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", " ", 
         SqrtBox["2"], " ", "\[Pi]", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox[
             RowBox[{"L", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "-", "L", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["L", "2"]}], "+", 
                SuperscriptBox["L", "3"]}], ")"}]}]], " ", "r", " ", 
            "\[Omega]", " ", 
            RowBox[{"Blm0p", "[", "r", "]"}], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SqrtBox[
                RowBox[{"L", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "-", "L", "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["L", "2"]}], "+", 
                   SuperscriptBox["L", "3"]}], ")"}]}]], " ", 
               RowBox[{"Blmp", "[", "r", "]"}]}], "-", 
              RowBox[{
               SqrtBox[
                RowBox[{"L", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "L"}], ")"}]}]], " ", "r", " ", 
               RowBox[{
                SuperscriptBox["Flmp", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]0", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{
            SqrtBox[
             RowBox[{"L", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "L"}], ")"}]}]], " ", 
            RowBox[{"Flmp", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Omega]", " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Sigma]", "+", 
                    RowBox[{"2", " ", "\[Omega]"}]}], ")"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"V", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["\[Omega]", "2"], "-", 
                 RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"M", "[", "r", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["r", "2"], " ", 
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "L"}], ")"}]}]], " ", 
         SqrtBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "-", "L", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["L", "2"]}], "+", 
             SuperscriptBox["L", "3"]}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"V", "[", "r", "]"}], "2"]}]], 
       RowBox[{"2", " ", "\[Sigma]", " ", "\[Omega]", " ", 
        RowBox[{"H1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "-", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"r", "-", 
                RowBox[{"2", " ", 
                 RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox["\[Phi]0", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{
              RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"r", "-", 
                RowBox[{
                 SuperscriptBox["r", "3"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"M", "[", "r", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                  ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]2", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      RowBox[{
       SuperscriptBox["\[Phi]2", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9292503830519295`*^9, 3.9292503975297556`*^9}, {
  3.929348813402157*^9, 3.929348839390555*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"64318848-717e-436b-8c5b-a1e70b6db877"],

Cell["We can define the homogeneous equations and the source terms", "Text",
 CellChangeTimes->{{3.929250435218067*^9, 
  3.9292504475348883`*^9}},ExpressionUUID->"68313883-6e29-4f4b-98b9-\
f12c2799888a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SOURCE", "=", 
   RowBox[{
    RowBox[{"-", "eqsperturbations"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H1", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"H0", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Kp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"\[Phi]1", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"\[Phi]2", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQHOM", "=", 
   RowBox[{"eqsperturbations", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Blm0p", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Flmp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Alm1p", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Blmp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Almp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8735143865429583`*^9, 3.873514414013742*^9}, {
   3.873514528044138*^9, 3.873514574962019*^9}, 3.873514897057378*^9, {
   3.929250449180204*^9, 3.9292504776327057`*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"6ca7f2ef-1aff-4696-ab0b-a4c4cb051825"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finding the boundary conditions at the origin", "Subsubsection",
 CellChangeTimes->{{3.9292534150660152`*^9, 
  3.929253421619045*^9}},ExpressionUUID->"7434d8a5-d7f1-46c5-aa3f-\
5dd16e974281"],

Cell[TextData[{
 "We do the same as we did for the background. The only diference is that the \
perturbations scales as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "L"], TraditionalForm]],ExpressionUUID->
  "528fc520-295c-4011-be96-1e1ef548b9a7"],
 " near the origin."
}], "Text",
 CellChangeTimes->{{3.929253424441883*^9, 
  3.9292534579335794`*^9}},ExpressionUUID->"7060e732-5c4b-4841-9ddb-\
ea1a595b2f8e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.929253484103348*^9, 3.929253509161499*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"727e51eb-15ed-47cd-82da-2ddf8a2826bb"],

Cell["Defining the expansions", "Text",
 CellChangeTimes->{{3.9292535242682095`*^9, 
  3.9292535270108204`*^9}},ExpressionUUID->"c3cf7386-4cab-4839-8d54-\
88992211ecf4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"M", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["Mi", "i"], " ", 
       SuperscriptBox["r", 
        RowBox[{"i", "+", "1"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], "/.", 
    "rubkgexp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["Vi", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}], "/.", 
    "rubkgexp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]0", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Phi]0i", "i"], 
        SuperscriptBox["r", "i"]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}], "/.", 
     RowBox[{
      SubscriptBox["\[Phi]0i", "0"], "\[Rule]", "\[Phi]c"}]}], "/.", 
    "rubkgexp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H0", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["h0", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H1", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["h1", "i"], 
       SuperscriptBox["r", 
        RowBox[{"i", "+", "1"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Kp", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["kp", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]1", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Phi]1i", "i"], 
       SuperscriptBox["r", 
        RowBox[{"i", "+", "1"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"\[Phi]2", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Phi]2i", "i"], 
       SuperscriptBox["r", 
        RowBox[{"i", "+", "1"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9292535284825354`*^9, 3.9292535792890496`*^9}, {
   3.9292536298462915`*^9, 3.929253688329521*^9}, {3.9292537197597423`*^9, 
   3.92925372035641*^9}, {3.929253787647439*^9, 3.929253789065509*^9}, {
   3.929253824500702*^9, 3.9292538449415555`*^9}, 3.9292539978035746`*^9, {
   3.929254182210389*^9, 3.929254212146351*^9}, {3.929254592122063*^9, 
   3.9292546640776205`*^9}, {3.929255139811023*^9, 3.929255139943655*^9}, {
   3.929255230389863*^9, 3.929255259009117*^9}, {3.929255307404224*^9, 
   3.929255313638034*^9}, {3.92925560674492*^9, 3.9292556274163494`*^9}, {
   3.9292558069524794`*^9, 3.929255847593094*^9}, {3.9292659066425157`*^9, 
   3.9292659069125037`*^9}, 3.929266831084097*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"ba324767-3636-4725-8c11-b10d47bd5acf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"EQHOM", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "r"}], ",", 
        RowBox[{"EQHOM", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"EQHOM", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "r"}], ",", 
        RowBox[{
         RowBox[{"EQHOM", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "r"}], ",", 
        RowBox[{
         RowBox[{"EQHOM", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "r"}]}], "}"}], 
      SuperscriptBox["r", "L"]], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "3"}], "}"}]}], "]"}], "//", "Simplify"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.929253481362446*^9, 3.9292534817161417`*^9}, {
   3.929253580709956*^9, 3.92925361023795*^9}, {3.929253656396912*^9, 
   3.9292536576222887`*^9}, {3.9292536923150735`*^9, 3.929253717458537*^9}, {
   3.929253836437602*^9, 3.9292538378628445`*^9}, {3.9292542234666452`*^9, 
   3.929254243945298*^9}, {3.929254338524437*^9, 3.9292544042235413`*^9}, {
   3.9292544361095247`*^9, 3.9292544870322714`*^9}, 3.9292545999972935`*^9, 
   3.9292546872309675`*^9, {3.9292551077272587`*^9, 3.92925510829888*^9}, {
   3.929255200562439*^9, 3.92925520267146*^9}, {3.929255633497661*^9, 
   3.9292556597606735`*^9}, {3.92925572433432*^9, 3.929255749883393*^9}, {
   3.929255818806813*^9, 3.929255821960252*^9}, {3.9292636847518005`*^9, 
   3.9292637297110357`*^9}, {3.929264107206977*^9, 3.9292641145187902`*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"f2b81fd2-a27d-41ee-a8e0-f8651c847e21"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rupertorigin", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"%", "\[Equal]", "0"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["h1", "0"], ",", 
         SubscriptBox["h0", "0"], ",", 
         SubscriptBox["h1", "1"], ",", 
         SubscriptBox["h0", "1"], ",", 
         SubscriptBox["kp", "1"], ",", 
         SubscriptBox["\[Phi]1i", "1"], ",", 
         SubscriptBox["\[Phi]2i", "1"], ",", 
         SubscriptBox["h1", "2"], ",", 
         SubscriptBox["h0", "2"], ",", 
         SubscriptBox["kp", "2"], ",", 
         SubscriptBox["\[Phi]1i", "2"], ",", 
         SubscriptBox["\[Phi]2i", "2"], ",", 
         SubscriptBox["h1", "3"], ",", 
         SubscriptBox["h0", "3"], ",", 
         SubscriptBox["kp", "3"], ",", 
         SubscriptBox["\[Phi]1i", "3"], ",", 
         SubscriptBox["\[Phi]2i", "3"]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9292542916756973`*^9, 3.9292543115862217`*^9}, {
  3.9292543681807656`*^9, 3.92925441841683*^9}, {3.929254453181978*^9, 
  3.929254482016921*^9}, {3.9292557386190853`*^9, 3.929255747046791*^9}, {
  3.9292637145715747`*^9, 3.9292637487845078`*^9}, {3.9292640652803793`*^9, 
  3.929264142078845*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"fd3ca2ff-4483-4d30-9081-d4b1c8266373"],

Cell["Therefore we have the following boundary conditions", "Text",
 CellChangeTimes->{{3.929264148037366*^9, 
  3.929264156630096*^9}},ExpressionUUID->"de5fb13e-3b83-41fc-a7a2-\
f0fe1cd7797c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BOUNOR", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H0", "[", "r", "]"}], ",", 
      RowBox[{"H1", "[", "r", "]"}], ",", 
      RowBox[{"Kp", "[", "r", "]"}], ",", 
      RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
      RowBox[{"\[Phi]2", "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}]}], "}"}], "/.", 
    "rupertorigin"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929264397833138*^9, 3.929264439008908*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"b438c5c5-f14e-4b33-aa12-a5e713ff588b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9292644477116027`*^9, 3.929264455811679*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"8eebbb36-a422-4ee5-8402-7970b44f7cd4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finding the boundary conditions at infinity", "Subsubsection",
 CellChangeTimes->{{3.929264466447201*^9, 
  3.929264472267169*^9}},ExpressionUUID->"e2e68186-35ab-4cef-a1dc-\
ea2d89aaadcc"],

Cell["\<\
At infinity, the boundary conditions are such that we have two scalar \
perturbations+gravitational perturbation in Schwarzschild. Therefore, we can \
use that for our problem.\
\>", "Text",
 CellChangeTimes->{{3.929264522771202*^9, 3.929264566079797*^9}, {
   3.9292646401334925`*^9, 3.929264663234372*^9}, {3.929265109026581*^9, 
   3.929265109913558*^9}, 
   3.929266865005639*^9},ExpressionUUID->"cee3e002-cac1-456a-8517-\
f287dc1f7bde"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellLabel->"In[39]:=",ExpressionUUID->"3277d677-9b2c-4589-a333-04f27978ef3f"],

Cell["\<\
The equations in vacuum can be obtained by considering \[Phi]0->0 and the \
Schwarzschild spacetime with mass Mt.\
\>", "Text",
 CellChangeTimes->{{3.9292651128556232`*^9, 3.929265126269923*^9}, {
  3.9292668898281045`*^9, 
  3.929266905971171*^9}},ExpressionUUID->"8d7e7434-2438-4d6b-83ad-\
4a557f8fd5dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQSVAC", "=", 
   RowBox[{"EQHOM", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Phi]0", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"V", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "-", 
          RowBox[{"2", 
           FractionBox["Mt", "#"]}]}], "&"}], ")"}]}], ",", 
      RowBox[{"M", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"Mt", "&"}], ")"}]}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929265128111204*^9, 3.9292651425810957`*^9}, {
   3.929266888490925*^9, 3.9292669295082426`*^9}, 3.929377323320628*^9},
 CellLabel->"In[40]:=",ExpressionUUID->"142f7ba8-9840-4226-8f39-755263838a39"],

Cell["\<\
So for the gravitational sector, we can use the Zerilli equations for \
simplicity\
\>", "Text",
 CellChangeTimes->{{3.9292651592852583`*^9, 3.9292651716599207`*^9}, {
  3.9293410282923284`*^9, 3.9293410319553633`*^9}, {3.9293411186768703`*^9, 
  3.9293411287010283`*^9}},ExpressionUUID->"199fb3b0-7518-436b-a1ea-\
bce6c444f98b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rst", "[", "r_", "]"}], ":=", 
   RowBox[{"r", "+", 
    RowBox[{"2", "Mt", " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       FractionBox["r", 
        RowBox[{"2", "Mt"}]], "-", "1"}], "]"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9292951680029116`*^9, 3.929295168430421*^9}, {
  3.929377822571955*^9, 3.9293778230138535`*^9}, {3.929378086105817*^9, 
  3.929378098447377*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"062cb86a-ac9f-43fb-b0cd-07a87df5c062"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqzr", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "Mt"}], "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"72", " ", 
             SuperscriptBox["Mt", "3"]}], "+", 
            RowBox[{"36", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "L", "+", 
               SuperscriptBox["L", "2"]}], ")"}], " ", 
             SuperscriptBox["Mt", "2"], " ", "x"}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "L", "+", 
                SuperscriptBox["L", "2"]}], ")"}], "2"], " ", "Mt", " ", 
             SuperscriptBox["x", "2"]}], "+", 
            RowBox[{"L", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "L"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "L", "+", 
                SuperscriptBox["L", "2"]}], ")"}], "2"], " ", 
             SuperscriptBox["x", "3"]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["x", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "Mt"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "L", "+", 
                SuperscriptBox["L", "2"]}], ")"}], " ", "x"}]}], ")"}], 
           "2"]}]], "+", 
        SuperscriptBox["\[Omega]", "2"]}], ")"}], " ", 
      RowBox[{"Z", "[", "x", "]"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", "Mt", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "Mt"}], "+", "x"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["Z", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}]}], 
      SuperscriptBox["x", "3"]], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "Mt"}], "x"]}], ")"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["Z", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Rule]", "r"}], ",", 
      RowBox[{"\[Omega]", "\[Rule]", "\[Sigma]"}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9293628297223616`*^9, 3.929362830750579*^9}, {
  3.9293629167158237`*^9, 3.9293629393427343`*^9}, {3.9293629796174393`*^9, 
  3.929362980186467*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"b97ac5a4-5309-4c63-8108-937c3306353b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ORDgINF", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Z", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"g", "[", "x", "]"}], 
    SuperscriptBox["E", 
     RowBox[{"I", " ", "\[Sigma]", " ", 
      RowBox[{"rst", "[", "x", "]"}]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqgZ", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     FractionBox["eqzr", 
      SuperscriptBox["E", 
       RowBox[{"I", " ", "\[Sigma]", " ", 
        RowBox[{"rst", "[", "r", "]"}]}]]], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "[", "r", "]"}], ",", 
       RowBox[{
        RowBox[{"g", "'"}], "[", "r", "]"}], ",", 
       RowBox[{
        RowBox[{"g", "''"}], "[", "r", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "x_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"gi", "[", "i", "]"}], 
      SuperscriptBox["x", "i"]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"ORDgINF", "+", "3"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SEgZ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"eqgZ", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "\[Infinity]", ",", 
       RowBox[{"ORDgINF", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqsgZinf", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"SEgZ", ",", "i"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", "ORDgINF"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vagZ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"gi", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgZINF", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqsgZinf", ",", "vagZ"}], "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{"Z", ",", "g"}], "]"}]}], "Input",
 CellChangeTimes->{{3.549188015921222*^9, 3.5491880388754835`*^9}, {
   3.5491881504613724`*^9, 3.5491881817760468`*^9}, 3.549188589211471*^9, {
   3.5491887545728683`*^9, 3.5491887547438784`*^9}, {3.549188809854812*^9, 
   3.549188810026822*^9}, {3.5491890769636173`*^9, 3.5491891052749043`*^9}, {
   3.5491892821983976`*^9, 3.549189283583475*^9}, {3.549189315621998*^9, 
   3.5491893205692673`*^9}, {3.549189555757177*^9, 3.5491896480916023`*^9}, {
   3.5491896996081934`*^9, 3.5491897226763096`*^9}, {3.5491897705008273`*^9, 
   3.5491897733479824`*^9}, 3.549198790599414*^9, {3.54927888748129*^9, 
   3.549278905739254*^9}, 3.54930863065969*^9, 3.549363599296094*^9, {
   3.55751336524298*^9, 3.557513399180564*^9}, {3.557513455473043*^9, 
   3.557513485341198*^9}, {3.557513561545974*^9, 3.557513561896056*^9}, {
   3.5575136276050873`*^9, 3.557513662705748*^9}, {3.557513723632738*^9, 
   3.557513729705844*^9}, {3.557691575793655*^9, 3.5576915766834183`*^9}, {
   3.557691801247293*^9, 3.55769180133803*^9}, 3.557702659343792*^9, {
   3.557703512204694*^9, 3.557703512608191*^9}, {3.559038357823995*^9, 
   3.5590384202861958`*^9}, {3.559478518608761*^9, 3.559478519176701*^9}, {
   3.55947987770216*^9, 3.559479878563641*^9}, 3.559488051644967*^9, {
   3.55984285155237*^9, 3.559842852018302*^9}, {3.5598988195156183`*^9, 
   3.559898828953313*^9}, {3.559951966041107*^9, 3.559951966226551*^9}, {
   3.560041317833596*^9, 3.560041317928666*^9}, {3.5601687763692904`*^9, 
   3.560168776457697*^9}, {3.929362887937426*^9, 3.9293629083824263`*^9}, {
   3.929362951673281*^9, 3.9293629748037004`*^9}, 3.92937722194779*^9, {
   3.929377608993801*^9, 3.929377609652095*^9}, {3.92937782508681*^9, 
   3.929377841570603*^9}, 3.929378126221942*^9},
 CellLabel->"In[44]:=",ExpressionUUID->"abf07497-742b-4110-bf38-c840e1be8d11"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalLambda]l", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{"L", "-", "1"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"L", "+", "2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ze", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{"I", " ", "\[Sigma]", " ", 
       RowBox[{"rst", "[", "x", "]"}]}]], 
     RowBox[{"Sum", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"gi", "[", "i", "]"}], 
        SuperscriptBox["x", "i"]], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", 
         RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], "/.", 
    "seriesgZINF"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bounkp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", 
         SuperscriptBox["Mt", "2"]}], "+", 
        RowBox[{"3", " ", "Mt", " ", "r", " ", "\[CapitalLambda]l"}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", "\[CapitalLambda]l", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "\[CapitalLambda]l"}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Ze", "[", "r", "]"}]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "Mt"}], "+", 
        RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}]}]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"2", " ", "Mt"}], "r"]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["Ze", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bounh1", "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["Mt", "2"]}], "-", 
        RowBox[{"3", " ", "Mt", " ", "r", " ", "\[CapitalLambda]l"}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", "\[CapitalLambda]l"}]}], ")"}], " ", 
      RowBox[{"Ze", "[", "r", "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "Mt"}], "+", 
        RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}]}]], "-", 
    RowBox[{"r", " ", 
     RowBox[{
      SuperscriptBox["Ze", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bounh0", "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "Mt"}], "+", 
         RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}], "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["Mt", "3"]}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Mt", "2"], " ", "r", " ", "\[CapitalLambda]l"}], 
            "+", 
            RowBox[{"3", " ", "Mt", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox["\[CapitalLambda]l", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox["\[CapitalLambda]l", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "\[CapitalLambda]l"}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox["r", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "Mt"}], "+", 
             RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}], "2"], " ", 
          SuperscriptBox["\[Sigma]", "2"]}]}], ")"}], " ", 
       RowBox[{"Ze", "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "Mt"}], "+", 
         RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["Mt", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "Mt"}], "-", "r"}], ")"}], " ", "r", " ", 
          "\[CapitalLambda]l"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["Ze", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bounginf", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"bounh0", ",", "bounh1", ",", "bounkp"}], "}"}], "//.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", 
     SubscriptBox["kpi", "0"]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5492995611448107`*^9, 3.5492995668377113`*^9}, {
   3.5493001508756027`*^9, 3.5493004357567177`*^9}, {3.5493005503119307`*^9, 
   3.5493005537669287`*^9}, {3.5493006532510033`*^9, 3.549300654184024*^9}, {
   3.549301989177497*^9, 3.549302073440977*^9}, {3.549302117195814*^9, 
   3.549302151352942*^9}, {3.549305977299405*^9, 3.5493059915774612`*^9}, {
   3.549308301769487*^9, 3.549308306908955*^9}, {3.549308595716675*^9, 
   3.549308620795586*^9}, {3.549308719604292*^9, 3.549308739273114*^9}, {
   3.549309475517529*^9, 3.549309742179122*^9}, 3.549309797970222*^9, {
   3.549366390031262*^9, 3.5493663911990557`*^9}, {3.549373766282969*^9, 
   3.549373767481742*^9}, {3.549465102252613*^9, 3.5494651101843233`*^9}, {
   3.549465146612115*^9, 3.549465162554783*^9}, {3.54946522458862*^9, 
   3.549465266327724*^9}, 3.54948890365985*^9, 3.549488971222426*^9, 
   3.5495490414996033`*^9, {3.5495625000594797`*^9, 3.549562502220541*^9}, {
   3.549562915610029*^9, 3.549562933252635*^9}, {3.5495669169420977`*^9, 
   3.5495669474401484`*^9}, 3.5495670293111763`*^9, {3.5495955822989225`*^9, 
   3.5495955851810875`*^9}, {3.557513414028261*^9, 3.557513414852181*^9}, {
   3.557513492134759*^9, 3.55751362216544*^9}, {3.5575137759256067`*^9, 
   3.5575137797673683`*^9}, {3.557522114145916*^9, 3.557522123530279*^9}, {
   3.557523816540864*^9, 3.5575238176411867`*^9}, {3.5575238672441397`*^9, 
   3.557523867362073*^9}, {3.559038441793056*^9, 3.55903848448711*^9}, {
   3.5590400589113417`*^9, 3.559040061492145*^9}, {3.559042229040206*^9, 
   3.559042230039226*^9}, {3.559478954442618*^9, 3.559478958220211*^9}, {
   3.5594792038471823`*^9, 3.559479216584775*^9}, {3.559479270020135*^9, 
   3.559479271267324*^9}, 3.559488051656258*^9, {3.560168797637251*^9, 
   3.56016882516424*^9}, {3.9293630237575192`*^9, 3.929363144394322*^9}, {
   3.929364049029535*^9, 3.929364049153607*^9}, {3.9293645762563076`*^9, 
   3.9293645924883385`*^9}, {3.9293772067290483`*^9, 
   3.9293772972274456`*^9}, {3.929377621932341*^9, 3.92937762289004*^9}, {
   3.9293778323999124`*^9, 3.929377834506875*^9}},
 CellLabel->"In[53]:=",ExpressionUUID->"228585c9-250a-4c14-aaf3-b4c4279a1c0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BOUGRAV", "=", "bounginf"}], ";"}]], "Input",
 CellChangeTimes->{{3.929298120437143*^9, 3.929298134628807*^9}, {
  3.929299087987913*^9, 3.9292991265708447`*^9}, {3.9293631491812844`*^9, 
  3.929363172068033*^9}},
 CellLabel->"In[59]:=",ExpressionUUID->"33977e49-15b3-4f95-b85f-d4b0d7f22ac7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9292991877200623`*^9, 3.929299194446289*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"3db108f4-4fc4-4ff2-bae3-50579fb02e56"],

Cell["\<\
For the scalar fields, let\[CloseCurlyQuote]s take the scalar perturbation \
for \[Phi]1. The difference between \[Phi]1 and \[Phi]2 can b\
\>", "Text",
 CellChangeTimes->{{3.929299202125712*^9, 3.9292992313238964`*^9}, {
  3.9293001784069977`*^9, 3.9293001921739993`*^9}, {3.9293408707300262`*^9, 
  3.9293408711838408`*^9}},ExpressionUUID->"3e3e0063-a5c0-40c5-bb52-\
01bb4497a883"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9293001600234337`*^9, 3.929300174525943*^9}, {
  3.9293002532740307`*^9, 3.929300258354559*^9}},
 CellLabel->"In[61]:=",ExpressionUUID->"0ce35a37-f2bc-4d0f-8521-b679f2f3440b"],

Cell["Defining the equation for the expansion", "Text",
 CellChangeTimes->{{3.9293017784411545`*^9, 
  3.929301784971286*^9}},ExpressionUUID->"6651286d-45d3-4786-9e11-\
9d5c2b7d3113"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqgp1", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", 
           FractionBox["Mt", "r"]}]}], ")"}], "2"], 
       FractionBox[
        RowBox[{"EQSVAC", "[", 
         RowBox[{"[", "4", "]"}], "]"}], 
        SuperscriptBox["E", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Kappa]p", " ", 
            RowBox[{"rst", "[", "r", "]"}]}], "-", 
           RowBox[{
            FractionBox["Mt", "\[Kappa]p"], " ", 
            RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]]]}], "/.", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "\[Rule]", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Kappa]p", "2"]}]}]}], "/.", 
     RowBox[{"\[Phi]1", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"g1", "[", "#", "]"}], 
         SuperscriptBox["E", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Kappa]p", " ", 
             RowBox[{"rst", "[", "#", "]"}]}], "-", 
            RowBox[{
             FractionBox["Mt", "\[Kappa]p"], " ", 
             RowBox[{"Log", "[", "#", "]"}]}]}], ")"}]]}], "&"}], ")"}]}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"g1", "''"}], "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"g1", "'"}], "[", "r", "]"}]}], "}"}], ",", "FullSimplify"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.929301593980744*^9, 3.9293017742423763`*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"1010dac9-99e4-4b8e-a002-0b0e95d38cbb"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Mt", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}], "2"]}], "+", 
      RowBox[{"Mt", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["Mt", "2"]}], "-", 
         RowBox[{"6", " ", "Mt", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", "\[Kappa]p"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "L", "+", 
            SuperscriptBox["L", "2"]}], ")"}], " ", "Mt", " ", "r"}], "-", 
         RowBox[{"L", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "L"}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["Mt", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["r", "2"]}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox["\[Kappa]p", "2"]}]}], ")"}], " ", 
    RowBox[{"g1", "[", "r", "]"}]}], 
   RowBox[{
    SuperscriptBox["r", "4"], " ", 
    SuperscriptBox["\[Kappa]p", "2"]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["Mt", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox["\[Kappa]p", "2"]}], "+", 
      RowBox[{"Mt", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "r"}], "+", "\[Kappa]p"}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["g1", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   RowBox[{
    SuperscriptBox["r", "3"], " ", "\[Kappa]p"}]], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "Mt"}], "r"]}], ")"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["g1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.929301597298538*^9, {3.9293017060180464`*^9, 3.929301757085286*^9}, 
   3.9293017896704493`*^9, 3.9293028738142667`*^9, 3.9293321351758037`*^9, 
   3.929339218611923*^9, 3.929340418005526*^9, 3.9293408240422096`*^9, 
   3.929340872751244*^9, 3.9293489113454957`*^9, 3.9293632033177805`*^9, {
   3.92936403220761*^9, 3.9293640588305764`*^9}, 3.929364614807353*^9, 
   3.929377061433199*^9, 3.9293776852673283`*^9, 3.9293778539269247`*^9, 
   3.929377915519204*^9, 3.9293780642205315`*^9, {3.929378121517057*^9, 
   3.9293781330450087`*^9}, 3.9294077585542164`*^9, 3.9295074172686*^9, 
   3.929698021831656*^9, 3.929724009802657*^9, 3.9297281963177137`*^9, 
   3.9297620067993746`*^9, 3.9297623472506747`*^9, 3.929774074917819*^9, 
   3.9297835478839765`*^9, 3.9324691435031586`*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"1d992997-734f-4eca-8728-17b0f05fc8db"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ORDgINF", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g1", "[", "x_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"gi", "[", "i", "]"}], 
      SuperscriptBox["x", "i"]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"ORDgINF", "+", "2"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SEg1", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"eqgp1", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "\[Infinity]", ",", 
       RowBox[{"ORDgINF", "+", "2"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqsg1inf", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"SEg1", ",", "i"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", "ORDgINF"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vag1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"gi", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgp1INF", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"eqsg1inf", ",", "vag1"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgp2INF", "=", 
   RowBox[{"seriesgp1INF", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Kappa]p", "\[Rule]", "\[Kappa]m"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"\[Phi]1", ",", "\[Phi]2", ",", "g1", ",", "g2"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgm1INF", "=", 
   RowBox[{"seriesgp1INF", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Kappa]p", "\[Rule]", 
      RowBox[{"-", "\[Kappa]p"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgm2INF", "=", 
   RowBox[{"seriesgp2INF", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Kappa]m", "\[Rule]", 
      RowBox[{"-", "\[Kappa]m"}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.929301811711835*^9, {3.929377987581792*^9, 3.9293780011737947`*^9}, 
   3.9293781291953344`*^9},
 CellLabel->"In[63]:=",ExpressionUUID->"a982b5b5-7a8a-41f6-9412-891ca3a08ba9"],

Cell["We have therefore some possible boundary conditions", "Text",
 CellChangeTimes->{{3.929301885467797*^9, 3.929301897014262*^9}, {
  3.9293408737427025`*^9, 
  3.929340875022051*^9}},ExpressionUUID->"e91943ec-a39f-4828-87b1-\
b77280066a5f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Phi]1infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Kappa]p", " ", 
          RowBox[{"rst", "[", "r", "]"}]}], "-", 
         RowBox[{
          FractionBox["Mt", "\[Kappa]p"], " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgp1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]1infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Kappa]p", " ", 
             RowBox[{"rst", "[", "r", "]"}]}], "-", 
            RowBox[{
             FractionBox["Mt", "\[Kappa]p"], " ", 
             RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgp1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]2infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Kappa]m", " ", 
          RowBox[{"rst", "[", "r", "]"}]}], "-", 
         RowBox[{
          FractionBox["Mt", "\[Kappa]m"], " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgp2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]2infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Kappa]m", " ", 
             RowBox[{"rst", "[", "r", "]"}]}], "-", 
            RowBox[{
             FractionBox["Mt", "\[Kappa]m"], " ", 
             RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgp2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]1infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Kappa]p", " ", 
           RowBox[{"rst", "[", "r", "]"}]}], "-", 
          RowBox[{
           FractionBox["Mt", "\[Kappa]p"], " ", 
           RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgm1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]1infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Kappa]p", " ", 
              RowBox[{"rst", "[", "r", "]"}]}], "-", 
             RowBox[{
              FractionBox["Mt", "\[Kappa]p"], " ", 
              RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgm1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]2infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Kappa]m", " ", 
           RowBox[{"rst", "[", "r", "]"}]}], "-", 
          RowBox[{
           FractionBox["Mt", "\[Kappa]m"], " ", 
           RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgm2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]2infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Kappa]m", " ", 
              RowBox[{"rst", "[", "r", "]"}]}], "-", 
             RowBox[{
              FractionBox["Mt", "\[Kappa]m"], " ", 
              RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgm2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.549306349150929*^9, 3.549306466408806*^9}, {
   3.549306506116749*^9, 3.5493066062179193`*^9}, 3.549306783897386*^9, {
   3.549306874372128*^9, 3.54930690611703*^9}, {3.549306968185348*^9, 
   3.5493069961053953`*^9}, {3.549307034018713*^9, 3.549307070537508*^9}, {
   3.549307147404871*^9, 3.549307170540349*^9}, {3.549308112051601*^9, 
   3.54930813548073*^9}, {3.5493083977470417`*^9, 3.549308421151948*^9}, {
   3.549465135194933*^9, 3.5494651399318943`*^9}, {3.549465246538871*^9, 
   3.549465249298683*^9}, {3.549564293282992*^9, 3.549564303836585*^9}, {
   3.549566862048184*^9, 3.549566879444447*^9}, {3.549566982238987*^9, 
   3.549567011822197*^9}, {3.557481739284869*^9, 3.557481767696821*^9}, {
   3.557481914705408*^9, 3.557481966296197*^9}, {3.557523476897417*^9, 
   3.557523492212922*^9}, {3.5575687364618893`*^9, 3.55756876197223*^9}, {
   3.559034655725813*^9, 3.5590346984898252`*^9}, {3.55903478495746*^9, 
   3.5590348690719757`*^9}, {3.559035285694399*^9, 3.559035325173521*^9}, {
   3.559036138391244*^9, 3.5590361432442083`*^9}, {3.5590406676256104`*^9, 
   3.5590406725465937`*^9}, {3.559382821023629*^9, 3.55938283847692*^9}, {
   3.55947758200563*^9, 3.559477590333901*^9}, {3.559477650319872*^9, 
   3.559477661262896*^9}, 3.5594880515987587`*^9, {3.8751662786375217`*^9, 
   3.87516631086554*^9}, {3.8751667751010246`*^9, 3.8751667890718665`*^9}, {
   3.875166858284505*^9, 3.875166892297215*^9}, {3.875166944318454*^9, 
   3.8751669497671604`*^9}, {3.897679557335617*^9, 3.8976795791399813`*^9}, {
   3.9293019436666927`*^9, 3.9293019888130674`*^9}, 3.929302039416875*^9, {
   3.9293361836525655`*^9, 3.929336234805143*^9}, {3.9293363478328886`*^9, 
   3.92933637283202*^9}, {3.929339229104553*^9, 3.9293392469115*^9}, {
   3.929339749982477*^9, 3.9293397690903273`*^9}, {3.9293403838404894`*^9, 
   3.9293404117985563`*^9}, {3.929377661727792*^9, 3.9293776804787436`*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"038f6354-9d39-47c0-b919-f494e33ee54d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"w1", "=", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"]}]]}], ";", 
  RowBox[{"w2", "=", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], "2"]}]]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9293360114424887`*^9, 3.9293360312015777`*^9}},
 CellLabel->"In[81]:=",ExpressionUUID->"78ac535d-5e28-4df6-afa8-adfdb0887021"],

Cell["Each of these boundary conditions depend on the frequency", "Text",
 CellChangeTimes->{{3.9293020480135145`*^9, 3.929302052545566*^9}, {
  3.929335988460447*^9, 
  3.9293359977562118`*^9}},ExpressionUUID->"b6602cc9-4fbd-48f5-a027-\
5a86c4f1ed7a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Specifying the source terms", "Subsubsection",
 CellChangeTimes->{{3.929302129098925*^9, 3.9293021351277795`*^9}, {
  3.929378146136842*^9, 
  3.929378148047904*^9}},ExpressionUUID->"4cb2f52a-88cf-4a5a-b305-\
b9bb2c999a0a"],

Cell["\<\
Here we show the source terms for a particle in circular motion.\
\>", "Text",
 CellChangeTimes->{{3.9293022422442684`*^9, 3.9293022455866537`*^9}, {
  3.9293023308313518`*^9, 
  3.9293023411541758`*^9}},ExpressionUUID->"97ff5e11-defe-420c-88b6-\
67e0f74a272d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Alm1p", ",", "Flmp", ",", "Blm0p", ",", "Blmp", ",", "Almp"}], 
   "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9293026583471556`*^9, 3.9293026773601675`*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"750793ea-9893-4f34-83bf-b332658061b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Alm1p", "[", "x_", "]"}], ":=", "0"}], ";", 
  RowBox[{
   RowBox[{"Flmp", "[", "x_", "]"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"u0", " ", 
      SuperscriptBox["\[CapitalOmega]0", "2"], " ", 
      RowBox[{"dir", "[", 
       RowBox[{"x", ",", "rp"}], "]"}], " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "x", "]"}]}], "x"]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         RowBox[{"Yp", "[", "\[Chi]p", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Chi]p", "2"]}], ")"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["Yp", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "\[Chi]p", "]"}]}]}], ")"}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "L"}], ")"}], " ", "L", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "L"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "L"}], ")"}]}]], " ", 
      SqrtBox[
       RowBox[{"V", "[", "x", "]"}]]}]]}]}], ";", 
  RowBox[{
   RowBox[{"Blm0p", "[", "x_", "]"}], ":=", 
   FractionBox[
    RowBox[{"m", " ", "u0", " ", "\[CapitalOmega]0", " ", 
     RowBox[{"dir", "[", 
      RowBox[{"x", ",", "rp"}], "]"}], " ", 
     SqrtBox[
      RowBox[{"2", "-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"M", "[", "x", "]"}]}], "x"]}]], " ", 
     SqrtBox[
      RowBox[{"V", "[", "x", "]"}]], " ", 
     RowBox[{"Yp", "[", "\[Chi]p", "]"}]}], 
    RowBox[{
     SqrtBox[
      RowBox[{"L", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "L"}], ")"}]}]], " ", "x"}]]}], ";", 
  RowBox[{
   RowBox[{"Blmp", "[", "x_", "]"}], ":=", "0"}], ";", 
  RowBox[{
   RowBox[{"Almp", "[", "x_", "]"}], ":=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.559583366075472*^9, 3.559583383006119*^9}, {
   3.5600202228098917`*^9, 3.5600202229754753`*^9}, 3.8725762990163937`*^9, {
   3.873516249002575*^9, 3.873516296539525*^9}, {3.8735290719085827`*^9, 
   3.8735290729269524`*^9}, {3.929302228065589*^9, 3.9293022402659736`*^9}, {
   3.9293030271233826`*^9, 3.9293030281788883`*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"d8bf5323-e245-4262-8fdc-f468cbb4d98d"],

Cell[TextData[{
 "defining the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["u", "0"], TraditionalForm]],ExpressionUUID->
  "7883c0a3-0625-400e-b137-a1777b3e14a5"],
 " and the rules for spherical harmonics"
}], "Text",
 CellChangeTimes->{{3.929302691755133*^9, 3.9293027139890747`*^9}, 
   3.9293392559691305`*^9, {3.929363210034976*^9, 3.929363212724832*^9}, {
   3.929378019509787*^9, 
   3.9293780200204196`*^9}},ExpressionUUID->"d80fe314-7c1e-4b3d-8f2d-\
5c7c27497277"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"V", "[", "r", "]"}], "-", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox["\[CapitalOmega]0", "2"]}]}], ")"}], 
    RowBox[{
     RowBox[{"-", "1"}], "/", "2"}]]}], ";", 
  RowBox[{"\[CapitalOmega]0", "=", 
   SqrtBox[
    FractionBox[
     RowBox[{
      RowBox[{"V", "'"}], "[", "r", "]"}], 
     RowBox[{"2", "r"}]]]}], ";"}]], "Input",
 CellChangeTimes->{
  3.559583825284994*^9, {3.5595856939332314`*^9, 3.5595857002384853`*^9}, {
   3.9293027603103633`*^9, 3.929302761659951*^9}, {3.9293030544848986`*^9, 
   3.929303063205927*^9}, {3.929303165781002*^9, 3.929303166083785*^9}, {
   3.9293335080975447`*^9, 3.929333508382555*^9}, 3.9293386020217223`*^9, 
   3.9297620867296968`*^9},
 CellLabel->"In[84]:=",ExpressionUUID->"6f01dd23-1fbd-4260-b661-9a6e79275c40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rYp", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["Yp", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "\[Chi]p", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"L", 
             RowBox[{"(", 
              RowBox[{"L", "+", "1"}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"m", "^", "2"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"\[Chi]p", "^", "2"}]}], ")"}]}]}], ")"}], 
          RowBox[{"Yp", "[", "\[Chi]p", "]"}]}], "-", 
         RowBox[{"2", " ", "\[Chi]p", " ", 
          RowBox[{
           SuperscriptBox["Yp", "\[Prime]",
            MultilineFunction->None], "[", "\[Chi]p", "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[Chi]p", "2"]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"Yp", "[", "\[Chi]p", "]"}], "\[Rule]", 
      RowBox[{"SphericalHarmonicY", "[", 
       RowBox[{"L", ",", "m", ",", 
        RowBox[{"\[Pi]", "/", "2"}], ",", "0"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Yp", "'"}], "[", "\[Chi]p", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{"\[Chi]p", "\[Rule]", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.8727560914259143`*^9, {3.8730235673299227`*^9, 3.873023581383875*^9}, {
   3.8735161005078697`*^9, 3.8735161046598377`*^9}, 3.873529902197666*^9, {
   3.929303100577754*^9, 3.9293031213426456`*^9}, {3.92934049174562*^9, 
   3.929340493157275*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"29208c5a-093a-4f1a-bfb1-aef8e7523324"],

Cell["\<\
Finally, we apply for the source terms, simplifying the metric derivatives by \
using the background equations. The source for the first order fundamental \
functions (Kp,H1,\[Phi]1,\[Phi]1\[CloseCurlyQuote],\[Phi]2,\[Phi]2\
\[CloseCurlyQuote]), is given by\
\>", "Text",
 CellChangeTimes->{{3.9293029241318913`*^9, 3.9293029443564186`*^9}, {
  3.929303309770793*^9, 3.9293033113138*^9}, {3.9293405533973427`*^9, 
  3.9293405538612337`*^9}},ExpressionUUID->"80d703f5-3b6f-46c8-b144-\
c28a665af398"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SOURCEN", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SOURCE", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"SOURCE", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", "0", ",", 
       RowBox[{"SOURCE", "[", 
        RowBox[{"[", "4", "]"}], "]"}], ",", "0", ",", 
       RowBox[{"SOURCE", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "//.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"eq1", ",", "eq2", ",", "eq3"}], "}"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"V", "'"}], "[", "r", "]"}], ",", 
          RowBox[{
           RowBox[{"M", "'"}], "[", "r", "]"}], ",", 
          RowBox[{
           RowBox[{"\[Phi]0", "''"}], "[", "r", "]"}]}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//.", "rYp"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929302896067937*^9, 3.9293028969256296`*^9}, {
  3.929302951241872*^9, 3.9293030185471787`*^9}, {3.929303316071729*^9, 
  3.9293033591637077`*^9}, {3.929338548428838*^9, 3.9293385505790787`*^9}},
 CellLabel->"In[86]:=",ExpressionUUID->"7a7d05a4-efda-4e50-9510-68aef78925ac"],

Cell["\<\
We then split the tems that depend on the delta and derivative\
\>", "Text",
 CellChangeTimes->{{3.9293034260884905`*^9, 
  3.929303438614642*^9}},ExpressionUUID->"edfed9fa-0cbb-4ff3-b80f-\
237652aef9e6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SOURCED", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"SOURCEN", ",", 
     RowBox[{"dir", "[", 
      RowBox[{"r", ",", "rp"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SOURCEDD", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"SOURCEN", ",", 
     RowBox[{
      SuperscriptBox["dir", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"r", ",", "rp"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dSOURCEDD", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"SOURCEDD", ",", "r"}], "]"}], "//.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"eq1", ",", "eq2", ",", "eq3"}], "}"}], "\[Equal]", "0"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"V", "'"}], "[", "r", "]"}], ",", 
         RowBox[{
          RowBox[{"M", "'"}], "[", "r", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Phi]0", "''"}], "[", "r", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9293034571944857`*^9, 3.929303497117684*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"07f22f7a-ea66-4548-9b4d-0a25953586ae"],

Cell["\<\
We are now able to integrate the equation. Let us start with the homogeneous \
system.\
\>", "Text",
 CellChangeTimes->{{3.92930318243312*^9, 3.9293032001157656`*^9}, {
  3.9293035037169275`*^9, 
  3.929303504684022*^9}},ExpressionUUID->"5bb541a8-791e-4eef-9b07-\
d1dc086c1a26"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating the homogeneous system", "Subsubsection",
 CellChangeTimes->{{3.9293032107375164`*^9, 
  3.9293032155647516`*^9}},ExpressionUUID->"b67787ca-dca5-4a02-83dd-\
a72142ff01f6"],

Cell["\<\
To obtain the homogeneous matrix, we integrate three times from the origin \
and three times from the infinity. First we define the integrations as \
functions of the amplitudes\
\>", "Text",
 CellChangeTimes->{{3.929303217918003*^9, 3.929303248205279*^9}, {
  3.9293035078250914`*^9, 3.9293035084938097`*^9}, {3.929332147099522*^9, 
  3.929332163750059*^9}},ExpressionUUID->"d9891260-7ef9-468b-8150-\
fe3a94d6b40c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"INT", "[", 
   RowBox[{
   "g01_", ",", "g02_", ",", "g03_", ",", "g11_", ",", "g12_", ",", "g13_", 
    ",", "L0_", ",", "m0_", ",", "r01_", ",", "rp0_", ",", "r02_", ",", 
    "rules_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Integrating", " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"paramint2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"MaxSteps", "\[Rule]", "\[Infinity]"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<StiffnessSwitching\>\""}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "10"}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "10"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"paramp", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Omega]", "\[Rule]", "\[Omega]s"}], ",", 
       RowBox[{"\[Sigma]", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"m0", " ", "\[CapitalOmega]0"}], "/.", "rules"}], "/.", 
          RowBox[{"r", "\[Rule]", "rp0"}]}], ")"}]}], ",", 
       RowBox[{"L", "\[Rule]", "L0"}], ",", 
       RowBox[{"m", "\[Rule]", "m0"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Defining", " ", "the", " ", "equations"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"EQSP", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"EQHOM", "\[Equal]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]}], 
        "]"}], "/.", "paramp"}], "/.", "rules"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Integrations", " ", "from", " ", "the", " ", "origin"}], "*)"}],
     "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"boundary", " ", "conditions"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"BOU", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"H0", "[", "r", "]"}], ",", 
             RowBox[{"H1", "[", "r", "]"}], ",", 
             RowBox[{"Kp", "[", "r", "]"}], ",", 
             RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
             RowBox[{
              RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
             RowBox[{"\[Phi]2", "[", "r", "]"}], ",", 
             RowBox[{
              RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}]}], "}"}], "\[Equal]", 
           "BOUNOR"}], "]"}], "/.", 
         RowBox[{
          SubscriptBox["Vi", "0"], "\[Rule]", "scal"}]}], "/.", "paramp"}], "/.", 
       RowBox[{"r", "\[Rule]", "r01"}]}], "/.", "rules"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", "integration", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"SOL1", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{"EQSP", ",", "BOU"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["kp", "0"], "\[Rule]", "g01"}], ",", 
           RowBox[{
            SubscriptBox["\[Phi]1i", "0"], "\[Rule]", "g02"}], ",", 
           RowBox[{
            SubscriptBox["\[Phi]2i", "0"], "\[Rule]", "g03"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"Kp", ",", "H0", ",", "H1", ",", "\[Phi]1", ",", "\[Phi]2"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r01", ",", "rp0"}], "}"}], ",", "paramint2"}], 
       "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Integrations", " ", "from", " ", "infinity"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"To", " ", "improve", " ", "boundary", " ", 
      RowBox[{"conditions", ".", " ", "We"}], " ", "first", " ", "integrate", 
      " ", "from", " ", "the", " ", "vacuum", " ", "region"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"for", " ", "the", " ", "gravitational", " ", 
      RowBox[{"part", ".", " ", "We"}], " ", "left", " ", "the", " ", 
      "scalar", " ", "and", " ", "gravitational", " ", "parts", " ", 
      "separately", " ", "as", " ", "scales", " ", "can", " ", "be", " ", 
      "different"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"EQSVACG", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"EQSVAC", "[", 
          RowBox[{"[", 
           RowBox[{"1", ";;", "3"}], "]"}], "]"}], "\[Equal]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], "/.", "paramp"}],
       "/.", "rules"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"BOUVACG", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"H0", "[", "r", "]"}], ",", 
             RowBox[{"H1", "[", "r", "]"}], ",", 
             RowBox[{"Kp", "[", "r", "]"}]}], "}"}], "==", "BOUGRAV"}], "]"}],
          "/.", "paramp"}], "/.", 
        RowBox[{"r", "\[Rule]", "r02"}]}], "/.", 
       RowBox[{
        SubscriptBox["kpi", "0"], "\[Rule]", "g11"}]}], "/.", "rules"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"SOLGV", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"EQSVACG", ",", "BOUVACG"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"H0", ",", "H1", ",", "Kp"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r02", ",", 
          RowBox[{"rinf", "/.", "rules"}]}], "}"}], ",", "paramint2"}], "]"}],
       "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"BOUGI", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H0", "[", 
         RowBox[{"rinf", "/.", "rules"}], "]"}], "\[Equal]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"H0", "[", 
           RowBox[{"rinf", "/.", "rules"}], "]"}], "/.", "SOLGV"}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"H1", "[", 
         RowBox[{"rinf", "/.", "rules"}], "]"}], "\[Equal]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"H1", "[", 
           RowBox[{"rinf", "/.", "rules"}], "]"}], "/.", "SOLGV"}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"Kp", "[", 
         RowBox[{"rinf", "/.", "rules"}], "]"}], "\[Equal]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Kp", "[", 
           RowBox[{"rinf", "/.", "rules"}], "]"}], "/.", "SOLGV"}], ")"}]}]}],
       "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"for", " ", "the", " ", "scalar", " ", 
       RowBox[{"part", ".", " ", "There"}], " ", "are", " ", "a", " ", 
       "bunch", " ", "of", " ", "Ifs"}], ",", " ", 
      RowBox[{
      "to", " ", "account", " ", "for", " ", "different", " ", "values", " ", 
       "of", " ", "the", " ", "frequency"}]}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"EQSVACS", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{
         RowBox[{"EQSVAC", "[", 
          RowBox[{"[", 
           RowBox[{"4", ";;", "5"}], "]"}], "]"}], "\[Equal]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "]"}], "/.", "paramp"}], "/.", 
      "rules"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"1", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"]}], ">", "0"}], 
        "/.", "paramp"}], "/.", "rules"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"BOUSI", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                "\[Phi]1infm"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                "d\[Phi]1infm"}], ",", 
               RowBox[{
                RowBox[{"\[Phi]2", "[", "r", "]"}], "\[Equal]", 
                "\[Phi]2infm"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}], "\[Equal]", 
                "d\[Phi]2infm"}]}], "}"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
               RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
            RowBox[{"r", "->", "rinf"}]}], "/.", "paramp"}], "/.", "rules"}], 
         "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Phi]01", "\[Rule]", "g12"}], ",", 
           RowBox[{"\[Phi]02", "\[Rule]", "g13"}]}], "}"}]}]}], ";"}], 
      "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"1", "-", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], "2"]}], ">", 
            "0"}], "/.", "paramp"}], "/.", "rules"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"BOUSIi", "=", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                   "\[Phi]1infp"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                   "d\[Phi]1infp"}]}], "}"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
                  RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
               RowBox[{"r", "\[Rule]", "r02"}]}], "/.", "paramp"}], "/.", 
             "rules"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Phi]01", "\[Rule]", "g12"}], ",", 
              RowBox[{"\[Phi]02", "\[Rule]", "g13"}]}], "}"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"S\[Phi]1", "=", 
           RowBox[{
            RowBox[{"NDSolve", "[", 
             RowBox[{
              RowBox[{"Join", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"EQSVACS", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "}"}], ",", "BOUSIi"}], 
               "]"}], ",", "\[Phi]1", ",", 
              RowBox[{"{", 
               RowBox[{"r", ",", "r02", ",", 
                RowBox[{"rinf", "/.", "rules"}]}], "}"}], ",", "paramint2"}], 
             "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"BOUSI", "=", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Phi]1", "[", "r", "]"}], "/.", "S\[Phi]1"}], 
                    ")"}]}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "/.", 
                    "S\[Phi]1"}], ")"}]}], ",", 
                  RowBox[{
                   RowBox[{"\[Phi]2", "[", "r", "]"}], "\[Equal]", 
                   "\[Phi]2infm"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}], "\[Equal]", 
                   "d\[Phi]2infm"}]}], "}"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
                  RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
               RowBox[{"r", "->", "rinf"}]}], "/.", "paramp"}], "/.", 
             "rules"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Phi]01", "\[Rule]", "g12"}], ",", 
              RowBox[{"\[Phi]02", "\[Rule]", "g13"}]}], "}"}]}]}], ";"}], 
         "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"BOUSIi", "=", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                   "\[Phi]1infp"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                   "d\[Phi]1infp"}], ",", 
                  RowBox[{
                   RowBox[{"\[Phi]2", "[", "r", "]"}], "\[Equal]", 
                   "\[Phi]2infp"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                   "d\[Phi]2infp"}]}], "}"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
                  RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
               RowBox[{"r", "\[Rule]", "r02"}]}], "/.", "paramp"}], "/.", 
             "rules"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Phi]01", "\[Rule]", "g12"}], ",", 
              RowBox[{"\[Phi]02", "\[Rule]", "g13"}]}], "}"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"S\[Phi]1", "=", 
           RowBox[{
            RowBox[{"NDSolve", "[", 
             RowBox[{
              RowBox[{"Join", "[", 
               RowBox[{"EQSVACS", ",", "BOUSIi"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"\[Phi]1", ",", "\[Phi]2"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"r", ",", "r02", ",", 
                RowBox[{"rinf", "/.", "rules"}]}], "}"}], ",", "paramint2"}], 
             "]"}], "[", 
            RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"BOUSI", "=", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", "1"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                   RowBox[{"(", 
                    RowBox[{
                    FractionBox[
                    RowBox[{
                    RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], 
                    RowBox[{"\[Phi]1", "[", "r", "]"}]], "/.", "S\[Phi]1"}], 
                    ")"}]}], ",", 
                  RowBox[{
                   RowBox[{"\[Phi]2", "[", "r", "]"}], "\[Equal]", "1"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}], "\[Equal]", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}], 
                    RowBox[{"\[Phi]2", "[", "r", "]"}]]}], "/.", 
                   "S\[Phi]1"}]}], "}"}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
                  RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
               RowBox[{"r", "->", "rinf"}]}], "/.", "paramp"}], "/.", 
             "rules"}], "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"\[Phi]01", "\[Rule]", "g12"}], ",", 
              RowBox[{"\[Phi]02", "\[Rule]", "g13"}]}], "}"}]}]}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "Now", " ", "we", " ", "can", " ", "finally", " ", "integrate", " ", 
      "inside", " ", "the", " ", "star", " ", "up", " ", "to", " ", "the", 
      " ", 
      RowBox[{"particle", "'"}], "s", " ", "position"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"BOUINF", "=", 
     RowBox[{"Join", "[", 
      RowBox[{"BOUGI", ",", "BOUSI"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"SOL2", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"EQSP", ",", "BOUINF"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"H0", ",", "H1", ",", "Kp", ",", "\[Phi]1", ",", "\[Phi]2"}],
          "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", 
          RowBox[{"rinf", "/.", "rules"}], ",", "rp0"}], "}"}], ",", 
        "paramint2"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.9293321735191293`*^9, 3.929332188272459*^9}, {
   3.929332366961613*^9, 3.929332463937969*^9}, {3.929332568985113*^9, 
   3.9293325730069304`*^9}, {3.929333308287141*^9, 3.929333424256067*^9}, {
   3.9293334747519255`*^9, 3.929333536008857*^9}, {3.9293345735165076`*^9, 
   3.929334603357423*^9}, {3.929334633415614*^9, 3.929334663396658*^9}, {
   3.929334698161705*^9, 3.9293347545373325`*^9}, {3.92933485238332*^9, 
   3.9293348533522973`*^9}, {3.929334898322174*^9, 3.9293353863499556`*^9}, {
   3.9293354303153057`*^9, 3.9293357077403345`*^9}, {3.929335862009441*^9, 
   3.9293359571370525`*^9}, {3.9293360451401944`*^9, 
   3.9293361775997562`*^9}, {3.9293362481944113`*^9, 3.929336334255066*^9}, {
   3.929336568245969*^9, 3.929336865128681*^9}, {3.929336952543502*^9, 
   3.929337017284218*^9}, {3.929337053452876*^9, 3.929337163226738*^9}, {
   3.929337201757922*^9, 3.9293372042354155`*^9}, {3.9293372820784197`*^9, 
   3.9293373245631943`*^9}, {3.929337382982788*^9, 3.9293375690242195`*^9}, {
   3.9293376095454226`*^9, 3.9293376113919687`*^9}, {3.929338057621595*^9, 
   3.9293380580381327`*^9}, 3.9293383709663477`*^9, 3.929339296549758*^9, {
   3.92934037017126*^9, 3.929340377016081*^9}, {3.9293634247685213`*^9, 
   3.929363429375661*^9}, {3.9293641069731445`*^9, 3.929364113383202*^9}, {
   3.929364325166173*^9, 3.9293643778943357`*^9}, {3.9293644664064646`*^9, 
   3.929364479157464*^9}, {3.9293645155503902`*^9, 3.9293645212871923`*^9}, {
   3.929368864523243*^9, 3.9293688651211615`*^9}, {3.929377705742117*^9, 
   3.9293777532956767`*^9}, 3.929407751078015*^9, 3.929774076481661*^9},
 CellLabel->"In[90]:=",ExpressionUUID->"a1230d2b-b2e5-4a9c-838c-2d004a704927"],

Cell["\<\
With the integrator above, we can construct the fundamental matrix\
\>", "Text",
 CellChangeTimes->{{3.9293376291114826`*^9, 
  3.929337640641464*^9}},ExpressionUUID->"a9c5b71d-8550-4a7f-8b6f-\
3970c5ff50b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MATRIX", "[", 
   RowBox[{
   "L0_", ",", "m0_", ",", "r01_", ",", "rp0_", ",", "r02_", ",", "rules_"}], 
   "]"}], ":=", 
  RowBox[{"(", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"INT", "[", 
     RowBox[{
     "1", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "L0", ",", 
      "m0", ",", "r01", ",", "rp0", ",", "r02", ",", "rules"}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]1", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL1"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]2", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL2"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"INT", "[", 
     RowBox[{
     "0", ",", "1", ",", "0", ",", "0", ",", "1", ",", "0", ",", "L0", ",", 
      "m0", ",", "r01", ",", "rp0", ",", "r02", ",", "rules"}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]3", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL1"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]4", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL2"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"INT", "[", 
     RowBox[{
     "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "1", ",", "L0", ",", 
      "m0", ",", "r01", ",", "rp0", ",", "r02", ",", "rules"}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]5", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL1"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]6", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL2"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"For", " ", "the", " ", "Matrix"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"XS", "=", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[CapitalPsi]1", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]2", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]3", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]4", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]5", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]6", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], "/.", 
      RowBox[{"r", "\[Rule]", "rp0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"dXS", "=", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"XS", ",", "r"}], "]"}], "/.", 
      RowBox[{"r", "\[Rule]", "rp0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"invXS", "=", 
     RowBox[{"Inverse", "[", "XS", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"dinvXS", "=", 
     RowBox[{"-", 
      RowBox[{"invXS", ".", "dXS", ".", "invXS"}]}]}], ";"}], 
   "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.9293376434735155`*^9, 3.9293377283061543`*^9}, {
  3.929337766271801*^9, 3.929337845122262*^9}, {3.929337876111882*^9, 
  3.9293380065407505`*^9}, {3.929338102552593*^9, 3.929338109157919*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"b2e9d75b-a3f8-47b4-9b31-6676fbf56e33"],

Cell["\<\
With the above and the source term we can construct the particular solution \
to find the fluxes\
\>", "Text",
 CellChangeTimes->{{3.9293381629393234`*^9, 3.9293381803307867`*^9}, {
  3.929378156077294*^9, 
  3.9293781568939595`*^9}},ExpressionUUID->"f784fac5-90a1-4205-b72e-\
a315d517a506"]
}, Closed]],

Cell[CellGroupData[{

Cell["Using the variation of parameters to find the fluxes", "Subsubsection",
 CellChangeTimes->{{3.9293381889079776`*^9, 
  3.9293382007169466`*^9}},ExpressionUUID->"6df26a84-fd1c-4752-8373-\
c6e9bdd9fc92"],

Cell["\<\
The flux can be computed by making the matrix product of the inverse of X \
with the source term and integrating it. Because of the deltas and \
derivatives, what remains is to compute it at the particle position\
\>", "Text",
 CellChangeTimes->{{3.9293670986276536`*^9, 3.92936709981993*^9}, {
  3.929367200381386*^9, 3.9293672048165307`*^9}, {3.929378158481496*^9, 
  3.9293782099901733`*^9}},ExpressionUUID->"e0677950-e79b-4427-8021-\
82990c70d048"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FLUXP", "[", 
   RowBox[{
   "l0_", ",", "m0_", ",", "r01_", ",", "rp0_", ",", "r02_", ",", "rules_"}], 
   "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MATRIX", "[", 
     RowBox[{
     "l0", ",", "m0", ",", "r01", ",", "rp0", ",", "r02", ",", "rules"}], 
     "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"param", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"paramp", ",", 
       RowBox[{"{", 
        RowBox[{"m", "\[Rule]", "m0"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"EvenQ", "[", 
        RowBox[{"l0", "+", "m0"}], "]"}], "==", "True"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rulesY", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Yp", "[", "\[Chi]p", "]"}], "\[Rule]", 
           RowBox[{"SphericalHarmonicY", "[", 
            RowBox[{"l0", ",", "m0", ",", 
             RowBox[{"\[Pi]", "/", "2"}], ",", "0"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Yp", "'"}], "[", "\[Chi]p", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Yp", "''"}], "[", "\[Chi]p", "]"}], "\[Rule]", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"SphericalHarmonicY", "[", 
               RowBox[{"l0", ",", "m0", ",", "\[Theta]", ",", "0"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\[Theta]", ",", "2"}], "}"}]}], "]"}]}], "/.", 
           RowBox[{"\[Theta]", "\[Rule]", 
            RowBox[{"\[Pi]", "/", "2"}]}]}]}], "}"}]}], ";"}], 
      "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rulesY", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Yp", "'"}], "[", "\[Chi]p", "]"}], "\[Rule]", 
            RowBox[{"-", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"SphericalHarmonicY", "[", 
                RowBox[{"l0", ",", "m0", ",", "\[Theta]", ",", "0"}], "]"}], 
               ",", "\[Theta]"}], "]"}]}]}], "/.", 
           RowBox[{"\[Theta]", "\[Rule]", 
            RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
          RowBox[{
           RowBox[{"Yp", "[", "\[Chi]p", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Yp", "''"}], "[", "\[Chi]p", "]"}], "\[Rule]", "0"}]}], 
         "}"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"II", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"invXS", ".", "SOURCED"}], ")"}], "/.", 
        RowBox[{"Union", "[", 
         RowBox[{"param", ",", "rulesY", ",", "rules"}], "]"}]}], "/.", 
       RowBox[{"r", "\[Rule]", "rp0"}]}], "/.", 
      RowBox[{"\[Chi]p", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"dII", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"invXS", ".", "dSOURCEDD"}], "+", 
           RowBox[{"dinvXS", ".", "SOURCEDD"}]}], ")"}]}], "/.", 
        RowBox[{"Union", "[", 
         RowBox[{"param", ",", "rulesY", ",", "rules"}], "]"}]}], "/.", 
       RowBox[{"r", "\[Rule]", "rp0"}]}], "/.", 
      RowBox[{"\[Chi]p", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"IIg", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"II", "+", "dII"}], ")"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"II\[Phi]1", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"II", "+", "dII"}], ")"}], "[", 
      RowBox[{"[", "4", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"II\[Phi]2", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"II", "+", "dII"}], ")"}], "[", 
      RowBox[{"[", "6", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Computing", " ", "the", " ", "fluxes"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"GravFlux", "=", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{"32", "\[Pi]"}]], 
       SuperscriptBox["\[Sigma]", "2"], 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"l0", "+", "2"}], ")"}], "!"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"l0", "-", "2"}], ")"}], "!"}]], 
       SuperscriptBox[
        RowBox[{"Abs", "[", "IIg", " ", "]"}], "2"]}], "/.", "param"}]}], ";",
     "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Omega]", "+", 
              RowBox[{"m0", " ", "\[CapitalOmega]0"}]}], ")"}], "2"], "/.", 
           "paramp"}], "/.", "rules"}], "/.", 
         RowBox[{"r", "\[Rule]", "rp0"}]}], ")"}], "\[GreaterEqual]", "1"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Phi]f1", "=", "II\[Phi]1"}], " ", ";"}], 
      "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Phi]f1", "=", "0"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"ScalFlux", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]], 
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "-", "1"}]], 
        SuperscriptBox[
         RowBox[{"Abs", "[", "\[Phi]f1", "]"}], "2"]}], "/.", "paramp"}], "/.",
       "rules"}]}], ";", 
    RowBox[{"QSFlux", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]], 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "-", "1"}]], 
        SuperscriptBox[
         RowBox[{"Abs", "[", "\[Phi]f1", "]"}], "2"]}], "/.", "paramp"}], "/.",
       "rules"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"ScalFluxM2", "=", 
     RowBox[{
      RowBox[{"2", 
       SuperscriptBox["Mt", "2"], " ", "ScalFlux"}], "/.", "rules"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"ScalQM2", "=", 
     RowBox[{
      RowBox[{"2", 
       SuperscriptBox["Mt", "2"], " ", "QSFlux"}], "/.", "rules"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"GravFluxM2", "=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Mt", "2"], "GravFlux"}], "/.", "rules"}]}], ";"}], 
   "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.929338289527746*^9, 3.929338315339635*^9}, {
   3.9293384197855415`*^9, 3.9293384577761526`*^9}, {3.929338611700952*^9, 
   3.9293386138132067`*^9}, {3.9293386669887347`*^9, 3.92933866866003*^9}, {
   3.9293387044652863`*^9, 3.9293387084473004`*^9}, {3.929338895355666*^9, 
   3.9293388955157614`*^9}, 3.9293655945357094`*^9, {3.9293662396862564`*^9, 
   3.929366351772291*^9}, {3.9293678887572613`*^9, 3.9293678902406263`*^9}, {
   3.9293680297342386`*^9, 3.9293680311952095`*^9}, {3.9293686926192536`*^9, 
   3.9293686969912214`*^9}, {3.929698303700062*^9, 3.929698309597985*^9}, {
   3.9296985709758277`*^9, 3.9296985713594947`*^9}, {3.9297009092228394`*^9, 
   3.9297009706261063`*^9}, {3.9297050352195654`*^9, 
   3.9297050375140047`*^9}, {3.929705082902956*^9, 3.929705100256337*^9}, {
   3.9297055513395762`*^9, 3.9297055607954574`*^9}, {3.9297057674959016`*^9, 
   3.9297057728619375`*^9}, 3.9297058284888983`*^9, {3.9297058626674376`*^9, 
   3.9297058663926764`*^9}, {3.929705946356805*^9, 3.9297059647914762`*^9}, 
   3.9297060034880524`*^9, 3.9297066003571596`*^9, {3.9297067047018776`*^9, 
   3.9297067498800783`*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"16c5713b-7e2e-41ca-85d6-b4927f5fb2e9"],

Cell["\<\
So you can compare now with the plot in Fig. 1 of the the supplemental \
material of https://arxiv.org/abs/2312.06767 \
\>", "Text",
 CellChangeTimes->{{3.929368890866228*^9, 3.9293689002432227`*^9}, {
  3.929377577497222*^9, 3.9293775781136913`*^9}, {3.929378351757225*^9, 
  3.9293783677050233`*^9}, {3.929378409109925*^9, 3.9293784325116196`*^9}, {
  3.929782426976737*^9, 
  3.9297824273012104`*^9}},ExpressionUUID->"642dcd08-db3a-4597-b10f-\
7c9d59385ad8"],

Cell[TextData[{
 "The limit for the scalar flux is given by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["w1", "2"], "=", "0"}], TraditionalForm]],ExpressionUUID->
  "c3645516-91bf-4d1b-a520-266767c99963"]
}], "Text",
 CellChangeTimes->{{3.9293784921716266`*^9, 
  3.929378511843335*^9}},ExpressionUUID->"1fd49b98-aca8-49ee-9e63-\
495c64b99fdd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["r", 
   RowBox[{"Mt", "/.", "rubkg"}]], "/.", 
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"1", "-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[CapitalOmega]0"}], "+", "\[Omega]"}], ")"}], 
        "2"]}], "\[Equal]", "0"}], "/.", "rubkg"}], ",", 
    RowBox[{"{", 
     RowBox[{"r", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.9297282125038304`*^9, 3.929728265325573*^9}, {
  3.9297282968559494`*^9, 3.9297282986624904`*^9}, {3.929762015078913*^9, 
  3.9297620628279853`*^9}, {3.929774084371025*^9, 3.929774096519755*^9}, {
  3.9297835553199797`*^9, 3.9297835608446617`*^9}, {3.9324691461601048`*^9, 
  3.932469158386943*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"e632f95c-5b9e-48a8-8bf8-1cb8c921f8a1"],

Cell[BoxData["7.3594679239283165`"], "Output",
 CellChangeTimes->{{3.9297282128423986`*^9, 3.9297282146261034`*^9}, {
   3.929728254149225*^9, 3.9297282656622977`*^9}, {3.9297282972789907`*^9, 
   3.929728298903483*^9}, {3.9297620440744233`*^9, 3.929762063648357*^9}, 
   3.929762115594101*^9, 3.9297623649098186`*^9, 3.9297624159105043`*^9, 
   3.9297624797656074`*^9, 3.9297740968539195`*^9, {3.9297835506331515`*^9, 
   3.929783561297818*^9}, {3.9324691589874415`*^9, 3.932469181807065*^9}},
 CellLabel->"Out[94]=",ExpressionUUID->"b6242cd6-4744-4bd0-9966-fd0b383ddda9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"tflux2", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xx", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"FLUXP", "[", 
            RowBox[{"2", ",", "2", ",", 
             SuperscriptBox["10", 
              RowBox[{"-", "3"}]], ",", 
             RowBox[{
              RowBox[{"xx", " ", "Mt"}], "//.", "rubkg"}], ",", "600", ",", 
             "rubkg"}], "]"}], "//", "Quiet"}], ";", "ScalQM2"}], ",", 
         "ScalFluxM2", ",", "GravFluxM2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"xx", ",", "0.01", ",", "7.4", ",", "0.1"}], "}"}]}], "]"}], 
     ",", "xx"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.9293784221100616`*^9, {3.929378452385352*^9, 3.929378487599452*^9}, {
   3.929378570083909*^9, 3.9293785872424045`*^9}, {3.9296981467710514`*^9, 
   3.9296981600657425`*^9}, {3.929698439499327*^9, 3.9296984429744987`*^9}, {
   3.9297011190479045`*^9, 3.9297011274330397`*^9}, {3.929706782624129*^9, 
   3.92970679251816*^9}, 3.9297084304455066`*^9, {3.929708474354906*^9, 
   3.929708474747869*^9}, {3.929728274260706*^9, 3.9297282827717104`*^9}, {
   3.9297623775817547`*^9, 3.9297623874664383`*^9}, {3.9297624335812087`*^9, 
   3.929762475255822*^9}, 3.929762510202894*^9, {3.9297625976183805`*^9, 
   3.929762629569219*^9}, {3.929774104608836*^9, 3.929774162376445*^9}, {
   3.9297762907840014`*^9, 3.9297763047183723`*^9}, {3.929776367809529*^9, 
   3.929776400220727*^9}, {3.929783568356598*^9, 3.929783574692551*^9}, 
   3.929783613341606*^9, {3.9324691897707677`*^9, 3.9324691940309925`*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"a43b4504-688f-4964-b6a9-6ee3ef94cdf1"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.9324693159398165`*^9},
 CellLabel->"Out[95]=",ExpressionUUID->"dd209bf5-1511-4341-bb73-41f712a81815"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Beep", "[", "]"}]], "Input",
 CellChangeTimes->{{3.93246919883433*^9, 
  3.932469200831957*^9}},ExpressionUUID->"284c4e86-fafc-4391-94cd-\
6c0aa6aef799"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1902, 966},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>1.3 Inherited,
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 196, 3, 37, "Input",ExpressionUUID->"5eabe3ca-11f0-4ce6-8804-d967e41bc368"],
Cell[CellGroupData[{
Cell[779, 27, 351, 7, 206, "Title",ExpressionUUID->"14d7fb90-fe0a-4865-b7df-e69fb8f5009f"],
Cell[1133, 36, 361, 9, 37, "Input",ExpressionUUID->"eae332e9-1963-468e-9c8a-2308583eb3a2"],
Cell[1497, 47, 244, 6, 44, "Text",ExpressionUUID->"2fe70975-9ee1-4638-a9df-7f1e8e2b4269"],
Cell[CellGroupData[{
Cell[1766, 57, 182, 3, 84, "Section",ExpressionUUID->"f4ea5f2e-aa29-430f-8578-b770ed4148e2"],
Cell[CellGroupData[{
Cell[1973, 64, 215, 4, 58, "Subsubsection",ExpressionUUID->"f6e5c295-8482-44a5-a551-5a2a76549749"],
Cell[2191, 70, 1050, 30, 137, "Text",ExpressionUUID->"8b4750ff-2197-4f67-9c3e-7a89be4400bb"],
Cell[3244, 102, 3406, 102, 191, "Input",ExpressionUUID->"e1880841-24cc-4cae-b8e9-325b9064d94f"],
Cell[6653, 206, 457, 8, 44, "Text",ExpressionUUID->"a0624733-4ecc-4359-b2a6-601f9f46e3d3"],
Cell[7113, 216, 260, 5, 37, "Input",ExpressionUUID->"f6e01616-10d4-46fe-a1c6-54f0fcc29d36"],
Cell[7376, 223, 1562, 44, 108, "Input",ExpressionUUID->"a1c63b01-86f0-4fdb-888c-bf24235333cf"],
Cell[8941, 269, 191, 3, 44, "Text",ExpressionUUID->"d3be96c5-693c-470d-b376-544af8772911"],
Cell[CellGroupData[{
Cell[9157, 276, 1559, 41, 42, "Input",ExpressionUUID->"a43dc386-a53b-4b48-be3c-ef3f91e39b17"],
Cell[10719, 319, 9209, 260, 70, "Output",ExpressionUUID->"b19aae06-5b84-401e-86e2-2bc627b3cbf0"]
}, Open  ]],
Cell[19943, 582, 225, 5, 44, "Text",ExpressionUUID->"05300666-11d5-4d92-8823-838f19fcbccb"],
Cell[20171, 589, 492, 13, 37, "Input",ExpressionUUID->"57ffd28c-7a55-443c-8248-3ed515c80611"],
Cell[20666, 604, 274, 5, 37, "Input",ExpressionUUID->"3dc87e96-66ab-4f49-9e4e-413980dc70e7"],
Cell[20943, 611, 221, 3, 44, "Text",ExpressionUUID->"1af02619-a71b-4478-98bf-849ee767fd29"]
}, Closed]],
Cell[CellGroupData[{
Cell[21201, 619, 193, 3, 46, "Subsubsection",ExpressionUUID->"6a305c5a-d0c6-4b1c-9c1f-c3aacc4df08e"],
Cell[21397, 624, 1066, 28, 87, "Text",ExpressionUUID->"dbc38347-e4fc-447e-8b43-906ba1d0ff68"],
Cell[22466, 654, 5640, 145, 797, "Input",ExpressionUUID->"276e9363-6de0-4957-a8a1-d2d14d5733ea"],
Cell[28109, 801, 420, 8, 73, "Text",ExpressionUUID->"d96ffe01-a0c3-43ae-9d7e-f40613916870"]
}, Closed]],
Cell[CellGroupData[{
Cell[28566, 814, 298, 4, 46, "Subsubsection",ExpressionUUID->"c1edfb44-ab40-4592-b092-fd3dd0318b88"],
Cell[28867, 820, 246, 6, 44, "Text",ExpressionUUID->"93ae8fd2-b220-4935-8434-9dbad2689ace"],
Cell[29116, 828, 688, 10, 37, "Input",ExpressionUUID->"ed3798b7-7b02-432c-914b-301c44bbf0d6"],
Cell[29807, 840, 256, 4, 44, "Text",ExpressionUUID->"2e6bffb1-2032-4492-ac35-464629041cf2"],
Cell[CellGroupData[{
Cell[30088, 848, 1261, 21, 63, "Input",ExpressionUUID->"d0b409fa-d7fa-4c4b-9086-9a903f532ce7"],
Cell[31352, 871, 1764, 25, 43, "Output",ExpressionUUID->"fd14f4f5-2bc8-4bad-b63f-675e75b63994"],
Cell[33119, 898, 1714, 23, 43, "Output",ExpressionUUID->"261d1d53-3af3-43ca-8330-5c78da6ff627"]
}, Open  ]],
Cell[34848, 924, 188, 3, 44, "Text",ExpressionUUID->"b3a17776-7ec5-4416-aff9-cc0d8392fcc4"],
Cell[CellGroupData[{
Cell[35061, 931, 856, 17, 57, "Input",ExpressionUUID->"e0479117-1ef8-49cf-ad00-1c2ddd1c1618"],
Cell[35920, 950, 9391, 182, 303, "Output",ExpressionUUID->"9c8c7016-d004-43d2-8761-246fbd813842"]
}, Open  ]],
Cell[45326, 1135, 334, 7, 44, "Text",ExpressionUUID->"cfc2967d-602d-457b-8007-321396a3b4cf"],
Cell[45663, 1144, 2222, 56, 63, "Input",ExpressionUUID->"1baeed4e-bcd7-4206-af8c-ee9a78badefe"]
}, Closed]],
Cell[CellGroupData[{
Cell[47922, 1205, 363, 6, 46, "Subsubsection",ExpressionUUID->"55e2bc1b-a103-43d7-8b4a-a4ca829f07be"],
Cell[48288, 1213, 292, 7, 44, "Text",ExpressionUUID->"f7c79746-a2b9-40cb-a79e-96b57dead4e9"],
Cell[48583, 1222, 915, 14, 37, "Input",ExpressionUUID->"9fd772ab-2d2c-4a48-8105-3123e42f6f9c"],
Cell[49501, 1238, 210, 4, 44, "Text",ExpressionUUID->"9da8377d-0e89-4249-98f4-007d83c3d216"],
Cell[CellGroupData[{
Cell[49736, 1246, 1357, 23, 63, "Input",ExpressionUUID->"b482a5ec-3120-4d4d-a935-702f7be7ca7a"],
Cell[51096, 1271, 2351, 33, 43, "Output",ExpressionUUID->"51f55431-1720-49de-ade6-7ee8aab0c487"],
Cell[53450, 1306, 2299, 31, 43, "Output",ExpressionUUID->"929578c5-97ac-47d4-817c-6e7f026a4337"]
}, Open  ]],
Cell[55764, 1340, 188, 3, 44, "Text",ExpressionUUID->"df7d3653-af9a-430c-8d27-13999bceeb5b"],
Cell[CellGroupData[{
Cell[55977, 1347, 890, 18, 57, "Input",ExpressionUUID->"266335c1-1b63-4b6e-9a53-a984c82f8bb7"],
Cell[56870, 1367, 14591, 282, 302, "Output",ExpressionUUID->"f685955e-5adc-4393-b790-890e62827b80"]
}, Open  ]],
Cell[71476, 1652, 334, 7, 44, "Text",ExpressionUUID->"43f5cf93-e521-45dc-93e0-910d38daa684"],
Cell[71813, 1661, 1233, 19, 37, "Input",ExpressionUUID->"72fd347c-eb78-4920-aa15-e0d630bc1f46"],
Cell[73049, 1682, 1115, 30, 42, "Input",ExpressionUUID->"06e7661e-27f7-4980-b8d9-af65a26df786"],
Cell[74167, 1714, 3547, 89, 105, "Input",ExpressionUUID->"1c598405-7992-4659-b426-7c1a7ebee490"],
Cell[77717, 1805, 315, 7, 44, "Text",ExpressionUUID->"fc2541de-dac5-433c-9dfa-457d7601553b"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78081, 1818, 241, 4, 84, "Section",ExpressionUUID->"26003b34-4475-4a22-9176-303559d6c86a"],
Cell[CellGroupData[{
Cell[78347, 1826, 179, 3, 58, "Subsubsection",ExpressionUUID->"7b362fd0-bb14-4a49-9bdf-39254c4700c1"],
Cell[78529, 1831, 272, 6, 44, "Text",ExpressionUUID->"dfcd49d3-6bd6-4e87-bd1e-1a36e1343690"],
Cell[78804, 1839, 40505, 1084, 944, "Input",ExpressionUUID->"64318848-717e-436b-8c5b-a1e70b6db877"],
Cell[119312, 2925, 204, 3, 44, "Text",ExpressionUUID->"68313883-6e29-4f4b-98b9-f12c2799888a"],
Cell[119519, 2930, 1564, 46, 65, "Input",ExpressionUUID->"6ca7f2ef-1aff-4696-ab0b-a4c4cb051825"]
}, Closed]],
Cell[CellGroupData[{
Cell[121120, 2981, 198, 3, 46, "Subsubsection",ExpressionUUID->"7434d8a5-d7f1-46c5-aa3f-5dd16e974281"],
Cell[121321, 2986, 416, 11, 44, "Text",ExpressionUUID->"7060e732-5c4b-4841-9ddb-ea1a595b2f8e"],
Cell[121740, 2999, 335, 7, 37, "Input",ExpressionUUID->"727e51eb-15ed-47cd-82da-2ddf8a2826bb"],
Cell[122078, 3008, 169, 3, 44, "Text",ExpressionUUID->"c3cf7386-4cab-4839-8d54-88992211ecf4"],
Cell[122250, 3013, 3780, 116, 268, "Input",ExpressionUUID->"ba324767-3636-4725-8c11-b10d47bd5acf"],
Cell[126033, 3131, 1680, 37, 56, "Input",ExpressionUUID->"f2b81fd2-a27d-41ee-a8e0-f8651c847e21"],
Cell[127716, 3170, 1416, 33, 37, "Input",ExpressionUUID->"fd3ca2ff-4483-4d30-9081-d4b1c8266373"],
Cell[129135, 3205, 193, 3, 44, "Text",ExpressionUUID->"de5fb13e-3b83-41fc-a7a2-f0fe1cd7797c"],
Cell[129331, 3210, 656, 17, 37, "Input",ExpressionUUID->"b438c5c5-f14e-4b33-aa12-a5e713ff588b"],
Cell[129990, 3229, 337, 7, 37, "Input",ExpressionUUID->"8eebbb36-a422-4ee5-8402-7970b44f7cd4"]
}, Closed]],
Cell[CellGroupData[{
Cell[130364, 3241, 194, 3, 46, "Subsubsection",ExpressionUUID->"e2e68186-35ab-4cef-a1dc-ea2d89aaadcc"],
Cell[130561, 3246, 451, 9, 44, "Text",ExpressionUUID->"cee3e002-cac1-456a-8517-f287dc1f7bde"],
Cell[131015, 3257, 269, 6, 37, "Input",ExpressionUUID->"3277d677-9b2c-4589-a333-04f27978ef3f"],
Cell[131287, 3265, 316, 7, 44, "Text",ExpressionUUID->"8d7e7434-2438-4d6b-83ad-4a557f8fd5dd"],
Cell[131606, 3274, 732, 20, 55, "Input",ExpressionUUID->"142f7ba8-9840-4226-8f39-755263838a39"],
Cell[132341, 3296, 339, 7, 44, "Text",ExpressionUUID->"199fb3b0-7518-436b-a1ea-bce6c444f98b"],
Cell[132683, 3305, 706, 18, 79, "Input",ExpressionUUID->"062cb86a-ac9f-43fb-b0cd-07a87df5c062"],
Cell[133392, 3325, 2816, 80, 74, "Input",ExpressionUUID->"b97ac5a4-5309-4c63-8108-937c3306353b"],
Cell[136211, 3407, 4137, 99, 283, "Input",ExpressionUUID->"abf07497-742b-4110-bf38-c840e1be8d11"],
Cell[140351, 3508, 7350, 190, 304, "Input",ExpressionUUID->"228585c9-250a-4c14-aaf3-b4c4279a1c0c"],
Cell[147704, 3700, 327, 6, 37, "Input",ExpressionUUID->"33977e49-15b3-4f95-b85f-d4b0d7f22ac7"],
Cell[148034, 3708, 337, 7, 37, "Input",ExpressionUUID->"3db108f4-4fc4-4ff2-bae3-50579fb02e56"],
Cell[148374, 3717, 393, 7, 44, "Text",ExpressionUUID->"3e3e0063-a5c0-40c5-bb52-01bb4497a883"],
Cell[148770, 3726, 388, 8, 37, "Input",ExpressionUUID->"0ce35a37-f2bc-4d0f-8521-b679f2f3440b"],
Cell[149161, 3736, 183, 3, 44, "Text",ExpressionUUID->"6651286d-45d3-4786-9e11-9d5c2b7d3113"],
Cell[CellGroupData[{
Cell[149369, 3743, 1690, 51, 71, "Input",ExpressionUUID->"1010dac9-99e4-4b8e-a002-0b0e95d38cbb"],
Cell[151062, 3796, 3121, 84, 70, "Output",ExpressionUUID->"1d992997-734f-4eca-8728-17b0f05fc8db"]
}, Open  ]],
Cell[154198, 3883, 2390, 73, 286, "Input",ExpressionUUID->"a982b5b5-7a8a-41f6-9412-891ca3a08ba9"],
Cell[156591, 3958, 244, 4, 44, "Text",ExpressionUUID->"e91943ec-a39f-4828-87b1-b77280066a5f"],
Cell[156838, 3964, 8984, 247, 417, "Input",ExpressionUUID->"038f6354-9d39-47c0-b919-f494e33ee54d"],
Cell[165825, 4213, 522, 16, 50, "Input",ExpressionUUID->"78ac535d-5e28-4df6-afa8-adfdb0887021"],
Cell[166350, 4231, 252, 4, 44, "Text",ExpressionUUID->"b6602cc9-4fbd-48f5-a027-5a86c4f1ed7a"]
}, Closed]],
Cell[CellGroupData[{
Cell[166639, 4240, 229, 4, 46, "Subsubsection",ExpressionUUID->"4cb2f52a-88cf-4a5a-b305-b9bb2c999a0a"],
Cell[166871, 4246, 271, 6, 44, "Text",ExpressionUUID->"97ff5e11-defe-420c-88b6-67e0f74a272d"],
Cell[167145, 4254, 300, 6, 37, "Input",ExpressionUUID->"750793ea-9893-4f34-83bf-b332658061b1"],
Cell[167448, 4262, 2498, 72, 296, "Input",ExpressionUUID->"d8bf5323-e245-4262-8fdc-f468cbb4d98d"],
Cell[169949, 4336, 475, 12, 44, "Text",ExpressionUUID->"d80fe314-7c1e-4b3d-8f2d-5c7c27497277"],
Cell[170427, 4350, 908, 24, 72, "Input",ExpressionUUID->"6f01dd23-1fbd-4260-b661-9a6e79275c40"],
Cell[171338, 4376, 1745, 46, 42, "Input",ExpressionUUID->"29208c5a-093a-4f1a-bfb1-aef8e7523324"],
Cell[173086, 4424, 508, 9, 44, "Text",ExpressionUUID->"80d703f5-3b6f-46c8-b144-c28a665af398"],
Cell[173597, 4435, 1295, 34, 37, "Input",ExpressionUUID->"7a7d05a4-efda-4e50-9510-68aef78925ac"],
Cell[174895, 4471, 214, 5, 44, "Text",ExpressionUUID->"edfed9fa-0cbb-4ff3-b80f-237652aef9e6"],
Cell[175112, 4478, 1378, 43, 95, "Input",ExpressionUUID->"07f22f7a-ea66-4548-9b4d-0a25953586ae"],
Cell[176493, 4523, 288, 7, 44, "Text",ExpressionUUID->"5bb541a8-791e-4eef-9b07-d1dc086c1a26"]
}, Closed]],
Cell[CellGroupData[{
Cell[176818, 4535, 189, 3, 46, "Subsubsection",ExpressionUUID->"b67787ca-dca5-4a02-83dd-a72142ff01f6"],
Cell[177010, 4540, 426, 8, 44, "Text",ExpressionUUID->"d9891260-7ef9-468b-8150-fe3a94d6b40c"],
Cell[177439, 4550, 19191, 470, 1061, "Input",ExpressionUUID->"a1230d2b-b2e5-4a9c-838c-2d004a704927"],
Cell[196633, 5022, 218, 5, 44, "Text",ExpressionUUID->"a9c5b71d-8550-4a7f-8b6f-3970c5ff50b0"],
Cell[196854, 5029, 5439, 139, 413, "Input",ExpressionUUID->"b2e9d75b-a3f8-47b4-9b31-6676fbf56e33"],
Cell[202296, 5170, 301, 7, 44, "Text",ExpressionUUID->"f784fac5-90a1-4205-b72e-a315d517a506"]
}, Closed]],
Cell[CellGroupData[{
Cell[202634, 5182, 207, 3, 46, "Subsubsection",ExpressionUUID->"6df26a84-fd1c-4752-8373-c6e9bdd9fc92"],
Cell[202844, 5187, 462, 8, 44, "Text",ExpressionUUID->"e0677950-e79b-4427-8021-82990c70d048"],
Cell[203309, 5197, 8092, 211, 741, "Input",ExpressionUUID->"16c5713b-7e2e-41ca-85d6-b4927f5fb2e9"],
Cell[211404, 5410, 471, 9, 44, "Text",ExpressionUUID->"642dcd08-db3a-4597-b10f-7c9d59385ad8"],
Cell[211878, 5421, 360, 10, 44, "Text",ExpressionUUID->"1fd49b98-aca8-49ee-9e63-495c64b99fdd"],
Cell[CellGroupData[{
Cell[212263, 5435, 852, 21, 55, "Input",ExpressionUUID->"e632f95c-5b9e-48a8-8bf8-1cb8c921f8a1"],
Cell[213118, 5458, 573, 7, 43, "Output",ExpressionUUID->"b6242cd6-4744-4bd0-9966-fd0b383ddda9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[213728, 5470, 1744, 35, 42, "Input",ExpressionUUID->"a43b4504-688f-4964-b6a9-6ee3ef94cdf1"],
Cell[215475, 5507, 158, 2, 43, "Output",ExpressionUUID->"dd209bf5-1511-4341-bb73-41f712a81815"]
}, Open  ]],
Cell[215648, 5512, 177, 4, 37, "Input",ExpressionUUID->"284c4e86-fafc-4391-94cd-6c0aa6aef799"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

