(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    237050,       5861]
NotebookOptionsPosition[    225211,       5693]
NotebookOutlinePosition[    225584,       5709]
CellTagsIndexPosition[    225541,       5706]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.929254188367724*^9, 3.929254189715686*^9}},
 CellLabel->
  "In[296]:=",ExpressionUUID->"5eabe3ca-11f0-4ce6-8804-d967e41bc368"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["l>=2",
  FontSize->48],
 " flux computations from circular orbits around BHs with scalar clouds"
}], "Title",
 CellChangeTimes->{{3.9292470912226987`*^9, 3.9292471260487275`*^9}, {
  3.9294488703191133`*^9, 3.929448871846858*^9}, {3.92952681691618*^9, 
  3.9295268230803394`*^9}, {3.9324812937076883`*^9, 
  3.9324812990306053`*^9}},ExpressionUUID->"14d7fb90-fe0a-4865-b7df-\
e69fb8f5009f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"L", ">", "1"}], ",", 
     RowBox[{"Mt", ">", "0"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9293014353375697`*^9, 3.92930144433936*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"eae332e9-1963-468e-9c8a-2308583eb3a2"],

Cell["\<\
Reference: F. Duque, C. Macedo, R. Vicente and V.Cardoso. Physical Review \
Letters (in production) (2024) 2312.06767.\
\>", "Text",
 CellChangeTimes->{
  3.9324812425534086`*^9},ExpressionUUID->"e93812aa-d89a-404d-a916-\
d4a6fd22ac0b"],

Cell[CellGroupData[{

Cell["Computing boson star configurations", "Section",
 CellChangeTimes->{{3.9292471315111165`*^9, 
  3.929247171885967*^9}},ExpressionUUID->"f4ea5f2e-aa29-430f-8578-\
b770ed4148e2"],

Cell[CellGroupData[{

Cell["Organizing the equations and finding the boundary conditions", \
"Subsubsection",
 CellChangeTimes->{{3.9292484189839134`*^9, 
  3.929248427679536*^9}},ExpressionUUID->"f6e5c295-8482-44a5-a551-\
5a2a76549749"],

Cell[TextData[{
 "We start by computing the background configurations. Notice that you can \
export these solutions if you wish to save some time. We consider the metric \
as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "tt"], "=", 
    RowBox[{"V", "[", "r", "]"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "47d302a8-300a-4e16-a3b2-6bef90ccd41f"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "rr"], "=", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", 
        FractionBox[
         RowBox[{"M", "[", "r", "]"}], "r"]}]}], ")"}], 
     RowBox[{"-", "1"}]]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "678f32f6-a753-4751-81f4-6a9b68815585"],
 ". Everything is in units of \[Mu]=1\n\nThe background field equations are"
}], "Text",
 CellChangeTimes->{{3.9292471734112387`*^9, 3.929247204242113*^9}, {
  3.929247242101017*^9, 
  3.9292473373567815`*^9}},ExpressionUUID->"8b4750ff-2197-4f67-9c3e-\
7a89be4400bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eq1", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"M", "[", "r", "]"}], " ", 
          RowBox[{"V", "[", "r", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Omega]", "2"], "-", 
            RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["V", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "-", 
    RowBox[{"2", " ", "r", " ", 
     RowBox[{"V", "[", "r", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]0", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "2"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq2", "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["M", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], "-", 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"r", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Omega]", "2"], "+", 
            RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
         RowBox[{"V", "[", "r", "]"}]], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]0", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}]}]}], 
   ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq3", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[Omega]", "2"]}], "+", 
          RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"V", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "r"}], "+", 
          RowBox[{"M", "[", "r", "]"}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]0", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"V", "[", "r", "]"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[Phi]0", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.929247317223193*^9, 3.929247395324712*^9}, {
  3.9292474441867228`*^9, 3.929247456710218*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"e1880841-24cc-4cae-b8e9-325b9064d94f"],

Cell["\<\
Now to improve boundary conditions at the origin we perform an expansion. \
Notice that we shall use this in the expansion for the perturbation as well. \
We also integrate using coordinates such that V[0]=1.\
\>", "Text",
 CellChangeTimes->{{3.9292474632356615`*^9, 3.9292475048624787`*^9}, {
  3.929247598297689*^9, 3.929247615681966*^9}, {3.929247706895056*^9, 
  3.929247711812069*^9}},ExpressionUUID->"a0624733-4ecc-4359-b2a6-\
601f9f46e3d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"M", ",", "V", ",", "\[Phi]0"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.929247507986782*^9, 3.929247513560466*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"f6e01616-10d4-46fe-a1c6-54f0fcc29d36"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"M", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["Mi", "i"], " ", 
      SuperscriptBox["r", 
       RowBox[{"i", "+", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["Vi", "i"], 
      SuperscriptBox["r", "i"]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]0", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Phi]0i", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Phi]0i", "0"], "\[Rule]", "\[Phi]c"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.9292475159160953`*^9, 3.9292475338163395`*^9}, {
   3.9292476202750487`*^9, 3.929247649639064*^9}, {3.929247702865054*^9, 
   3.9292477048287163`*^9}, {3.9292478840323696`*^9, 3.929247939558627*^9}, {
   3.9292479788642426`*^9, 3.929248063121293*^9}, {3.929248143487468*^9, 
   3.92924814741041*^9}, {3.9292481859052343`*^9, 3.929248196800125*^9}, {
   3.92924828964904*^9, 3.9292482924941416`*^9}, 3.9292659305015554`*^9},
 CellLabel->"In[23]:=",ExpressionUUID->"a1c63b01-86f0-4fdb-888c-bf24235333cf"],

Cell["We solve the following equation near the origin", "Text",
 CellChangeTimes->{{3.929248254245061*^9, 
  3.9292482635819073`*^9}},ExpressionUUID->"d3be96c5-693c-470d-b376-\
544af8772911"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rubkgexp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"eq1", ",", 
           RowBox[{"eq2", " ", 
            SuperscriptBox["r", 
             RowBox[{"-", "1"}]]}], ",", 
           RowBox[{"eq3", " ", "r"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "5"}], "}"}]}], "]"}], "\[Equal]", 
       "0"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["Mi", "1"], ",", 
        SubscriptBox["Vi", "1"], ",", 
        SubscriptBox["\[Phi]0i", "1"], ",", 
        SubscriptBox["Mi", "2"], ",", 
        SubscriptBox["Vi", "2"], ",", 
        SubscriptBox["\[Phi]0i", "2"], ",", 
        SubscriptBox["Mi", "3"], ",", 
        SubscriptBox["Vi", "3"], ",", 
        SubscriptBox["\[Phi]0i", "3"], ",", 
        SubscriptBox["Mi", "4"], ",", 
        SubscriptBox["Vi", "4"], ",", 
        SubscriptBox["\[Phi]0i", "4"], ",", 
        SubscriptBox["Mi", "5"], ",", 
        SubscriptBox["Vi", "5"], ",", 
        SubscriptBox["\[Phi]0i", "5"], ",", 
        SubscriptBox["Mi", "6"], ",", 
        SubscriptBox["Vi", "6"], ",", 
        SubscriptBox["\[Phi]0i", "6"]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.9292480915563326`*^9, 3.9292481203392935`*^9}, {
  3.9292481710683517`*^9, 3.9292483320222607`*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"a43dc386-a53b-4b48-be3c-ef3f91e39b17"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["Mi", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Vi", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Mi", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "+", 
        SubscriptBox["Vi", "0"]}], ")"}]}], 
     RowBox[{"3", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Vi", "2"], "\[Rule]", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SuperscriptBox["\[Phi]c", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Omega]", "2"]}], "-", 
       SubscriptBox["Vi", "0"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Omega]", "2"]}], "+", 
        SubscriptBox["Vi", "0"]}], ")"}]}], 
     RowBox[{"6", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Mi", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Vi", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Mi", "4"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Phi]c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "4"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], 
      RowBox[{"45", " ", 
       SubsuperscriptBox["Vi", "0", "2"]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["Vi", "4"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Omega]", "2"]}], "-", 
        SubscriptBox["Vi", "0"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"]}], "+", 
        SubscriptBox["Vi", "0"]}], ")"}]}], 
     RowBox[{"15", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "4"], "\[Rule]", 
    FractionBox[
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"16", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubscriptBox["Vi", "0"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"20", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], 
     RowBox[{"360", " ", 
      SubsuperscriptBox["Vi", "0", "2"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Mi", "5"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Vi", "5"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "5"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Mi", "6"], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"945", " ", 
       SubsuperscriptBox["Vi", "0", "3"]}]], 
     RowBox[{
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"64", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"168", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "6"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"73", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "-", 
           RowBox[{"204", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"], " ", 
         SubscriptBox["Vi", "0"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "15"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"60", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"9", "+", 
           RowBox[{"25", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "3"]}]}], ")"}]}]}]}], ",", 
   RowBox[{
    SubscriptBox["Vi", "6"], "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Omega]", "2"]}], "-", 
        SubscriptBox["Vi", "0"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"34", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "12"}], "+", 
           RowBox[{"37", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"180", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubscriptBox["Vi", "0"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"40", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], 
     RowBox[{"2835", " ", 
      SubsuperscriptBox["Vi", "0", "2"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "6"], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"45360", " ", 
       SubsuperscriptBox["Vi", "0", "3"]}]], 
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"9", "+", 
            RowBox[{"272", " ", 
             SuperscriptBox["\[Phi]c", "2"]}], "+", 
            RowBox[{"448", " ", 
             SuperscriptBox["\[Phi]c", "4"]}]}], ")"}]}], " ", 
         SuperscriptBox["\[Omega]", "6"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"27", "+", 
           RowBox[{"912", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"1184", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"], " ", 
         SubscriptBox["Vi", "0"]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"27", "+", 
           RowBox[{"1236", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"992", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"9", "+", 
           RowBox[{"596", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"1120", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "3"]}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.929248204751193*^9, 3.929248216087762*^9}, {
   3.9292482483558836`*^9, 3.9292483330902443`*^9}, 3.9292501872866626`*^9, 
   3.929253093825842*^9, 3.9292541944542603`*^9, 3.9292550943355837`*^9, 
   3.9292659351449823`*^9, 3.929302819332726*^9, 3.929332125864173*^9, 
   3.9293391563011384`*^9, 3.9293458707995768`*^9, 3.929348649040341*^9, 
   3.9293488553492527`*^9, 3.9293622341375065`*^9, 3.9293636700648518`*^9, 
   3.9293736775123625`*^9, 3.9293777937328568`*^9, 3.9293779090941286`*^9, 
   3.92937805392465*^9, 3.929378111410643*^9, 3.9294073766925755`*^9, 
   3.9294488783839116`*^9, 3.9294525100751767`*^9, 3.929454730313549*^9, 
   3.929464225679813*^9, {3.9295043955137014`*^9, 3.9295044200458784`*^9}},
 CellLabel->"Out[26]=",ExpressionUUID->"1af77308-37ec-4fa4-9bb2-8ec1d21cf670"]
}, Open  ]],

Cell["\<\
Therefore, we have the following boundary conditions for the background\
\>", "Text",
 CellChangeTimes->{{3.9292483424267063`*^9, 
  3.9292483517890263`*^9}},ExpressionUUID->"05300666-11d5-4d92-8823-\
838f19fcbccb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BOUNBKG", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"V", "[", "r", "]"}], ",", 
      RowBox[{"M", "[", "r", "]"}], ",", 
      RowBox[{"\[Phi]0", "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}]}], "}"}], "/.", 
    "rubkgexp"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9292483534932485`*^9, 3.9292483830798287`*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"57ffd28c-7a55-443c-8248-3ed515c80611"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"M", ",", "V", ",", "\[Phi]0"}], "]"}]], "Input",
 CellChangeTimes->{{3.9292483875207577`*^9, 3.9292483936006165`*^9}, 
   3.9292487587731743`*^9},
 CellLabel->"In[28]:=",ExpressionUUID->"3dc87e96-66ab-4f49-9e4e-413980dc70e7"],

Cell["Finally, we can perform the background computations.", "Text",
 CellChangeTimes->{{3.929248402766037*^9, 3.9292484107695827`*^9}, 
   3.9292484440644293`*^9},ExpressionUUID->"1af02619-a71b-4478-98bf-\
849ee767fd29"]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining the integrator and the shooting", "Subsubsection",
 CellChangeTimes->{{3.929248431048627*^9, 
  3.9292484511651163`*^9}},ExpressionUUID->"6a305c5a-d0c6-4b1c-9c1f-\
c3aacc4df08e"],

Cell[TextData[{
 "Usually, one search for a solution that has a scalar field at the origin ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", "c"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f1aba4d0-035a-4424-8215-a53f3ed414da"],
 " and frequency \[Omega] in which the scalar decays to zero far from the \
center. Here we search for a solution in which the scalar decreases \
exponentially as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"exp", "[", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        RowBox[{
         SuperscriptBox["w", "2"], "/", 
         RowBox[{"V", "[", "r", "]"}]}]}]]}], 
     RowBox[{"rst", "[", "r", "]"}]}], "]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "3a681a8f-ad97-4264-8699-3fada8fbfa10"],
 ", where rst[r] is the tortoise coordinate. You can change that if you wish."
}], "Text",
 CellChangeTimes->{{3.929248454414774*^9, 
  3.9292486014469795`*^9}},ExpressionUUID->"dbc38347-e4fc-447e-8b43-\
906ba1d0ff68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BKGI", "[", 
   RowBox[{
    RowBox[{"\[Omega]0_", "?", "NumberQ"}], ",", "\[Phi]c0_", ",", "r10_", 
    ",", "r20_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"paramint", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"MaxSteps", "\[Rule]", "\[Infinity]"}], ",", 
       RowBox[{"Method", "->", "\"\<StiffnessSwitching\>\""}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "12"}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "12"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"defining", " ", "the", " ", "parameters"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"param", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Omega]", "\[Rule]", "\[Omega]0"}], ",", 
       RowBox[{"\[Phi]c", "\[Rule]", "\[Phi]c0"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "defining", " ", "equations", " ", "to", " ", "be", " ", "integrated", 
      " ", "and", " ", "boundary", " ", "conditions"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"EQS", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"eq1", "\[Equal]", "0"}], ",", 
        RowBox[{"eq2", "\[Equal]", "0"}], ",", 
        RowBox[{"eq3", "\[Equal]", "0"}]}], "}"}], "/.", "param"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"BOU", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Thread", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"V", "[", "r", "]"}], ",", 
            RowBox[{"M", "[", "r", "]"}], ",", 
            RowBox[{"\[Phi]0", "[", "r", "]"}], ",", 
            RowBox[{
             RowBox[{"\[Phi]0", "''"}], "[", "r", "]"}]}], "}"}], "\[Equal]", 
          "BOUNBKG"}], "]"}], "/.", "param"}], "/.", 
       RowBox[{
        SubscriptBox["Vi", "0"], "\[Rule]", "1"}]}], "/.", 
      RowBox[{"r", "\[Rule]", "r10"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "Integrating", " ", "the", " ", "differential", " ", "equations"}], 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{"SOLBK", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"EQS", ",", "BOU"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]0", ",", "M", ",", "V"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r10", ",", "r20"}], "}"}], ",", "paramint"}], 
       "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{
      "Computing", " ", "the", " ", "scaled", " ", "quantities", " ", "such", 
       " ", "that", " ", "V", 
       RowBox[{"(", "0", ")"}]}], "=", "1"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"sc1", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", 
         RowBox[{"2", 
          FractionBox[
           RowBox[{"M", "[", "r", "]"}], "r"]}]}], 
        RowBox[{"V", "[", "r", "]"}]], "/.", "SOLBK"}], "/.", 
      RowBox[{"r", "\[Rule]", "r20"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[Omega]s", "=", 
     RowBox[{
      SuperscriptBox["sc1", 
       RowBox[{"1", "/", "2"}]], "\[Omega]0"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"MT", "=", 
     RowBox[{
      RowBox[{"M", "[", "r20", "]"}], "/.", "SOLBK"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"param2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Omega]", "\[Rule]", "\[Omega]s"}], ",", 
       RowBox[{"\[Phi]c", "\[Rule]", "\[Phi]c0"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "We", " ", "demand", " ", "that", " ", "the", " ", "following", " ", 
      "should", " ", "be", " ", "zero", " ", 
      RowBox[{"(", 
       RowBox[{"it", " ", "is", " ", "a", " ", "Wronskian"}], ")"}]}], "*)"}],
     "\[IndentingNewLine]", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "MT"}], "-", "r20", "-", 
           RowBox[{
            SuperscriptBox["r20", "2"], " ", 
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox[
               SuperscriptBox["\[Omega]0", "2"], 
               RowBox[{"V", "[", "r20", "]"}]]}]]}]}], ")"}], " ", 
         RowBox[{"\[Phi]0", "[", "r20", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "MT"}], "-", "r20"}], ")"}], " ", "r20", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]0", "\[Prime]",
           MultilineFunction->None], "[", "r20", "]"}]}]}], ")"}], 
      "\[Phi]c0"], "/.", "SOLBK"}]}], "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.9292486085980663`*^9, 3.9292488467621107`*^9}, {
   3.929248990670339*^9, 3.9292491202336435`*^9}, 3.9292491676546793`*^9, {
   3.9292492155534267`*^9, 3.9292493544064484`*^9}, {3.929249927160367*^9, 
   3.9292499331641264`*^9}, {3.9292659610233355`*^9, 3.929265961893789*^9}, {
   3.9292665087222977`*^9, 3.9292665509769993`*^9}, {3.92926659544553*^9, 
   3.9292666315715055`*^9}, {3.929333738399108*^9, 3.929333748825523*^9}, {
   3.9294074529344325`*^9, 3.9294074749913445`*^9}, {3.9294075722372227`*^9, 
   3.929407614381418*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"276e9363-6de0-4957-a8a1-d2d14d5733ea"],

Cell["\<\
Now we can search for numerical background solutions. I\[CloseCurlyQuote]ll \
focus on the maximum mass configurations, but you can change that to whataver \
you want. In our case \[Phi]max=.1916\
\>", "Text",
 CellChangeTimes->{{3.929249359430789*^9, 3.9292493954370785`*^9}, {
   3.929249432021922*^9, 3.929249436534418*^9}, 
   3.929265966007163*^9},ExpressionUUID->"d96ffe01-a0c3-43ae-9d7e-\
f40613916870"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating the background equations", "Subsubsection",
 CellChangeTimes->{{3.9292494103901134`*^9, 3.9292494190639863`*^9}, {
  3.929250099103907*^9, 
  3.92925010278119*^9}},ExpressionUUID->"c1edfb44-ab40-4592-b092-\
fd3dd0318b88"],

Cell["\<\
We define the maximum value for the scalar field (we know that from previous \
computations)\
\>", "Text",
 CellChangeTimes->{{3.9292495208946223`*^9, 
  3.9292495364007826`*^9}},ExpressionUUID->"93ae8fd2-b220-4935-8434-\
9dbad2689ace"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]max", "=", ".1916"}], ";"}]], "Input",
 CellChangeTimes->{{3.929249437782932*^9, 3.9292494377849317`*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"ed3798b7-7b02-432c-914b-301c44bbf0d6"],

Cell["Do the FindRoot", "Text",
 CellChangeTimes->{{3.929249540638618*^9, 3.929249542585072*^9}, {
  3.9293028255610857`*^9, 
  3.9293028269798717`*^9}},ExpressionUUID->"2e6bffb1-2032-4492-ac35-\
464629041cf2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"BKGI", "[", 
      RowBox[{"xx", ",", "\[Phi]max", ",", "0.001", ",", "30"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "1.2430576002496563`"}], "}"}]}], "]"}], ",", "xx"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.9292494429627295`*^9, 3.92924950389202*^9}, {
   3.929249944980235*^9, 3.9292499673516393`*^9}, {3.9292664785397224`*^9, 
   3.9292664803980227`*^9}, 3.9293028300016327`*^9, 3.9293326418163033`*^9, {
   3.9293777696667614`*^9, 3.9293777794540195`*^9}, {3.9294073826716056`*^9, 
   3.9294074354014163`*^9}, {3.929407481350754*^9, 3.929407587465705*^9}, {
   3.9294076228637533`*^9, 3.929407690686348*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"d0b409fa-d7fa-4c4b-9086-9a903f532ce7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"xx", "\[Rule]", "1.2430576002491156`"}], "}"}]], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9294488790587654`*^9, 
   3.929452510673891*^9, 3.929454730841896*^9, 3.9294642261700907`*^9, {
   3.929504395938223*^9, 3.9295044204678793`*^9}},
 CellLabel->"Out[31]=",ExpressionUUID->"1929b80c-6f37-4c35-8335-041a46f23d23"]
}, Open  ]],

Cell["Check whether it has the required behavior", "Text",
 CellChangeTimes->{{3.9292495459155874`*^9, 
  3.9292495552133665`*^9}},ExpressionUUID->"b3a17776-7ec5-4416-aff9-\
cc0d8392fcc4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Phi]max"], "/.", "SOLBK"}], "//",
     "Abs"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.001", ",", "30"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9292494836639752`*^9, 3.9292495080226245`*^9}, {
   3.9292499435687823`*^9, 3.9292499693386297`*^9}, {3.9292664856166754`*^9, 
   3.929266485754013*^9}, {3.929407440147979*^9, 3.9294074407258964`*^9}, 
   3.9294075095150137`*^9, {3.929407640633501*^9, 3.9294076407509*^9}, {
   3.9294076815384417`*^9, 3.929407694341484*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"e0479117-1ef8-49cf-ad00-1c2ddd1c1618"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV0Hk81OkDwPGJikgJo1zJEXJ8hZD4eh5HK1dKciy5QknGapUzOyjrytkW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       "]]},
     Annotation[#, "Charting`Private`Tag$3156#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.001, -15.43060970883283},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0.001, 30}, {-15.43060970883283, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }, {
    Automatic, {{-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.3978952727983707`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.4849066497880004`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.5649493574615367`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.6390573296152584`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.70805020110221, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.772588722239781, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.833213344056216, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.8903717578961645`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Output",
 CellChangeTimes->{{3.929249499414241*^9, 3.929249508236535*^9}, 
   3.929249557036867*^9, {3.929249940217453*^9, 3.929249982873658*^9}, 
   3.929250187778839*^9, 3.929253094377042*^9, 3.929254194968627*^9, 
   3.9292550948815937`*^9, 3.9292659747844057`*^9, {3.9292664818552923`*^9, 
   3.92926648611342*^9}, 3.9292665588788905`*^9, 3.9292666071786065`*^9, {
   3.9292667978789897`*^9, 3.9292668159846287`*^9}, 3.92930282023897*^9, 
   3.9293321267239904`*^9, 3.929332643894393*^9, 3.929333756545707*^9, 
   3.9293391569207497`*^9, 3.9293458718712273`*^9, 3.9293486494894686`*^9, 
   3.929348855931329*^9, 3.9293622347871356`*^9, 3.929363673009411*^9, 
   3.929364155569137*^9, 3.929373678152976*^9, {3.9293777708941693`*^9, 
   3.9293777945168324`*^9}, 3.9293779095937853`*^9, 3.9293780544818*^9, 
   3.929378112284787*^9, {3.929407393241271*^9, 3.929407441695442*^9}, {
   3.9294074788297763`*^9, 3.929407568827527*^9}, {3.92940761927335*^9, 
   3.9294076947031097`*^9}, 3.929448879469905*^9, 3.9294525109119945`*^9, 
   3.9294547312413125`*^9, 3.929464226366027*^9, {3.9295043966418147`*^9, 
   3.929504420560215*^9}},
 CellLabel->"Out[32]=",ExpressionUUID->"eb67ea11-8ede-48a2-b665-f53853da5272"]
}, Open  ]],

Cell["\<\
The mass matches Kaup\[CloseCurlyQuote]s result. We can define now a rule to \
apply this background to compute the perturbations\
\>", "Text",
 CellChangeTimes->{{3.9292495682876253`*^9, 3.9292495813126645`*^9}, {
  3.929249856357086*^9, 
  3.9292498740360937`*^9}},ExpressionUUID->"cfc2967d-602d-457b-8007-\
321396a3b4cf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rubkg", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"M", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"M", "[", "r", "]"}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"V", "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{"V", "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Phi]0", "[", "r", "]"}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "/.", "SOLBK"}], 
         ")"}]}]}], "}"}], ",", "param2", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"scal", "\[Rule]", "sc1"}], ",", 
       RowBox[{"Mt", "\[Rule]", "MT"}], ",", 
       RowBox[{"rinf", "\[Rule]", "30"}], ",", 
       RowBox[{"ror", "\[Rule]", "0.001"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.92924987838093*^9, 3.929249936003543*^9}, {
   3.9292499886164703`*^9, 3.929250038820092*^9}, {3.929266001586071*^9, 
   3.929266011117361*^9}, {3.9292663967428517`*^9, 3.929266433375227*^9}, 
   3.929266563067258*^9, {3.929266639443221*^9, 3.9292667149650593`*^9}, {
   3.929302844729826*^9, 3.9293028449277954`*^9}, {3.929332674253724*^9, 
   3.9293326788328404`*^9}, {3.9293337610959473`*^9, 3.929333763125454*^9}, {
   3.929363678553999*^9, 3.9293638126658096`*^9}, {3.9293641590776215`*^9, 
   3.9293641658586626`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"1baeed4e-bcd7-4206-af8c-ee9a78badefe"],

Cell["Now we can compute the perturbations", "Text",
 CellChangeTimes->{{3.929250044288864*^9, 
  3.9292500513422513`*^9}},ExpressionUUID->"579c0f7a-16d0-4809-ac67-\
3f32baed3162"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rules for bosonic clouds", "Subsubsection",
 CellChangeTimes->{{3.929448896182952*^9, 3.9294489039434276`*^9}, 
   3.9294490551217313`*^9},ExpressionUUID->"2d4379e9-bb3f-45a7-907b-\
492b8d9ac78b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruclou", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"M", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"Mbh", "&"}], ")"}]}], ",", 
     RowBox[{"V", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", "Mbh"}], "#"]}], "&"}], ")"}]}], ",", 
     RowBox[{"\[Phi]0", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox[
          FractionBox["M\[CapitalPhi]", 
           RowBox[{"\[Pi]", " ", "Mbh"}]]], 
         SuperscriptBox[
          RowBox[{"(", "Mbh", ")"}], "2"], 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "Mbh"}], " ", "#"}], "]"}]}], "&"}], ")"}]}], ",", 
     RowBox[{"\[Omega]", "\[Rule]", 
      RowBox[{"1", "-", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["Mbh", "2"]}]}]}], ",", 
     RowBox[{"M\[CapitalPhi]", "\[Rule]", 
      RowBox[{"0.1", "Mbh"}]}], ",", 
     RowBox[{"Mbh", "\[Rule]", "0.08"}], ",", 
     RowBox[{"\[Phi]c", "\[Rule]", 
      RowBox[{"\[Phi]0", "[", 
       RowBox[{"2.1", "Mbh"}], "]"}]}], ",", 
     RowBox[{"rinf", "\[Rule]", "400"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929449240069426*^9, 3.9294492421152616`*^9}, {
   3.929449279785485*^9, 3.9294493034619274`*^9}, {3.9294493367150364`*^9, 
   3.9294493403530593`*^9}, {3.929449375391882*^9, 3.9294494578581123`*^9}, {
   3.929449678240612*^9, 3.92944968077606*^9}, {3.9294497317333765`*^9, 
   3.9294497319484696`*^9}, {3.9294502435185523`*^9, 
   3.9294502490959663`*^9}, {3.929450490572243*^9, 3.9294504908262663`*^9}, {
   3.929456886330635*^9, 3.9294568870819745`*^9}, 3.9294615388202515`*^9, 
   3.929461877751098*^9, {3.92946225684772*^9, 3.929462271463732*^9}, {
   3.9294623095513325`*^9, 3.9294623423371997`*^9}, {3.9294624001407766`*^9, 
   3.9294624018676286`*^9}, 3.9294624818448*^9, {3.929462903491332*^9, 
   3.9294629050333047`*^9}, {3.9295043802655315`*^9, 3.9295043891138783`*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"07d448b0-9921-4ff5-b4f9-c0dc9d683a5a"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbations and fluxes: Circular orbits", "Section",
 CellChangeTimes->{{3.9292501049071674`*^9, 3.929250110446314*^9}, {
  3.9294310685810246`*^9, 
  3.9294310706097107`*^9}},ExpressionUUID->"26003b34-4475-4a22-9176-\
303559d6c86a"],

Cell[CellGroupData[{

Cell["Setting up the equations", "Subsubsection",
 CellChangeTimes->{{3.9292534082675037`*^9, 
  3.9292534115183926`*^9}},ExpressionUUID->"7b362fd0-bb14-4a49-9bdf-\
39254c4700c1"],

Cell["\<\
We define the equations describing the perturbations below (l>=2)\
\>", "Text",
 CellChangeTimes->{{3.9292501226636486`*^9, 3.9292501351978397`*^9}, {
  3.9292503881458445`*^9, 
  3.9292503914754114`*^9}},ExpressionUUID->"dfcd49d3-6bd6-4e87-bd1e-\
1a36e1343690"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqsperturbations", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "\[Pi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"Alm1p", "[", "r", "]"}], "\[Sigma]"]}], "+", 
         FractionBox[
          RowBox[{"4", " ", "r", " ", 
           RowBox[{"Flmp", "[", "r", "]"}]}], 
          SqrtBox[
           RowBox[{"L", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "-", "L", "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["L", "2"]}], "+", 
              SuperscriptBox["L", "3"]}], ")"}]}]]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{"H0", "[", "r", "]"}], "r"], "+", 
      RowBox[{
       RowBox[{"H1", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "L"}], ")"}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"]}]], "-", 
         FractionBox[
          RowBox[{"4", " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
          RowBox[{"V", "[", "r", "]"}]]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["Kp", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Omega]", " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Omega]", " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "3"]}], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"r", "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{"r", "-", 
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{"V", "[", "r", "]"}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]1", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"r", " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]2", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"r", " ", "\[Sigma]"}]]}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", 
        SqrtBox["2"], " ", "\[Pi]", " ", 
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"Blm0p", "[", "r", "]"}], 
            RowBox[{
             SqrtBox[
              RowBox[{"L", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", "L"}], ")"}]}]], " ", "\[Sigma]"}]]}], "-", 
          FractionBox[
           RowBox[{"2", " ", "r", " ", 
            RowBox[{"Flmp", "[", "r", "]"}]}], 
           SqrtBox[
            RowBox[{"L", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "L", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["L", "2"]}], "+", 
               SuperscriptBox["L", "3"]}], ")"}]}]]]}], ")"}]}], 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      FractionBox[
       RowBox[{"r", " ", 
        RowBox[{"H0", "[", "r", "]"}]}], 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      FractionBox[
       RowBox[{"r", " ", 
        RowBox[{"Kp", "[", "r", "]"}]}], 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"H1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "-", 
      FractionBox[
       RowBox[{"4", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{"\[Phi]1", "[", "r", "]"}]}], 
       RowBox[{
        RowBox[{"r", " ", "\[Sigma]"}], "-", 
        RowBox[{"2", " ", "\[Sigma]", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      FractionBox[
       RowBox[{"4", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{"\[Phi]2", "[", "r", "]"}]}], 
       RowBox[{
        RowBox[{"r", " ", "\[Sigma]"}], "-", 
        RowBox[{"2", " ", "\[Sigma]", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      RowBox[{
       SuperscriptBox["H1", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"H1", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "L"}], ")"}]}], 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"]}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["\[Sigma]", "2"], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], 
          RowBox[{"V", "[", "r", "]"}]]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["H0", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Omega]", " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "\[Sigma]"}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Omega]", " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"r", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{"r", "-", 
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{"V", "[", "r", "]"}]}]], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "3"]}], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"r", "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], 
       RowBox[{"r", " ", 
        RowBox[{"(", 
         RowBox[{"r", "-", 
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{"V", "[", "r", "]"}]}]], "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"], " ", "\[Pi]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"Alm1p", "[", "r", "]"}], "\[Sigma]"]}], "-", 
         FractionBox[
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"Blmp", "[", "r", "]"}]}], 
          SqrtBox[
           RowBox[{"L", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "L"}], ")"}]}]]], "-", 
         FractionBox[
          RowBox[{"4", " ", "r", " ", 
           RowBox[{"Flmp", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"V", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["\[Omega]", "2"], "-", 
                   RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
                 SuperscriptBox[
                  RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"V", "[", "r", "]"}], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}], 
          RowBox[{
           SqrtBox[
            RowBox[{"L", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "L", "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["L", "2"]}], "+", 
               SuperscriptBox["L", "3"]}], ")"}]}]], " ", 
           RowBox[{"(", 
            RowBox[{"r", "-", 
             RowBox[{"2", " ", 
              RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
           RowBox[{"V", "[", "r", "]"}]}]]}], ")"}]}], "-", 
      FractionBox[
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]1", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"r", " ", "\[Sigma]"}]], "+", 
      FractionBox[
       RowBox[{"2", " ", "\[Omega]", " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]2", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{"r", " ", "\[Sigma]"}]]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "r", " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], 
      "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]], 
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Omega]", "2"]}], "-", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Omega]", "2"], "-", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"M", "[", "r", "]"}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{"M", "[", "r", "]"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
            ")"}]}]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]], 
       RowBox[{
        RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[Omega]", "2"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"2", "-", 
                RowBox[{"8", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"L", "+", 
                SuperscriptBox["L", "2"], "+", 
                SuperscriptBox["r", "2"], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", " ", 
         SqrtBox["2"], " ", "\[Pi]", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox[
             RowBox[{"L", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "-", "L", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["L", "2"]}], "+", 
                SuperscriptBox["L", "3"]}], ")"}]}]], " ", "r", " ", 
            "\[Omega]", " ", 
            RowBox[{"Blm0p", "[", "r", "]"}], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SqrtBox[
                 RowBox[{"L", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "-", "L", "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["L", "2"]}], "+", 
                    SuperscriptBox["L", "3"]}], ")"}]}]]}], " ", 
               RowBox[{"Blmp", "[", "r", "]"}]}], "+", 
              RowBox[{
               SqrtBox[
                RowBox[{"L", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "L"}], ")"}]}]], " ", "r", " ", 
               RowBox[{
                SuperscriptBox["Flmp", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]0", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{
            SqrtBox[
             RowBox[{"L", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "L"}], ")"}]}]], " ", 
            RowBox[{"Flmp", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"\[Sigma]", "-", 
                    RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", 
                  "\[Omega]"}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"V", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["\[Omega]", "2"]}], "+", 
                 RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "-", 
              RowBox[{"2", " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"M", "[", "r", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["r", "2"], " ", 
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "L"}], ")"}]}]], " ", 
         SqrtBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "-", "L", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["L", "2"]}], "+", 
             SuperscriptBox["L", "3"]}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"V", "[", "r", "]"}], "2"]}]], 
       RowBox[{"2", " ", "\[Sigma]", " ", "\[Omega]", " ", 
        RowBox[{"H1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["r", "3"]}], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"r", "-", 
                RowBox[{"2", " ", 
                 RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox["\[Phi]0", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{
              RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"r", "-", 
                RowBox[{
                 SuperscriptBox["r", "3"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"M", "[", "r", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                  ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]1", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      RowBox[{
       SuperscriptBox["\[Phi]1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"4", " ", "r", " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], 
      "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]], 
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", 
              SuperscriptBox["\[Omega]", "2"]}], "-", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Omega]", "2"], "-", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"M", "[", "r", "]"}], "+", 
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["r", "2"], " ", 
              RowBox[{"M", "[", "r", "]"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
            ")"}]}]}], ")"}]}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]], 
       RowBox[{
        RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], "2"], 
             "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["\[Omega]", "2"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"M", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"2", "-", 
                RowBox[{"8", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"L", "+", 
                SuperscriptBox["L", "2"], "+", 
                SuperscriptBox["r", "2"], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
                RowBox[{"4", " ", 
                 SuperscriptBox["r", "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"8", " ", 
         SqrtBox["2"], " ", "\[Pi]", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox[
             RowBox[{"L", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "-", "L", "+", 
                RowBox[{"2", " ", 
                 SuperscriptBox["L", "2"]}], "+", 
                SuperscriptBox["L", "3"]}], ")"}]}]], " ", "r", " ", 
            "\[Omega]", " ", 
            RowBox[{"Blm0p", "[", "r", "]"}], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SqrtBox[
                RowBox[{"L", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "-", "L", "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["L", "2"]}], "+", 
                   SuperscriptBox["L", "3"]}], ")"}]}]], " ", 
               RowBox[{"Blmp", "[", "r", "]"}]}], "-", 
              RowBox[{
               SqrtBox[
                RowBox[{"L", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "L"}], ")"}]}]], " ", "r", " ", 
               RowBox[{
                SuperscriptBox["Flmp", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]0", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], "+", 
           RowBox[{
            SqrtBox[
             RowBox[{"L", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "L"}], ")"}]}]], " ", 
            RowBox[{"Flmp", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Omega]", " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Sigma]", "+", 
                    RowBox[{"2", " ", "\[Omega]"}]}], ")"}]}], "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"V", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["\[Omega]", "2"], "-", 
                 RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"M", "[", "r", "]"}], "+", 
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["r", "2"], " ", 
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SqrtBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "L"}], ")"}]}]], " ", 
         SqrtBox[
          RowBox[{"L", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "-", "L", "+", 
             RowBox[{"2", " ", 
              SuperscriptBox["L", "2"]}], "+", 
             SuperscriptBox["L", "3"]}], ")"}]}]], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}], ")"}]}], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"V", "[", "r", "]"}], "2"]}]], 
       RowBox[{"2", " ", "\[Sigma]", " ", "\[Omega]", " ", 
        RowBox[{"H1", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "-", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox["r", "3"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"r", "-", 
                RowBox[{"2", " ", 
                 RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox["\[Phi]0", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "+", 
             RowBox[{
              RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"r", "-", 
                RowBox[{
                 SuperscriptBox["r", "3"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                RowBox[{
                 RowBox[{"M", "[", "r", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                  ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]2", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "+", 
      RowBox[{
       SuperscriptBox["\[Phi]2", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9292503830519295`*^9, 3.9292503975297556`*^9}, {
  3.929348813402157*^9, 3.929348839390555*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"64318848-717e-436b-8c5b-a1e70b6db877"],

Cell["We can define the homogeneous equations and the source terms", "Text",
 CellChangeTimes->{{3.929250435218067*^9, 
  3.9292504475348883`*^9}},ExpressionUUID->"68313883-6e29-4f4b-98b9-\
f12c2799888a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SOURCE", "=", 
   RowBox[{
    RowBox[{"-", "eqsperturbations"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H1", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"H0", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Kp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"\[Phi]1", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"\[Phi]2", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQHOM", "=", 
   RowBox[{"eqsperturbations", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Blm0p", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Flmp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Alm1p", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Blmp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Almp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8735143865429583`*^9, 3.873514414013742*^9}, {
   3.873514528044138*^9, 3.873514574962019*^9}, 3.873514897057378*^9, {
   3.929250449180204*^9, 3.9292504776327057`*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"6ca7f2ef-1aff-4696-ab0b-a4c4cb051825"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finding the boundary conditions at the origin", "Subsubsection",
 CellChangeTimes->{{3.9292534150660152`*^9, 
  3.929253421619045*^9}},ExpressionUUID->"7434d8a5-d7f1-46c5-aa3f-\
5dd16e974281"],

Cell[TextData[{
 "We do the same as we did for the background. The only diference is that the \
perturbations scales as ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["r", "L"], TraditionalForm]],ExpressionUUID->
  "528fc520-295c-4011-be96-1e1ef548b9a7"],
 " near the origin."
}], "Text",
 CellChangeTimes->{{3.929253424441883*^9, 
  3.9292534579335794`*^9}},ExpressionUUID->"7060e732-5c4b-4841-9ddb-\
ea1a595b2f8e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.929253484103348*^9, 3.929253509161499*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"727e51eb-15ed-47cd-82da-2ddf8a2826bb"],

Cell["Defining the expansions", "Text",
 CellChangeTimes->{{3.9292535242682095`*^9, 
  3.9292535270108204`*^9}},ExpressionUUID->"c3cf7386-4cab-4839-8d54-\
88992211ecf4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"M", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["Mi", "i"], " ", 
       SuperscriptBox["r", 
        RowBox[{"i", "+", "1"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], "/.", 
    "rubkgexp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["Vi", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}], "/.", 
    "rubkgexp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]0", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Phi]0i", "i"], 
        SuperscriptBox["r", "i"]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}], "/.", 
     RowBox[{
      SubscriptBox["\[Phi]0i", "0"], "\[Rule]", "\[Phi]c"}]}], "/.", 
    "rubkgexp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H0", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["h0", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H1", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["h1", "i"], 
       SuperscriptBox["r", 
        RowBox[{"i", "+", "1"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Kp", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["kp", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]1", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Phi]1i", "i"], 
       SuperscriptBox["r", 
        RowBox[{"i", "+", "1"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], ";", 
  RowBox[{
   RowBox[{"\[Phi]2", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "L"], 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Phi]2i", "i"], 
       SuperscriptBox["r", 
        RowBox[{"i", "+", "1"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9292535284825354`*^9, 3.9292535792890496`*^9}, {
   3.9292536298462915`*^9, 3.929253688329521*^9}, {3.9292537197597423`*^9, 
   3.92925372035641*^9}, {3.929253787647439*^9, 3.929253789065509*^9}, {
   3.929253824500702*^9, 3.9292538449415555`*^9}, 3.9292539978035746`*^9, {
   3.929254182210389*^9, 3.929254212146351*^9}, {3.929254592122063*^9, 
   3.9292546640776205`*^9}, {3.929255139811023*^9, 3.929255139943655*^9}, {
   3.929255230389863*^9, 3.929255259009117*^9}, {3.929255307404224*^9, 
   3.929255313638034*^9}, {3.92925560674492*^9, 3.9292556274163494`*^9}, {
   3.9292558069524794`*^9, 3.929255847593094*^9}, {3.9292659066425157`*^9, 
   3.9292659069125037`*^9}, 3.929266831084097*^9},
 CellLabel->"In[39]:=",ExpressionUUID->"ba324767-3636-4725-8c11-b10d47bd5acf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Series", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"EQHOM", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "r"}], ",", 
        RowBox[{"EQHOM", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", 
        RowBox[{
         RowBox[{"EQHOM", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "r"}], ",", 
        RowBox[{
         RowBox[{"EQHOM", "[", 
          RowBox[{"[", "4", "]"}], "]"}], "r"}], ",", 
        RowBox[{
         RowBox[{"EQHOM", "[", 
          RowBox[{"[", "5", "]"}], "]"}], "r"}]}], "}"}], 
      SuperscriptBox["r", "L"]], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "3"}], "}"}]}], "]"}], "//", "Simplify"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.929253481362446*^9, 3.9292534817161417`*^9}, {
   3.929253580709956*^9, 3.92925361023795*^9}, {3.929253656396912*^9, 
   3.9292536576222887`*^9}, {3.9292536923150735`*^9, 3.929253717458537*^9}, {
   3.929253836437602*^9, 3.9292538378628445`*^9}, {3.9292542234666452`*^9, 
   3.929254243945298*^9}, {3.929254338524437*^9, 3.9292544042235413`*^9}, {
   3.9292544361095247`*^9, 3.9292544870322714`*^9}, 3.9292545999972935`*^9, 
   3.9292546872309675`*^9, {3.9292551077272587`*^9, 3.92925510829888*^9}, {
   3.929255200562439*^9, 3.92925520267146*^9}, {3.929255633497661*^9, 
   3.9292556597606735`*^9}, {3.92925572433432*^9, 3.929255749883393*^9}, {
   3.929255818806813*^9, 3.929255821960252*^9}, {3.9292636847518005`*^9, 
   3.9292637297110357`*^9}, {3.929264107206977*^9, 3.9292641145187902`*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"f2b81fd2-a27d-41ee-a8e0-f8651c847e21"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rupertorigin", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"%", "\[Equal]", "0"}], ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["h1", "0"], ",", 
         SubscriptBox["h0", "0"], ",", 
         SubscriptBox["h1", "1"], ",", 
         SubscriptBox["h0", "1"], ",", 
         SubscriptBox["kp", "1"], ",", 
         SubscriptBox["\[Phi]1i", "1"], ",", 
         SubscriptBox["\[Phi]2i", "1"], ",", 
         SubscriptBox["h1", "2"], ",", 
         SubscriptBox["h0", "2"], ",", 
         SubscriptBox["kp", "2"], ",", 
         SubscriptBox["\[Phi]1i", "2"], ",", 
         SubscriptBox["\[Phi]2i", "2"], ",", 
         SubscriptBox["h1", "3"], ",", 
         SubscriptBox["h0", "3"], ",", 
         SubscriptBox["kp", "3"], ",", 
         SubscriptBox["\[Phi]1i", "3"], ",", 
         SubscriptBox["\[Phi]2i", "3"]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9292542916756973`*^9, 3.9292543115862217`*^9}, {
  3.9292543681807656`*^9, 3.92925441841683*^9}, {3.929254453181978*^9, 
  3.929254482016921*^9}, {3.9292557386190853`*^9, 3.929255747046791*^9}, {
  3.9292637145715747`*^9, 3.9292637487845078`*^9}, {3.9292640652803793`*^9, 
  3.929264142078845*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"fd3ca2ff-4483-4d30-9081-d4b1c8266373"],

Cell["Therefore we have the following boundary conditions", "Text",
 CellChangeTimes->{{3.929264148037366*^9, 
  3.929264156630096*^9}},ExpressionUUID->"de5fb13e-3b83-41fc-a7a2-\
f0fe1cd7797c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BOUNOR", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H0", "[", "r", "]"}], ",", 
      RowBox[{"H1", "[", "r", "]"}], ",", 
      RowBox[{"Kp", "[", "r", "]"}], ",", 
      RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
      RowBox[{"\[Phi]2", "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]2", "'"}], "[", "r", "]"}]}], "}"}], "/.", 
    "rupertorigin"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929264397833138*^9, 3.929264439008908*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"b438c5c5-f14e-4b33-aa12-a5e713ff588b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9292644477116027`*^9, 3.929264455811679*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"8eebbb36-a422-4ee5-8402-7970b44f7cd4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finding the boundary conditions at infinity", "Subsubsection",
 CellChangeTimes->{{3.929264466447201*^9, 
  3.929264472267169*^9}},ExpressionUUID->"e2e68186-35ab-4cef-a1dc-\
ea2d89aaadcc"],

Cell["\<\
At infinity, the boundary conditions are such that we have two scalar \
perturbations+gravitational perturbation in Schwarzschild. Therefore, we can \
use that for our problem.\
\>", "Text",
 CellChangeTimes->{{3.929264522771202*^9, 3.929264566079797*^9}, {
   3.9292646401334925`*^9, 3.929264663234372*^9}, {3.929265109026581*^9, 
   3.929265109913558*^9}, 
   3.929266865005639*^9},ExpressionUUID->"cee3e002-cac1-456a-8517-\
f287dc1f7bde"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellLabel->"In[50]:=",ExpressionUUID->"3277d677-9b2c-4589-a333-04f27978ef3f"],

Cell["\<\
The equations in vacuum can be obtained by considering \[Phi]0->0 and the \
Schwarzschild spacetime with mass Mt.\
\>", "Text",
 CellChangeTimes->{{3.9292651128556232`*^9, 3.929265126269923*^9}, {
  3.9292668898281045`*^9, 
  3.929266905971171*^9}},ExpressionUUID->"8d7e7434-2438-4d6b-83ad-\
4a557f8fd5dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQSVAC", "=", 
   RowBox[{"EQHOM", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Phi]0", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"V", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "-", 
          RowBox[{"2", 
           FractionBox["Mt", "#"]}]}], "&"}], ")"}]}], ",", 
      RowBox[{"M", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"Mt", "&"}], ")"}]}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929265128111204*^9, 3.9292651425810957`*^9}, {
   3.929266888490925*^9, 3.9292669295082426`*^9}, 3.929377323320628*^9},
 CellLabel->"In[51]:=",ExpressionUUID->"142f7ba8-9840-4226-8f39-755263838a39"],

Cell["\<\
So for the gravitational sector, we can use the Zerilli equations for \
simplicity\
\>", "Text",
 CellChangeTimes->{{3.9292651592852583`*^9, 3.9292651716599207`*^9}, {
  3.9293410282923284`*^9, 3.9293410319553633`*^9}, {3.9293411186768703`*^9, 
  3.9293411287010283`*^9}},ExpressionUUID->"199fb3b0-7518-436b-a1ea-\
bce6c444f98b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"rst", "[", "r_", "]"}], ":=", 
   RowBox[{"r", "+", 
    RowBox[{"2", "Mt", " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       FractionBox["r", 
        RowBox[{"2", "Mt"}]], "-", "1"}], "]"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9292951680029116`*^9, 3.929295168430421*^9}, {
  3.929377822571955*^9, 3.9293778230138535`*^9}, {3.929378086105817*^9, 
  3.929378098447377*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"062cb86a-ac9f-43fb-b0cd-07a87df5c062"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqzr", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "Mt"}], "-", "x"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"72", " ", 
             SuperscriptBox["Mt", "3"]}], "+", 
            RowBox[{"36", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "L", "+", 
               SuperscriptBox["L", "2"]}], ")"}], " ", 
             SuperscriptBox["Mt", "2"], " ", "x"}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "L", "+", 
                SuperscriptBox["L", "2"]}], ")"}], "2"], " ", "Mt", " ", 
             SuperscriptBox["x", "2"]}], "+", 
            RowBox[{"L", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "L"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "L", "+", 
                SuperscriptBox["L", "2"]}], ")"}], "2"], " ", 
             SuperscriptBox["x", "3"]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["x", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "Mt"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "L", "+", 
                SuperscriptBox["L", "2"]}], ")"}], " ", "x"}]}], ")"}], 
           "2"]}]], "+", 
        SuperscriptBox["\[Omega]", "2"]}], ")"}], " ", 
      RowBox[{"Z", "[", "x", "]"}]}], "+", 
     FractionBox[
      RowBox[{"2", " ", "Mt", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "Mt"}], "+", "x"}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["Z", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}]}], 
      SuperscriptBox["x", "3"]], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "Mt"}], "x"]}], ")"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["Z", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "x", "]"}]}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Rule]", "r"}], ",", 
      RowBox[{"\[Omega]", "\[Rule]", "\[Sigma]"}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9293628297223616`*^9, 3.929362830750579*^9}, {
  3.9293629167158237`*^9, 3.9293629393427343`*^9}, {3.9293629796174393`*^9, 
  3.929362980186467*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"b97ac5a4-5309-4c63-8108-937c3306353b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ORDgINF", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Z", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"g", "[", "x", "]"}], 
    SuperscriptBox["E", 
     RowBox[{"I", " ", "\[Sigma]", " ", 
      RowBox[{"rst", "[", "x", "]"}]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqgZ", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     FractionBox["eqzr", 
      SuperscriptBox["E", 
       RowBox[{"I", " ", "\[Sigma]", " ", 
        RowBox[{"rst", "[", "r", "]"}]}]]], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "[", "r", "]"}], ",", 
       RowBox[{
        RowBox[{"g", "'"}], "[", "r", "]"}], ",", 
       RowBox[{
        RowBox[{"g", "''"}], "[", "r", "]"}]}], "}"}], ",", "Simplify"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "x_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"gi", "[", "i", "]"}], 
      SuperscriptBox["x", "i"]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"ORDgINF", "+", "3"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SEgZ", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"eqgZ", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "\[Infinity]", ",", 
       RowBox[{"ORDgINF", "+", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqsgZinf", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"SEgZ", ",", "i"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", "ORDgINF"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vagZ", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"gi", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgZINF", "=", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{"eqsgZinf", ",", "vagZ"}], "]"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{"Z", ",", "g"}], "]"}]}], "Input",
 CellChangeTimes->{{3.549188015921222*^9, 3.5491880388754835`*^9}, {
   3.5491881504613724`*^9, 3.5491881817760468`*^9}, 3.549188589211471*^9, {
   3.5491887545728683`*^9, 3.5491887547438784`*^9}, {3.549188809854812*^9, 
   3.549188810026822*^9}, {3.5491890769636173`*^9, 3.5491891052749043`*^9}, {
   3.5491892821983976`*^9, 3.549189283583475*^9}, {3.549189315621998*^9, 
   3.5491893205692673`*^9}, {3.549189555757177*^9, 3.5491896480916023`*^9}, {
   3.5491896996081934`*^9, 3.5491897226763096`*^9}, {3.5491897705008273`*^9, 
   3.5491897733479824`*^9}, 3.549198790599414*^9, {3.54927888748129*^9, 
   3.549278905739254*^9}, 3.54930863065969*^9, 3.549363599296094*^9, {
   3.55751336524298*^9, 3.557513399180564*^9}, {3.557513455473043*^9, 
   3.557513485341198*^9}, {3.557513561545974*^9, 3.557513561896056*^9}, {
   3.5575136276050873`*^9, 3.557513662705748*^9}, {3.557513723632738*^9, 
   3.557513729705844*^9}, {3.557691575793655*^9, 3.5576915766834183`*^9}, {
   3.557691801247293*^9, 3.55769180133803*^9}, 3.557702659343792*^9, {
   3.557703512204694*^9, 3.557703512608191*^9}, {3.559038357823995*^9, 
   3.5590384202861958`*^9}, {3.559478518608761*^9, 3.559478519176701*^9}, {
   3.55947987770216*^9, 3.559479878563641*^9}, 3.559488051644967*^9, {
   3.55984285155237*^9, 3.559842852018302*^9}, {3.5598988195156183`*^9, 
   3.559898828953313*^9}, {3.559951966041107*^9, 3.559951966226551*^9}, {
   3.560041317833596*^9, 3.560041317928666*^9}, {3.5601687763692904`*^9, 
   3.560168776457697*^9}, {3.929362887937426*^9, 3.9293629083824263`*^9}, {
   3.929362951673281*^9, 3.9293629748037004`*^9}, 3.92937722194779*^9, {
   3.929377608993801*^9, 3.929377609652095*^9}, {3.92937782508681*^9, 
   3.929377841570603*^9}, 3.929378126221942*^9},
 CellLabel->"In[55]:=",ExpressionUUID->"abf07497-742b-4110-bf38-c840e1be8d11"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalLambda]l", "=", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{"L", "-", "1"}], ")"}], 
    RowBox[{"(", 
     RowBox[{"L", "+", "2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ze", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["E", 
      RowBox[{"I", " ", "\[Sigma]", " ", 
       RowBox[{"rst", "[", "x", "]"}]}]], 
     RowBox[{"Sum", "[", 
      RowBox[{
       FractionBox[
        RowBox[{"gi", "[", "i", "]"}], 
        SuperscriptBox["x", "i"]], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", 
         RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], "/.", 
    "seriesgZINF"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bounkp", "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", 
         SuperscriptBox["Mt", "2"]}], "+", 
        RowBox[{"3", " ", "Mt", " ", "r", " ", "\[CapitalLambda]l"}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", "\[CapitalLambda]l", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "\[CapitalLambda]l"}], ")"}]}]}], ")"}], " ", 
      RowBox[{"Ze", "[", "r", "]"}]}], 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "Mt"}], "+", 
        RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}]}]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"2", " ", "Mt"}], "r"]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["Ze", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bounh1", "=", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["Mt", "2"]}], "-", 
        RowBox[{"3", " ", "Mt", " ", "r", " ", "\[CapitalLambda]l"}], "+", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", "\[CapitalLambda]l"}]}], ")"}], " ", 
      RowBox[{"Ze", "[", "r", "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "Mt"}], "+", 
        RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}]}]], "-", 
    RowBox[{"r", " ", 
     RowBox[{
      SuperscriptBox["Ze", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bounh0", "=", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "Mt"}], "+", 
         RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}], "2"]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"9", " ", 
             SuperscriptBox["Mt", "3"]}], "+", 
            RowBox[{"9", " ", 
             SuperscriptBox["Mt", "2"], " ", "r", " ", "\[CapitalLambda]l"}], 
            "+", 
            RowBox[{"3", " ", "Mt", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox["\[CapitalLambda]l", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox["\[CapitalLambda]l", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "\[CapitalLambda]l"}], ")"}]}]}], ")"}]}], 
         "+", 
         RowBox[{
          SuperscriptBox["r", "4"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "Mt"}], "+", 
             RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}], "2"], " ", 
          SuperscriptBox["\[Sigma]", "2"]}]}], ")"}], " ", 
       RowBox[{"Ze", "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "Mt"}], "+", 
         RowBox[{"r", " ", "\[CapitalLambda]l"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["Mt", "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "Mt"}], "-", "r"}], ")"}], " ", "r", " ", 
          "\[CapitalLambda]l"}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["Ze", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bounginf", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"bounh0", ",", "bounh1", ",", "bounkp"}], "}"}], "//.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", 
     SubscriptBox["kpi", "0"]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5492995611448107`*^9, 3.5492995668377113`*^9}, {
   3.5493001508756027`*^9, 3.5493004357567177`*^9}, {3.5493005503119307`*^9, 
   3.5493005537669287`*^9}, {3.5493006532510033`*^9, 3.549300654184024*^9}, {
   3.549301989177497*^9, 3.549302073440977*^9}, {3.549302117195814*^9, 
   3.549302151352942*^9}, {3.549305977299405*^9, 3.5493059915774612`*^9}, {
   3.549308301769487*^9, 3.549308306908955*^9}, {3.549308595716675*^9, 
   3.549308620795586*^9}, {3.549308719604292*^9, 3.549308739273114*^9}, {
   3.549309475517529*^9, 3.549309742179122*^9}, 3.549309797970222*^9, {
   3.549366390031262*^9, 3.5493663911990557`*^9}, {3.549373766282969*^9, 
   3.549373767481742*^9}, {3.549465102252613*^9, 3.5494651101843233`*^9}, {
   3.549465146612115*^9, 3.549465162554783*^9}, {3.54946522458862*^9, 
   3.549465266327724*^9}, 3.54948890365985*^9, 3.549488971222426*^9, 
   3.5495490414996033`*^9, {3.5495625000594797`*^9, 3.549562502220541*^9}, {
   3.549562915610029*^9, 3.549562933252635*^9}, {3.5495669169420977`*^9, 
   3.5495669474401484`*^9}, 3.5495670293111763`*^9, {3.5495955822989225`*^9, 
   3.5495955851810875`*^9}, {3.557513414028261*^9, 3.557513414852181*^9}, {
   3.557513492134759*^9, 3.55751362216544*^9}, {3.5575137759256067`*^9, 
   3.5575137797673683`*^9}, {3.557522114145916*^9, 3.557522123530279*^9}, {
   3.557523816540864*^9, 3.5575238176411867`*^9}, {3.5575238672441397`*^9, 
   3.557523867362073*^9}, {3.559038441793056*^9, 3.55903848448711*^9}, {
   3.5590400589113417`*^9, 3.559040061492145*^9}, {3.559042229040206*^9, 
   3.559042230039226*^9}, {3.559478954442618*^9, 3.559478958220211*^9}, {
   3.5594792038471823`*^9, 3.559479216584775*^9}, {3.559479270020135*^9, 
   3.559479271267324*^9}, 3.559488051656258*^9, {3.560168797637251*^9, 
   3.56016882516424*^9}, {3.9293630237575192`*^9, 3.929363144394322*^9}, {
   3.929364049029535*^9, 3.929364049153607*^9}, {3.9293645762563076`*^9, 
   3.9293645924883385`*^9}, {3.9293772067290483`*^9, 
   3.9293772972274456`*^9}, {3.929377621932341*^9, 3.92937762289004*^9}, {
   3.9293778323999124`*^9, 3.929377834506875*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"228585c9-250a-4c14-aaf3-b4c4279a1c0c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BOUGRAV", "=", "bounginf"}], ";"}]], "Input",
 CellChangeTimes->{{3.929298120437143*^9, 3.929298134628807*^9}, {
  3.929299087987913*^9, 3.9292991265708447`*^9}, {3.9293631491812844`*^9, 
  3.929363172068033*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"33977e49-15b3-4f95-b85f-d4b0d7f22ac7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9292991877200623`*^9, 3.929299194446289*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"3db108f4-4fc4-4ff2-bae3-50579fb02e56"],

Cell["\<\
For the scalar fields, let\[CloseCurlyQuote]s take the scalar perturbation \
for \[Phi]1. The difference between \[Phi]1 and \[Phi]2 can b\
\>", "Text",
 CellChangeTimes->{{3.929299202125712*^9, 3.9292992313238964`*^9}, {
  3.9293001784069977`*^9, 3.9293001921739993`*^9}, {3.9293408707300262`*^9, 
  3.9293408711838408`*^9}},ExpressionUUID->"3e3e0063-a5c0-40c5-bb52-\
01bb4497a883"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9293001600234337`*^9, 3.929300174525943*^9}, {
  3.9293002532740307`*^9, 3.929300258354559*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"0ce35a37-f2bc-4d0f-8521-b679f2f3440b"],

Cell["Defining the equation for the expansion", "Text",
 CellChangeTimes->{{3.9293017784411545`*^9, 
  3.929301784971286*^9}},ExpressionUUID->"6651286d-45d3-4786-9e11-\
9d5c2b7d3113"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqgp1", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", 
           FractionBox["Mt", "r"]}]}], ")"}], "2"], 
       FractionBox[
        RowBox[{"EQSVAC", "[", 
         RowBox[{"[", "4", "]"}], "]"}], 
        SuperscriptBox["E", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Kappa]p", " ", 
            RowBox[{"rst", "[", "r", "]"}]}], "-", 
           RowBox[{
            FractionBox["Mt", "\[Kappa]p"], " ", 
            RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]]]}], "/.", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "\[Rule]", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Kappa]p", "2"]}]}]}], "/.", 
     RowBox[{"\[Phi]1", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"g1", "[", "#", "]"}], 
         SuperscriptBox["E", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Kappa]p", " ", 
             RowBox[{"rst", "[", "#", "]"}]}], "-", 
            RowBox[{
             FractionBox["Mt", "\[Kappa]p"], " ", 
             RowBox[{"Log", "[", "#", "]"}]}]}], ")"}]]}], "&"}], ")"}]}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"g1", "''"}], "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"g1", "'"}], "[", "r", "]"}]}], "}"}], ",", "FullSimplify"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.929301593980744*^9, 3.9293017742423763`*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"1010dac9-99e4-4b8e-a002-0b0e95d38cbb"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Mt", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}], "2"]}], "+", 
      RowBox[{"Mt", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["Mt", "2"]}], "-", 
         RowBox[{"6", " ", "Mt", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", "\[Kappa]p"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "L", "+", 
            SuperscriptBox["L", "2"]}], ")"}], " ", "Mt", " ", "r"}], "-", 
         RowBox[{"L", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "L"}], ")"}], " ", 
          SuperscriptBox["r", "2"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["Mt", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["r", "2"]}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox["\[Kappa]p", "2"]}]}], ")"}], " ", 
    RowBox[{"g1", "[", "r", "]"}]}], 
   RowBox[{
    SuperscriptBox["r", "4"], " ", 
    SuperscriptBox["\[Kappa]p", "2"]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["Mt", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox["\[Kappa]p", "2"]}], "+", 
      RowBox[{"Mt", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "r"}], "+", "\[Kappa]p"}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["g1", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   RowBox[{
    SuperscriptBox["r", "3"], " ", "\[Kappa]p"}]], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "Mt"}], "r"]}], ")"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["g1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.929301597298538*^9, {3.9293017060180464`*^9, 3.929301757085286*^9}, 
   3.9293017896704493`*^9, 3.9293028738142667`*^9, 3.9293321351758037`*^9, 
   3.929339218611923*^9, 3.929340418005526*^9, 3.9293408240422096`*^9, 
   3.929340872751244*^9, 3.9293489113454957`*^9, 3.9293632033177805`*^9, {
   3.92936403220761*^9, 3.9293640588305764`*^9}, 3.929364614807353*^9, 
   3.929377061433199*^9, 3.9293776852673283`*^9, 3.9293778539269247`*^9, 
   3.929377915519204*^9, 3.9293780642205315`*^9, {3.929378121517057*^9, 
   3.9293781330450087`*^9}, 3.9294077585542164`*^9, 3.929449628462654*^9, 
   3.9294525164562535`*^9, 3.929454779406613*^9, 3.929464299500291*^9, 
   3.9295045177993383`*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"003779d0-aa14-499f-b409-0de60cbab571"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ORDgINF", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g1", "[", "x_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"gi", "[", "i", "]"}], 
      SuperscriptBox["x", "i"]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"ORDgINF", "+", "2"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SEg1", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"eqgp1", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "\[Infinity]", ",", 
       RowBox[{"ORDgINF", "+", "2"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqsg1inf", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"SEg1", ",", "i"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", "ORDgINF"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vag1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"gi", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgp1INF", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"eqsg1inf", ",", "vag1"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgp2INF", "=", 
   RowBox[{"seriesgp1INF", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Kappa]p", "\[Rule]", "\[Kappa]m"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"\[Phi]1", ",", "\[Phi]2", ",", "g1", ",", "g2"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgm1INF", "=", 
   RowBox[{"seriesgp1INF", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Kappa]p", "\[Rule]", 
      RowBox[{"-", "\[Kappa]p"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgm2INF", "=", 
   RowBox[{"seriesgp2INF", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Kappa]m", "\[Rule]", 
      RowBox[{"-", "\[Kappa]m"}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.929301811711835*^9, {3.929377987581792*^9, 3.9293780011737947`*^9}, 
   3.9293781291953344`*^9},
 CellLabel->"In[74]:=",ExpressionUUID->"a982b5b5-7a8a-41f6-9412-891ca3a08ba9"],

Cell["We have therefore some possible boundary conditions", "Text",
 CellChangeTimes->{{3.929301885467797*^9, 3.929301897014262*^9}, {
  3.9293408737427025`*^9, 
  3.929340875022051*^9}},ExpressionUUID->"e91943ec-a39f-4828-87b1-\
b77280066a5f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Phi]1infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Kappa]p", " ", 
          RowBox[{"rst", "[", "r", "]"}]}], "-", 
         RowBox[{
          FractionBox["Mt", "\[Kappa]p"], " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgp1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]1infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Kappa]p", " ", 
             RowBox[{"rst", "[", "r", "]"}]}], "-", 
            RowBox[{
             FractionBox["Mt", "\[Kappa]p"], " ", 
             RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgp1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]2infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Kappa]m", " ", 
          RowBox[{"rst", "[", "r", "]"}]}], "-", 
         RowBox[{
          FractionBox["Mt", "\[Kappa]m"], " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgp2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]2infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Kappa]m", " ", 
             RowBox[{"rst", "[", "r", "]"}]}], "-", 
            RowBox[{
             FractionBox["Mt", "\[Kappa]m"], " ", 
             RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgp2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]1infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Kappa]p", " ", 
           RowBox[{"rst", "[", "r", "]"}]}], "-", 
          RowBox[{
           FractionBox["Mt", "\[Kappa]p"], " ", 
           RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgm1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]1infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Kappa]p", " ", 
              RowBox[{"rst", "[", "r", "]"}]}], "-", 
             RowBox[{
              FractionBox["Mt", "\[Kappa]p"], " ", 
              RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgm1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]2infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Kappa]m", " ", 
           RowBox[{"rst", "[", "r", "]"}]}], "-", 
          RowBox[{
           FractionBox["Mt", "\[Kappa]m"], " ", 
           RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgm2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]2infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Kappa]m", " ", 
              RowBox[{"rst", "[", "r", "]"}]}], "-", 
             RowBox[{
              FractionBox["Mt", "\[Kappa]m"], " ", 
              RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgm2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.549306349150929*^9, 3.549306466408806*^9}, {
   3.549306506116749*^9, 3.5493066062179193`*^9}, 3.549306783897386*^9, {
   3.549306874372128*^9, 3.54930690611703*^9}, {3.549306968185348*^9, 
   3.5493069961053953`*^9}, {3.549307034018713*^9, 3.549307070537508*^9}, {
   3.549307147404871*^9, 3.549307170540349*^9}, {3.549308112051601*^9, 
   3.54930813548073*^9}, {3.5493083977470417`*^9, 3.549308421151948*^9}, {
   3.549465135194933*^9, 3.5494651399318943`*^9}, {3.549465246538871*^9, 
   3.549465249298683*^9}, {3.549564293282992*^9, 3.549564303836585*^9}, {
   3.549566862048184*^9, 3.549566879444447*^9}, {3.549566982238987*^9, 
   3.549567011822197*^9}, {3.557481739284869*^9, 3.557481767696821*^9}, {
   3.557481914705408*^9, 3.557481966296197*^9}, {3.557523476897417*^9, 
   3.557523492212922*^9}, {3.5575687364618893`*^9, 3.55756876197223*^9}, {
   3.559034655725813*^9, 3.5590346984898252`*^9}, {3.55903478495746*^9, 
   3.5590348690719757`*^9}, {3.559035285694399*^9, 3.559035325173521*^9}, {
   3.559036138391244*^9, 3.5590361432442083`*^9}, {3.5590406676256104`*^9, 
   3.5590406725465937`*^9}, {3.559382821023629*^9, 3.55938283847692*^9}, {
   3.55947758200563*^9, 3.559477590333901*^9}, {3.559477650319872*^9, 
   3.559477661262896*^9}, 3.5594880515987587`*^9, {3.8751662786375217`*^9, 
   3.87516631086554*^9}, {3.8751667751010246`*^9, 3.8751667890718665`*^9}, {
   3.875166858284505*^9, 3.875166892297215*^9}, {3.875166944318454*^9, 
   3.8751669497671604`*^9}, {3.897679557335617*^9, 3.8976795791399813`*^9}, {
   3.9293019436666927`*^9, 3.9293019888130674`*^9}, 3.929302039416875*^9, {
   3.9293361836525655`*^9, 3.929336234805143*^9}, {3.9293363478328886`*^9, 
   3.92933637283202*^9}, {3.929339229104553*^9, 3.9293392469115*^9}, {
   3.929339749982477*^9, 3.9293397690903273`*^9}, {3.9293403838404894`*^9, 
   3.9293404117985563`*^9}, {3.929377661727792*^9, 3.9293776804787436`*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"038f6354-9d39-47c0-b919-f494e33ee54d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"w1", "=", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"]}]]}], ";", 
  RowBox[{"w2", "=", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], "2"]}]]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9293360114424887`*^9, 3.9293360312015777`*^9}},
 CellLabel->"In[92]:=",ExpressionUUID->"78ac535d-5e28-4df6-afa8-adfdb0887021"],

Cell["Each of these boundary conditions depend on the frequency", "Text",
 CellChangeTimes->{{3.9293020480135145`*^9, 3.929302052545566*^9}, {
  3.929335988460447*^9, 
  3.9293359977562118`*^9}},ExpressionUUID->"b6602cc9-4fbd-48f5-a027-\
5a86c4f1ed7a"]
}, Closed]],

Cell[CellGroupData[{

Cell["Specifying the source terms", "Subsubsection",
 CellChangeTimes->{{3.929302129098925*^9, 3.9293021351277795`*^9}, {
  3.929378146136842*^9, 
  3.929378148047904*^9}},ExpressionUUID->"4cb2f52a-88cf-4a5a-b305-\
b9bb2c999a0a"],

Cell["\<\
Here we show the source terms for a particle in circular motion.\
\>", "Text",
 CellChangeTimes->{{3.9293022422442684`*^9, 3.9293022455866537`*^9}, {
  3.9293023308313518`*^9, 
  3.9293023411541758`*^9}},ExpressionUUID->"97ff5e11-defe-420c-88b6-\
67e0f74a272d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "Alm1p", ",", "Flmp", ",", "Blm0p", ",", "Blmp", ",", "Almp", ",", 
    "\[CapitalOmega]0", ",", "u0"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9293026583471556`*^9, 3.9293026773601675`*^9}, {
  3.9294499865184965`*^9, 3.9294499918344584`*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"750793ea-9893-4f34-83bf-b332658061b1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Alm1p", "[", "x_", "]"}], ":=", "0"}], ";", 
  RowBox[{
   RowBox[{"Flmp", "[", "x_", "]"}], ":=", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"u0", " ", 
      SuperscriptBox["\[CapitalOmega]0", "2"], " ", 
      RowBox[{"dir", "[", 
       RowBox[{"x", ",", "rp"}], "]"}], " ", 
      SqrtBox[
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "x", "]"}]}], "x"]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["m", "2"], " ", 
         RowBox[{"Yp", "[", "\[Chi]p", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            SuperscriptBox["\[Chi]p", "2"]}], ")"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["Yp", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "\[Chi]p", "]"}]}]}], ")"}]}], 
     RowBox[{
      SqrtBox["2"], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "L"}], ")"}], " ", "L", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "L"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", "L"}], ")"}]}]], " ", 
      SqrtBox[
       RowBox[{"V", "[", "x", "]"}]]}]]}]}], ";", 
  RowBox[{
   RowBox[{"Blm0p", "[", "x_", "]"}], ":=", 
   FractionBox[
    RowBox[{"m", " ", "u0", " ", "\[CapitalOmega]0", " ", 
     RowBox[{"dir", "[", 
      RowBox[{"x", ",", "rp"}], "]"}], " ", 
     SqrtBox[
      RowBox[{"2", "-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"M", "[", "x", "]"}]}], "x"]}]], " ", 
     SqrtBox[
      RowBox[{"V", "[", "x", "]"}]], " ", 
     RowBox[{"Yp", "[", "\[Chi]p", "]"}]}], 
    RowBox[{
     SqrtBox[
      RowBox[{"L", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "L"}], ")"}]}]], " ", "x"}]]}], ";", 
  RowBox[{
   RowBox[{"Blmp", "[", "x_", "]"}], ":=", "0"}], ";", 
  RowBox[{
   RowBox[{"Almp", "[", "x_", "]"}], ":=", "0"}], ";"}]], "Input",
 CellChangeTimes->{{3.559583366075472*^9, 3.559583383006119*^9}, {
   3.5600202228098917`*^9, 3.5600202229754753`*^9}, 3.8725762990163937`*^9, {
   3.873516249002575*^9, 3.873516296539525*^9}, {3.8735290719085827`*^9, 
   3.8735290729269524`*^9}, {3.929302228065589*^9, 3.9293022402659736`*^9}, {
   3.9293030271233826`*^9, 3.9293030281788883`*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"d8bf5323-e245-4262-8fdc-f468cbb4d98d"],

Cell[TextData[{
 "defining the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["u", "0"], TraditionalForm]],ExpressionUUID->
  "7883c0a3-0625-400e-b137-a1777b3e14a5"],
 " and the rules for spherical harmonics"
}], "Text",
 CellChangeTimes->{{3.929302691755133*^9, 3.9293027139890747`*^9}, 
   3.9293392559691305`*^9, {3.929363210034976*^9, 3.929363212724832*^9}, {
   3.929378019509787*^9, 3.9293780200204196`*^9}, {3.9294506600647345`*^9, 
   3.929450661670266*^9}, {3.929452514933166*^9, 
   3.929452516219146*^9}},ExpressionUUID->"d80fe314-7c1e-4b3d-8f2d-\
5c7c27497277"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"V", "[", "r", "]"}], "-", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox["\[CapitalOmega]0", "2"]}]}], ")"}], 
    RowBox[{
     RowBox[{"-", "1"}], "/", "2"}]]}], ";", 
  RowBox[{"\[CapitalOmega]0", "=", 
   SqrtBox[
    FractionBox["Mbh", 
     SuperscriptBox["r", "3"]]]}], ";"}]], "Input",
 CellChangeTimes->{
  3.559583825284994*^9, {3.5595856939332314`*^9, 3.5595857002384853`*^9}, {
   3.9293027603103633`*^9, 3.929302761659951*^9}, {3.9293030544848986`*^9, 
   3.929303063205927*^9}, {3.929303165781002*^9, 3.929303166083785*^9}, {
   3.9293335080975447`*^9, 3.929333508382555*^9}, 3.9293386020217223`*^9, {
   3.9294499828097334`*^9, 3.929449982983261*^9}, {3.9294506524660697`*^9, 
   3.929450656406375*^9}},
 CellLabel->"In[95]:=",ExpressionUUID->"6f01dd23-1fbd-4260-b661-9a6e79275c40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rYp", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["Yp", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "\[Chi]p", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"L", 
             RowBox[{"(", 
              RowBox[{"L", "+", "1"}], ")"}]}], "-", 
            RowBox[{
             RowBox[{"m", "^", "2"}], "/", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"\[Chi]p", "^", "2"}]}], ")"}]}]}], ")"}], 
          RowBox[{"Yp", "[", "\[Chi]p", "]"}]}], "-", 
         RowBox[{"2", " ", "\[Chi]p", " ", 
          RowBox[{
           SuperscriptBox["Yp", "\[Prime]",
            MultilineFunction->None], "[", "\[Chi]p", "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[Chi]p", "2"]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"Yp", "[", "\[Chi]p", "]"}], "\[Rule]", 
      RowBox[{"SphericalHarmonicY", "[", 
       RowBox[{"L", ",", "m", ",", 
        RowBox[{"\[Pi]", "/", "2"}], ",", "0"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Yp", "'"}], "[", "\[Chi]p", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{"\[Chi]p", "\[Rule]", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.8727560914259143`*^9, {3.8730235673299227`*^9, 3.873023581383875*^9}, {
   3.8735161005078697`*^9, 3.8735161046598377`*^9}, 3.873529902197666*^9, {
   3.929303100577754*^9, 3.9293031213426456`*^9}, {3.92934049174562*^9, 
   3.929340493157275*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"29208c5a-093a-4f1a-bfb1-aef8e7523324"],

Cell["\<\
Finally, we apply for the source terms, simplifying the metric derivatives by \
using the background equations. The source for the first order fundamental \
functions (Kp,H1,\[Phi]1,\[Phi]1\[CloseCurlyQuote],\[Phi]2,\[Phi]2\
\[CloseCurlyQuote]), is given by\
\>", "Text",
 CellChangeTimes->{{3.9293029241318913`*^9, 3.9293029443564186`*^9}, {
  3.929303309770793*^9, 3.9293033113138*^9}, {3.9293405533973427`*^9, 
  3.9293405538612337`*^9}},ExpressionUUID->"80d703f5-3b6f-46c8-b144-\
c28a665af398"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SOURCEN", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SOURCE", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"SOURCE", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", "0", ",", 
       RowBox[{"SOURCE", "[", 
        RowBox[{"[", "4", "]"}], "]"}], ",", "0", ",", 
       RowBox[{"SOURCE", "[", 
        RowBox[{"[", "5", "]"}], "]"}]}], "}"}], "//.", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"eq1", ",", "eq2", ",", "eq3"}], "}"}], "\[Equal]", "0"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"V", "'"}], "[", "r", "]"}], ",", 
          RowBox[{
           RowBox[{"M", "'"}], "[", "r", "]"}], ",", 
          RowBox[{
           RowBox[{"\[Phi]0", "''"}], "[", "r", "]"}]}], "}"}]}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "//.", "rYp"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929302896067937*^9, 3.9293028969256296`*^9}, {
  3.929302951241872*^9, 3.9293030185471787`*^9}, {3.929303316071729*^9, 
  3.9293033591637077`*^9}, {3.929338548428838*^9, 3.9293385505790787`*^9}},
 CellLabel->"In[97]:=",ExpressionUUID->"7a7d05a4-efda-4e50-9510-68aef78925ac"],

Cell["\<\
We then split the tems that depend on the delta and derivative\
\>", "Text",
 CellChangeTimes->{{3.9293034260884905`*^9, 
  3.929303438614642*^9}},ExpressionUUID->"edfed9fa-0cbb-4ff3-b80f-\
237652aef9e6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SOURCED", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"SOURCEN", ",", 
     RowBox[{"dir", "[", 
      RowBox[{"r", ",", "rp"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SOURCEDD", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"SOURCEN", ",", 
     RowBox[{
      SuperscriptBox["dir", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"r", ",", "rp"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dSOURCEDD", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"SOURCEDD", ",", "r"}], "]"}], "//.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"eq1", ",", "eq2", ",", "eq3"}], "}"}], "\[Equal]", "0"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"V", "'"}], "[", "r", "]"}], ",", 
         RowBox[{
          RowBox[{"M", "'"}], "[", "r", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Phi]0", "''"}], "[", "r", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9293034571944857`*^9, 3.929303497117684*^9}},
 CellLabel->"In[98]:=",ExpressionUUID->"07f22f7a-ea66-4548-9b4d-0a25953586ae"],

Cell["\<\
We are now able to integrate the equation. Let us start with the homogeneous \
system.\
\>", "Text",
 CellChangeTimes->{{3.92930318243312*^9, 3.9293032001157656`*^9}, {
  3.9293035037169275`*^9, 
  3.929303504684022*^9}},ExpressionUUID->"5bb541a8-791e-4eef-9b07-\
d1dc086c1a26"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating the homogeneous system", "Subsubsection",
 CellChangeTimes->{{3.9293032107375164`*^9, 
  3.9293032155647516`*^9}},ExpressionUUID->"b67787ca-dca5-4a02-83dd-\
a72142ff01f6"],

Cell["\<\
To obtain the homogeneous matrix, we integrate three times from the origin \
and three times from the infinity. First we define the integrations as \
functions of the amplitudes\
\>", "Text",
 CellChangeTimes->{{3.929303217918003*^9, 3.929303248205279*^9}, {
  3.9293035078250914`*^9, 3.9293035084938097`*^9}, {3.929332147099522*^9, 
  3.929332163750059*^9}},ExpressionUUID->"d9891260-7ef9-468b-8150-\
fe3a94d6b40c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"INT", "[", 
    RowBox[{
    "g01_", ",", "g02_", ",", "g11_", ",", "g12_", ",", "L0_", ",", "m0_", 
     ",", "r01_", ",", "rp0_", ",", "r02_", ",", "rules_"}], "]"}], ":=", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Integrating", " ", "parameters"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"paramint2", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"MaxSteps", "\[Rule]", "\[Infinity]"}], ",", 
        RowBox[{"Method", "\[Rule]", "\"\<StiffnessSwitching\>\""}], ",", 
        RowBox[{"AccuracyGoal", "\[Rule]", "12"}], ",", 
        RowBox[{"PrecisionGoal", "\[Rule]", "12"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"paramp", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Sigma]", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"m0", " ", "\[CapitalOmega]0"}], "//.", "rules"}], "/.", 
           RowBox[{"r", "\[Rule]", "rp0"}]}], ")"}]}], ",", 
        RowBox[{"L", "\[Rule]", "L0"}], ",", 
        RowBox[{"m", "\[Rule]", "m0"}], ",", 
        RowBox[{"Mt", "\[Rule]", 
         RowBox[{"(", "Mbh", ")"}]}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Defining", " ", "the", " ", "equations"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"EQSP", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{
           RowBox[{"EQHOM", "[", 
            RowBox[{"[", 
             RowBox[{"1", ";;", "4"}], "]"}], "]"}], "\[Equal]", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]}], "]"}], "/.",
          "paramp"}], "//.", "rules"}], "/.", 
       RowBox[{"\[Phi]2", "\[Rule]", 
        RowBox[{"(", 
         RowBox[{"0", "&"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Integrations", " ", "from", " ", "the", " ", "origin"}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"boundary", " ", "conditions"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"BOU", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Thread", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"H0", "[", "r", "]"}], ",", 
              RowBox[{"H1", "[", "r", "]"}], ",", 
              RowBox[{"Kp", "[", "r", "]"}], ",", 
              RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
              RowBox[{
               RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "\[Equal]", 
            RowBox[{"BOUNOR", "[", 
             RowBox[{"[", 
              RowBox[{"1", ";;", "5"}], "]"}], "]"}]}], 
           RowBox[{"(*", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "g01", ",", "g02", ",", "0"}], "}"}],
             "*)"}], "]"}], "/.", 
          RowBox[{
           SubscriptBox["Vi", "0"], "\[Rule]", "1"}]}], "/.", "paramp"}], "/.", 
        RowBox[{"r", "\[Rule]", "r01"}]}], "//.", "rules"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", "integration", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"SOL1", "=", 
      RowBox[{
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{"EQSP", ",", "BOU"}], "]"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             SubscriptBox["kp", "0"], "\[Rule]", "g01"}], ",", 
            RowBox[{
             SubscriptBox["\[Phi]1i", "0"], "\[Rule]", "g02"}], ",", 
            RowBox[{
             SubscriptBox["\[Phi]2i", "0"], "\[Rule]", "0"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"Kp", ",", "H0", ",", "H1", ",", "\[Phi]1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "r01", ",", "rp0"}], "}"}], ",", "paramint2"}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"Integrations", " ", "from", " ", "infinity"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"To", " ", "improve", " ", "boundary", " ", 
       RowBox[{"conditions", ".", " ", "We"}], " ", "first", " ", "integrate",
        " ", "from", " ", "the", " ", "vacuum", " ", "region"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"for", " ", "the", " ", "gravitational", " ", 
       RowBox[{"part", ".", " ", "We"}], " ", "left", " ", "the", " ", 
       "scalar", " ", "and", " ", "gravitational", " ", "parts", " ", 
       "separately", " ", "as", " ", "scales", " ", "can", " ", "be", " ", 
       "different"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"EQSVACG", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Thread", "[", 
         RowBox[{
          RowBox[{"EQSVAC", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "3"}], "]"}], "]"}], "\[Equal]", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], "/.", 
        "paramp"}], "//.", "rules"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"BOUVACG", "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Thread", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"H0", "[", "r", "]"}], ",", 
              RowBox[{"H1", "[", "r", "]"}], ",", 
              RowBox[{"Kp", "[", "r", "]"}]}], "}"}], "==", "BOUGRAV"}], 
           "]"}], "/.", "paramp"}], "/.", 
         RowBox[{"r", "\[Rule]", "r02"}]}], "/.", 
        RowBox[{
         SubscriptBox["kpi", "0"], "\[Rule]", "g11"}]}], "//.", "rules"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"SOLGV", "=", 
      RowBox[{
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{"EQSVACG", ",", "BOUVACG"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"H0", ",", "H1", ",", "Kp"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "r02", ",", 
           RowBox[{"rinf", "//.", "rules"}]}], "}"}], ",", "paramint2"}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"BOUGI", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"H0", "[", 
          RowBox[{"rinf", "//.", "rules"}], "]"}], "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"H0", "[", 
            RowBox[{"rinf", "//.", "rules"}], "]"}], "/.", "SOLGV"}], ")"}]}],
         ",", 
        RowBox[{
         RowBox[{"H1", "[", 
          RowBox[{"rinf", "//.", "rules"}], "]"}], "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"H1", "[", 
            RowBox[{"rinf", "//.", "rules"}], "]"}], "/.", "SOLGV"}], ")"}]}],
         ",", 
        RowBox[{
         RowBox[{"Kp", "[", 
          RowBox[{"rinf", "//.", "rules"}], "]"}], "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Kp", "[", 
            RowBox[{"rinf", "//.", "rules"}], "]"}], "/.", "SOLGV"}], 
          ")"}]}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"for", " ", "the", " ", "scalar", " ", 
        RowBox[{"part", ".", " ", "There"}], " ", "are", " ", "a", " ", 
        "bunch", " ", "of", " ", "Ifs"}], ",", " ", 
       RowBox[{
       "to", " ", "account", " ", "for", " ", "different", " ", "values", " ",
         "of", " ", "the", " ", "frequency"}]}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"EQSVACS", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"Thread", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"EQSVAC", "[", 
            RowBox[{"[", "4", "]"}], "]"}], "}"}], "\[Equal]", 
          RowBox[{"{", "0", "}"}]}], "]"}], "/.", "paramp"}], "//.", 
       "rules"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"1", "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"]}], ">", "0"}],
          "/.", "paramp"}], "//.", "rules"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"BOUSI", "=", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                 "\[Phi]1infm"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                 "d\[Phi]1infm"}]}], "}"}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
                RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
             RowBox[{"r", "->", "rinf"}]}], "/.", "paramp"}], "//.", 
           "rules"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Phi]01", "\[Rule]", "g12"}], ",", 
            RowBox[{"\[Phi]02", "\[Rule]", "g13"}]}], "}"}]}]}], ";"}], 
       "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"BOUSIi", "=", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                 "\[Phi]1infp"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                 "d\[Phi]1infp"}]}], "}"}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
                RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
             RowBox[{"r", "\[Rule]", "r02"}]}], "/.", "paramp"}], "//.", 
           "rules"}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Phi]01", "\[Rule]", "g12"}], ",", 
            RowBox[{"\[Phi]02", "\[Rule]", "g13"}]}], "}"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"S\[Phi]1", "=", 
         RowBox[{
          RowBox[{"NDSolve", "[", 
           RowBox[{
            RowBox[{"Join", "[", 
             RowBox[{"EQSVACS", ",", "BOUSIi"}], "]"}], ",", 
            RowBox[{"{", "\[Phi]1", "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"r", ",", "r02", ",", 
              RowBox[{"rinf", "//.", "rules"}]}], "}"}], ",", "paramint2"}], 
           "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"BOUSI", "=", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"\[Phi]1", "[", "r", "]"}], "/.", "S\[Phi]1"}], 
                  ")"}]}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "/.", 
                   "S\[Phi]1"}], ")"}]}]}], "}"}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
                RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
             RowBox[{"r", "->", "rinf"}]}], "/.", "paramp"}], "//.", 
           "rules"}], "/.", 
          RowBox[{"{", 
           RowBox[{"\[Phi]01", "\[Rule]", "g12"}], "}"}]}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
      "Now", " ", "we", " ", "can", " ", "finally", " ", "integrate", " ", 
       "inside", " ", "the", " ", "star", " ", "up", " ", "to", " ", "the", 
       " ", 
       RowBox[{"particle", "'"}], "s", " ", "position"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"BOUINF", "=", 
      RowBox[{"Join", "[", 
       RowBox[{"BOUGI", ",", "BOUSI"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"SOL2", "=", 
      RowBox[{
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{"EQSP", ",", "BOUINF"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"H0", ",", "H1", ",", "Kp", ",", "\[Phi]1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", 
           RowBox[{"rinf", "//.", "rules"}], ",", "rp0"}], "}"}], ",", 
         "paramint2"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
    ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9293321735191293`*^9, 3.929332188272459*^9}, {
   3.929332366961613*^9, 3.929332463937969*^9}, {3.929332568985113*^9, 
   3.9293325730069304`*^9}, {3.929333308287141*^9, 3.929333424256067*^9}, {
   3.9293334747519255`*^9, 3.929333536008857*^9}, {3.9293345735165076`*^9, 
   3.929334603357423*^9}, {3.929334633415614*^9, 3.929334663396658*^9}, {
   3.929334698161705*^9, 3.9293347545373325`*^9}, {3.92933485238332*^9, 
   3.9293348533522973`*^9}, {3.929334898322174*^9, 3.9293353863499556`*^9}, {
   3.9293354303153057`*^9, 3.9293357077403345`*^9}, {3.929335862009441*^9, 
   3.9293359571370525`*^9}, {3.9293360451401944`*^9, 
   3.9293361775997562`*^9}, {3.9293362481944113`*^9, 3.929336334255066*^9}, {
   3.929336568245969*^9, 3.929336865128681*^9}, {3.929336952543502*^9, 
   3.929337017284218*^9}, {3.929337053452876*^9, 3.929337163226738*^9}, {
   3.929337201757922*^9, 3.9293372042354155`*^9}, {3.9293372820784197`*^9, 
   3.9293373245631943`*^9}, {3.929337382982788*^9, 3.9293375690242195`*^9}, {
   3.9293376095454226`*^9, 3.9293376113919687`*^9}, {3.929338057621595*^9, 
   3.9293380580381327`*^9}, 3.9293383709663477`*^9, 3.929339296549758*^9, {
   3.92934037017126*^9, 3.929340377016081*^9}, {3.9293634247685213`*^9, 
   3.929363429375661*^9}, {3.9293641069731445`*^9, 3.929364113383202*^9}, {
   3.929364325166173*^9, 3.9293643778943357`*^9}, {3.9293644664064646`*^9, 
   3.929364479157464*^9}, {3.9293645155503902`*^9, 3.9293645212871923`*^9}, {
   3.929368864523243*^9, 3.9293688651211615`*^9}, {3.929377705742117*^9, 
   3.9293777532956767`*^9}, 3.929407751078015*^9, {3.9294496433671136`*^9, 
   3.9294496704152355`*^9}, {3.9294497888851805`*^9, 
   3.9294498222920837`*^9}, {3.9294499079481544`*^9, 
   3.9294499385122166`*^9}, {3.9294509485534816`*^9, 
   3.9294509519865613`*^9}, {3.9294514276319737`*^9, 3.929451455828657*^9}, {
   3.929452361045472*^9, 3.92945244521133*^9}, {3.929452478934063*^9, 
   3.929452491287875*^9}, {3.9294525312944117`*^9, 3.9294525868373647`*^9}, {
   3.9294528461181974`*^9, 3.9294528462791185`*^9}, {3.9294548700162754`*^9, 
   3.9294548866982822`*^9}, {3.929456692466968*^9, 3.9294566945065985`*^9}, {
   3.929457034868334*^9, 3.929457238182355*^9}, {3.9294573070059814`*^9, 
   3.929457310985074*^9}, {3.929457486560855*^9, 3.9294574989470606`*^9}, {
   3.9294581877006335`*^9, 3.929458262538633*^9}, {3.9294597215888805`*^9, 
   3.92945972549531*^9}, {3.9294602069598904`*^9, 3.92946020939289*^9}, {
   3.929460721505473*^9, 3.929460745927327*^9}, {3.929460952748859*^9, 
   3.929460954549646*^9}, 3.9294612119111505`*^9, {3.9295045052062874`*^9, 
   3.929504507041168*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"a1230d2b-b2e5-4a9c-838c-2d004a704927"],

Cell[BoxData[
 RowBox[{"INT", "[", 
  RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "2", ",", 
   RowBox[{
    RowBox[{"2.1", "Mbh"}], "//.", "ruclou"}], ",", 
   RowBox[{
    RowBox[{"10", "Mbh"}], "//.", "ruclou"}], ",", "500", ",", "ruclou"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.9294498332725134`*^9, 3.9294498731882124`*^9}, 
   3.929456897187831*^9, {3.9294572279067187`*^9, 3.929457228948459*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"4b0b668b-67a7-445d-af8a-cfd898f54cce"],

Cell["\<\
With the integrator above, we can construct the fundamental matrix\
\>", "Text",
 CellChangeTimes->{{3.9293376291114826`*^9, 
  3.929337640641464*^9}},ExpressionUUID->"a9c5b71d-8550-4a7f-8b6f-\
3970c5ff50b0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MATRIX", "[", 
   RowBox[{
   "L0_", ",", "m0_", ",", "r01_", ",", "rp0_", ",", "r02_", ",", "rules_"}], 
   "]"}], ":=", 
  RowBox[{"(", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"INT", "[", 
     RowBox[{
     "1", ",", "0", ",", "1", ",", "0", ",", "L0", ",", "m0", ",", "r01", ",",
       "rp0", ",", "r02", ",", "rules"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]1", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL1"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]2", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL2"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"INT", "[", 
     RowBox[{
     "0", ",", "1", ",", "0", ",", "1", ",", "L0", ",", "m0", ",", "r01", ",",
       "rp0", ",", "r02", ",", "rules"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]3", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL1"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]4", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Kp", "[", "r", "]"}], ",", 
        RowBox[{"H1", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL2"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"For", " ", "the", " ", "Matrix"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"XS", "=", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[CapitalPsi]1", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]2", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]3", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]4", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", 
      RowBox[{"r", "\[Rule]", "rp0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"dXS", "=", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"XS", ",", "r"}], "]"}], "/.", 
      RowBox[{"r", "\[Rule]", "rp0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"invXS", "=", 
     RowBox[{"Inverse", "[", "XS", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"dinvXS", "=", 
     RowBox[{"-", 
      RowBox[{"invXS", ".", "dXS", ".", "invXS"}]}]}], ";"}], 
   "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.9293376434735155`*^9, 3.9293377283061543`*^9}, {
  3.929337766271801*^9, 3.929337845122262*^9}, {3.929337876111882*^9, 
  3.9293380065407505`*^9}, {3.929338102552593*^9, 3.929338109157919*^9}, {
  3.9294575081535077`*^9, 3.929457544285553*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"b2e9d75b-a3f8-47b4-9b31-6676fbf56e33"],

Cell["\<\
With the above and the source term we can construct the particular solution \
to find the fluxes\
\>", "Text",
 CellChangeTimes->{{3.9293381629393234`*^9, 3.9293381803307867`*^9}, {
  3.929378156077294*^9, 
  3.9293781568939595`*^9}},ExpressionUUID->"f784fac5-90a1-4205-b72e-\
a315d517a506"]
}, Closed]],

Cell[CellGroupData[{

Cell["Using the variation of parameters to find the fluxes", "Subsubsection",
 CellChangeTimes->{{3.9293381889079776`*^9, 
  3.9293382007169466`*^9}},ExpressionUUID->"6df26a84-fd1c-4752-8373-\
c6e9bdd9fc92"],

Cell["\<\
The flux can be computed by making the matrix product of the inverse of X \
with the source term and integrating it. Because of the deltas and \
derivatives, what remains is to compute it at the particle position\
\>", "Text",
 CellChangeTimes->{{3.9293670986276536`*^9, 3.92936709981993*^9}, {
  3.929367200381386*^9, 3.9293672048165307`*^9}, {3.929378158481496*^9, 
  3.9293782099901733`*^9}},ExpressionUUID->"e0677950-e79b-4427-8021-\
82990c70d048"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FLUXP", "[", 
   RowBox[{
   "l0_", ",", "m0_", ",", "r01_", ",", "rp0_", ",", "r02_", ",", "rules_"}], 
   "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MATRIX", "[", 
     RowBox[{
     "l0", ",", "m0", ",", "r01", ",", "rp0", ",", "r02", ",", "rules"}], 
     "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"param", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"paramp", ",", 
       RowBox[{"{", 
        RowBox[{"m", "\[Rule]", "m0"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"EvenQ", "[", 
        RowBox[{"l0", "+", "m0"}], "]"}], "==", "True"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rulesY", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"Yp", "[", "\[Chi]p", "]"}], "\[Rule]", 
           RowBox[{"SphericalHarmonicY", "[", 
            RowBox[{"l0", ",", "m0", ",", 
             RowBox[{"\[Pi]", "/", "2"}], ",", "0"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Yp", "'"}], "[", "\[Chi]p", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Yp", "''"}], "[", "\[Chi]p", "]"}], "\[Rule]", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"SphericalHarmonicY", "[", 
               RowBox[{"l0", ",", "m0", ",", "\[Theta]", ",", "0"}], "]"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"\[Theta]", ",", "2"}], "}"}]}], "]"}]}], "/.", 
           RowBox[{"\[Theta]", "\[Rule]", 
            RowBox[{"\[Pi]", "/", "2"}]}]}]}], "}"}]}], ";"}], 
      "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"rulesY", "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Yp", "'"}], "[", "\[Chi]p", "]"}], "\[Rule]", 
            RowBox[{"-", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"SphericalHarmonicY", "[", 
                RowBox[{"l0", ",", "m0", ",", "\[Theta]", ",", "0"}], "]"}], 
               ",", "\[Theta]"}], "]"}]}]}], "/.", 
           RowBox[{"\[Theta]", "\[Rule]", 
            RowBox[{"\[Pi]", "/", "2"}]}]}], ",", 
          RowBox[{
           RowBox[{"Yp", "[", "\[Chi]p", "]"}], "\[Rule]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Yp", "''"}], "[", "\[Chi]p", "]"}], "\[Rule]", "0"}]}], 
         "}"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"II", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"invXS", ".", 
          RowBox[{"SOURCED", "[", 
           RowBox[{"[", 
            RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], ")"}], "/.", 
        RowBox[{"Union", "[", 
         RowBox[{"param", ",", "rulesY", ",", "rules"}], "]"}]}], "/.", 
       RowBox[{"r", "\[Rule]", "rp0"}]}], "/.", 
      RowBox[{"\[Chi]p", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"dII", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"invXS", ".", 
            RowBox[{"dSOURCEDD", "[", 
             RowBox[{"[", 
              RowBox[{"1", ";;", "4"}], "]"}], "]"}]}], "+", 
           RowBox[{"dinvXS", ".", 
            RowBox[{"SOURCEDD", "[", 
             RowBox[{"[", 
              RowBox[{"1", ";;", "4"}], "]"}], "]"}]}]}], ")"}]}], "/.", 
        RowBox[{"Union", "[", 
         RowBox[{"param", ",", "rulesY", ",", "rules"}], "]"}]}], "/.", 
       RowBox[{"r", "\[Rule]", "rp0"}]}], "/.", 
      RowBox[{"\[Chi]p", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"IIg", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"II", "+", "dII"}], ")"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"II\[Phi]1", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"II", "+", "dII"}], ")"}], "[", 
      RowBox[{"[", "4", "]"}], "]"}]}], ";", 
    RowBox[{"(*", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"II\[Phi]2", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"II", "+", "dII"}], ")"}], "[", 
        RowBox[{"[", "6", "]"}], "]"}]}], ";"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Computing", " ", "the", " ", "fluxes"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"GravFlux", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"32", "\[Pi]"}]], 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l0", "+", "2"}], ")"}], "!"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l0", "-", "2"}], ")"}], "!"}]], 
        SuperscriptBox[
         RowBox[{"Abs", "[", 
          RowBox[{"IIg", " ", "\[Sigma]"}], "]"}], "2"]}], "/.", "param"}], "//.",
       "ruclou"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Omega]", "+", 
              RowBox[{"m0", " ", "\[CapitalOmega]0"}]}], ")"}], "2"], "/.", 
           "paramp"}], "//.", "rules"}], "/.", 
         RowBox[{"r", "\[Rule]", "rp0"}]}], ")"}], "\[GreaterEqual]", "1"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Phi]f1", "=", "II\[Phi]1"}], " ", ";"}], 
      "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Phi]f1", "=", "0"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"ScalFlux", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]], 
        RowBox[{"(", "\[Sigma]", ")"}], 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "-", "1"}]], 
        SuperscriptBox[
         RowBox[{"Abs", "[", "\[Phi]f1", "]"}], "2"]}], "/.", "paramp"}], "//.",
       "rules"}]}], ";"}], "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.929338289527746*^9, 3.929338315339635*^9}, {
   3.9293384197855415`*^9, 3.9293384577761526`*^9}, {3.929338611700952*^9, 
   3.9293386138132067`*^9}, {3.9293386669887347`*^9, 3.92933866866003*^9}, {
   3.9293387044652863`*^9, 3.9293387084473004`*^9}, {3.929338895355666*^9, 
   3.9293388955157614`*^9}, 3.9293655945357094`*^9, {3.9293662396862564`*^9, 
   3.929366351772291*^9}, {3.9293678887572613`*^9, 3.9293678902406263`*^9}, {
   3.9293680297342386`*^9, 3.9293680311952095`*^9}, {3.9293686926192536`*^9, 
   3.9293686969912214`*^9}, {3.9294498255794363`*^9, 3.9294498271575933`*^9}, 
   3.9294528525725136`*^9, {3.9294551618903866`*^9, 3.929455162238994*^9}, {
   3.9294562437126694`*^9, 3.929456247517359*^9}, {3.9294562933383336`*^9, 
   3.929456293499444*^9}, {3.9294567793218765`*^9, 3.929456781457656*^9}, {
   3.9294575621452427`*^9, 3.9294576134157076`*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"16c5713b-7e2e-41ca-85d6-b4927f5fb2e9"],

Cell["With the above we can extract the fluxes", "Text",
 CellChangeTimes->{{3.9324694485371857`*^9, 
  3.9324694554157543`*^9}},ExpressionUUID->"a2ecf9d2-b1ad-4cfd-b79c-\
58ba37faf482"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FLUXP", "[", 
  RowBox[{"2", ",", "2", ",", 
   RowBox[{
    RowBox[{"2.1", "Mbh"}], "//.", "ruclou2"}], ",", 
   RowBox[{
    RowBox[{"15", " ", "Mbh"}], "//.", "ruclou2"}], ",", "1600", ",", 
   "ruclou2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ScalFlux", " ", 
  SuperscriptBox["0.08", "2"]}]}], "Input",
 CellChangeTimes->{{3.9295080361924295`*^9, 3.9295080482913876`*^9}, {
   3.929508080511306*^9, 3.929508103386363*^9}, {3.92950822106278*^9, 
   3.929508222630168*^9}, 3.929508261727236*^9, {3.9295083272514524`*^9, 
   3.929508327356535*^9}, {3.929508540713266*^9, 3.9295085821098385`*^9}},
 CellLabel->
  "In[292]:=",ExpressionUUID->"09e032fd-e5f3-4e7f-9bc3-732a037f9bc0"],

Cell[BoxData["4.177938475286358`*^-10"], "Output",
 CellChangeTimes->{{3.929508223480465*^9, 3.9295082628424253`*^9}, {
   3.929508317198204*^9, 3.9295083282161665`*^9}, 3.9295083591153603`*^9, {
   3.929508542021758*^9, 3.9295085832606525`*^9}},
 CellLabel->
  "Out[293]=",ExpressionUUID->"ae8f9ffd-3c22-4a0b-8750-7d02f3449c7f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruclou2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"M", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{"Mbh", "&"}], ")"}]}], ",", 
     RowBox[{"V", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "Mbh"}], "#1"]}], "&"}], ")"}]}], ",", 
     RowBox[{"\[Phi]0", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox[
          SqrtBox["\[Pi]"], "2"], 
         SqrtBox[
          FractionBox["M\[CapitalPhi]", 
           RowBox[{"\[Pi]", " ", "Mbh"}]]], " ", 
         SuperscriptBox["Mbh", "2"], " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "Mbh"}], " ", "#1"}], "]"}]}], "&"}], ")"}]}], ",", 
     RowBox[{"\[Omega]", "\[Rule]", 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["Mbh", "2"], "2"]}]}], ",", 
     RowBox[{"M\[CapitalPhi]", "\[Rule]", 
      RowBox[{"0.1`", " ", "Mbh"}]}], ",", 
     RowBox[{"Mbh", "\[Rule]", "0.08`"}], ",", 
     RowBox[{"\[Phi]c", "\[Rule]", 
      RowBox[{"\[Phi]0", "[", 
       RowBox[{"2.1`", " ", "Mbh"}], "]"}]}], ",", 
     RowBox[{"rinf", "\[Rule]", "400"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9295080106055045`*^9, 3.929508031767767*^9}, {
   3.9295080865704517`*^9, 3.929508100566685*^9}, {3.929508162197341*^9, 
   3.929508254226837*^9}, 3.9295083146643114`*^9},
 CellLabel->
  "In[276]:=",ExpressionUUID->"ef11a761-029f-4724-89dc-80f79ce38e17"],

Cell[BoxData[
 RowBox[{"FLUXP", "[", 
  RowBox[{"2", ",", "2", ",", 
   RowBox[{
    RowBox[{"2.2", "Mbh"}], "//.", "ruclou"}], ",", 
   RowBox[{
    RowBox[{"xx", " ", "Mbh"}], "//.", "ruclou"}], ",", "1600", ",", 
   "ruclou"}], "]"}]], "Input",ExpressionUUID->"00c23082-eb13-4d62-acd4-\
2dc220e15e2a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tt2", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xx", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"FLUXP", "[", 
            RowBox[{"2", ",", "2", ",", 
             RowBox[{
              RowBox[{"2.2", "Mbh"}], "//.", "ruclou"}], ",", 
             RowBox[{
              RowBox[{"xx", " ", "Mbh"}], "//.", "ruclou"}], ",", "1600", ",",
              "ruclou"}], "]"}], "//", "Quiet"}], ";", 
          RowBox[{
           FractionBox["ScalFlux", 
            SqrtBox[
             FractionBox["\[Pi]", "2"]]], " ", 
           SuperscriptBox["0.08", "2"]}]}], ",", 
         RowBox[{"GravFlux", " ", 
          SuperscriptBox["0.08", "2"]}]}], " ", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"xx", ",", "6", ",", "450", ",", "1"}], "}"}]}], "]"}], ",", 
     "xx"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929450031357421*^9, 3.9294500342089005`*^9}, {
   3.929450114524139*^9, 3.9294501343199797`*^9}, {3.929450973206047*^9, 
   3.9294510304230523`*^9}, {3.929451170365488*^9, 3.9294511768402653`*^9}, {
   3.9294514019642353`*^9, 3.9294514145453215`*^9}, {3.9294516455122175`*^9, 
   3.9294516747977304`*^9}, {3.929452908936305*^9, 3.9294529296226096`*^9}, {
   3.9294529973911324`*^9, 3.9294530120179815`*^9}, {3.929455351021806*^9, 
   3.929455351220272*^9}, {3.929455427221921*^9, 3.9294554275640373`*^9}, {
   3.9294555803485675`*^9, 3.9294555819548836`*^9}, {3.929455622692171*^9, 
   3.9294556417857733`*^9}, {3.929455748065428*^9, 3.929455767142266*^9}, {
   3.9294558877307887`*^9, 3.929455902574319*^9}, {3.929456350219634*^9, 
   3.9294563545843287`*^9}, {3.9294565291486063`*^9, 
   3.9294565309336567`*^9}, {3.9294576287965593`*^9, 
   3.9294576359684334`*^9}, {3.929458148679843*^9, 3.92945816557682*^9}, {
   3.929459508245403*^9, 3.9294595096165247`*^9}, {3.929464414106464*^9, 
   3.929464414192691*^9}, {3.929464860713113*^9, 3.9294648613413553`*^9}, {
   3.929506352082446*^9, 3.9295063523442197`*^9}, 3.9295066048660927`*^9},
 CellLabel->
  "In[176]:=",ExpressionUUID->"3c23d6e6-591b-4322-976f-88027f4a8da1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tt3", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xx", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"FLUXP", "[", 
            RowBox[{"3", ",", "3", ",", 
             RowBox[{
              RowBox[{"2.2", "Mbh"}], "//.", "ruclou"}], ",", 
             RowBox[{
              RowBox[{"xx", " ", "Mbh"}], "//.", "ruclou"}], ",", "1000", ",",
              "ruclou"}], "]"}], "//", "Quiet"}], ";", 
          RowBox[{
           FractionBox["ScalFlux", 
            SqrtBox[
             FractionBox["\[Pi]", "2"]]], " ", 
           SuperscriptBox["0.08", "2"]}]}], ",", 
         RowBox[{"GravFlux", " ", 
          SuperscriptBox["0.08", "2"]}]}], " ", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"xx", ",", "6", ",", "450", ",", "1"}], "}"}]}], "]"}], ",", 
     "xx"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9294595033773537`*^9, 3.929459514327814*^9}, {
   3.929459608704912*^9, 3.9294596087777157`*^9}, {3.9294644161758704`*^9, 
   3.929464416297605*^9}, {3.929505945464533*^9, 3.9295059456068664`*^9}, 
   3.9295066064774323`*^9},
 CellLabel->
  "In[177]:=",ExpressionUUID->"c4744d6b-3807-455c-a5f4-d304a2a71f2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9295077396042385`*^9, 3.929507765460101*^9}},
 CellLabel->
  "In[179]:=",ExpressionUUID->"8c0cd337-a86d-4bdf-af0c-dcec9b88464d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"texp", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"tt2", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"tt2", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
       RowBox[{"tt2", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "3"}], "]"}], "]"}], ",", 
       RowBox[{"tt3", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
       RowBox[{"tt3", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "@", "tt2"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929507772041153*^9, 3.929507792232365*^9}, {
  3.929507986045354*^9, 3.929507998100926*^9}},
 CellLabel->
  "In[185]:=",ExpressionUUID->"ced4bf84-6e1e-4818-9d37-17411dbdc828"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<data/flux_clouds_rp_l2l3.dat\>\"", ",", "texp"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.929507766824147*^9, 3.929507768146317*^9}, {
  3.929507814735301*^9, 3.929507835665262*^9}},
 CellLabel->
  "In[186]:=",ExpressionUUID->"8fc7a870-dcbd-4861-80f3-3f34021bc7f2"],

Cell[BoxData["\<\"data/flux_clouds_rp_l2l3.dat\"\>"], "Output",
 CellChangeTimes->{3.9295078361544456`*^9, 3.929507999135435*^9},
 CellLabel->
  "Out[186]=",ExpressionUUID->"00471a58-e7e3-4cd9-aec1-96f02b4202a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogLogPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"tt2", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"tt3", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"tt2", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"tt3", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"6", ",", "400"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["10", 
         RowBox[{"-", "12"}]], ",", 
        SuperscriptBox["10", 
         RowBox[{"-", "3"}]]}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.929506316804185*^9, 3.929506379574899*^9}, {
   3.9295064539887867`*^9, 3.929506486282062*^9}, {3.9295065453436337`*^9, 
   3.9295065956541514`*^9}, 3.929506670517394*^9, {3.9295069406556563`*^9, 
   3.929506956426801*^9}, {3.9295069886008635`*^9, 3.9295069887174983`*^9}},
 CellLabel->
  "In[178]:=",ExpressionUUID->"a91fb940-1d79-4a04-858a-944ec575db0c"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHk4F+33x4Xs22eZmWSLKOJRNDNKixOJFCkpRFSUipIlRUWbKEtlK0uF
7CL7GndEq8reLqG9qGyJ/O7v9Ty/vz7X67pmPjP3Oe/zPueM6vb9G9wEBQQE
Tk4TEPjfr+CseeOSuRNGKwXen1PcxqDNDvr53mpTRqyf7Jz0MAb55C4xKkoV
gJbR3TtfXmGQpNCNgM/R02DD3N1nZmQziLQtrS7cKwhzuXAmIY9Baw2Cynt1
heDBP+7uj3MZdPRKWw3ZIwSaB4XW6WUxaH24nrbwaWF4/e3QjopUBmVWd5EP
FKdD0l2zdJEkBqmYWy4mc6bDK0FxlXMxDBpYPP7XWFcE9lkt77wYzqCAoPHb
e3NEwJpgB2xOMSjkwl7DQBVR8Ot43jIUyCCdYmERNlIUIs3WvTvvw6ALvT6B
xqOi4NOzpXDJXgYV5u+P0d0iButSV+gK7WDQvcZl/r5VYvC3p3jBDwcGDRa3
TB4lxMHVtue8lA2DfutcPJLpIQ6CqS2D9msYtDDi2+gKJA7mPPl1r0wY1Dxz
8HOMnAT0T4R7xy5l0PlTQhXdThKwMZwyDGEYNNsirtMhSwImWz2e5evi8/1t
frhoUAKWX0UCspoMSuyU/J3BSIL9cK5YhiqDHLQvmD8+JAnaE4+m+SgwaO+9
itq2SknY72nT7EswqKWiY+jZmCTY2vTNy5Fl0Ih05fEJRgoM1nxp4EgwqPGX
rI3DASmY4G+ic4QZ9G9+pUDdgeB4T9Ho1l3D75q9UjBLZMG3XeM0ylrR0Ngk
Lw2/sw87nR2mUad0qPtvK2mwE3D90zVII2lv/SVtJ6RhpQBv17qvNLLKizR1
K5WGoBfPzAc+0OifZbob695Lw3d10w1lvTTifOWTg6QMPLbrWp7WTSOTjRPs
9FUyEL/Ho73kJY2u3087KOkrA9Wqx3o/ddHIw/j8LZkUGeiJ0jdb0U6jssHz
82c2y0Cm4ab+yqc08qu2XrpoTAacFbXzNzTT/+lTFtY/NUuSeECjAoW88tY1
stApbVLytolGUwLrp1x8ZWHl8gDh9gYarc7Oz9FIkoW5VWXXexGNcpequWs2
yIJT/vNSmVoaSfHq/b0+yULJZPy2jdU0+vW3yv6EqBzIfp72oriCRtYe8x4O
y8vB7IaN9jplNLJPuJFC6MjB0vEzqreKaWS5qqmxb5kc0P3TjrgV0uiw1t3f
buvk4H6ddaV6AY3O6bu9SnSRg6CilgXjeTieHtwvoQfkoNd2G/Tn0OjLq7mn
5p+Qg0gphbX9WTRSmNH78cJFORgp5tX+zqD/qz85MFomK6KWjuOhFRN9sUgO
nrsvueyURqOM2RYv6Ho5OKUh8DM3BeeDo/kjoUUOKodvRUldo9Hix9XXmt7K
wUTA+ZFjV2hUPTMmuXJADvzDVQoEk2mkumJXmN9fORDY4boqPpFG9zvVh/5I
caD31UnLpQk0Mto85GilwAHvwlj7H5do9H6+2sJ9WhyIqTwqVBZPI6XciU5H
Aw7YdNz+EBZHI0fR1AQFUw4kDDlkeMTSiPsR1edu4EDWSPw7pxgaLdVfe0bG
hQO3YkaMnaJppGU1m2/qyQGXPVNeey7i8xYWhFkHcOCwobr86Qs0Whl8aFLv
DAeSTVM/552n//MfDgRd2hnfE0Ujt+QMwcBrHGif+NKmhvlE3/aIvjwOVEXN
3ewVSaN2txFxzUoOOBftfnE/gkYSaWNbVzVyIDJhlfx8zKtufdoDLRwIXHe8
5Wo4jVqNLgpTrzlgJzlYr4DZ5YDTnwcfOTB+al9B6jkajZzNp5yGONA/p8GB
xiyno6fweIoDk7uizz49S6NaR43bypJcEAoxF/HH7OueWbuO5ILpqGD8XMxe
nb/qt6lyYbNcmOi7MBpdrsv0t9XhQqjKEvUMzL01k8HaBlzI2Dpe5YN57Lro
sb4VXOgKUU+0+B+v6Rc7vpYL8meCY+dh3uM7VjZtMxfiTPSP8DBrK5Hyu7Zx
IflUvtp0zP/6Mxeu++Q7TYXSSK9KYe47Py7cFFcXEgz7nx+c6R4L4oKm5PzP
Upi/8uzdRsK48Hkx94sK5neJLPMymgs7jbW6DTGnGy68l5nMBR3z7mtOmKPd
BqMdM7kg7p8uGYp5i1mdxPhNLrz88+lPJeY71igxuIoL2kdk1/3CLGI7rXiw
gQs9T117F+J46K1KqLRo5oLHd8VLgZhTrt8jojq5wCqbWz7AHFEsrl3bzQWb
kYe9KjjejicXOjz7yIVZyHHZEczxPeHT3vzgwkDJwaXdmE2X9R15Ms6F8KTN
d8xx/s5FpGvcEOLBpPlYRQXmfLOBDf5SPHiTIzali/Nf7pVhr0vwQOjt+8Bc
zDadYeGtSjzwzkkkdLF+7h9eudR1Dg+SlTqKyjD/2994YOfaY2iK9bam+IfF
egMeWHRmxz7H/CnOe8UNI/z/Vvm5PlivWuqifaNmPEhXnraTh/X8QevnYT1r
HuhOX5Ffgdneud7cwY4HRRbx+3Zg/RvrusR4u/DgZHPRBR6uj8KfM68GuPOg
+HyD4H3MD8tKs729eHAj1f/GSVxPxV4+vxwO8UCfHT1qgutt+z21qoXBPNgV
0uMihuuxb4+W4eQZHsT9s9qkFbPOYGR+eRQPnkze5Kbg+t1rJ7p+Rzw+n5T4
LV9c37Eak/YCV3ngtit3geVlGvkTiQJRGTywDbJ3nIf9IDm4I0A2nwc1sxfP
l8J+8Xubz+TxUh7E17dc+omZK0nVvK/hwewFEmGvk2i0NXTVp2V3eKCXpjH4
CPuNcqVP2ZmHOB+Xbtci7EeiysIb77TyYK5bW3/FVRo93mb349dzHjQ9Sd9U
iv3r3/mBB4XyXYJl2N8ct7/r1fnIA176pldVqTRS958WzQ7w4JXSjo4G7Iff
Pe8MLxzB8XYMffv0Oo0cfr5kNSZ5oOSYPNiD/fOfDwrBEsJ8sCmpHxvB/ppg
dXy8V4IPDgEuX2Wx/9oILHpcyOHDjiz1Op1s7P/zr6n5zuDDDfdpbpbYr41v
2yhrq2AO1G49kEujgMPaHzo1+BCUOOPPZezv42Mmqf46fPj66Wh74w0a7YoV
9JVeyAepUCub4Xz8/mIzgy8t5kPp7CoPzZs4v2ORn2YAH+TjtUln3D9mONe0
Rq7iw95dZqaXi7Cf3d3sNL6WD9Jlnwc6cb+J9PLL2WLDh0fvtKRmlNLI3CL8
RZE9HxTM1513xP0psOOwtIALH8pGn3tfL6dRWt/p7SY7+UB0HckZwP2s1Gjn
2BEPPpBrlHSXV9EIaRt/y/PmQ8fM1qEo3P+cu0q3th3iQ3vIu+G+GpzPGx27
B4/xwUevUXMZ7pf/zm98qNNTOX2pDj//c1etzDk+yI7VC47i/qr40g7kLvDh
ZVzBZbt6Gp0Svv9ALJ4P+omyxrdwPz4TcOfQWBIfso4tGlJvxP555oBrdyqO
h3d2VhTu3wucTmbeyuJDxGcJu8m7WG8VS7dE5/PBxeqfP573abRkj/cllxI+
qDWLnevB/Z9ujfDXqOJDm1GNgN0jGtmZR8m9q+NDiV+4bQueF6x85ALjGvkg
ENN7wvIJ9seoVY+NH/KhaL31iUd4vphIE1b98JQP4atPW1q10uhp3q2wk518
EEywe9PaRqOighDlGa/4IPG4XtehA99/d8bw9R4+3I97s6ivE/uJUpvavA98
KJ78MOL1jEY7XtbUZH7lQ6b80h0CL2jUJXKmS+knHyr17Q5dxPPPG7vIM+Gj
fNjk8nzB3Ne4/wq/fvtrgg+8scAztW9oVOWlM2ojSIDK6Ex/u7c0Yr++f50n
SsC72oLxoR5c31ZaWX+lCBC0Wy8dg+ctNvqO+2ouAQeV6Bymn0aL9hjpR1AE
aK3NfvT8Pf3ffE3ApvXKXsEfaXR79ilNATUC5F8pntf6TKPdrsOH5s8loOHH
as2OLzQKaY6Xt9MhoOCNG33yG66HpBiFAD0CumPX3Fw4QKPB9W1RsSwB384P
xr/H8+H+aX9CcpYQoDzP9UPiT9wfYn04lUCA+pEnCTZDNPojs8votim+fsQ3
X3oE98PK+lkNFgT0fi5QfjBKo3lbFjXWriPg59GhD6G/cb1vMVpaspEAe+4T
EYs/NJrVS8Sm2RPQQvb5S0/i+WH49pvwrQTMfzdg0PYX98vjXE2vHQQk8JtM
EgUY9OfAtSBLdwI8MtdfchPE83Lek1/qngSEHIrR18fzcDj19OLIAQLmzMmU
nSbCoMuRV/bUHyTg0dUKnVZRBtk+nx4WGkhA+zyZM+nieH6+dPWPeTAB7n8F
FQMlGWSi0/FE6DQB4RJinzZIM2hl0ltuZRgBDz+kfdHB83i2V3OLeyQBFt7e
quIcBu2POCzPi8bxyVQP/cBlUP/0uJHyeAI2xAYr3eMzqPtLpt/mJAJSply6
c0gGsTPF035cI8Bsc+nDqBkMejj+8WxIOgGXvI6/PTjz//cjAvZGvVZwUWRQ
wgNu1bV8An49Gg5co8ygXM73GXOKCejJkJhaNItBHZoe2zLKsV4MvdI01RjU
YP7rimoNAX+PRu6aqc6gk6caXsUjAh4MvV0tM4dBf71HNcQbCQjOGjEXxvvJ
/fZTp/3uE1A/03vHhBaDnNllIq+bCXD4LnZpRJtBXyMfFxm1EjC84FT/z38Y
lPWyITa5k4APH+ssfsxn0HD56cqRFwSs1c9t+qGHz/fTQXNNN9Ynz9xuaCHe
z5R2f03oxdeH5v4dw/tSwqxS2fcfCLjiNlkxZcAg0duzk3S+EqAw81CImCGD
jukEJO4bJMBQdPdOHt63zh7bSuUNEWA3a4HdrOV4HzOxk+8fw3oTgy3zgUFh
409z5CcJeDagtB+MGXT4PL9j9TQSktG2aJuVDJr7Zn2K33QSfnaU3nVfxaA6
lcQZyeIkBCzqkgw2Z9Cuve9NkDQJrbtjnS9b4HxryOh0c0g4ENNaX7KWQeoH
Wp7/Jkh453ySabVi0LuUdlu5mSQsUCoo/2HNoPiMlCw1ZRK8bu1fzcP75BW/
rBcL1EhwvvXjM2vLoGA/oyHDOSR8s/NNctzMoEe9aZMwjwS/I6u3nrL///2X
hLT+jgX5WxjEOW8lsEKfBFOZC/wXTgwS/xsjvoQlgXKdLiHmwiDf8Ww1PUMS
4pY/5SzazqAf5RtsZi8nwVIgVWePK4Nig5elcYxJyJJfvuXKTgZdkxWcOWFK
Qq5R4JV2dwYd/6Ra9241CYGbTUal8L6sViSW0GhJwuWa6J1mngxKPS5VdH09
CU1rj347uZ9Bewz2yQTbknDQTz2i/gCDKh/al222JyH40O1VQr64Hq6+v6nt
RILP+msKqw4yqPwhNX3ChYT3rKr0uUMMavN4VXnPlQSBtRWKrQEMEhmU7bzg
ToKxxvc1CkcZVOoY4LLZgwSVV85JO4Pw+yU/dZb3IsF1Rp1syXEGvbxb8qLL
h4S63a2ZQqcYBNvLui76k/Dbzm+nbQjWW/YGJ4tAErYXXLLMDmWQZNvQgb/H
SGBzjJ2nzjLIesOIQsEJEnqpqOTNEQzSp65ucwwhwaOwQKIoikFJTzRWi5wl
QcPsa5bMRQYZzrn5LC+ChKA/qQGeMQxyFLAhrS+Q8D3J/MTjOAbVVnHFBmNI
2ITc6/UuM8jUrbc4/BIJBJuxLD6RQRmTWSpzkkiYPbd65G8yg6SyDdbXXCVh
VtDhQfdrDLr11cZqXRoJPWoP/+lIZVB1f5FidwYJGZ5FhSbp///9gwRxS4ug
kkxcL9m3TYZvkCB3u+ny3Bx8ffj5zMBCrD8NP+HkPAZtr337828JCXaxNfX8
AgZN91XSDqogQd5Q+VlkIYN0StNsJ6pJeD7GmEuWMKgpvN7/YB1mzyrybBmD
Li2ujvtWT8LNm0fNJCsZ9N3pdvm2Jvz8UM83kdUM2qv7p7v1Pgkvf0d382sZ
pHrtOH9FMwnzxql1yYhBz2JdHPKe4ni7LdPTbMD6l4ov47eTsHLS7WxpI65/
M0o3oIuEiByOs+k9Bv0ab2p89YKEEsXu4q4HDIo8GHRi6Rusn8XhER7NDHJ4
Ir37cg8J/cKjg0JPcf2ILTz2q4+Ei7VKvcmtDMpbcr3J4iMJw29Vdht2YL0h
CbOrX0i8by4Pfd7FoIKNwsI/vpNQ6/HaNPAFgxbBbEH4ic8rfjJT5TWD7I9+
Nw0fJsGg/nlRUzeD0l/1tHWMkaAfcNPT6x32Y619NxUn8P9t/fNasR/Hf93v
bpcpEmT92sUffWCQe+CbnamCFEihI6NHP+P6Ndq3umc6BfuqHW/of8N6Kv9+
TkmcgoCc6fqfBxi0KSNRf7MUBUff64Vf/4n1npCxIlKWAje9pvptwwxCMga3
6rkUXChsfaU6xiDl0D3ZQwQFi1Oie/rGsV+Ub5RQl8fPC/R+ljPJIJvLU73W
ihQEqone9xFg//s+RsHhrhnVRkIsqg+P4qSpUaCz8WqZjAiLKhXtPe9pUFDP
vdPwVoxF92Pz1n/RpKDDsvdzqSSLerTd6iV18P3REXSkDIt+yNg2aM2nYFNr
aPZuDot+hZjamepTkFzRssGcz6Jg2dFTWxkKvoonL55HsWjSW9XSbxEF4Vvt
d8nOZJFrv09J2BIK1qrf7B9VZFGycmxt4nIKjPPP1PaqsCjAd/b+3BUUCFkL
T7Sqsch6qOR+xUoKgg+fzWrUYNGcI10tDWYU9I/XPa7WZFFUm9y5RxYUaO+I
PFyqzSLlO2/GWi0pSDNQLynSxefXK1fusqbghsNoWLEei2z0xASe21CQkN0k
UkGzyF5t0bVnmyi4FJLEIgMW3W5IF+y0p6Du5FONR4Y4Xmuy5rU4UkA/E+95
uYxFYseiFB44U9D7aYXfALCo8XbaM7SdgujJxgGRlSzyM5jjVupGQUqB4VY1
MxZZPba+k+mOz/s4+fEKCxa52G/6Hb+XguKtq9e5WbLI8/p20ZB9FHxZMvI9
3JpFXqEJPw4coKBwR11NhQ2LXk4pVG/xpWDvWfV7HzexKNzw704TfwokGqRV
lRxYdLhw/ZhmAAW+go+7bJ1YRBrO8pY6SoHqzrmTF11Y5C3v2fUtiAKlo1ap
7TtYRFCMdvMJCkzRt2czd7EoLmqfV85pCuQ7tYrd9rDoW4h4zulQCmSfXjcp
9cTPqxp4sfUcBdJnTyaLH2D/+75KQVDlgfbtviza3amhK3mBgjWqGRPIn0Uy
h+ZtehNNwTPH9/PUA1lk+KU3uCCOgoMXI3zDj7FoYbRS4bHLFKRXXxz4fZxF
0kNJn9YkURC6I7zI4zSLeA2q/1BXKcg/XdTeF8qiwRG3Y29TKPik88lzeziL
8rqU3mZex3qQbo7rj8LPlxnb6JlJAXm12H1fNIu+lCR3L8ih4FFWyuREHGbX
ohM/8ygQOevmdSGBRYvN2qGogALd8/WvtK+wKEUtSdGrCOu72sL5UQqLsvck
z9AppWCblQrhk47jZbXT4H05BSa7khVnZbNoUWNQ4JUqXD+P5OLa8likeM3z
w8ZbFEzFNaVE3GSRT0z+UXGE8+X73NmqhEXOa2qgpp4Cf/3zY0QFi6bvl1zo
2Yj1WXgrvq+aRWPlkpsV72F9uq7ZWFWH9TM+t+D+A1xflRUH4htY5LuwaZlf
MwUCPndcjtxlUVis2XSVp/j9DWRddz1k0bVYMbG7rRS45oXGbXrCoshRF3PP
Dgqo5i6FhW34/hdp9zjPKKgxzvWc04nr8Y7KuZIXFJSoaOfFYD5YqHzR9jUF
qw9lVCt0s6hU/n33UDcFczVIg42qhujYhcIc97cUXJuKunw2ZQn6P+SJGLU=

       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1WWk4VW0XRub5OOfsfRBClOGV8rb3RrIUkTIlhUiUkqEQqZShEjIlSiFj
IZQ3kVB6kMY3DUJFVJqoTEkofM93fX2/XPd17PM8615r3ete+6h67V7nLcDH
x3eTn4/vv38F5mlPSZT9Nh1oMkn8KUGjja5LLgerzZr6v1cR9XGi0Z4yY9PK
Aj6wNHzAyoumkcScSwcG0vjBeKBkdHs2jQin6vorfgKweMLz2XgZjdbSkTV9
enPg36U1kb+v0uhQTtsN4u0c6KUXyT68RiOHxMU6gjGCkBY/qfytmkbF9Z3E
g7lCsEO8yyeokkYqVjaGRKkQaKm/iSIu0WjIcGpmhZ4wXHL0NfEuotGByKlG
v1JhMH38j39jDo2OpfoZhauIgHtNc3PIaRrpXhUUppJFYN/+euNrSTRK7dsT
vuKnCPDpGmpUHKXRlcu70/U2icL59z9rI8JpdK/FJCykThRyHguXLgum0fDV
p9OHuGKQK9H0Y8qHRpO6Jw8W+4vBYLCo9V0PGhkkfftphsTgxKDKnPINNHqk
MDyQLisOVtSvwX9saHTi6Jzrve7icHtl0JsucxqpW5/ucC0Rh0SdHJXFy3B8
M48eMsPisOnzJnTVgEZZHRKTRUslQMhK74O3Do1cdVKtWvdJQOLcrd+t1Gnk
d+96Q1utBKQ3vql3V6TR0+vtYy8mJCCYa5J1nk2jcana6N9LJUHpMidNSZJG
Ld9lHF2DJGHy/rzN9wRp9L/8SoL1fL2o89MUunnXaHBhnySszmtfd2WcQiVm
zS135KVgS/d5mcEhCnVIxflM2krBsQKTFy79FJIKXmLcdlgKvGuf3/j+jkK2
5ckW3tVSIM3b3ljXTaG/TPTW3/ooBYN3u99e6qAQ6yuHGCak4dFmb+6/Tyi0
cv1vSmiVNMz4sx04Dyl0/n7hXokQaTizdSo+poVC/itO3JTOl4YB245ryohC
14ZPLFJ4JA3qzs5Pe+ooFFpvv4yZkAZpea3O29XUn/qUgf7Cyw8e/0OhCsXy
mmdrZGCpb/7VmTIKzfI5zG4JkYG5B/fn2hdTaPXFy6Ua2TJweUt9/u0CCpUt
U/NZ2CwDq9N0nrvkUEiS3RQW2C8DrUZfN8hkUuj7TJ3LYRFZCHoUb//+FIXs
/bUf/pCXhXT7X986Uynkknkpn6srC2pVp736kyhks+pOy3sTWRC99/sTeZxC
+7XuTnrbyYJP/OxNr2MUSlji3Z21RRbKfkRr3z+M+fSX+xIXJAtpP9fvt46k
0JfuBUcXHZaFWS7r94dwCiny+j6nnpQFhfFvYln7qD/9JwucgLOzPqGYD630
tJOVsiD0VsLULphCRerWr/5ukoVSPo9FNrtxPlgLRzKfyoJ0aMEyL38KGbbW
5915IwsJif90Ju2kUL1C+rnaIVkY3CO89/F2Cqma7YgPnZEFu8qzqZrbKHS/
Y/7YL0kW6PxbUXLSk0KmG8fcbBVZ8KKjxoTtQaGPi9QMdmmxIEllfmexG4WU
yn53uNEs+FZqPmvnSiE3kYJMRQsWKDiom0s4U0juM2oqW8eCel1P+qUThZYt
WRsrvYUFarbcXbWOFNKyVedYBLDg71tlUWUOON4rFfH2B1gw/KNFvMKOQuZR
+6YXx7LAb6tSWbMN9Ud/WLB7x/Y5/Wso5H2uSCA8jwV8S/++rmxNocPvvZLe
l7OgKfN14DYrCj33HhdbWMuCw/u3dtauopB44cTmVS0scLZxPqNsQaFVN/t9
4SkLbIl7XidXUuiZ6UlB8jULMg+pfuasoNCWIPdfDz6zwPGRSvcFoND48cuk
+xgL2saqx8xNKSSru1ixdZYFn3sm+0dMKNTgptGoLCEHQsJye8uXUSjEp7jB
jpCD3i5VpxBjCgV2fG/yVJUDYUPGYrURhc7eKg5z0pWDQ/OWC+sYUqjvxnSU
Di0HDVEfXeQZCk2cF4l4byYHmX3n5nBojNd8EI1eKwch2eH3FCgK+YZMXOPf
KAfatMHuv5ZSSEeJkN/hKQdWi4TRmr+pP/osB9/Trx0NNaDQ4jrFBe9C8XnW
B+JKl/xXD2J7JyLl4HbGYMbAYgp9Zbt4j8fLgTpLMnopxu+yqKVdaXIQTCiy
E/QpdMHI4F7xOTnoKChR/rKIQmnew2luxXIw1XIw1AnjTZa3xKf+kQNvVsrA
fT0K3bZHWVF1chDdM+1ghbGwE//V4WY5uLVIMPrJX/g+qzJrrR/Jwd2BYRsv
jPPP3+OmdMjBlvXKJ6Z1KZR0VUynoVcOWk73qxRg7HbEwPXFZ3xfv9IOO4wz
3iby94zIweX0smRhjC1M3h98PCUHxA519Ts6uP+SLmhcmsOG1tO6gckYX7Yc
WhcmyQbFFbfWeWBcE1jkosdlg5JFaQmDsWNHfOIzJTbY3E20V8D4/n7zZds0
2RAo9ERLEOP/zTc26OzM54xrU2jN1RFrB5oNMbVfR4Yw7j8dbHbJlA3SWRsK
RzDWmi/y/qclGz5q0RK/MP6kNbp/sT0b9J6mS0ri73PxaLJydWaDFa2SMB/j
FXpb0oO3sOF2mbafOcZXRhVyD/iwQcSyLNUP44fXqi8GB7LhSLL++7MYXw3c
8911HxuMJd9aPcbY655anUEUG2p09xZJYD7e+2oZTceyoRiY97YY6w4nX65J
YYPjgan+Mxj7OYs4bM1gw62lZF4/xqc0pl34ctnQsdN/CHA+wrhZfClFbNg4
ubExB+NzUe0HZC6zod2/alYA53PSc890dDUbDFLb0wMwlpMgb3y8wQZh1xi/
How3x63qN7nNBrcbfLv/Wx/KtXuuxT5kQ9D1sePPMBZRFlx/+xkbfp0IL3PC
9dXq6Tzy/SUb4h/L3+zB+H/+AcdbXV8egOvRzetdn+5nNiSnV+4QwPU7P4w/
jRpiww6o7MrGeDDg9g+DcTbcTG0dX4br3XW0i9KYZkOV9v7idxj/9UkxSlyQ
A+bfI7qTcH9k2kZP9Ylz4LS0cMxy3D+OfEzrFRYHpJITToxhbL8oTy2ExwHL
kLeDFbjfVjQ6KuuocOBciu6JQNyPB/brfOrQ4EBGxrttFO7XqYmVBWG6HDiy
+J47P+7nHacEQqQMOFCiMuT3FGM3UYWoM4Yc2JtYFVWE+//KRHI/DziwSulW
UhTWB57HjWfJqzjgvXr6qAfWj8N3N7pPreXASF+h80qsL8mBoaWbHDnwY63u
L53lFLKyTnxV6cIBxe51HvJYj8Lb90vxbcHfd4uLXQSFCt/HeK3czoEzglcZ
ATMKVZtunzjoj58/VZw+jTHSWfGtPJgDrbGXIqex3nl0Vm9u28eBN6L13/jN
cT4vte8cjuAA85avTRzr5f/8Gwfer+5X52E9tRrobJBO4EBMPtGuZUmhuV3O
IJvKgbP2Xl2mWH+PCt5/IJqB40np0nFdTaHYA7f3TWRzAJncqd+H9Vo2Nmhb
bwEHbvWdjcrCeq7vfqT4ZgkH9iTyBTatxfV2fdmmtMscOInaI79h/Tf2DT6z
pYoDb2M0iubi+fD3s6QwjToOJOzUeWlnTyFnqxTZd7c40BTuIBOL54ntHtnw
0y0ciAheZNq0DutjyqrWFQ85UFod78G/nkK/CwVVPz3hQFqC/Q5zPJ+elN+M
P9LBgWv6uTYJGyhUWXFMmdeN60GwXqxjI37+Lu/H+bccyEZyafNdsJ4otalp
f8L3LzJ5uxfPv61dN24Uf+XAp9tTX/7dRKFO4dhOpVEO6Bvol2m6U6jHOTk2
8ScHtpkPEEc34/kr+PrN998cuDTkuuADnq91gbo/HQW4MCb/8vlqPH+prx9f
l4twQbm1l6z0wv1tq1UyI8mFyQapfiU8r6m02z6r5biwJ2S+WZI3hRhf0yVJ
JBced4jI8+2g/vhrLpwIu7lzrw+FGtWPLuRT48I1rr/uMPYDO7f92LdoARfW
9bq6BvhR6NijDHlnXS4YsEa+fsP+wTE7XfHAYi54mVW/DtpFoWGHtpRTFBeO
/V6rOYn9xm7+X8dKjbnwbOFBdCQIz4dTe1i1wIUDMfOLWHso9Et6h2mjBReW
GVg8LQjB87C2aV6zNRcUVkwZ03sppL2JaWmw40KUysE3rWG43zeZLqtaz4Wr
Riq1O/dTaF4f91ShCxc+xToiEeyPlv1o7EnczIV60fPDJQfxvIyWWxi4lQst
YdfMbSLweUF5kTY++PkW65ox7K+elj/+Pj+AC1XNRitzoymUSD45OR7EBeuK
/X1rj+D5m5zj27SXC9N97LTpoxRyeikUHxfOhdjtejZXsH8TOJP7yyqKC7Ln
haV84rCf1W1/PCeGC0JjI49Usd8zz34jVxvPhX883RN6Eih0MfDRU59kLvxL
PYIc7A93J+2XZ6dxobC5u39LCoU+CJ0er8ngQt6kyWFN7Cd7vxSHbszmQphW
rdDQSZxPBbHCkTwuDFfoBtalY72f+nz82AUubMtNvBl3mvqzH+H4Yt/1u5zB
+vVAri7vMuZzrs3IX9i/lrEGeZpXudAnzPdEMJtC7Qv9PYtquHAqdeXhnnMU
arb6nqN6gwt2riGC9bkUOnK0uTsDcUFee45jZj6FZoJ/aoi1cEGtIsT3YCGe
f8+PxoTex3zM87T0vID1gTIRfv0I59My5KMV9tdfk1srTZ9xwXDU39zgIt4n
uppPnevA/MzO3TwP+/EfNTG146+44P3TR1/2Eo5v1HXhml4u/JqxvC5QQaFU
pZ1fM/u4MBTcPPoT+/nMedUyHz/h+vsy3j1UiedDo3q27lcuLH8tEzJQRaEI
3QNZu4a5oJhgU/3pGoWOR2wmy8e4YHSLL+fTdQo9Wuks/2GCC8Z5CToDeH+I
n3pSKj/NheA8z01DN7A/P8FpX81PwFFVEZ2fDRRa0OOQHypEgGEM6wx/I4Vu
qWTxzokR4NaumSfdjPXb7+NKJEWAevU0KON9xVxDWreXRUDhIvd9+nfx/Al6
+nKSS8D3rLnmFvexX8p/7iSrQEBrpHqBG953MoryS9SUCdBes/PE3kcUygkt
eaWvRsDQ1h+SaY8pFBVqOmakSYDUQA+38imF/u0rnAZtAmRz115sa6P+7L/4
vo0hLT/b8X51wpbPbAkBDP85H+UXFBKbSRczpghwsFNItXyF+2vqotpiIwJ4
d+1N9uD9bKRmnaP6cnx+5VW//B4836NMClkrCNhLtSg8e0OhPBkBhd8WBCTt
JlYL9VEoul/11rvVBBwDyx9GHyikVima2WJDwA0zYeU9nyhUEC1Zed4Bn18h
23QJ74e+9C7pKCcCouyWvBn4QqHahy7XNroQ4OttEaY9iPsh9+M/Ou4EuGYt
OeY/jP3WQ1Lo9xYCoH9Y4soohdr8u2vvbSPAPitGZGIM+8NhmY5UHwL2zBPc
Z/YTzyu3A1s2+hPwQSnZLWkS3+/cEw/5QMyvpWNV1y8Kdd2tetW5hwBd59QI
3RkKgde1zpNhBNxRSK+L5KMRdXGdu3U4AT8Mq3e0C9BIom0saCaCgBMb3GL+
EqKR/bpxxYrDBMQMzcjFidBoCZnr6XaMgE6nebIfxGiU/VhjtfBxfH6xw0Fz
vF8baf7zojyJAMEHizcWSdPIjc+RsE8l4NX2gDxxFo0a6uREh9MJqP7QsDEI
7+cW3n1XE88QEOAxePAVl0ZF0yUqmtkEdBQ+lVnFo5HkRdrhRi4BavPXylYp
0OjmV0dbu0ICNhF2EfOVaFT/oXJubxEBcTYvXTJU/v/+g4BY258Fkmo0yrzY
uPLHJQLumzS7HJ2P/z/xRHH4FQL0p7dFzGjSyKvhzehMFa4vnhwrXItGQiFK
OpHXCTBtlpKb0qGRbnWh0+96Al6Ml0SH69HoTmJT2N5bBMxsWLFlVp9GZwzr
T39rIsDHdtXlGAMaDbo31njewXxLLvKXpmjkp/er99l9Av4+fjTzLEMj1bxo
jtkjApac7DZcYEyjF6e2uJY/IeDz01fWNSY0ypHMuMZ5juPr0m9dDTRKtST1
DnQSsEsj53bPChp9n7rT0v2KgEXLh/X2WtAoeW/k4WU9uF5TBKRlrWjk+lhq
59m3BES0NHiVW9MoStQg4vt7XH9Jc/XW2NCo3Pj8HevPBHR3qwZ9taNRDRK3
zP1CwKHn73RPrKNRxXpBwZFBAoif0V6UE40YUBeAUdzv2vrs3o00cjk0aJH4
gwCnm7pw3JVGF7rftrVPEDB5umWAdqfRQ61d/8z9TUC41kbOZw/Mv91k75ZZ
AlilaxsyvWjkE96zvUCAhGTxeQN23jQaMt21+q0QCXV6rmdFfHA91QwmKImR
YNZ18lGjL402FGUt2ShJwuxUYFxEAI2qM4vMkmVIsE8vfWgSSCMkTd9skiOB
X1jo7GwwjZTjfC+OcUkQEXEabQ6l0b8168Xny5MQ+SDi5fF9NHI8O9tnP5eE
ItO99uvD//9+jIR1U8td5kXQqCkxhVWoRgIT8vXHYBSNaue6BNzTIGGTfsFC
dIRG90+VO3xZSMJod9r3tGM0eqvj3SShS8JBTyEX33gajUg7NWstIkFhwZpN
KxNxvo5ZOFssIcFY98Fv5RScD5mfRzcvJeGlxoTpdCqNpoNVbUIZElxubFrQ
k06jbR/2VMUbk7AiJ7G6MYNG55RPNWQtJ2G6xeBbcSau7xD13WVmJIwUSjw9
cQ7351jV/evmmI/5b7YezKOR5sHOp82WJExpp5T4FtIopU024V9rErR2iRZs
KsL83O6ZeGZDwvdZG0e7izj+xTXKnfYkOFEhtyzKMT+LRfleOpJQqljQv7wC
51uNyXuxgYSIcFa7USWNGpsvCHS4kFBuIRNjWI35WlOi/dSNhFM5v34bXaeR
aESK4gMPEgyNrcG0nkYtjYUvkBcJbWcOr1vVQKNQWtO72puElZpA2zfSyLbV
/naxDwkODUtG3W7TaIvLhskMPxJqMpRj/e/SKOC8l8ixXSSIfe6ejHhAo8C4
zJGgIBI+vNpkm/6IRl2zivWbQkj4Wzo3rvwJjRKNZravDCPhQPut8rttNNp/
xWFi4QES1EK+NXzooBFhNC9Y8hAJX2MCmoVf0ShYPqDzWyQ+b3l2g/ZrGnHJ
pTqPDmM+mr5WObyh0emUXYGlMSQcT+wvDe+j0bdjYqUxcSQoXfv7QslHfF7d
0KvNCSSYbI0redH///erJPTMqamV+EajnR0aehKpmK/ustdmwzSS3qe9oSeN
BA9TP/nw71gvv/RFVZzG/Oixg2vGaWSQpnQl4iwJr4O6vo5P0khqLLt/TTYJ
V9YTKYbTNGI3q/5F5pLQ+Fp/cyQfg4bHvSPe5JOg7HbV494cBpV3Kr0pPk/C
7idmZzkiDNopPbE+oJgE86PZstvEGfSl6lyvfin+PuO8h9ekMN5WeXi0nISz
EpZPJFkMMrR8DpUVuB/rSuZv5zAoXy17bmAlCQPzfrU2kQy66HuOp1tNQsiv
k+1qigzi2m6nP9aQUPn3++XHlBnEtESG59SRoHj1MOubKoPm5gV8Wn8Tf16h
tn6jBoP2pF8+JIZIyMo7K9WykEEea27AjSYSLkT2mFO6DBLaLWEQ0EICC4nz
ly1i0ESNxMa590hoL3ddrW7AoNCpBRX3H5DQ6qSnkUsxKMTgjknoI8y3ini2
shGD4k9ZCqk8IcFie0Z1vgmD8k6Jit59RsKXgxf2LzRjUPLPLVYB7STMU9ce
rjTHz78qvMd6QcKxhBWqZlYMmr6tklD1ioSqCQNu2xoG7b2ifNLpNe7Xev/n
PnYMqpb/2DvWiz//eHSHgCODPgjU7D35joTcpaaduRsYpCHW6qz3gQRr7eO6
Zq4MmvXdGnfvEwlDGVGBH90ZhDhlIp4DJMjM+paneDKouOz5i59fSfhkjPqX
eTNo9IzETOIQCdwKzSWDPgy6zQnbP2+UBE8mNKXQn0FD+kY2lWMkTIZXSbgH
Mn/e35NQXKRyRSGEQdksU+GnkyS8EtU83h3GIL2zlUPuv7HelfnlF4QzqH3T
W8P+GayXRg/5AyIZdMnq1cdgfh6sadxwzfgIgzZuL5mYmsODC9IuD6RjGdTX
vS4oWpgHTo4bV388zqCjs93rhMV4sNlAzrQpGdfLhlW58RI88NgQW1NwkkFr
io87S0hj3DPaEHuaQZV8BVEJsjxom3niGZSJ890YJS/O5oFLWG+5Rw6DfApI
jVguD+uVyqV1BQySQY4XBHg8iJtu321dxKD6AuXsgwo8kHU8IWBZyqBWy80S
P+byIF9KfY/VZQZt1v4x5qfCgwCbS49tK3F8a5pc36ryIGNXpqbrNQYdWJa/
3Gk+DxZ+KjzmW8egLnXfgruaPPDJapuJbGCQ6v2RWEaLB6fPxeRkNjFoVZbY
SLEOD2ZKfEPr7uD4aiN7uXo8mPU+ntb7gEFvJpWdDuvz4Hi8hZj4Y3zfscuO
35bwwCrd+ZNhG+ZPeKx7w1IepOr3LN/dyaAHmytGG2geOH5xUC3tYlChQO5p
DSMepDWdzBvoZVBn+6EHx5fxIEb9Y6v+e5zPgjknBpfzgNs/1XDwM4PS5n34
bG/GgztaX4+0fsX1/but48pKHvTkmi/WHGEQ9EZsYq3iAX8jf9eRHwy6E5K6
b7cVD37ZZ5z6NMmg6D1Vi/615sHNy6OhDjMMUilMOrzAhgfnWiJSGwUM0eG+
W8HRdjxoObVghhYxRMkGX/hfOfDAYtvmZ1UShuhTTfnixesx3y+VNBhZQ3Sm
MWdO7AYerDYdlGriGKLy5877u5xx/MID59fJG/75/YgHNfuaBAaUDJG6TeiG
KHceeB+6DXFqhujJ9wn0xIMHdndf7/trgSFSMohtV/HigVl3fstLHUO0cvDi
qYBtPGi+YrciSd8QhXh+FqjbzoMHgZ3iVksN0fCCu8pCO3nwVP+NsbiRIRJb
cW/A1o8HsTmto23LDZG8op9PRgDOp+lDmwsrDZF7iu7Znt080I277xdhZYj+
A5mijQI=
       "]]}, 
     {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtWHlcTt/zT4v2etZ7VUQlldL+bPeRRglZUpJWZC0JrVKWFhLakPQhEaFV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       "]]}, 
     {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwtlWk4lYsWxwmJbQ/v+5qdBkrI1N7bnt6t01Khi0jlFkk4OIVzKkNSiYab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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334],
       AbsoluteThickness[
      1.6]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.560181, 0.691569, 0.194885], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.922526, 0.385626, 0.209179], PointSize[0.004583333333333334],
       AbsoluteThickness[
      1.6]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{1.791759469228055, -27.631021115928547`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Exp[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Exp[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->NCache[{{
      Log[6], 
      Log[400]}, {-Log[1000000000000], -Log[1000]}}, {{1.791759469228055, 
    5.991464547107982}, {-27.631021115928547`, -6.907755278982137}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->FrontEndValueCache[{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledTicks[{Log, Exp}]}, {{{2.302585092994046, 
       FormBox["10", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {3.912023005428146, 
       FormBox["50", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox["100", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.791759469228055, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.0943445622221, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.248495242049359, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.382026634673881, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {4.499809670330265, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {5.703782474656201, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {5.991464547107982, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.214608098422191, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.396929655216146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.551080335043404, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.684611727667927, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.802394763324311, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {6.907755278982137, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {7.003065458786462, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {7.090076835776092, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {7.170119543449628, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {7.24422751560335, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {7.313220387090301, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {7.3777589082278725`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}, {{-27.631021115928547`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Output",
 CellChangeTimes->{{3.929506566911626*^9, 3.9295065959436674`*^9}, 
   3.9295066710389757`*^9, {3.929506942653819*^9, 3.929506989020917*^9}, 
   3.929507703513447*^9},
 CellLabel->
  "Out[178]=",ExpressionUUID->"aa890f55-4e55-442e-b97c-47ca3087c6bd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"TT2", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.9295063701146564`*^9, 3.929506371279101*^9}},
 CellLabel->"",ExpressionUUID->"6ad19296-07a1-46d8-bcf1-d9b48d395bf9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TT2", "=", 
   RowBox[{"Monitor", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"y", " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             FractionBox["1", 
              RowBox[{"2", "\[Pi]"}]], 
             RowBox[{"(", 
              RowBox[{"(*", 
               RowBox[{"w", "+"}], "*)"}], 
              RowBox[{"m", " ", "\[CapitalOmega]0"}], ")"}], 
             RowBox[{"Re", "[", 
              RowBox[{
               SqrtBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"\[Omega]", "+", 
                    RowBox[{"m", " ", "\[CapitalOmega]0"}]}], ")"}], "2"], 
                 "-", "1"}]], "+", 
               SuperscriptBox["10", 
                RowBox[{"-", "30"}]]}], "]"}], 
             SuperscriptBox[
              RowBox[{"Abs", "[", 
               RowBox[{
                RowBox[{"-", "8"}], 
                SuperscriptBox["\[Pi]", 
                 RowBox[{"3", "/", "2"}]], 
                RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                FractionBox[
                 RowBox[{
                  RowBox[{"SphericalHarmonicY", "[", 
                   RowBox[{"m", ",", "m", ",", 
                    RowBox[{"\[Pi]", "/", "2"}], ",", "0"}], "]"}], 
                  SuperscriptBox["m", 
                   RowBox[{
                    FractionBox["m", "2"], "-", "1"}]], 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    SuperscriptBox["\[CapitalOmega]0", "3"]}], ")"}], 
                   RowBox[{"m", "/", "3"}]]}], 
                 RowBox[{
                  RowBox[{"Gamma", "[", 
                   RowBox[{"m", "+", 
                    FractionBox["3", "2"]}], "]"}], 
                  SuperscriptBox["2", 
                   RowBox[{"2", "+", 
                    RowBox[{"m", "/", "2"}]}]], 
                  SuperscriptBox["\[CapitalOmega]0", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"m", "/", "2"}]}], ")"}]]}]]}], "]"}], "2"]}], 
            " ", "//.", "ruclou"}], "//.", 
           RowBox[{"{", 
            RowBox[{"m", "\[Rule]", "2"}], "}"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{"r", "\[Rule]", 
            RowBox[{"y", " ", "0.08"}]}], "}"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "6", ",", "450", ",", "2"}], "}"}]}], "]"}], ",", 
     "y"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9294530901055965`*^9, 3.9294531116175976`*^9}, {
   3.929455009950424*^9, 3.9294550764344277`*^9}, {3.9294551371377754`*^9, 
   3.929455153320204*^9}, {3.929455265946951*^9, 3.929455277118656*^9}, {
   3.929455327538889*^9, 3.92945532924883*^9}, {3.929455431437693*^9, 
   3.9294554316813636`*^9}, 3.9294558676240416`*^9, {3.929455996740104*^9, 
   3.9294560020985475`*^9}, 3.929456261546759*^9, 3.9294563044765034`*^9, 
   3.9294563942197657`*^9, {3.929457687103937*^9, 3.9294576890817947`*^9}, {
   3.9294577226647387`*^9, 3.929457729358182*^9}, {3.9294579434953265`*^9, 
   3.929457962159936*^9}, {3.9294646678266525`*^9, 3.929464712387444*^9}, 
   3.929464760904688*^9, {3.9294648352229223`*^9, 3.929464851098555*^9}, 
   3.929504878098158*^9, {3.9295063899453707`*^9, 3.9295064091511235`*^9}, {
   3.929506874997797*^9, 3.9295069835425377`*^9}},
 CellLabel->
  "In[173]:=",ExpressionUUID->"ffd7ebd1-cd8f-4e4d-91ad-7626a924097e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TT2", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.9295069298974524`*^9, 3.9295069339497347`*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"9cf30dca-2810-4e20-890a-ae0f245fdef0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "1.821228772494937`*^-8"}], "}"}]], "Output",
 CellChangeTimes->{{3.9295069342088814`*^9, 3.929506938237382*^9}},
 CellLabel->
  "Out[161]=",ExpressionUUID->"5b76e31c-0a88-4f08-a162-32b28c5bb171"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 966},
WindowMargins->{{-9, Automatic}, {Automatic, -9}},
Magnification:>1.3 Inherited,
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 201, 4, 37, "Input",ExpressionUUID->"5eabe3ca-11f0-4ce6-8804-d967e41bc368"],
Cell[CellGroupData[{
Cell[784, 28, 417, 9, 130, "Title",ExpressionUUID->"14d7fb90-fe0a-4865-b7df-e69fb8f5009f"],
Cell[1204, 39, 362, 9, 37, "Input",ExpressionUUID->"eae332e9-1963-468e-9c8a-2308583eb3a2"],
Cell[1569, 50, 246, 6, 44, "Text",ExpressionUUID->"e93812aa-d89a-404d-a916-d4a6fd22ac0b"],
Cell[CellGroupData[{
Cell[1840, 60, 182, 3, 84, "Section",ExpressionUUID->"f4ea5f2e-aa29-430f-8578-b770ed4148e2"],
Cell[CellGroupData[{
Cell[2047, 67, 215, 4, 58, "Subsubsection",ExpressionUUID->"f6e5c295-8482-44a5-a551-5a2a76549749"],
Cell[2265, 73, 1050, 30, 135, "Text",ExpressionUUID->"8b4750ff-2197-4f67-9c3e-7a89be4400bb"],
Cell[3318, 105, 3407, 102, 195, "Input",ExpressionUUID->"e1880841-24cc-4cae-b8e9-325b9064d94f"],
Cell[6728, 209, 457, 8, 72, "Text",ExpressionUUID->"a0624733-4ecc-4359-b2a6-601f9f46e3d3"],
Cell[7188, 219, 261, 5, 36, "Input",ExpressionUUID->"f6e01616-10d4-46fe-a1c6-54f0fcc29d36"],
Cell[7452, 226, 1563, 44, 96, "Input",ExpressionUUID->"a1c63b01-86f0-4fdb-888c-bf24235333cf"],
Cell[9018, 272, 191, 3, 43, "Text",ExpressionUUID->"d3be96c5-693c-470d-b376-544af8772911"],
Cell[CellGroupData[{
Cell[9234, 279, 1560, 41, 68, "Input",ExpressionUUID->"a43dc386-a53b-4b48-be3c-ef3f91e39b17"],
Cell[10797, 322, 9112, 261, 50, "Output",ExpressionUUID->"1af77308-37ec-4fa4-9bb2-8ec1d21cf670"]
}, Open  ]],
Cell[19924, 586, 225, 5, 43, "Text",ExpressionUUID->"05300666-11d5-4d92-8823-838f19fcbccb"],
Cell[20152, 593, 493, 13, 36, "Input",ExpressionUUID->"57ffd28c-7a55-443c-8248-3ed515c80611"],
Cell[20648, 608, 274, 5, 36, "Input",ExpressionUUID->"3dc87e96-66ab-4f49-9e4e-413980dc70e7"],
Cell[20925, 615, 221, 3, 43, "Text",ExpressionUUID->"1af02619-a71b-4478-98bf-849ee767fd29"]
}, Closed]],
Cell[CellGroupData[{
Cell[21183, 623, 193, 3, 46, "Subsubsection",ExpressionUUID->"6a305c5a-d0c6-4b1c-9c1f-c3aacc4df08e"],
Cell[21379, 628, 1066, 28, 86, "Text",ExpressionUUID->"dbc38347-e4fc-447e-8b43-906ba1d0ff68"],
Cell[22448, 658, 5409, 140, 771, "Input",ExpressionUUID->"276e9363-6de0-4957-a8a1-d2d14d5733ea"],
Cell[27860, 800, 420, 8, 43, "Text",ExpressionUUID->"d96ffe01-a0c3-43ae-9d7e-f40613916870"]
}, Closed]],
Cell[CellGroupData[{
Cell[28317, 813, 239, 4, 46, "Subsubsection",ExpressionUUID->"c1edfb44-ab40-4592-b092-fd3dd0318b88"],
Cell[28559, 819, 246, 6, 44, "Text",ExpressionUUID->"93ae8fd2-b220-4935-8434-9dbad2689ace"],
Cell[28808, 827, 226, 4, 36, "Input",ExpressionUUID->"ed3798b7-7b02-432c-914b-301c44bbf0d6"],
Cell[29037, 833, 210, 4, 44, "Text",ExpressionUUID->"2e6bffb1-2032-4492-ac35-464629041cf2"],
Cell[CellGroupData[{
Cell[29272, 841, 821, 16, 36, "Input",ExpressionUUID->"d0b409fa-d7fa-4c4b-9086-9a903f532ce7"],
Cell[30096, 859, 1258, 18, 50, "Output",ExpressionUUID->"1929b80c-6f37-4c35-8335-041a46f23d23"]
}, Open  ]],
Cell[31369, 880, 188, 3, 44, "Text",ExpressionUUID->"b3a17776-7ec5-4416-aff9-cc0d8392fcc4"],
Cell[CellGroupData[{
Cell[31582, 887, 706, 15, 59, "Input",ExpressionUUID->"e0479117-1ef8-49cf-ad00-1c2ddd1c1618"],
Cell[32291, 904, 8837, 174, 50, "Output",ExpressionUUID->"eb67ea11-8ede-48a2-b665-f53853da5272"]
}, Open  ]],
Cell[41143, 1081, 334, 7, 44, "Text",ExpressionUUID->"cfc2967d-602d-457b-8007-321396a3b4cf"],
Cell[41480, 1090, 1868, 46, 61, "Input",ExpressionUUID->"1baeed4e-bcd7-4206-af8c-ee9a78badefe"],
Cell[43351, 1138, 180, 3, 44, "Text",ExpressionUUID->"579c0f7a-16d0-4809-ac67-3f32baed3162"]
}, Closed]],
Cell[CellGroupData[{
Cell[43568, 1146, 202, 3, 46, "Subsubsection",ExpressionUUID->"2d4379e9-bb3f-45a7-907b-492b8d9ac78b"],
Cell[43773, 1151, 2088, 49, 77, "Input",ExpressionUUID->"07d448b0-9921-4ff5-b4f9-c0dc9d683a5a"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45910, 1206, 241, 4, 84, "Section",ExpressionUUID->"26003b34-4475-4a22-9176-303559d6c86a"],
Cell[CellGroupData[{
Cell[46176, 1214, 179, 3, 58, "Subsubsection",ExpressionUUID->"7b362fd0-bb14-4a49-9bdf-39254c4700c1"],
Cell[46358, 1219, 272, 6, 44, "Text",ExpressionUUID->"dfcd49d3-6bd6-4e87-bd1e-1a36e1343690"],
Cell[46633, 1227, 40505, 1084, 944, "Input",ExpressionUUID->"64318848-717e-436b-8c5b-a1e70b6db877"],
Cell[87141, 2313, 204, 3, 44, "Text",ExpressionUUID->"68313883-6e29-4f4b-98b9-f12c2799888a"],
Cell[87348, 2318, 1564, 46, 63, "Input",ExpressionUUID->"6ca7f2ef-1aff-4696-ab0b-a4c4cb051825"]
}, Closed]],
Cell[CellGroupData[{
Cell[88949, 2369, 198, 3, 46, "Subsubsection",ExpressionUUID->"7434d8a5-d7f1-46c5-aa3f-5dd16e974281"],
Cell[89150, 2374, 416, 11, 44, "Text",ExpressionUUID->"7060e732-5c4b-4841-9ddb-ea1a595b2f8e"],
Cell[89569, 2387, 335, 7, 37, "Input",ExpressionUUID->"727e51eb-15ed-47cd-82da-2ddf8a2826bb"],
Cell[89907, 2396, 169, 3, 44, "Text",ExpressionUUID->"c3cf7386-4cab-4839-8d54-88992211ecf4"],
Cell[90079, 2401, 3780, 116, 268, "Input",ExpressionUUID->"ba324767-3636-4725-8c11-b10d47bd5acf"],
Cell[93862, 2519, 1680, 37, 56, "Input",ExpressionUUID->"f2b81fd2-a27d-41ee-a8e0-f8651c847e21"],
Cell[95545, 2558, 1416, 33, 37, "Input",ExpressionUUID->"fd3ca2ff-4483-4d30-9081-d4b1c8266373"],
Cell[96964, 2593, 193, 3, 44, "Text",ExpressionUUID->"de5fb13e-3b83-41fc-a7a2-f0fe1cd7797c"],
Cell[97160, 2598, 656, 17, 37, "Input",ExpressionUUID->"b438c5c5-f14e-4b33-aa12-a5e713ff588b"],
Cell[97819, 2617, 337, 7, 37, "Input",ExpressionUUID->"8eebbb36-a422-4ee5-8402-7970b44f7cd4"]
}, Closed]],
Cell[CellGroupData[{
Cell[98193, 2629, 194, 3, 46, "Subsubsection",ExpressionUUID->"e2e68186-35ab-4cef-a1dc-ea2d89aaadcc"],
Cell[98390, 2634, 451, 9, 73, "Text",ExpressionUUID->"cee3e002-cac1-456a-8517-f287dc1f7bde"],
Cell[98844, 2645, 269, 6, 37, "Input",ExpressionUUID->"3277d677-9b2c-4589-a333-04f27978ef3f"],
Cell[99116, 2653, 316, 7, 44, "Text",ExpressionUUID->"8d7e7434-2438-4d6b-83ad-4a557f8fd5dd"],
Cell[99435, 2662, 732, 20, 55, "Input",ExpressionUUID->"142f7ba8-9840-4226-8f39-755263838a39"],
Cell[100170, 2684, 339, 7, 44, "Text",ExpressionUUID->"199fb3b0-7518-436b-a1ea-bce6c444f98b"],
Cell[100512, 2693, 706, 18, 79, "Input",ExpressionUUID->"062cb86a-ac9f-43fb-b0cd-07a87df5c062"],
Cell[101221, 2713, 2816, 80, 124, "Input",ExpressionUUID->"b97ac5a4-5309-4c63-8108-937c3306353b"],
Cell[104040, 2795, 4137, 99, 283, "Input",ExpressionUUID->"abf07497-742b-4110-bf38-c840e1be8d11"],
Cell[108180, 2896, 7350, 190, 390, "Input",ExpressionUUID->"228585c9-250a-4c14-aaf3-b4c4279a1c0c"],
Cell[115533, 3088, 327, 6, 37, "Input",ExpressionUUID->"33977e49-15b3-4f95-b85f-d4b0d7f22ac7"],
Cell[115863, 3096, 337, 7, 37, "Input",ExpressionUUID->"3db108f4-4fc4-4ff2-bae3-50579fb02e56"],
Cell[116203, 3105, 393, 7, 44, "Text",ExpressionUUID->"3e3e0063-a5c0-40c5-bb52-01bb4497a883"],
Cell[116599, 3114, 388, 8, 37, "Input",ExpressionUUID->"0ce35a37-f2bc-4d0f-8521-b679f2f3440b"],
Cell[116990, 3124, 183, 3, 44, "Text",ExpressionUUID->"6651286d-45d3-4786-9e11-9d5c2b7d3113"],
Cell[CellGroupData[{
Cell[117198, 3131, 1690, 51, 111, "Input",ExpressionUUID->"1010dac9-99e4-4b8e-a002-0b0e95d38cbb"],
Cell[118891, 3184, 3025, 83, 133, "Output",ExpressionUUID->"003779d0-aa14-499f-b409-0de60cbab571"]
}, Open  ]],
Cell[121931, 3270, 2390, 73, 286, "Input",ExpressionUUID->"a982b5b5-7a8a-41f6-9412-891ca3a08ba9"],
Cell[124324, 3345, 244, 4, 44, "Text",ExpressionUUID->"e91943ec-a39f-4828-87b1-b77280066a5f"],
Cell[124571, 3351, 8984, 247, 417, "Input",ExpressionUUID->"038f6354-9d39-47c0-b919-f494e33ee54d"],
Cell[133558, 3600, 522, 16, 50, "Input",ExpressionUUID->"78ac535d-5e28-4df6-afa8-adfdb0887021"],
Cell[134083, 3618, 252, 4, 44, "Text",ExpressionUUID->"b6602cc9-4fbd-48f5-a027-5a86c4f1ed7a"]
}, Closed]],
Cell[CellGroupData[{
Cell[134372, 3627, 229, 4, 46, "Subsubsection",ExpressionUUID->"4cb2f52a-88cf-4a5a-b305-b9bb2c999a0a"],
Cell[134604, 3633, 271, 6, 44, "Text",ExpressionUUID->"97ff5e11-defe-420c-88b6-67e0f74a272d"],
Cell[134878, 3641, 394, 8, 37, "Input",ExpressionUUID->"750793ea-9893-4f34-83bf-b332658061b1"],
Cell[135275, 3651, 2498, 72, 296, "Input",ExpressionUUID->"d8bf5323-e245-4262-8fdc-f468cbb4d98d"],
Cell[137776, 3725, 573, 13, 44, "Text",ExpressionUUID->"d80fe314-7c1e-4b3d-8f2d-5c7c27497277"],
Cell[138352, 3740, 939, 23, 73, "Input",ExpressionUUID->"6f01dd23-1fbd-4260-b661-9a6e79275c40"],
Cell[139294, 3765, 1745, 46, 42, "Input",ExpressionUUID->"29208c5a-093a-4f1a-bfb1-aef8e7523324"],
Cell[141042, 3813, 508, 9, 44, "Text",ExpressionUUID->"80d703f5-3b6f-46c8-b144-c28a665af398"],
Cell[141553, 3824, 1295, 34, 37, "Input",ExpressionUUID->"7a7d05a4-efda-4e50-9510-68aef78925ac"],
Cell[142851, 3860, 214, 5, 44, "Text",ExpressionUUID->"edfed9fa-0cbb-4ff3-b80f-237652aef9e6"],
Cell[143068, 3867, 1378, 43, 90, "Input",ExpressionUUID->"07f22f7a-ea66-4548-9b4d-0a25953586ae"],
Cell[144449, 3912, 288, 7, 44, "Text",ExpressionUUID->"5bb541a8-791e-4eef-9b07-d1dc086c1a26"]
}, Closed]],
Cell[CellGroupData[{
Cell[144774, 3924, 189, 3, 46, "Subsubsection",ExpressionUUID->"b67787ca-dca5-4a02-83dd-a72142ff01f6"],
Cell[144966, 3929, 426, 8, 44, "Text",ExpressionUUID->"d9891260-7ef9-468b-8150-fe3a94d6b40c"],
Cell[145395, 3939, 15691, 374, 810, "Input",ExpressionUUID->"a1230d2b-b2e5-4a9c-838c-2d004a704927"],
Cell[161089, 4315, 505, 11, 37, "Input",ExpressionUUID->"4b0b668b-67a7-445d-af8a-cfd898f54cce"],
Cell[161597, 4328, 218, 5, 44, "Text",ExpressionUUID->"a9c5b71d-8550-4a7f-8b6f-3970c5ff50b0"],
Cell[161818, 4335, 3579, 92, 338, "Input",ExpressionUUID->"b2e9d75b-a3f8-47b4-9b31-6676fbf56e33"],
Cell[165400, 4429, 301, 7, 44, "Text",ExpressionUUID->"f784fac5-90a1-4205-b72e-a315d517a506"]
}, Closed]],
Cell[CellGroupData[{
Cell[165738, 4441, 207, 3, 46, "Subsubsection",ExpressionUUID->"6df26a84-fd1c-4752-8373-c6e9bdd9fc92"],
Cell[165948, 4446, 462, 8, 44, "Text",ExpressionUUID->"e0677950-e79b-4427-8021-82990c70d048"],
Cell[166413, 4456, 7312, 192, 690, "Input",ExpressionUUID->"16c5713b-7e2e-41ca-85d6-b4927f5fb2e9"],
Cell[173728, 4650, 186, 3, 44, "Text",ExpressionUUID->"a2ecf9d2-b1ad-4cfd-b79c-58ba37faf482"],
Cell[CellGroupData[{
Cell[173939, 4657, 710, 15, 63, "Input",ExpressionUUID->"09e032fd-e5f3-4e7f-9bc3-732a037f9bc0"],
Cell[174652, 4674, 329, 5, 43, "Output",ExpressionUUID->"ae8f9ffd-3c22-4a0b-8750-7d02f3449c7f"]
}, Open  ]],
Cell[174996, 4682, 1515, 42, 77, "Input",ExpressionUUID->"ef11a761-029f-4724-89dc-80f79ce38e17"],
Cell[176514, 4726, 304, 8, 37, "Input",ExpressionUUID->"00c23082-eb13-4d62-acd4-2dc220e15e2a"],
Cell[176821, 4736, 2187, 45, 73, "Input",ExpressionUUID->"3c23d6e6-591b-4322-976f-88027f4a8da1"],
Cell[179011, 4783, 1272, 33, 73, "Input",ExpressionUUID->"c4744d6b-3807-455c-a5f4-d304a2a71f2b"],
Cell[180286, 4818, 274, 6, 37, "Input",ExpressionUUID->"8c0cd337-a86d-4bdf-af0c-dcec9b88464d"],
Cell[180563, 4826, 977, 28, 37, "Input",ExpressionUUID->"ced4bf84-6e1e-4818-9d37-17411dbdc828"],
Cell[CellGroupData[{
Cell[181565, 4858, 321, 7, 37, "Input",ExpressionUUID->"8fc7a870-dcbd-4861-80f3-3f34021bc7f2"],
Cell[181889, 4867, 212, 3, 43, "Output",ExpressionUUID->"00471a58-e7e3-4cd9-aec1-96f02b4202a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[182138, 4875, 1525, 43, 72, "Input",ExpressionUUID->"a91fb940-1d79-4a04-858a-944ec575db0c"],
Cell[183666, 4920, 37106, 658, 308, "Output",ExpressionUUID->"aa890f55-4e55-442e-b97c-47ca3087c6bd"]
}, Open  ]],
Cell[220787, 5581, 218, 4, 37, "Input",ExpressionUUID->"6ad19296-07a1-46d8-bcf1-d9b48d395bf9"],
Cell[221008, 5587, 3646, 84, 125, "Input",ExpressionUUID->"ffd7ebd1-cd8f-4e4d-91ad-7626a924097e"],
Cell[CellGroupData[{
Cell[224679, 5675, 232, 5, 37, "Input",ExpressionUUID->"9cf30dca-2810-4e20-890a-ae0f245fdef0"],
Cell[224914, 5682, 245, 5, 48, "Output",ExpressionUUID->"5b76e31c-0a88-4f08-a162-32b28c5bb171"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

