(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    331026,       8069]
NotebookOptionsPosition[    317340,       7869]
NotebookOutlinePosition[    317713,       7885]
CellTagsIndexPosition[    317670,       7882]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.929254188367724*^9, 3.929254189715686*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"5eabe3ca-11f0-4ce6-8804-d967e41bc368"],

Cell[CellGroupData[{

Cell["\<\
l=1 (dipole) flux computations from circular orbits in scalar boson stars\
\>", "Title",
 CellChangeTimes->{{3.9292470912226987`*^9, 3.9292471260487275`*^9}, {
  3.9295307032339134`*^9, 3.929530705352947*^9}, {3.932481278475408*^9, 
  3.932481279960615*^9}},ExpressionUUID->"14d7fb90-fe0a-4865-b7df-\
e69fb8f5009f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"L", ">", "1"}], ",", 
     RowBox[{"Mt", ">", "0"}], ",", 
     RowBox[{"r", ">", "0"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9293014353375697`*^9, 3.92930144433936*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"eae332e9-1963-468e-9c8a-2308583eb3a2"],

Cell["\<\
Reference: F. Duque, C. Macedo, R. Vicente and V.Cardoso. Physical Review \
Letters (in production) (2024) 2312.06767.\
\>", "Text",
 CellChangeTimes->{
  3.932481247375435*^9},ExpressionUUID->"5e768322-87f5-49f8-acd1-\
d8d850091437"],

Cell[CellGroupData[{

Cell["Computing boson star configurations", "Section",
 CellChangeTimes->{{3.9292471315111165`*^9, 
  3.929247171885967*^9}},ExpressionUUID->"f4ea5f2e-aa29-430f-8578-\
b770ed4148e2"],

Cell[CellGroupData[{

Cell["Organizing the equations and finding the boundary conditions", \
"Subsubsection",
 CellChangeTimes->{{3.9292484189839134`*^9, 
  3.929248427679536*^9}},ExpressionUUID->"f6e5c295-8482-44a5-a551-\
5a2a76549749"],

Cell[TextData[{
 "We start by computing the background configurations. Notice that you can \
export these solutions if you wish to save some time. We consider the metric \
as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "tt"], "=", 
    RowBox[{"V", "[", "r", "]"}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "47d302a8-300a-4e16-a3b2-6bef90ccd41f"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "rr"], "=", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", 
        FractionBox[
         RowBox[{"M", "[", "r", "]"}], "r"]}]}], ")"}], 
     RowBox[{"-", "1"}]]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "678f32f6-a753-4751-81f4-6a9b68815585"],
 ". Everything is in units of \[Mu]=1\n\nThe background field equations are"
}], "Text",
 CellChangeTimes->{{3.9292471734112387`*^9, 3.929247204242113*^9}, {
  3.929247242101017*^9, 
  3.9292473373567815`*^9}},ExpressionUUID->"8b4750ff-2197-4f67-9c3e-\
7a89be4400bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eq1", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"M", "[", "r", "]"}], " ", 
          RowBox[{"V", "[", "r", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Omega]", "2"], "-", 
            RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["V", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "-", 
    RowBox[{"2", " ", "r", " ", 
     RowBox[{"V", "[", "r", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]0", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "2"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eq2", "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["M", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], "-", 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"r", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Omega]", "2"], "+", 
            RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
         RowBox[{"V", "[", "r", "]"}]], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]0", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}]}]}], 
   ";"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq3", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["r", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[Omega]", "2"]}], "+", 
          RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
        RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"V", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "r"}], "+", 
          RowBox[{"M", "[", "r", "]"}], "+", 
          RowBox[{
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]0", "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}]}]}], 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"V", "[", "r", "]"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["\[Phi]0", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.929247317223193*^9, 3.929247395324712*^9}, {
  3.9292474441867228`*^9, 3.929247456710218*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"e1880841-24cc-4cae-b8e9-325b9064d94f"],

Cell["\<\
Now to improve boundary conditions at the origin we perform an expansion. \
Notice that we shall use this in the expansion for the perturbation as well. \
We also integrate using coordinates such that V[0]=1.\
\>", "Text",
 CellChangeTimes->{{3.9292474632356615`*^9, 3.9292475048624787`*^9}, {
  3.929247598297689*^9, 3.929247615681966*^9}, {3.929247706895056*^9, 
  3.929247711812069*^9}},ExpressionUUID->"a0624733-4ecc-4359-b2a6-\
601f9f46e3d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"M", ",", "V", ",", "\[Phi]0"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.929247507986782*^9, 3.929247513560466*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"f6e01616-10d4-46fe-a1c6-54f0fcc29d36"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"M", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["Mi", "i"], " ", 
      SuperscriptBox["r", 
       RowBox[{"i", "+", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["Vi", "i"], 
      SuperscriptBox["r", "i"]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]0", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[Phi]0i", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}], "/.", 
    RowBox[{
     SubscriptBox["\[Phi]0i", "0"], "\[Rule]", "\[Phi]c"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.9292475159160953`*^9, 3.9292475338163395`*^9}, {
   3.9292476202750487`*^9, 3.929247649639064*^9}, {3.929247702865054*^9, 
   3.9292477048287163`*^9}, {3.9292478840323696`*^9, 3.929247939558627*^9}, {
   3.9292479788642426`*^9, 3.929248063121293*^9}, {3.929248143487468*^9, 
   3.92924814741041*^9}, {3.9292481859052343`*^9, 3.929248196800125*^9}, {
   3.92924828964904*^9, 3.9292482924941416`*^9}, 3.9292659305015554`*^9},
 CellLabel->"In[6]:=",ExpressionUUID->"a1c63b01-86f0-4fdb-888c-bf24235333cf"],

Cell["We solve the following equation near the origin", "Text",
 CellChangeTimes->{{3.929248254245061*^9, 
  3.9292482635819073`*^9}},ExpressionUUID->"d3be96c5-693c-470d-b376-\
544af8772911"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rubkgexp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"eq1", ",", 
           RowBox[{"eq2", " ", 
            SuperscriptBox["r", 
             RowBox[{"-", "1"}]]}], ",", 
           RowBox[{"eq3", " ", "r"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"r", ",", "0", ",", "5"}], "}"}]}], "]"}], "\[Equal]", 
       "0"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["Mi", "1"], ",", 
        SubscriptBox["Vi", "1"], ",", 
        SubscriptBox["\[Phi]0i", "1"], ",", 
        SubscriptBox["Mi", "2"], ",", 
        SubscriptBox["Vi", "2"], ",", 
        SubscriptBox["\[Phi]0i", "2"], ",", 
        SubscriptBox["Mi", "3"], ",", 
        SubscriptBox["Vi", "3"], ",", 
        SubscriptBox["\[Phi]0i", "3"], ",", 
        SubscriptBox["Mi", "4"], ",", 
        SubscriptBox["Vi", "4"], ",", 
        SubscriptBox["\[Phi]0i", "4"], ",", 
        SubscriptBox["Mi", "5"], ",", 
        SubscriptBox["Vi", "5"], ",", 
        SubscriptBox["\[Phi]0i", "5"], ",", 
        SubscriptBox["Mi", "6"], ",", 
        SubscriptBox["Vi", "6"], ",", 
        SubscriptBox["\[Phi]0i", "6"]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.9292480915563326`*^9, 3.9292481203392935`*^9}, {
  3.9292481710683517`*^9, 3.9292483320222607`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"a43dc386-a53b-4b48-be3c-ef3f91e39b17"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["Mi", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Vi", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Mi", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "+", 
        SubscriptBox["Vi", "0"]}], ")"}]}], 
     RowBox[{"3", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Vi", "2"], "\[Rule]", 
    RowBox[{
     FractionBox["2", "3"], " ", 
     SuperscriptBox["\[Phi]c", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Omega]", "2"]}], "-", 
       SubscriptBox["Vi", "0"]}], ")"}]}]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[Omega]", "2"]}], "+", 
        SubscriptBox["Vi", "0"]}], ")"}]}], 
     RowBox[{"6", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Mi", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Vi", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "3"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Mi", "4"], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["\[Phi]c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "4"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"2", " ", 
          SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], 
      RowBox[{"45", " ", 
       SubsuperscriptBox["Vi", "0", "2"]}]]}]}], ",", 
   RowBox[{
    SubscriptBox["Vi", "4"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Omega]", "2"]}], "-", 
        SubscriptBox["Vi", "0"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"]}], "+", 
        SubscriptBox["Vi", "0"]}], ")"}]}], 
     RowBox[{"15", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "4"], "\[Rule]", 
    FractionBox[
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"16", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubscriptBox["Vi", "0"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"20", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], 
     RowBox[{"360", " ", 
      SubsuperscriptBox["Vi", "0", "2"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Mi", "5"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Vi", "5"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "5"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["Mi", "6"], "\[Rule]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "+", 
           RowBox[{"64", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"168", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "6"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"73", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "-", 
           RowBox[{"204", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"], " ", 
         SubscriptBox["Vi", "0"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "15"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"60", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"9", "+", 
           RowBox[{"25", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "3"]}]}], ")"}]}], 
     RowBox[{"945", " ", 
      SubsuperscriptBox["Vi", "0", "3"]}]]}], ",", 
   RowBox[{
    SubscriptBox["Vi", "6"], "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["\[Phi]c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Omega]", "2"]}], "-", 
        SubscriptBox["Vi", "0"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"3", "-", 
           RowBox[{"34", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "12"}], "+", 
           RowBox[{"37", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"180", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubscriptBox["Vi", "0"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"6", "+", 
           RowBox[{"40", " ", 
            SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], 
     RowBox[{"2835", " ", 
      SubsuperscriptBox["Vi", "0", "2"]}]]}], ",", 
   RowBox[{
    SubscriptBox["\[Phi]0i", "6"], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"45360", " ", 
       SubsuperscriptBox["Vi", "0", "3"]}]], 
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"9", "+", 
            RowBox[{"272", " ", 
             SuperscriptBox["\[Phi]c", "2"]}], "+", 
            RowBox[{"448", " ", 
             SuperscriptBox["\[Phi]c", "4"]}]}], ")"}]}], " ", 
         SuperscriptBox["\[Omega]", "6"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"27", "+", 
           RowBox[{"912", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"1184", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "4"], " ", 
         SubscriptBox["Vi", "0"]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"27", "+", 
           RowBox[{"1236", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"992", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubsuperscriptBox["Vi", "0", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"9", "+", 
           RowBox[{"596", " ", 
            SuperscriptBox["\[Phi]c", "2"]}], "+", 
           RowBox[{"1120", " ", 
            SuperscriptBox["\[Phi]c", "4"]}]}], ")"}], " ", 
         SubsuperscriptBox["Vi", "0", "3"]}]}], ")"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.929248204751193*^9, 3.929248216087762*^9}, {
   3.9292482483558836`*^9, 3.9292483330902443`*^9}, 3.9292501872866626`*^9, 
   3.929253093825842*^9, 3.9292541944542603`*^9, 3.9292550943355837`*^9, 
   3.9292659351449823`*^9, 3.929302819332726*^9, 3.929332125864173*^9, 
   3.9293391563011384`*^9, 3.9293458707995768`*^9, 3.929348649040341*^9, 
   3.9293488553492527`*^9, 3.9293622341375065`*^9, 3.9293636700648518`*^9, 
   3.9293736775123625`*^9, 3.9293777937328568`*^9, 3.9293779090941286`*^9, 
   3.92937805392465*^9, 3.929378111410643*^9, 3.9294073766925755`*^9, 
   3.9295073324204803`*^9, 3.9295092804591103`*^9, 3.92951020455838*^9, 
   3.929517491052245*^9, 3.9295177958759885`*^9, 3.929519802716513*^9, 
   3.9295202279563427`*^9, 3.9295204408354015`*^9, 3.9295243326950927`*^9, 
   3.929528733715914*^9, 3.9295296312667522`*^9, 3.9295307371666403`*^9, 
   3.9295312169880867`*^9, 3.9295881250008693`*^9, 3.929589530660967*^9, 
   3.9296110194049945`*^9, 3.929616722075148*^9, 3.9296195307234354`*^9, 
   3.9296311553105507`*^9, 3.9296759041378508`*^9, 3.9296759676144447`*^9, 
   3.9296969836666546`*^9, 3.929761775984743*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"e17d01d4-5928-4e07-8866-e4000a456532"]
}, Open  ]],

Cell["\<\
Therefore, we have the following boundary conditions for the background\
\>", "Text",
 CellChangeTimes->{{3.9292483424267063`*^9, 
  3.9292483517890263`*^9}},ExpressionUUID->"05300666-11d5-4d92-8823-\
838f19fcbccb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BOUNBKG", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"V", "[", "r", "]"}], ",", 
      RowBox[{"M", "[", "r", "]"}], ",", 
      RowBox[{"\[Phi]0", "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}]}], "}"}], "/.", 
    "rubkgexp"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.9292483534932485`*^9, 3.9292483830798287`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"57ffd28c-7a55-443c-8248-3ed515c80611"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"M", ",", "V", ",", "\[Phi]0"}], "]"}]], "Input",
 CellChangeTimes->{{3.9292483875207577`*^9, 3.9292483936006165`*^9}, 
   3.9292487587731743`*^9},
 CellLabel->"In[11]:=",ExpressionUUID->"3dc87e96-66ab-4f49-9e4e-413980dc70e7"],

Cell["Finally, we can perform the background computations.", "Text",
 CellChangeTimes->{{3.929248402766037*^9, 3.9292484107695827`*^9}, 
   3.9292484440644293`*^9},ExpressionUUID->"1af02619-a71b-4478-98bf-\
849ee767fd29"]
}, Closed]],

Cell[CellGroupData[{

Cell["Defining the integrator and the shooting", "Subsubsection",
 CellChangeTimes->{{3.929248431048627*^9, 
  3.9292484511651163`*^9}},ExpressionUUID->"6a305c5a-d0c6-4b1c-9c1f-\
c3aacc4df08e"],

Cell[TextData[{
 "Usually, one search for a solution that has a scalar field at the origin ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Phi]", "c"], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "f1aba4d0-035a-4424-8215-a53f3ed414da"],
 " and frequency \[Omega] in which the scalar decays to zero far from the \
center. Here we search for a solution in which the scalar decreases \
exponentially as ",
 Cell[BoxData[
  FormBox[
   RowBox[{"exp", "[", 
    RowBox[{
     RowBox[{"-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], "-", 
        RowBox[{
         SuperscriptBox["w", "2"], "/", 
         RowBox[{"V", "[", "r", "]"}]}]}]]}], 
     RowBox[{"rst", "[", "r", "]"}]}], "]"}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "3a681a8f-ad97-4264-8699-3fada8fbfa10"],
 ", where rst[r] is the tortoise coordinate. You can change that if you wish."
}], "Text",
 CellChangeTimes->{{3.929248454414774*^9, 
  3.9292486014469795`*^9}},ExpressionUUID->"dbc38347-e4fc-447e-8b43-\
906ba1d0ff68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BKGI", "[", 
   RowBox[{
    RowBox[{"\[Omega]0_", "?", "NumberQ"}], ",", "\[Phi]c0_", ",", "r10_", 
    ",", "r20_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"paramint", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"MaxSteps", "\[Rule]", "\[Infinity]"}], ",", 
       RowBox[{"Method", "->", "\"\<StiffnessSwitching\>\""}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "12"}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "12"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"defining", " ", "the", " ", "parameters"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"param", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Omega]", "\[Rule]", "\[Omega]0"}], ",", 
       RowBox[{"\[Phi]c", "\[Rule]", "\[Phi]c0"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "defining", " ", "equations", " ", "to", " ", "be", " ", "integrated", 
      " ", "and", " ", "boundary", " ", "conditions"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"EQS", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"eq1", "\[Equal]", "0"}], ",", 
        RowBox[{"eq2", "\[Equal]", "0"}], ",", 
        RowBox[{"eq3", "\[Equal]", "0"}]}], "}"}], "/.", "param"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"BOU", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Thread", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"V", "[", "r", "]"}], ",", 
            RowBox[{"M", "[", "r", "]"}], ",", 
            RowBox[{"\[Phi]0", "[", "r", "]"}], ",", 
            RowBox[{
             RowBox[{"\[Phi]0", "''"}], "[", "r", "]"}]}], "}"}], "\[Equal]", 
          "BOUNBKG"}], "]"}], "/.", "param"}], "/.", 
       RowBox[{
        SubscriptBox["Vi", "0"], "\[Rule]", "1"}]}], "/.", 
      RowBox[{"r", "\[Rule]", "r10"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "Integrating", " ", "the", " ", "differential", " ", "equations"}], 
     "*)"}], "\[IndentingNewLine]", 
    RowBox[{"SOLBK", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"EQS", ",", "BOU"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Phi]0", ",", "M", ",", "V"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r10", ",", "r20"}], "}"}], ",", "paramint"}], 
       "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{
      "Computing", " ", "the", " ", "scaled", " ", "quantities", " ", "such", 
       " ", "that", " ", "V", 
       RowBox[{"(", "0", ")"}]}], "=", "1"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"sc1", "=", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"1", "-", 
         RowBox[{"2", 
          FractionBox[
           RowBox[{"M", "[", "r", "]"}], "r"]}]}], 
        RowBox[{"V", "[", "r", "]"}]], "/.", "SOLBK"}], "/.", 
      RowBox[{"r", "\[Rule]", "r20"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"\[Omega]s", "=", 
     RowBox[{
      SuperscriptBox["sc1", 
       RowBox[{"1", "/", "2"}]], "\[Omega]0"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"MT", "=", 
     RowBox[{
      RowBox[{"M", "[", "r20", "]"}], "/.", "SOLBK"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"param2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Omega]", "\[Rule]", "\[Omega]s"}], ",", 
       RowBox[{"\[Phi]c", "\[Rule]", "\[Phi]c0"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"RINF", "=", 
     RowBox[{"SOLBK", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2", ",", "1", ",", "1", ",", "2"}], "]"}], "]"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "We", " ", "demand", " ", "that", " ", "the", " ", "following", " ", 
      "should", " ", "be", " ", "zero", " ", 
      RowBox[{"(", 
       RowBox[{"it", " ", "is", " ", "a", " ", "Wronskian"}], ")"}]}], "*)"}],
     "\[IndentingNewLine]", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "MT"}], "-", "r20", "-", 
           RowBox[{
            SuperscriptBox["r20", "2"], " ", 
            SqrtBox[
             RowBox[{"1", "-", 
              FractionBox[
               SuperscriptBox["\[Omega]0", "2"], 
               RowBox[{"V", "[", "r20", "]"}]]}]]}]}], ")"}], " ", 
         RowBox[{"\[Phi]0", "[", "r20", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "MT"}], "-", "r20"}], ")"}], " ", "r20", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]0", "\[Prime]",
           MultilineFunction->None], "[", "r20", "]"}]}]}], ")"}], 
      "\[Phi]c0"], "/.", "SOLBK"}]}], "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.9292486085980663`*^9, 3.9292488467621107`*^9}, {
   3.929248990670339*^9, 3.9292491202336435`*^9}, 3.9292491676546793`*^9, {
   3.9292492155534267`*^9, 3.9292493544064484`*^9}, {3.929249927160367*^9, 
   3.9292499331641264`*^9}, {3.9292659610233355`*^9, 3.929265961893789*^9}, {
   3.9292665087222977`*^9, 3.9292665509769993`*^9}, {3.92926659544553*^9, 
   3.9292666315715055`*^9}, {3.929333738399108*^9, 3.929333748825523*^9}, {
   3.9294074529344325`*^9, 3.9294074749913445`*^9}, {3.9294075722372227`*^9, 
   3.929407614381418*^9}, {3.9295288110549765`*^9, 3.9295288173262634`*^9}, {
   3.9295288873018923`*^9, 3.929528887589785*^9}, {3.9295297040730696`*^9, 
   3.929529704139697*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"276e9363-6de0-4957-a8a1-d2d14d5733ea"],

Cell["\<\
Now we can search for numerical background solutions. I\[CloseCurlyQuote]ll \
focus on the maximum mass configurations, but you can change that to whataver \
you want. In our case \[Phi]max=.1916\
\>", "Text",
 CellChangeTimes->{{3.929249359430789*^9, 3.9292493954370785`*^9}, {
   3.929249432021922*^9, 3.929249436534418*^9}, 
   3.929265966007163*^9},ExpressionUUID->"d96ffe01-a0c3-43ae-9d7e-\
f40613916870"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating the background equations", "Subsubsection",
 CellChangeTimes->{{3.9292494103901134`*^9, 3.9292494190639863`*^9}, {
  3.929250099103907*^9, 
  3.92925010278119*^9}},ExpressionUUID->"6bf26153-0215-45d2-abe5-\
0667fa1f0a4a"],

Cell["\<\
We define the maximum value for the scalar field (we know that from previous \
computations)\
\>", "Text",
 CellChangeTimes->{{3.9292495208946223`*^9, 
  3.9292495364007826`*^9}},ExpressionUUID->"5e934734-14e1-4240-ad31-\
a2aad47b5743"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]max", "=", 
   RowBox[{"0.304", ".1916"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929249437782932*^9, 3.9292494377849317`*^9}, {
   3.9297279096389275`*^9, 3.9297279114358788`*^9}, {3.9297280534673047`*^9, 
   3.9297280708113623`*^9}, 3.9297281065325646`*^9, {3.9297281413425937`*^9, 
   3.9297281491856146`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"d176f7a7-a063-4622-bbf6-ccbe17a362b0"],

Cell["Do the FindRoot", "Text",
 CellChangeTimes->{{3.929249540638618*^9, 3.929249542585072*^9}, {
  3.9293028255610857`*^9, 3.9293028269798717`*^9}, {3.9297279987802*^9, 
  3.9297280003135414`*^9}},ExpressionUUID->"ec50739c-c2aa-4b04-902a-\
64dc73deb85b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"BKGI", "[", 
      RowBox[{"xx", ",", "\[Phi]max", ",", "0.001", ",", "40"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "1.0586767834595936`"}], "}"}]}], "]"}], ",", "xx"}],
   "]"}], "\[IndentingNewLine]", "MT"}], "Input",
 CellChangeTimes->{{3.9292494429627295`*^9, 3.92924950389202*^9}, {
   3.929249944980235*^9, 3.9292499673516393`*^9}, {3.9292664785397224`*^9, 
   3.9292664803980227`*^9}, 3.9293028300016327`*^9, 3.9293326418163033`*^9, {
   3.9293777696667614`*^9, 3.9293777794540195`*^9}, {3.9294073826716056`*^9, 
   3.9294074354014163`*^9}, {3.929407481350754*^9, 3.929407587465705*^9}, {
   3.9294076228637533`*^9, 3.929407690686348*^9}, {3.9297279240555267`*^9, 
   3.9297279497034016`*^9}, {3.929728013206674*^9, 3.9297280148428235`*^9}, {
   3.9297280493877153`*^9, 3.9297281615182443`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"3e41872e-765f-4c4f-beb2-2d911ed40523"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"xx", "\[Rule]", "1.0586767820158045`"}], "}"}]], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295204238487635`*^9, 3.929698010720002*^9, 3.929724003898614*^9, {
   3.9297279159519415`*^9, 3.9297279502312717`*^9}, {3.929728001133248*^9, 
   3.929728019743812*^9}, {3.9297280505654383`*^9, 3.929728162035088*^9}, 
   3.9297617765394964`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"818745a3-abfa-4eb5-a08e-ead49fc735f8"],

Cell[BoxData["0.5005476426897318`"], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295204238487635`*^9, 3.929698010720002*^9, 3.929724003898614*^9, {
   3.9297279159519415`*^9, 3.9297279502312717`*^9}, {3.929728001133248*^9, 
   3.929728019743812*^9}, {3.9297280505654383`*^9, 3.929728162035088*^9}, 
   3.9297617765429997`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"e4f72978-51c1-46f5-9724-d64c8a37bda4"]
}, Open  ]],

Cell["Check whether it has the required behavior", "Text",
 CellChangeTimes->{{3.9292495459155874`*^9, 
  3.9292495552133665`*^9}},ExpressionUUID->"edd9cfed-2ea1-40be-ac13-\
4ee2c40a1b5e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Phi]max"], "/.", "SOLBK"}], "//",
     "Abs"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.001", ",", "RINF"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9292494836639752`*^9, 3.9292495080226245`*^9}, {
   3.9292499435687823`*^9, 3.9292499693386297`*^9}, {3.9292664856166754`*^9, 
   3.929266485754013*^9}, {3.929407440147979*^9, 3.9294074407258964`*^9}, 
   3.9294075095150137`*^9, {3.929407640633501*^9, 3.9294076407509*^9}, {
   3.9294076815384417`*^9, 3.929407694341484*^9}, {3.929727952303987*^9, 
   3.929727952546246*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"fc7d3f4b-d5ca-4a50-be91-a977abdb3d78"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVzHk81OkDwHEalGuFCD/HYIZck5BjwvPoW3LkjLTkPkrJEbk3w7Rylooi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       "]]},
     Annotation[#, "Charting`Private`Tag$2885#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.001, -10.711044206026488`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0.001, 40.}, {-10.711044206026488`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }, {
    Automatic, {{-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-10.41431317630212, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.903487552536127, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.721165995742174, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.567015315914915, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.433483923290392, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.315700887634009, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-8.517193191416238, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-8.111728083308073, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.824046010856292, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.600902459542082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.418580902748128, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.264430222920869, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.013115794639964, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.214608098422191, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.809142990314028, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.521460917862246, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.916290731874155, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.791759469228055, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.70805020110221, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Output",
 CellChangeTimes->{{3.929249499414241*^9, 3.929249508236535*^9}, 
   3.929249557036867*^9, {3.929249940217453*^9, 3.929249982873658*^9}, 
   3.929250187778839*^9, 3.929253094377042*^9, 3.929254194968627*^9, 
   3.9292550948815937`*^9, 3.9292659747844057`*^9, {3.9292664818552923`*^9, 
   3.92926648611342*^9}, 3.9292665588788905`*^9, 3.9292666071786065`*^9, {
   3.9292667978789897`*^9, 3.9292668159846287`*^9}, 3.92930282023897*^9, 
   3.9293321267239904`*^9, 3.929332643894393*^9, 3.929333756545707*^9, 
   3.9293391569207497`*^9, 3.9293458718712273`*^9, 3.9293486494894686`*^9, 
   3.929348855931329*^9, 3.9293622347871356`*^9, 3.929363673009411*^9, 
   3.929364155569137*^9, 3.929373678152976*^9, {3.9293777708941693`*^9, 
   3.9293777945168324`*^9}, 3.9293779095937853`*^9, 3.9293780544818*^9, 
   3.929378112284787*^9, {3.929407393241271*^9, 3.929407441695442*^9}, {
   3.9294074788297763`*^9, 3.929407568827527*^9}, {3.92940761927335*^9, 
   3.9294076947031097`*^9}, 3.9295073328996954`*^9, 3.9295204240411444`*^9, 
   3.9296980108962393`*^9, 3.929724004083865*^9, {3.929727919177136*^9, 
   3.9297279465329943`*^9}, {3.9297280021194763`*^9, 
   3.9297280213078833`*^9}, {3.929728061775769*^9, 3.929728163284441*^9}, 
   3.9297617767307854`*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"19988f73-bc7e-400a-922c-708c63ed4849"]
}, Open  ]],

Cell["\<\
The mass matches Kaup\[CloseCurlyQuote]s result. We can define now a rule to \
apply this background to compute the perturbations\
\>", "Text",
 CellChangeTimes->{{3.9292495682876253`*^9, 3.9292495813126645`*^9}, {
  3.929249856357086*^9, 
  3.9292498740360937`*^9}},ExpressionUUID->"724b293e-196d-464a-912e-\
5cb9949761a4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rubkg", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"M", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"M", "[", "r", "]"}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"V", "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{"V", "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"V", "'"}], "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{
            RowBox[{"V", "'"}], "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Phi]0", "[", "r", "]"}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "/.", "SOLBK"}], 
         ")"}]}]}], "}"}], ",", "param2", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"scal", "\[Rule]", "sc1"}], ",", 
       RowBox[{"Mt", "\[Rule]", "MT"}], ",", 
       RowBox[{"rinf", "\[Rule]", "RINF"}], ",", 
       RowBox[{"ror", "\[Rule]", "0.001"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.92924987838093*^9, 3.929249936003543*^9}, {
   3.9292499886164703`*^9, 3.929250038820092*^9}, {3.929266001586071*^9, 
   3.929266011117361*^9}, {3.9292663967428517`*^9, 3.929266433375227*^9}, 
   3.929266563067258*^9, {3.929266639443221*^9, 3.9292667149650593`*^9}, {
   3.929302844729826*^9, 3.9293028449277954`*^9}, {3.929332674253724*^9, 
   3.9293326788328404`*^9}, {3.9293337610959473`*^9, 3.929333763125454*^9}, {
   3.929363678553999*^9, 3.9293638126658096`*^9}, {3.9293641590776215`*^9, 
   3.9293641658586626`*^9}, 3.929728006565918*^9, {3.929728178826312*^9, 
   3.9297281831630545`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"71f444f7-014f-4da8-8038-0030508ff14d"],

Cell["Now we can compute the perturbations", "Text",
 CellChangeTimes->{{3.929250044288864*^9, 
  3.9292500513422513`*^9}},ExpressionUUID->"498ab69e-9751-4f4f-9f46-\
3b315e323f04"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating the background equations: Boson stars", "Subsubsection",
 CellChangeTimes->{{3.9292494103901134`*^9, 3.9292494190639863`*^9}, {
  3.929250099103907*^9, 3.92925010278119*^9}, {3.932467785828891*^9, 
  3.932467790367651*^9}},ExpressionUUID->"ccbde603-85c3-4ed7-a286-\
6d042a19e157"],

Cell["\<\
We define the maximum value for the scalar field (we know that from previous \
computations)\
\>", "Text",
 CellChangeTimes->{{3.9292495208946223`*^9, 
  3.9292495364007826`*^9}},ExpressionUUID->"5c931606-38ff-4a30-872b-\
1a495c89a165"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]max", "=", "0.1916"}], ";"}]], "Input",
 CellChangeTimes->{{3.929249437782932*^9, 3.9292494377849317`*^9}, {
   3.9297279096389275`*^9, 3.9297279114358788`*^9}, {3.9297280534673047`*^9, 
   3.9297280708113623`*^9}, 3.9297281065325646`*^9, {3.9297281413425937`*^9, 
   3.9297281491856146`*^9}, 3.9297621600851297`*^9, {3.9297739035333385`*^9, 
   3.9297740310960174`*^9}, {3.9297832519266415`*^9, 3.9297833240638*^9}, {
   3.92978336466422*^9, 3.9297833829313655`*^9}, {3.929783466920102*^9, 
   3.9297834763429413`*^9}, {3.930054473662819*^9, 3.9300544754327607`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"b57ec35a-a3a2-49d4-8e4a-16feb57183f3"],

Cell["Do the FindRoot", "Text",
 CellChangeTimes->{{3.929249540638618*^9, 3.929249542585072*^9}, {
  3.9293028255610857`*^9, 3.9293028269798717`*^9}, {3.9297279987802*^9, 
  3.9297280003135414`*^9}},ExpressionUUID->"21f81a58-63a8-49fd-b1c9-\
f9747f4a7a46"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"BKGI", "[", 
      RowBox[{"xx", ",", "\[Phi]max", ",", "0.001", ",", "30"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "1.2430593520827826`"}], "}"}]}], "]"}], ",", "xx"}],
   "]"}], "\[IndentingNewLine]", "MT"}], "Input",
 CellChangeTimes->{{3.9292494429627295`*^9, 3.92924950389202*^9}, {
   3.929249944980235*^9, 3.9292499673516393`*^9}, {3.9292664785397224`*^9, 
   3.9292664803980227`*^9}, 3.9293028300016327`*^9, 3.9293326418163033`*^9, {
   3.9293777696667614`*^9, 3.9293777794540195`*^9}, {3.9294073826716056`*^9, 
   3.9294074354014163`*^9}, {3.929407481350754*^9, 3.929407587465705*^9}, {
   3.9294076228637533`*^9, 3.929407690686348*^9}, {3.9297279240555267`*^9, 
   3.9297279497034016`*^9}, {3.929728013206674*^9, 3.9297280148428235`*^9}, {
   3.9297280493877153`*^9, 3.9297281615182443`*^9}, {3.9297621670858126`*^9, 
   3.929762286580372*^9}, {3.92977390846953*^9, 3.929774050417148*^9}, {
   3.9297832550123644`*^9, 3.9297833129400167`*^9}, {3.9297833698543925`*^9, 
   3.929783533960082*^9}, {3.9300544889202023`*^9, 3.9300545411807375`*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"3ca05f87-f0d0-4d53-9b27-39e2b61985c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"xx", "\[Rule]", "1.2430576002491154`"}], "}"}]], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295204238487635`*^9, 3.929698010720002*^9, 3.929724003898614*^9, {
   3.9297279159519415`*^9, 3.9297279502312717`*^9}, {3.929728001133248*^9, 
   3.929728019743812*^9}, {3.9297280505654383`*^9, 3.929728162035088*^9}, 
   3.929761919455723*^9, 3.929761991215452*^9, {3.9297621741234207`*^9, 
   3.9297622869779572`*^9}, 3.9297733033491187`*^9, {3.9297739096109123`*^9, 
   3.9297740508166075`*^9}, {3.9297832566005573`*^9, 
   3.9297833361721134`*^9}, {3.929783370610485*^9, 3.9297833840818205`*^9}, {
   3.929783451345046*^9, 3.929783534159384*^9}, {3.9300544905180197`*^9, 
   3.930054541653688*^9}, 3.932469004970302*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"61d3cbf8-ac71-43c8-b8d2-3789f6104f9b"],

Cell[BoxData["0.6330008427817497`"], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295204238487635`*^9, 3.929698010720002*^9, 3.929724003898614*^9, {
   3.9297279159519415`*^9, 3.9297279502312717`*^9}, {3.929728001133248*^9, 
   3.929728019743812*^9}, {3.9297280505654383`*^9, 3.929728162035088*^9}, 
   3.929761919455723*^9, 3.929761991215452*^9, {3.9297621741234207`*^9, 
   3.9297622869779572`*^9}, 3.9297733033491187`*^9, {3.9297739096109123`*^9, 
   3.9297740508166075`*^9}, {3.9297832566005573`*^9, 
   3.9297833361721134`*^9}, {3.929783370610485*^9, 3.9297833840818205`*^9}, {
   3.929783451345046*^9, 3.929783534159384*^9}, {3.9300544905180197`*^9, 
   3.930054541653688*^9}, 3.9324690049728107`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"8b05f4d0-f504-472c-9966-5528886e8399"]
}, Open  ]],

Cell["Check whether it has the required behavior", "Text",
 CellChangeTimes->{{3.9292495459155874`*^9, 
  3.9292495552133665`*^9}},ExpressionUUID->"bde97fcc-e003-4c87-a4a9-\
32c543005443"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Phi]max"], "/.", "SOLBK"}], "//",
     "Abs"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.001", ",", "RINF"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9292494836639752`*^9, 3.9292495080226245`*^9}, {
   3.9292499435687823`*^9, 3.9292499693386297`*^9}, {3.9292664856166754`*^9, 
   3.929266485754013*^9}, {3.929407440147979*^9, 3.9294074407258964`*^9}, 
   3.9294075095150137`*^9, {3.929407640633501*^9, 3.9294076407509*^9}, {
   3.9294076815384417`*^9, 3.929407694341484*^9}, {3.929727952303987*^9, 
   3.929727952546246*^9}, {3.929783497276108*^9, 3.929783525018915*^9}, {
   3.9300545187342234`*^9, 3.930054519243215*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"e2c1baa2-d88f-48dc-bc81-1667586ba7e0"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVxXk8lekCAGCRKCl7HSJkj0/2pM/7WmZEWbOGkJ0wGpqswyGDpIOpkGRr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       "]]},
     Annotation[#, "Charting`Private`Tag$3015#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.001, -15.430587493520905`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0.001, 30.}, {-15.430587493520905`, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }, {
    Automatic, {{-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.3978952727983707`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.4849066497880004`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.5649493574615367`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.6390573296152584`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.70805020110221, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.772588722239781, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.833213344056216, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.8903717578961645`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Output",
 CellChangeTimes->{{3.929249499414241*^9, 3.929249508236535*^9}, 
   3.929249557036867*^9, {3.929249940217453*^9, 3.929249982873658*^9}, 
   3.929250187778839*^9, 3.929253094377042*^9, 3.929254194968627*^9, 
   3.9292550948815937`*^9, 3.9292659747844057`*^9, {3.9292664818552923`*^9, 
   3.92926648611342*^9}, 3.9292665588788905`*^9, 3.9292666071786065`*^9, {
   3.9292667978789897`*^9, 3.9292668159846287`*^9}, 3.92930282023897*^9, 
   3.9293321267239904`*^9, 3.929332643894393*^9, 3.929333756545707*^9, 
   3.9293391569207497`*^9, 3.9293458718712273`*^9, 3.9293486494894686`*^9, 
   3.929348855931329*^9, 3.9293622347871356`*^9, 3.929363673009411*^9, 
   3.929364155569137*^9, 3.929373678152976*^9, {3.9293777708941693`*^9, 
   3.9293777945168324`*^9}, 3.9293779095937853`*^9, 3.9293780544818*^9, 
   3.929378112284787*^9, {3.929407393241271*^9, 3.929407441695442*^9}, {
   3.9294074788297763`*^9, 3.929407568827527*^9}, {3.92940761927335*^9, 
   3.9294076947031097`*^9}, 3.9295073328996954`*^9, 3.9295204240411444`*^9, 
   3.9296980108962393`*^9, 3.929724004083865*^9, {3.929727919177136*^9, 
   3.9297279465329943`*^9}, {3.9297280021194763`*^9, 
   3.9297280213078833`*^9}, {3.929728061775769*^9, 3.929728163284441*^9}, 
   3.929761919707611*^9, 3.9297619913412004`*^9, {3.9297621994786663`*^9, 
   3.9297622881183386`*^9}, 3.92977330372106*^9, {3.9297739103179226`*^9, 
   3.9297739279805903`*^9}, {3.9297739785564904`*^9, 
   3.9297740519772425`*^9}, {3.929783263445797*^9, 3.929783321628007*^9}, {
   3.929783371921524*^9, 3.929783385432563*^9}, {3.9297834526230135`*^9, 
   3.929783535451419*^9}, {3.930054519761766*^9, 3.930054542722932*^9}, 
   3.9324690054539537`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"b8001d49-6b95-444b-a028-7d9983f16411"]
}, Open  ]],

Cell["\<\
The mass matches Kaup\[CloseCurlyQuote]s result. We can define now a rule to \
apply this background to compute the perturbations\
\>", "Text",
 CellChangeTimes->{{3.9292495682876253`*^9, 3.9292495813126645`*^9}, {
  3.929249856357086*^9, 
  3.9292498740360937`*^9}},ExpressionUUID->"91b5d5cf-ba05-4c16-b592-\
68fdc8fbf82e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rubkg", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"M", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"M", "[", "r", "]"}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"V", "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{"V", "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"V", "'"}], "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{
            RowBox[{"V", "'"}], "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Phi]0", "[", "r", "]"}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "/.", "SOLBK"}], 
         ")"}]}]}], "}"}], ",", "param2", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"scal", "\[Rule]", "sc1"}], ",", 
       RowBox[{"Mt", "\[Rule]", "MT"}], ",", 
       RowBox[{"rinf", "\[Rule]", "RINF"}], ",", 
       RowBox[{"ror", "\[Rule]", "0.001"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.92924987838093*^9, 3.929249936003543*^9}, {
   3.9292499886164703`*^9, 3.929250038820092*^9}, {3.929266001586071*^9, 
   3.929266011117361*^9}, {3.9292663967428517`*^9, 3.929266433375227*^9}, 
   3.929266563067258*^9, {3.929266639443221*^9, 3.9292667149650593`*^9}, {
   3.929302844729826*^9, 3.9293028449277954`*^9}, {3.929332674253724*^9, 
   3.9293326788328404`*^9}, {3.9293337610959473`*^9, 3.929333763125454*^9}, {
   3.929363678553999*^9, 3.9293638126658096`*^9}, {3.9293641590776215`*^9, 
   3.9293641658586626`*^9}, 3.929728006565918*^9, {3.929728178826312*^9, 
   3.9297281831630545`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"15f3121a-d64c-4f6c-a8ca-a4b1e0f90c01"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating the background equations: Parasitic black hole ", \
"Subsubsection",
 CellChangeTimes->{{3.9292494103901134`*^9, 3.9292494190639863`*^9}, {
  3.929250099103907*^9, 3.92925010278119*^9}, {3.932467785828891*^9, 
  3.9324678030468454`*^9}, {3.932468857079599*^9, 
  3.9324688719448986`*^9}},ExpressionUUID->"7b524ab4-c59d-4dc9-8e70-\
7a831a78f0aa"],

Cell["\<\
We show the case for M\[Mu]=0.1, but other cases can be computed in the same \
fashion.\
\>", "Text",
 CellChangeTimes->{{3.9292495208946223`*^9, 3.9292495364007826`*^9}, {
  3.932468942618695*^9, 
  3.9324689738119087`*^9}},ExpressionUUID->"6c1473b1-8a3d-469f-a528-\
3c0871e8d781"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Phi]max", "=", "0.00170524"}], ";"}]], "Input",
 CellChangeTimes->{{3.929249437782932*^9, 3.9292494377849317`*^9}, {
   3.929528709895975*^9, 3.929528713717223*^9}, {3.929631106684226*^9, 
   3.929631135989314*^9}, {3.9296335086039467`*^9, 3.929633509343091*^9}, {
   3.929636560020132*^9, 3.929636560355353*^9}, 3.9296366432120285`*^9, {
   3.929636681191718*^9, 3.9296366815837603`*^9}, {3.929636711699109*^9, 
   3.929636753818775*^9}, {3.9296378009712934`*^9, 3.9296378013378153`*^9}, {
   3.9296378389336452`*^9, 3.929637852067519*^9}, {3.929637885888035*^9, 
   3.9296378864424353`*^9}, {3.9296770954719477`*^9, 
   3.9296771530219526`*^9}, {3.9296788835048976`*^9, 
   3.9296788845729437`*^9}, {3.92968097183395*^9, 3.9296810469040728`*^9}, {
   3.93246897654338*^9, 3.9324689819755163`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"d13655f6-0f42-443e-a2f1-5c524a55670b"],

Cell["Do the FindRoot", "Text",
 CellChangeTimes->{{3.929249540638618*^9, 3.929249542585072*^9}, {
  3.9293028255610857`*^9, 
  3.9293028269798717`*^9}},ExpressionUUID->"acfbb88a-a8e3-4be3-ace5-\
4e782133f2ea"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Monitor", "[", 
  RowBox[{
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"BKGI", "[", 
      RowBox[{"xx", ",", "\[Phi]max", ",", "0.001", ",", "180"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"xx", ",", "1.0015705361986202`"}], "}"}]}], "]"}], ",", "xx"}],
   "]"}], "\[IndentingNewLine]", "MT"}], "Input",
 CellChangeTimes->{{3.9292494429627295`*^9, 3.92924950389202*^9}, {
   3.929249944980235*^9, 3.9292499673516393`*^9}, {3.9292664785397224`*^9, 
   3.9292664803980227`*^9}, 3.9293028300016327`*^9, 3.9293326418163033`*^9, {
   3.9293777696667614`*^9, 3.9293777794540195`*^9}, {3.9294073826716056`*^9, 
   3.9294074354014163`*^9}, {3.929407481350754*^9, 3.929407587465705*^9}, {
   3.9294076228637533`*^9, 3.929407690686348*^9}, {3.929528719260462*^9, 
   3.929528777411563*^9}, {3.929528828861417*^9, 3.929528927565572*^9}, {
   3.9296123761697645`*^9, 3.92961243244993*^9}, {3.9296311408706264`*^9, 
   3.9296314163667364`*^9}, {3.9296335026376605`*^9, 3.929633579773094*^9}, {
   3.92963656847721*^9, 3.9296368164917345`*^9}, {3.9296378156345344`*^9, 
   3.929637913322214*^9}, {3.929677105592987*^9, 3.929677198959568*^9}, {
   3.9296788869389677`*^9, 3.9296789472249627`*^9}, {3.929680975297878*^9, 
   3.9296810884619613`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"0ed91164-798a-43fd-88a0-125f1059f539"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"xx", "\[Rule]", "1.001570537126463`"}], "}"}]], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295092810304503`*^9, 3.929510205121914*^9, 3.9295174915576053`*^9, 
   3.929517796372939*^9, 3.929519803414409*^9, 3.9295202286797314`*^9, 
   3.9295204412758026`*^9, 3.929524333168296*^9, {3.9295287362582006`*^9, 
   3.929528778039892*^9}, {3.9295288245264025`*^9, 3.929528927876172*^9}, 
   3.9295297184268875`*^9, 3.929530737931596*^9, 3.9295312654867153`*^9, 
   3.929588126249632*^9, 3.9295895330736074`*^9, 3.9296110205436034`*^9, {
   3.9296123785027204`*^9, 3.9296124329394355`*^9}, 3.9296161809661655`*^9, 
   3.9296164840669527`*^9, 3.9296167231889825`*^9, {3.9296195099903135`*^9, 
   3.9296195321260138`*^9}, 3.9296207233979654`*^9, 3.929620791215168*^9, {
   3.9296311415336065`*^9, 3.929631416663517*^9}, 3.9296315123429337`*^9, {
   3.929633512389043*^9, 3.9296335804729195`*^9}, {3.9296365642904778`*^9, 
   3.929636825783084*^9}, {3.9296378190002584`*^9, 3.929637923857246*^9}, {
   3.9296758931180577`*^9, 3.929675906733467*^9}, 3.9296759381485357`*^9, {
   3.9296759681729717`*^9, 3.9296759742895875`*^9}, {3.9296771066004086`*^9, 
   3.9296772071107635`*^9}, {3.9296788898118186`*^9, 
   3.9296789543740454`*^9}, {3.9296809765407686`*^9, 3.9296810887915015`*^9}, 
   3.9324690093273325`*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"acb3f1e7-4186-4052-9ec9-ecab6594333c"],

Cell[BoxData["0.10076501773286792`"], "Output",
 CellChangeTimes->{{3.929249320322093*^9, 3.929249357470085*^9}, {
   3.929249477037979*^9, 3.929249504326875*^9}, {3.929249939189016*^9, 
   3.9292499820587406`*^9}, 3.929250187632022*^9, 3.9292530941714783`*^9, 
   3.929254194818327*^9, 3.929255094641053*^9, 3.92926597289817*^9, {
   3.9292664749288874`*^9, 3.9292664808660808`*^9}, 3.9292665577887917`*^9, 
   3.9292666064209127`*^9, 3.929266796823285*^9, 3.929302819858574*^9, 
   3.9293321262442355`*^9, 3.9293326429791145`*^9, 3.9293337547421017`*^9, 
   3.9293391566293387`*^9, 3.929345871423238*^9, 3.929348649270562*^9, 
   3.9293488556492214`*^9, 3.9293622345929904`*^9, 3.929363671691431*^9, 
   3.9293641547577114`*^9, 3.929373677942938*^9, {3.929377768228626*^9, 
   3.9293777941203566`*^9}, 3.9293779094338264`*^9, 3.9293780542004385`*^9, 
   3.9293781121133385`*^9, {3.9294073782959366`*^9, 3.929407568064397*^9}, {
   3.929407618356101*^9, 3.9294076909792247`*^9}, 3.9295073326765566`*^9, 
   3.9295092810304503`*^9, 3.929510205121914*^9, 3.9295174915576053`*^9, 
   3.929517796372939*^9, 3.929519803414409*^9, 3.9295202286797314`*^9, 
   3.9295204412758026`*^9, 3.929524333168296*^9, {3.9295287362582006`*^9, 
   3.929528778039892*^9}, {3.9295288245264025`*^9, 3.929528927876172*^9}, 
   3.9295297184268875`*^9, 3.929530737931596*^9, 3.9295312654867153`*^9, 
   3.929588126249632*^9, 3.9295895330736074`*^9, 3.9296110205436034`*^9, {
   3.9296123785027204`*^9, 3.9296124329394355`*^9}, 3.9296161809661655`*^9, 
   3.9296164840669527`*^9, 3.9296167231889825`*^9, {3.9296195099903135`*^9, 
   3.9296195321260138`*^9}, 3.9296207233979654`*^9, 3.929620791215168*^9, {
   3.9296311415336065`*^9, 3.929631416663517*^9}, 3.9296315123429337`*^9, {
   3.929633512389043*^9, 3.9296335804729195`*^9}, {3.9296365642904778`*^9, 
   3.929636825783084*^9}, {3.9296378190002584`*^9, 3.929637923857246*^9}, {
   3.9296758931180577`*^9, 3.929675906733467*^9}, 3.9296759381485357`*^9, {
   3.9296759681729717`*^9, 3.9296759742895875`*^9}, {3.9296771066004086`*^9, 
   3.9296772071107635`*^9}, {3.9296788898118186`*^9, 
   3.9296789543740454`*^9}, {3.9296809765407686`*^9, 3.9296810887915015`*^9}, 
   3.932469009330331*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"d2e4edf3-cf20-44f4-a632-31d1f27daa3b"]
}, Open  ]],

Cell["Check whether it has the required behavior", "Text",
 CellChangeTimes->{{3.9292495459155874`*^9, 
  3.9292495552133665`*^9}},ExpressionUUID->"b4c81d4f-31b8-4ba3-beae-\
3e1688815327"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Phi]max"], "/.", "SOLBK"}], "//",
     "Abs"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0.001", ",", "RINF"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9292494836639752`*^9, 3.9292495080226245`*^9}, {
   3.9292499435687823`*^9, 3.9292499693386297`*^9}, {3.9292664856166754`*^9, 
   3.929266485754013*^9}, {3.929407440147979*^9, 3.9294074407258964`*^9}, 
   3.9294075095150137`*^9, {3.929407640633501*^9, 3.9294076407509*^9}, {
   3.9294076815384417`*^9, 3.929407694341484*^9}, {3.929528749288994*^9, 
   3.9295287499006157`*^9}, {3.9295287855811167`*^9, 
   3.9295287857739363`*^9}, {3.929528826317542*^9, 3.9295288265913305`*^9}, 
   3.9296312341372566`*^9},
 CellLabel->"In[20]:=",ExpressionUUID->"abc4925c-c363-41e2-bdb1-1fbf15ccd861"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVkWk8lWkfgO1Rhxw51p6yxKihZA2T5x/JFtlDlognTEM4GRlZfrbsKiVL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       "]]},
     Annotation[#, "Charting`Private`Tag$4422#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.001, -7.479048764762567},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& , 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0.001, 180.}, {-7.479048764762567, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, Quiet[
      Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }, {
    Automatic, {{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-8.517193191416238, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-8.111728083308073, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.824046010856292, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.600902459542082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.418580902748128, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.264430222920869, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-7.013115794639964, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.214608098422191, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.809142990314028, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.521460917862246, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.298317366548036, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.115995809754082, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.961845129926823, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.710530701645918, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.912023005428146, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.506557897319982, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.659260036932778, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.916290731874155, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.791759469228055, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.3978952727983707`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.4849066497880004`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Output",
 CellChangeTimes->{{3.929249499414241*^9, 3.929249508236535*^9}, 
   3.929249557036867*^9, {3.929249940217453*^9, 3.929249982873658*^9}, 
   3.929250187778839*^9, 3.929253094377042*^9, 3.929254194968627*^9, 
   3.9292550948815937`*^9, 3.9292659747844057`*^9, {3.9292664818552923`*^9, 
   3.92926648611342*^9}, 3.9292665588788905`*^9, 3.9292666071786065`*^9, {
   3.9292667978789897`*^9, 3.9292668159846287`*^9}, 3.92930282023897*^9, 
   3.9293321267239904`*^9, 3.929332643894393*^9, 3.929333756545707*^9, 
   3.9293391569207497`*^9, 3.9293458718712273`*^9, 3.9293486494894686`*^9, 
   3.929348855931329*^9, 3.9293622347871356`*^9, 3.929363673009411*^9, 
   3.929364155569137*^9, 3.929373678152976*^9, {3.9293777708941693`*^9, 
   3.9293777945168324`*^9}, 3.9293779095937853`*^9, 3.9293780544818*^9, 
   3.929378112284787*^9, {3.929407393241271*^9, 3.929407441695442*^9}, {
   3.9294074788297763`*^9, 3.929407568827527*^9}, {3.92940761927335*^9, 
   3.9294076947031097`*^9}, 3.9295073328996954`*^9, 3.9295092812085023`*^9, 
   3.9295102053240047`*^9, 3.9295174917749777`*^9, 3.9295177966841106`*^9, 
   3.9295198036165447`*^9, 3.9295202288976407`*^9, 3.929520441463235*^9, 
   3.9295243333769608`*^9, {3.9295287392003107`*^9, 3.929528779356004*^9}, {
   3.9295288269166203`*^9, 3.9295289285816364`*^9}, 3.9295297194091253`*^9, 
   3.929530737991251*^9, 3.9295312655726767`*^9, 3.9295881265296717`*^9, 
   3.9295895331791267`*^9, 3.9296110209608088`*^9, {3.929612380125873*^9, 
   3.9296124339391766`*^9}, 3.929616181073738*^9, 3.9296164841682053`*^9, 
   3.9296167235638*^9, {3.929619510226305*^9, 3.9296195325087714`*^9}, 
   3.9296207234849644`*^9, 3.9296207913036833`*^9, {3.929631228197781*^9, 
   3.9296314186699905`*^9}, 3.929631512410444*^9, {3.929633513916045*^9, 
   3.929633581517001*^9}, {3.929636580289713*^9, 3.9296368258516893`*^9}, {
   3.929637826233843*^9, 3.929637923927761*^9}, {3.9296758933402967`*^9, 
   3.929675906844017*^9}, 3.929675938252068*^9, {3.92967596826658*^9, 
   3.9296759743511424`*^9}, {3.9296771173424993`*^9, 
   3.9296771448663473`*^9}, {3.9296771882136507`*^9, 3.929677207176755*^9}, {
   3.929678890989393*^9, 3.929678954440596*^9}, {3.9296809776124973`*^9, 
   3.929681089874009*^9}, 3.932469010568404*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"fe561659-2761-4c6d-9ad2-6970f5bb9439"]
}, Open  ]],

Cell["\<\
The mass matches Kaup\[CloseCurlyQuote]s result. We can define now a rule to \
apply this background to compute the perturbations\
\>", "Text",
 CellChangeTimes->{{3.9292495682876253`*^9, 3.9292495813126645`*^9}, {
  3.929249856357086*^9, 
  3.9292498740360937`*^9}},ExpressionUUID->"4baa6d49-ff90-4d66-8596-\
a80f34509732"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Mbh", "=", "0.001"}], ";"}]], "Input",
 CellChangeTimes->{{3.896769679540101*^9, 3.896769719539468*^9}, {
   3.89677000074851*^9, 3.896770004853426*^9}, 3.8975077239561586`*^9, {
   3.8975692291846333`*^9, 3.897569243511019*^9}, 3.897570230784814*^9, 
   3.89765360114114*^9, 3.897653644422191*^9, 3.8978133328717737`*^9, {
   3.898326663863903*^9, 3.8983266640077972`*^9}, {3.928003263859724*^9, 
   3.928003276678523*^9}, {3.928327682497426*^9, 3.9283276979574585`*^9}, {
   3.928327754426407*^9, 3.9283277545424523`*^9}, {3.9289985713560476`*^9, 
   3.9289985724143114`*^9}, {3.9289986129217796`*^9, 
   3.9289986137245426`*^9}, {3.9289990292391167`*^9, 
   3.9289990307852182`*^9}, {3.9290061813297663`*^9, 
   3.9290061813923674`*^9}, {3.929023106976755*^9, 3.9290231075043974`*^9}, {
   3.929025722449685*^9, 3.929025723002118*^9}, 3.92950899721614*^9, {
   3.9295291004281225`*^9, 3.929529104571277*^9}, {3.9296194871775928`*^9, 
   3.9296195064886007`*^9}, 3.9296207164656954`*^9, 3.9296207870246005`*^9, {
   3.929631425485407*^9, 3.9296314255694947`*^9}, {3.9296759245890007`*^9, 
   3.9296759283800197`*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"ae98ff27-cff3-4fe5-8d71-9e2fd106f123"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solbh2", "=", 
   RowBox[{
    RowBox[{"NDSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"m2", "'"}], "[", "r", "]"}], "\[Equal]", 
          RowBox[{"2", 
           SuperscriptBox["r", "2"], 
           SuperscriptBox[
            RowBox[{"Abs", "[", 
             RowBox[{"\[Phi]0", "[", "r", "]"}], "]"}], "2"]}]}], "/.", 
         "SOLBK"}], ",", 
        RowBox[{
         RowBox[{"m2", "[", 
          RowBox[{"2", "Mbh"}], "]"}], "\[Equal]", "Mbh"}]}], "}"}], ",", 
      "m2", ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", 
        RowBox[{"2", "Mbh"}], ",", "RINF"}], "}"}], ",", 
      RowBox[{"PrecisionGoal", "\[Rule]", "12"}], ",", 
      RowBox[{"AccuracyGoal", "\[Rule]", "12"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.92952902825517*^9, 3.9295290337659383`*^9}, {
   3.9295291235816545`*^9, 3.929529133847395*^9}, 3.929633548865143*^9},
 CellLabel->"In[22]:=",ExpressionUUID->"991d8425-ba17-46ba-b01d-ad89659b97e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rubh1", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"M", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"m2", "[", "r", "]"}], "/.", "solbh2"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"V", "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", 
              FractionBox["Mbh", "r"]}]}], ")"}], 
           RowBox[{"V", "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"V", "'"}], "[", "r", "]"}], "\[Rule]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"sc1", " ", 
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"V", "[", "r", "]"}], 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", " ", 
                 FractionBox["Mbh", "r"]}]}], ")"}]}], ",", "r"}], "]"}]}], "/.",
           "SOLBK"}], ")"}]}], ",", 
       RowBox[{
        RowBox[{"\[Phi]0", "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"2", 
               FractionBox["Mbh", "r"]}]}], ")"}], 
            RowBox[{
             RowBox[{"-", "2"}], "I", " ", "Mbh"}]], 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], "/.", "SOLBK"}], ")"}]}], 
       ",", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]0", "'"}], "[", "r", "]"}], "\[Rule]", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", 
                 FractionBox["Mbh", "r"]}]}], ")"}], 
              RowBox[{
               RowBox[{"-", "2"}], "I", " ", "Mbh"}]], 
             RowBox[{"\[Phi]0", "[", "r", "]"}]}], ",", "r"}], "]"}], "/.", 
          "SOLBK"}], ")"}]}]}], "}"}], ",", "param2", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"scal", "\[Rule]", "sc1"}], ",", 
       RowBox[{
        RowBox[{"Mt", "\[Rule]", 
         RowBox[{"m2", "[", "RINF", "]"}]}], "/.", "solbh2"}], ",", 
       RowBox[{"rinf", "\[Rule]", "RINF"}], ",", 
       RowBox[{"ror", "\[Rule]", "0.001"}], ",", 
       RowBox[{"MBH", "\[Rule]", "Mbh"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.92924987838093*^9, 3.929249936003543*^9}, {
   3.9292499886164703`*^9, 3.929250038820092*^9}, {3.929266001586071*^9, 
   3.929266011117361*^9}, {3.9292663967428517`*^9, 3.929266433375227*^9}, 
   3.929266563067258*^9, {3.929266639443221*^9, 3.9292667149650593`*^9}, {
   3.929302844729826*^9, 3.9293028449277954`*^9}, {3.929332674253724*^9, 
   3.9293326788328404`*^9}, {3.9293337610959473`*^9, 3.929333763125454*^9}, {
   3.929363678553999*^9, 3.9293638126658096`*^9}, {3.9293641590776215`*^9, 
   3.9293641658586626`*^9}, {3.929510642977871*^9, 3.9295106468570724`*^9}, {
   3.9295289319688683`*^9, 3.929528944645793*^9}, {3.929529172189934*^9, 
   3.929529208287392*^9}, {3.9295293832993712`*^9, 3.929529392028884*^9}, {
   3.92952943339783*^9, 3.9295294610246577`*^9}, {3.9296125326329613`*^9, 
   3.929612535073872*^9}, 3.9296164755331097`*^9},
 CellLabel->"In[23]:=",ExpressionUUID->"3ae589e8-e254-4882-894e-01f6d6ad7af3"],

Cell["\<\
We can select either rule depending on the situation of interest. Now we \
compute the perturbations and fluxes.\
\>", "Text",
 CellChangeTimes->{{3.929250044288864*^9, 3.9292500513422513`*^9}, {
  3.9324690164436865`*^9, 
  3.932469077210146*^9}},ExpressionUUID->"87a27ed7-d56a-4451-a79e-\
019f9527e813"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Perturbations and fluxes: Circular orbits", "Section",
 CellChangeTimes->{{3.9292501049071674`*^9, 3.929250110446314*^9}, {
  3.9294310685810246`*^9, 3.9294310706097107`*^9}, {3.9296110226032133`*^9, 
  3.929611029628138*^9}, {3.93247103060763*^9, 
  3.9324710321773577`*^9}},ExpressionUUID->"15a3b179-6f49-451b-838b-\
7ef3c4b3da1c"],

Cell[CellGroupData[{

Cell["Setting up the equations", "Subsubsection",
 CellChangeTimes->{{3.9292534082675037`*^9, 
  3.9292534115183926`*^9}},ExpressionUUID->"61da9da6-53ec-4046-9e88-\
38e1a7d7f592"],

Cell["\<\
We define the equations describing the perturbations below (l=1)\
\>", "Text",
 CellChangeTimes->{{3.9292501226636486`*^9, 3.9292501351978397`*^9}, {
  3.9292503881458445`*^9, 3.9292503914754114`*^9}, {3.9324709274546328`*^9, 
  3.9324709361884584`*^9}},ExpressionUUID->"f3baf43d-edf0-4a6a-a058-\
ca67af8ef9d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqsperturbations", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", "\[Pi]", " ", "r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Almp", "[", "r", "]"}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Blmp", "[", "r", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["H0", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "-", 
      RowBox[{
       RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Omega]", " ", 
              RowBox[{"(", 
               RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}]}], "-", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r", "-", 
             RowBox[{"2", " ", 
              RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
           RowBox[{"V", "[", "r", "]"}]}]], "+", 
         FractionBox[
          RowBox[{"6", " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "r"]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"2", " ", "r", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], " ", 
               "\[Omega]"}], "+", 
              RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}]}], 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"V", "[", "r", "]"}]}]]}], "+", 
         FractionBox[
          RowBox[{"6", " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "r"]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"H2", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "r"]}], "-", 
         RowBox[{"2", " ", "r", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], 
      "-", 
      FractionBox[
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"r", "-", 
          RowBox[{"6", " ", 
           RowBox[{"M", "[", "r", "]"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["r", "3"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]0", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["r", "2"], " ", 
           RowBox[{"M", "[", "r", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]0", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], 
       RowBox[{
        SuperscriptBox["r", "2"], "-", 
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}]], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["\[Phi]0", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]1", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["\[Phi]0", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]2", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"8", " ", "\[Pi]", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"Alm0p", "[", "r", "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["\[Omega]", "2"], " ", 
        RowBox[{"H0", "[", "r", "]"}], " ", 
        SuperscriptBox[
         RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "-", 
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{"V", "[", "r", "]"}]}]], "-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"H2", "[", "r", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox["\[Omega]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"V", "[", "r", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SuperscriptBox["r", "2"], " ", 
              SuperscriptBox[
               RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}]}], 
         ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "-", 
          RowBox[{"2", " ", 
           RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
        RowBox[{"V", "[", "r", "]"}]}]], "+", 
      RowBox[{
       SuperscriptBox["H2", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}], "-", 
      RowBox[{
       RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Omega]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}]}], "+", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r", "-", 
             RowBox[{"2", " ", 
              RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
           RowBox[{"V", "[", "r", "]"}]}]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "r"]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"2", " ", "r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Omega]", " ", 
              RowBox[{"(", 
               RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}]}], "+", 
             RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
           RowBox[{"\[Phi]0", "[", "r", "]"}]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r", "-", 
             RowBox[{"2", " ", 
              RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
           RowBox[{"V", "[", "r", "]"}]}]], "-", 
         FractionBox[
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox["\[Phi]0", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "r"]}], ")"}]}], 
      "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["\[Phi]0", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]1", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{
        SuperscriptBox["\[Phi]0", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]2", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"r", " ", 
         RowBox[{"H0", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "r"}], " ", "\[Omega]", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]", "+", 
              RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]0", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", " ", 
         RowBox[{"H2", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox["\[Omega]", "4"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"V", "[", "r", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "-", 
              RowBox[{"4", " ", 
               SuperscriptBox["r", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"\[Omega]", " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox["r", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "+", 
                 RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
              RowBox[{"4", " ", "r", " ", "\[Sigma]", " ", 
               RowBox[{"(", 
                RowBox[{"r", "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "-", 
              RowBox[{"12", " ", 
               SuperscriptBox["r", "2"], " ", "\[Omega]", " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"16", " ", 
               SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "4"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", "r", " ", "\[Sigma]"}], "+", 
                 RowBox[{"2", " ", "r", " ", "\[Omega]"}], "-", 
                 RowBox[{"4", " ", 
                  SuperscriptBox["r", "3"], " ", "\[Sigma]", " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                 RowBox[{"4", " ", "\[Sigma]", " ", 
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "\[Omega]", " ", 
            RowBox[{"M", "[", "r", "]"}], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["r", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}]}], ")"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["\[Omega]", "2"]}], "+", 
                 RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "4"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "2"], " ", "\[Omega]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["\[Omega]", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}]}], 
                 "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"\[Sigma]", "-", 
                    RowBox[{"3", " ", "\[Omega]"}]}], ")"}], " ", 
                  RowBox[{"V", "[", "r", "]"}]}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"2", " ", "r", " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], " ", "\[Omega]",
                " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["\[Phi]0", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", "r", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["\[Phi]0", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
              RowBox[{
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"V", "[", "r", "]"}], "+", 
                 RowBox[{"2", " ", "\[Omega]", " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Sigma]", "-", 
                    RowBox[{"2", " ", "\[Omega]"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]
                   }]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"V", "[", "r", "]"}], "2"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "r"}], "+", 
              SuperscriptBox["r", "3"], "+", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "3"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "4"], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "5"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"]}], "-", 
              RowBox[{"3", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
              RowBox[{"r", " ", "\[Omega]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "12"}], " ", 
               SuperscriptBox["r", "3"], " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "4"]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "+", "\[Omega]", "-", 
                 RowBox[{"4", " ", "r", " ", "\[Omega]", " ", 
                  RowBox[{"(", 
                   RowBox[{"r", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    SuperscriptBox["r", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}], "+", 
              RowBox[{"4", " ", "r", " ", "\[Omega]", " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"3", " ", "\[Sigma]"}], "+", 
                    RowBox[{"5", " ", "\[Omega]"}], "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "\[Sigma]"}], "-", 
                    RowBox[{"2", " ", "\[Omega]"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", " ", "\[Pi]", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"V", "[", "r", "]"}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Omega]", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "r", " ", "\[Omega]", " ", 
               RowBox[{"Blm0p", "[", "r", "]"}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "r"}], " ", 
                  RowBox[{"Alm0p", "[", "r", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"Almp", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"r", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                  RowBox[{"V", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["2"], " ", "\[Omega]", " ", 
            RowBox[{"Alm1p", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", "3"], " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "-", 
              RowBox[{
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{"(", 
                   RowBox[{"r", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"r", "-", 
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                    RowBox[{
                    RowBox[{"M", "[", "r", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox[
                 RowBox[{"V", "[", "r", "]"}], "2"]}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "2"], " ", 
               SuperscriptBox["\[Omega]", "4"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Phi]0", "[", "r", "]"}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["r", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "-", 
                 RowBox[{
                  SuperscriptBox["r", "2"], " ", 
                  RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"M", "[", "r", "]"}], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"V", "[", "r", "]"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "2"], " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "r", " ", 
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]1", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["r", "4"], " ", 
            SuperscriptBox["\[Omega]", "4"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "4"]}], "-", 
           RowBox[{"4", " ", "r", " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", "3"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{"r", "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"r", "-", 
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                 RowBox[{
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]2", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox["\[Phi]1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"r", " ", 
         RowBox[{"H0", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]", "-", 
              RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", "\[Omega]", " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
           RowBox[{
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]0", "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", " ", 
         RowBox[{"H2", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "8"}], " ", 
            SuperscriptBox["r", "3"], " ", 
            SuperscriptBox["\[Omega]", "4"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"V", "[", "r", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "-", 
              RowBox[{"4", " ", 
               SuperscriptBox["r", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"\[Omega]", " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SuperscriptBox["r", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "-", 
                 RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "-", 
              RowBox[{"4", " ", "r", " ", "\[Sigma]", " ", 
               RowBox[{"(", 
                RowBox[{"r", "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "-", 
              RowBox[{"12", " ", 
               SuperscriptBox["r", "2"], " ", "\[Omega]", " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"16", " ", 
               SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "4"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", " ", "\[Sigma]", " ", 
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", "\[Sigma]"}], "+", 
                    RowBox[{"2", " ", "\[Omega]"}], "+", 
                    RowBox[{"4", " ", 
                    SuperscriptBox["r", "2"], " ", "\[Sigma]", " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Phi]2", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox[
              RowBox[{"V", "[", "r", "]"}], "2"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "r"}], "+", 
              SuperscriptBox["r", "3"], "+", 
              RowBox[{"2", " ", 
               RowBox[{"M", "[", "r", "]"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "3"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "4"], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "5"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], "2"], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], " ", "\[Omega]",
                " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "12"}], " ", 
               SuperscriptBox["r", "3"], " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "4"]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "-", "\[Omega]", "+", 
                 RowBox[{"4", " ", "r", " ", "\[Omega]", " ", 
                  RowBox[{"(", 
                   RowBox[{"r", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"5", "-", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{"(", 
                   RowBox[{"2", "+", 
                    SuperscriptBox["r", "2"], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}], "+", 
              RowBox[{"4", " ", "r", " ", "\[Omega]", " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "3"}], " ", "\[Sigma]"}], "+", 
                    RowBox[{"5", " ", "\[Omega]"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Sigma]", "-", 
                    RowBox[{"2", " ", "\[Omega]"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", "\[Omega]", " ", 
            RowBox[{"M", "[", "r", "]"}], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[Omega]", " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["r", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["r", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "r", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["\[Omega]", "2"]}], "+", 
                 RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "4"]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "2"], " ", "\[Omega]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["\[Omega]", "2"], " ", 
                  RowBox[{"(", 
                   RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"\[Sigma]", "+", 
                    RowBox[{"3", " ", "\[Omega]"}]}], ")"}], " ", 
                  RowBox[{"V", "[", "r", "]"}]}]}], ")"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{"2", " ", "r", " ", "\[Omega]", " ", 
               RowBox[{"(", 
                RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["\[Phi]0", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
              RowBox[{"2", " ", "r", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["\[Phi]0", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}], "2"]}], "-", 
              RowBox[{
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"V", "[", "r", "]"}], "+", 
                 RowBox[{"2", " ", "\[Omega]", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "\[Sigma]"}], "-", 
                    RowBox[{"2", " ", "\[Omega]"}], "+", 
                    RowBox[{
                    SuperscriptBox["r", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", " ", "\[Pi]", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"V", "[", "r", "]"}], "-", 
              RowBox[{"4", " ", 
               SuperscriptBox["r", "2"], " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "r", " ", "\[Omega]", " ", 
               RowBox[{"Blm0p", "[", "r", "]"}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "r"}], " ", 
                  RowBox[{"Alm0p", "[", "r", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"Almp", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"r", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                  RowBox[{"V", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["2"], " ", "\[Omega]", " ", 
            RowBox[{"Alm1p", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", "3"], " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "-", 
              RowBox[{
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{"(", 
                   RowBox[{"r", "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{"r", "-", 
                    RowBox[{
                    SuperscriptBox["r", "3"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                    RowBox[{
                    RowBox[{"M", "[", "r", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
        ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"4", " ", 
            SuperscriptBox["r", "4"], " ", 
            SuperscriptBox["\[Omega]", "4"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "4"]}], "-", 
           RowBox[{"4", " ", "r", " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["r", "3"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
              RowBox[{"r", " ", 
               RowBox[{"(", 
                RowBox[{"r", "-", 
                 RowBox[{"2", " ", 
                  RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]0", "\[Prime]",
                 MultilineFunction->None], "[", "r", "]"}]}], "+", 
              RowBox[{
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"r", "-", 
                 RowBox[{
                  SuperscriptBox["r", "3"], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                 RowBox[{
                  RowBox[{"M", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]1", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["r", "3"], " ", 
            RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox[
                 RowBox[{"V", "[", "r", "]"}], "2"]}], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}]}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "2"], " ", 
               SuperscriptBox["\[Omega]", "4"], " ", 
               SuperscriptBox[
                RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               RowBox[{"V", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Phi]0", "[", "r", "]"}], "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["r", "2"], " ", 
                  SuperscriptBox[
                   RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
                 RowBox[{"r", " ", 
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "-", 
                 RowBox[{
                  SuperscriptBox["r", "2"], " ", 
                  RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                  SuperscriptBox[
                   RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                ")"}]}]}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"M", "[", "r", "]"}], " ", 
            RowBox[{"V", "[", "r", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"V", "[", "r", "]"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["r", "2"], " ", 
               SuperscriptBox["\[Omega]", "2"], " ", 
               RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "2"}], " ", "r", " ", 
                  RowBox[{
                   SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}], "+", 
                 RowBox[{
                  RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]2", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"r", " ", 
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"V", "[", "r", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      "+", 
      RowBox[{
       SuperscriptBox["\[Phi]2", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9292503830519295`*^9, 3.9292503975297556`*^9}, {
   3.929348813402157*^9, 3.929348839390555*^9}, 3.9295092645877542`*^9, {
   3.9295177267121205`*^9, 3.929517743588995*^9}, {3.9295177779090796`*^9, 
   3.929517782036043*^9}, {3.9295197506239824`*^9, 3.9295197714161015`*^9}, 
   3.929524316775158*^9, 3.9295244336797714`*^9, 3.9295245022603517`*^9, 
   3.9296110386233807`*^9},
 CellLabel->"In[18]:=",ExpressionUUID->"dca04bf3-e9cf-41db-9343-24452a1b67ec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"eqsperturbations", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"eqsperturbations", "[", 
       RowBox[{"[", "2", "]"}], "]"}], ",", 
      RowBox[{"eqsperturbations", "[", 
       RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "/.", 
    RowBox[{"\[Phi]2", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"0", "&"}], ")"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"H0", "'"}], "[", "r", "]"}], ",", 
     RowBox[{
      RowBox[{"H1", "'"}], "[", "r", "]"}], ",", 
     RowBox[{
      RowBox[{"H2", "'"}], "[", "r", "]"}], ",", 
     RowBox[{"H0", "[", "r", "]"}], ",", 
     RowBox[{"H1", "[", "r", "]"}], ",", 
     RowBox[{"H2", "[", "r", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]1", "''"}], "[", "r", "]"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], ",", 
     RowBox[{"\[Phi]1", "[", "r", "]"}]}], "}"}], ",", "Simplify"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.929524338223543*^9, 3.929524406527892*^9}, {
   3.9295244765862684`*^9, 3.929524495030656*^9}, {3.929611048345992*^9, 
   3.9296110484705563`*^9}, 3.9296110878242884`*^9},
 CellLabel->"In[19]:=",ExpressionUUID->"6c03b161-25fc-4a16-92a4-8d882f6ccc80"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", "\[Pi]", " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Almp", "[", "r", "]"}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Blmp", "[", "r", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["H0", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "+", 
    RowBox[{
     RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}]}], "-", 
            RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
          RowBox[{"\[Phi]0", "[", "r", "]"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"r", "-", 
            RowBox[{"2", " ", 
             RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
          RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
       FractionBox[
        RowBox[{"6", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]0", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "r"]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"H2", "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "r"], "+", 
       RowBox[{"2", " ", "r", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]0", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"H0", "[", "r", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"6", " ", 
         RowBox[{"M", "[", "r", "]"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]0", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"M", "[", "r", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]0", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], 
     RowBox[{
      SuperscriptBox["r", "2"], "-", 
      RowBox[{"2", " ", "r", " ", 
       RowBox[{"M", "[", "r", "]"}]}]}]], "-", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]0", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]1", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"8", " ", "\[Pi]", " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"Alm0p", "[", "r", "]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["\[Omega]", "2"], " ", 
      RowBox[{"H0", "[", "r", "]"}], " ", 
      SuperscriptBox[
       RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
      RowBox[{"V", "[", "r", "]"}]}]], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"H2", "[", "r", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
      RowBox[{"V", "[", "r", "]"}]}]], "+", 
    RowBox[{
     SuperscriptBox["H2", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "+", 
    RowBox[{
     RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Omega]", " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}]}], "+", 
            RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
          RowBox[{"\[Phi]0", "[", "r", "]"}]}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"r", "-", 
            RowBox[{"2", " ", 
             RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
          RowBox[{"V", "[", "r", "]"}]}]]}], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]0", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "r"]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]0", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]1", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{"r", " ", 
      RowBox[{"H0", "[", "r", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"r", " ", "\[Omega]", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]", "+", 
           RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", 
         RowBox[{"\[Phi]0", "[", "r", "]"}]}], "-", 
        RowBox[{
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]0", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
      RowBox[{"V", "[", "r", "]"}]}]], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", " ", 
       RowBox[{"H2", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "8"}], " ", 
          SuperscriptBox["r", "3"], " ", 
          SuperscriptBox["\[Omega]", "4"], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"V", "[", "r", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "r", " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"\[Omega]", " ", 
          RowBox[{"V", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["r", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", 
               RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
            RowBox[{"4", " ", "r", " ", "\[Sigma]", " ", 
             RowBox[{"(", 
              RowBox[{"r", "-", 
               RowBox[{"2", " ", 
                RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "-", 
            RowBox[{"12", " ", 
             SuperscriptBox["r", "2"], " ", "\[Omega]", " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "4"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "r", " ", "\[Sigma]"}], "+", 
               RowBox[{"2", " ", "r", " ", "\[Omega]"}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["r", "3"], " ", "\[Sigma]", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Phi]0", "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
               RowBox[{"4", " ", "\[Sigma]", " ", 
                RowBox[{"M", "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"V", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"V", "[", "r", "]"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"V", "[", "r", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "r"}], "+", 
            SuperscriptBox["r", "3"], "+", 
            RowBox[{"2", " ", 
             RowBox[{"M", "[", "r", "]"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "4"], " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["r", "5"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
            RowBox[{"r", " ", "\[Omega]", " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"V", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"12", " ", 
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "4"]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["r", "4"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], " ", "\[Omega]", 
             " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "3"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "-", 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]", "-", 
               RowBox[{"4", " ", "r", " ", "\[Omega]", " ", 
                RowBox[{"(", 
                 RowBox[{"r", "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Phi]0", "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
              ")"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"M", "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"5", "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}], "+", 
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  SuperscriptBox["r", "2"], "+", 
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}]}], ")"}]}], "-", 
            RowBox[{"4", " ", "r", " ", "\[Omega]", " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"M", "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[Sigma]"}], "+", 
                  RowBox[{"5", " ", "\[Omega]"}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}], "+", 
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "\[Sigma]"}], "-", 
                  RowBox[{"2", " ", "\[Omega]"}], "+", 
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"V", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"V", "[", "r", "]"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", " ", "\[Pi]", " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"V", "[", "r", "]"}]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "r", " ", "\[Omega]", " ", 
             RowBox[{"Blm0p", "[", "r", "]"}], " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "r"}], " ", 
                RowBox[{"Alm0p", "[", "r", "]"}]}], "+", 
               RowBox[{
                RowBox[{"Almp", "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"r", "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                RowBox[{"V", "[", "r", "]"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", "\[Omega]", " ", 
          RowBox[{"Alm1p", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "-", 
            RowBox[{
             RowBox[{"V", "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["r", "3"], " ", 
                SuperscriptBox[
                 RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{"r", "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["\[Phi]0", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "+", 
               RowBox[{
                RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"r", "-", 
                  RowBox[{
                   SuperscriptBox["r", "3"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"M", "[", "r", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"V", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"V", "[", "r", "]"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox[
              RowBox[{"V", "[", "r", "]"}], "2"], " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox["\[Omega]", "4"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             RowBox[{"V", "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"\[Phi]0", "[", "r", "]"}], "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
               RowBox[{"r", " ", 
                RowBox[{
                 SuperscriptBox["\[Phi]0", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "-", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Phi]0", "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
              ")"}]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}], " ", 
          RowBox[{"V", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"V", "[", "r", "]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "r", " ", 
                RowBox[{
                 SuperscriptBox["\[Phi]0", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "+", 
               RowBox[{
                RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "5"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]1", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"V", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"V", "[", "r", "]"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
    "+", 
    RowBox[{
     SuperscriptBox["\[Phi]1", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.9295243993204947`*^9, 3.9295244070598793`*^9}, {
   3.9295244817145042`*^9, 3.9295245047644978`*^9}, 3.9295295237222548`*^9, 
   3.9295297301517015`*^9, 3.929530743158023*^9, 3.9295312273064437`*^9, 
   3.929588160492231*^9, {3.9295895337664375`*^9, 3.9295895427749205`*^9}, 
   3.9296110492883916`*^9, 3.929611088736084*^9, 3.929616736335973*^9, 
   3.9296195976644497`*^9, 3.929631542803687*^9, 3.9296759819282227`*^9, 
   3.929696996434994*^9, 3.929761825736492*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"42116b41-0e19-46b5-971f-6deec3f803ef"]
}, Open  ]],

Cell["We can define the homogeneous equations and the source terms", "Text",
 CellChangeTimes->{{3.929250435218067*^9, 
  3.9292504475348883`*^9}},ExpressionUUID->"a006cc56-8d6b-4619-8972-\
1e068e9a049d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SOURCE", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"eqsperturbations", "[", 
      RowBox[{"[", 
       RowBox[{"1", ";;", "3"}], "]"}], "]"}]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H1", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"H0", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Kp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"\[Phi]1", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"\[Phi]2", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"H2", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQHOM", "=", 
   RowBox[{
    RowBox[{"eqsperturbations", "[", 
     RowBox[{"[", 
      RowBox[{"1", ";;", "3"}], "]"}], "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Blm0p", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Flmp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Alm1p", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Blmp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Almp", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"Alm0p", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"\[Phi]2", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8735143865429583`*^9, 3.873514414013742*^9}, {
   3.873514528044138*^9, 3.873514574962019*^9}, 3.873514897057378*^9, {
   3.929250449180204*^9, 3.9292504776327057`*^9}, {3.929509291409243*^9, 
   3.9295092948517847`*^9}, {3.929510203274208*^9, 3.929510208047736*^9}, {
   3.929611097149782*^9, 3.9296111300463815`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"2d75aa07-073b-4efd-bb05-bc65ad75a54d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQHOM", "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.9296111146366177`*^9, 3.929611136023477*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"2c611093-fd22-4671-b92c-8d12d7e5190d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["H0", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "-", 
    RowBox[{
     RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Omega]", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}]}], "-", 
           RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
         RowBox[{"\[Phi]0", "[", "r", "]"}]}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", " ", 
            RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
         RowBox[{"V", "[", "r", "]"}]}]], "+", 
       FractionBox[
        RowBox[{"6", " ", 
         RowBox[{
          SuperscriptBox["\[Phi]0", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "r"]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"H2", "[", "r", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", "r"], "+", 
       RowBox[{"2", " ", "r", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Phi]0", "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"H0", "[", "r", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["r", "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]0", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"M", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "6"}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}], "2"]}]}], ")"}]}]}],
        ")"}]}], 
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}], ")"}]}]], "-", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]0", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]1", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox["\[Omega]", "2"], " ", 
       RowBox[{"H0", "[", "r", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", " ", 
          RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
       RowBox[{"V", "[", "r", "]"}]}]]}], "-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"H2", "[", "r", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"V", "[", "r", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox[
             RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
      RowBox[{"V", "[", "r", "]"}]}]], "-", 
    FractionBox[
     RowBox[{"2", " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Omega]", " ", 
         RowBox[{"(", 
          RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}]}], "+", 
        RowBox[{"V", "[", "r", "]"}]}], ")"}], " ", 
      RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
      RowBox[{"\[Phi]1", "[", "r", "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
      RowBox[{"V", "[", "r", "]"}]}]], "+", 
    RowBox[{
     SuperscriptBox["H2", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]0", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], "r"], "-", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["\[Phi]0", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]1", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       RowBox[{"H0", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"V", "[", "r", "]"}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["r", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "r"}], " ", "\[Omega]", " ", 
          RowBox[{"(", 
           RowBox[{"\[Sigma]", "+", 
            RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", 
          RowBox[{"\[Phi]0", "[", "r", "]"}]}], "+", 
         RowBox[{
          RowBox[{"V", "[", "r", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]0", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["r", "3"], " ", 
       RowBox[{"H2", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["r", "3"], " ", 
          SuperscriptBox["\[Omega]", "4"], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"V", "[", "r", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "r", " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}]}], "-", 
            RowBox[{"3", " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["r", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"\[Omega]", " ", 
          RowBox[{"V", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["r", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", 
               RowBox[{"2", " ", "\[Omega]"}]}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "3"]}], "+", 
            RowBox[{"4", " ", "r", " ", "\[Sigma]", " ", 
             RowBox[{"(", 
              RowBox[{"r", "-", 
               RowBox[{"2", " ", 
                RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "-", 
            RowBox[{"12", " ", 
             SuperscriptBox["r", "2"], " ", "\[Omega]", " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "4"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "r", " ", "\[Sigma]"}], "+", 
               RowBox[{"2", " ", "r", " ", "\[Omega]"}], "-", 
               RowBox[{"4", " ", 
                SuperscriptBox["r", "3"], " ", "\[Sigma]", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Phi]0", "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
               RowBox[{"4", " ", "\[Sigma]", " ", 
                RowBox[{"M", "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["r", "5"], " ", 
       SuperscriptBox["\[Omega]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "-", 
            RowBox[{"r", " ", "\[Omega]", " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"r", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]1", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"V", "[", "r", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "r"}], "+", 
            SuperscriptBox["r", "3"], "+", 
            RowBox[{"2", " ", 
             RowBox[{"M", "[", "r", "]"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["r", "4"], " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "r", " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]1", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["\[Phi]1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}], ")"}]}], "+", 
         RowBox[{"2", " ", "r", " ", 
          RowBox[{"M", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SuperscriptBox["\[Phi]1", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{
              SuperscriptBox["\[Phi]1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"V", "[", "r", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]1", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "12"}], " ", 
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "4"]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["r", "4"], " ", "\[Omega]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "\[Sigma]"}], "+", "\[Omega]"}], ")"}], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "3"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"\[Sigma]", "+", "\[Omega]", "-", 
               RowBox[{"4", " ", "r", " ", "\[Omega]", " ", 
                RowBox[{"(", 
                 RowBox[{"r", "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Phi]0", "\[Prime]",
                   MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
              ")"}]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[Omega]", "2"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"M", "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{"5", "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}], "+", 
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  SuperscriptBox["r", "2"], "+", 
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}]}], ")"}]}], "+", 
            RowBox[{"4", " ", "r", " ", "\[Omega]", " ", 
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"M", "[", "r", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"3", " ", "\[Sigma]"}], "+", 
                  RowBox[{"5", " ", "\[Omega]"}], "-", 
                  RowBox[{"2", " ", 
                   SuperscriptBox["r", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}], "+", 
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "\[Sigma]"}], "-", 
                  RowBox[{"2", " ", "\[Omega]"}], "+", 
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
         RowBox[{"4", " ", "r", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["r", "3"], " ", 
             SuperscriptBox[
              RowBox[{"\[Phi]0", "[", "r", "]"}], "3"], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]1", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{"r", "-", 
               RowBox[{"2", " ", 
                RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]0", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]1", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{
             RowBox[{"\[Phi]0", "[", "r", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"r", "-", 
                  RowBox[{
                   SuperscriptBox["r", "3"], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"M", "[", "r", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["r", "2"], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]0", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}], "2"]}]}], 
                    ")"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["\[Phi]1", "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "-", 
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{"r", "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["\[Phi]1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", 
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "r", "]"}]}]}], ")"}], " ", 
      RowBox[{"V", "[", "r", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"V", "[", "r", "]"}]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"\[Phi]0", "[", "r", "]"}], "2"]}]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.929611115662591*^9, 3.929611137059184*^9}, 
   3.9296167370878496`*^9, 3.929619598464978*^9, 3.9296315435638027`*^9, 
   3.9296759826839857`*^9, 3.929696997200038*^9, 3.9297618265779953`*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"4f30ec9a-8a4a-4b30-a6cd-5a929ea215be"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Finding the boundary conditions at the origin", "Subsubsection",
 CellChangeTimes->{{3.9292534150660152`*^9, 
  3.929253421619045*^9}},ExpressionUUID->"27e0e6e7-3352-4504-b1d4-\
67ecee84ddb7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2", ",", "H2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9292644477116027`*^9, 3.929264455811679*^9}, {
   3.9295098393722153`*^9, 3.9295098398694572`*^9}, 3.929611243874157*^9},
 CellLabel->"In[23]:=",ExpressionUUID->"02f23ecc-1981-4c57-8694-c7bbe43cdc55"],

Cell["Segunda solu\[CCedilla]\[ATilde]o", "Text",
 CellChangeTimes->{{3.929541583614012*^9, 3.9295415906050005`*^9}, {
  3.9296055935839357`*^9, 
  3.9296055939854083`*^9}},ExpressionUUID->"763bba11-cf34-48c1-9f61-\
d4fd9e562ba9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"M", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["Mi", "i"], " ", 
       SuperscriptBox["r", 
        RowBox[{"i", "+", "1"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "6"}], "}"}]}], "]"}], "/.", 
    "rubkgexp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"V", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       SubscriptBox["Vi", "i"], 
       SuperscriptBox["r", "i"]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}], "/.", 
    "rubkgexp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]0", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[Phi]0i", "i"], 
        SuperscriptBox["r", "i"]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "6"}], "}"}]}], "]"}], "/.", 
     RowBox[{
      SubscriptBox["\[Phi]0i", "0"], "\[Rule]", "\[Phi]c"}]}], "/.", 
    "rubkgexp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]1", "[", "x_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["f1", "i"], 
      SuperscriptBox["x", 
       RowBox[{"i", "+", "2"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H0", "[", "x_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["h0", "i"], 
      SuperscriptBox["x", 
       RowBox[{"i", "+", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "3"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"H2", "[", "x_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["h2", "i"], 
      SuperscriptBox["x", 
       RowBox[{"i", "+", "3"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9295415962349386`*^9, 3.9295416758519926`*^9}, {
   3.9295417094576507`*^9, 3.9295417208316784`*^9}, {3.9295417889787426`*^9, 
   3.929541795110998*^9}, {3.929542310349121*^9, 3.929542312227212*^9}, 
   3.9295423436977797`*^9, {3.9295424393100324`*^9, 3.9295425642972984`*^9}, {
   3.9295430641409035`*^9, 3.9295430688854036`*^9}, {3.9295481336119304`*^9, 
   3.9295482749348936`*^9}, 3.9296103018678684`*^9},
 CellLabel->"In[24]:=",ExpressionUUID->"86b56670-c735-4a05-9eca-0a2fdfe41c9f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"EQHOM", "[", 
       RowBox[{"[", "1", "]"}], "]"}], 
      SuperscriptBox["r", 
       RowBox[{"-", "1"}]]}], ",", 
     RowBox[{"EQHOM", "[", 
      RowBox[{"[", "2", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"EQHOM", "[", 
       RowBox[{"[", "3", "]"}], "]"}], 
      SuperscriptBox["r", "0"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"r", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.929541615682703*^9, 3.9295416274084234`*^9}, {
   3.929541684934601*^9, 3.9295417049487495`*^9}, {3.929541755456527*^9, 
   3.929541758402239*^9}, {3.929541798470788*^9, 3.9295418577469387`*^9}, {
   3.929541983372075*^9, 3.929541991798589*^9}, {3.929542206658761*^9, 
   3.9295422192877903`*^9}, {3.9295422943421454`*^9, 
   3.9295423854040127`*^9}, {3.9295424244234886`*^9, 3.929542432724128*^9}, {
   3.929542531410743*^9, 3.929542568591978*^9}, 3.9295426140723286`*^9, {
   3.9295426535520196`*^9, 3.9295426536182475`*^9}, {3.929542687876832*^9, 
   3.929542697980754*^9}, {3.9295481476762037`*^9, 3.929548237943818*^9}, {
   3.9295482805196996`*^9, 3.929548293834505*^9}, 3.929548385830682*^9, 
   3.9295484271377554`*^9, {3.9296103065404043`*^9, 3.929610326860128*^9}, {
   3.9296103677131963`*^9, 3.929610381043301*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"c59a5dee-45d1-4ab3-8953-0bbc6e38079f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     SubscriptBox["h0", "1"], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", "\[Sigma]", " ", "\[Phi]c", " ", 
          "\[Omega]", " ", 
          SubscriptBox["f1", "0"]}], "+", 
         RowBox[{"4", " ", "\[Phi]c", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "0"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["h0", "0"]}], "-", 
         RowBox[{"4", " ", "\[Phi]c", " ", 
          SubscriptBox["f1", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SubscriptBox["h0", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"6", " ", 
          SubscriptBox["h0", "2"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"3", " ", 
          SubscriptBox["h2", "0"], " ", 
          SubscriptBox["Vi", "0"]}]}], ")"}], " ", "r"}], 
      RowBox[{"3", " ", 
       SubscriptBox["Vi", "0"]}]], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", "\[Sigma]", " ", "\[Phi]c", " ", 
          "\[Omega]", " ", 
          SubscriptBox["f1", "1"]}], "+", 
         RowBox[{"6", " ", "\[Phi]c", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "1"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["h0", "1"]}], "-", 
         RowBox[{"6", " ", "\[Phi]c", " ", 
          SubscriptBox["f1", "1"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SubscriptBox["h0", "1"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"9", " ", 
          SubscriptBox["h0", "3"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"3", " ", 
          SubscriptBox["h2", "1"], " ", 
          SubscriptBox["Vi", "0"]}]}], ")"}], " ", 
       SuperscriptBox["r", "2"]}], 
      RowBox[{"3", " ", 
       SubscriptBox["Vi", "0"]}]], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"45", " ", 
        SubsuperscriptBox["Vi", "0", "2"]}]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"15", " ", "\[Sigma]", " ", "\[Phi]c", " ", 
          SuperscriptBox["\[Omega]", "3"], " ", 
          SubscriptBox["f1", "0"]}], "+", 
         RowBox[{"60", " ", "\[Sigma]", " ", 
          SuperscriptBox["\[Phi]c", "3"], " ", 
          SuperscriptBox["\[Omega]", "3"], " ", 
          SubscriptBox["f1", "0"]}], "-", 
         RowBox[{"20", " ", 
          SuperscriptBox["\[Phi]c", "3"], " ", 
          SuperscriptBox["\[Omega]", "4"], " ", 
          SubscriptBox["f1", "0"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SuperscriptBox["\[Omega]", "4"], " ", 
          SubscriptBox["h0", "0"]}], "-", 
         RowBox[{"8", " ", 
          SuperscriptBox["\[Phi]c", "4"], " ", 
          SuperscriptBox["\[Omega]", "4"], " ", 
          SubscriptBox["h0", "0"]}], "-", 
         RowBox[{"15", " ", "\[Sigma]", " ", "\[Phi]c", " ", "\[Omega]", " ", 
          SubscriptBox["f1", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"120", " ", "\[Sigma]", " ", 
          SuperscriptBox["\[Phi]c", "3"], " ", "\[Omega]", " ", 
          SubscriptBox["f1", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"60", " ", 
          SuperscriptBox["\[Phi]c", "3"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"90", " ", "\[Sigma]", " ", "\[Phi]c", " ", "\[Omega]", " ", 
          SubscriptBox["f1", "2"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"120", " ", "\[Phi]c", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "2"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["h0", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"44", " ", 
          SuperscriptBox["\[Phi]c", "4"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["h0", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"60", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["h0", "2"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"40", " ", 
          SuperscriptBox["\[Phi]c", "3"], " ", 
          SubscriptBox["f1", "0"], " ", 
          SubsuperscriptBox["Vi", "0", "2"]}], "-", 
         RowBox[{"120", " ", "\[Phi]c", " ", 
          SubscriptBox["f1", "2"], " ", 
          SubsuperscriptBox["Vi", "0", "2"]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SubscriptBox["h0", "0"], " ", 
          SubsuperscriptBox["Vi", "0", "2"]}], "-", 
         RowBox[{"20", " ", 
          SuperscriptBox["\[Phi]c", "4"], " ", 
          SubscriptBox["h0", "0"], " ", 
          SubsuperscriptBox["Vi", "0", "2"]}], "-", 
         RowBox[{"30", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SubscriptBox["h0", "2"], " ", 
          SubsuperscriptBox["Vi", "0", "2"]}], "+", 
         RowBox[{"45", " ", 
          SubscriptBox["h2", "2"], " ", 
          SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}], " ", 
       SuperscriptBox["r", "3"]}]}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "r", "]"}], "4"],
      SeriesData[$CellContext`r, 0, {}, 0, 4, 1],
      Editable->False]}],
    SeriesData[$CellContext`r, 0, {
      Subscript[$CellContext`h0, 1], Rational[1, 3] 
      Subscript[$CellContext`Vi, 
         0]^(-1) ((-6) $CellContext`\[Sigma] $CellContext`\[Phi]c \
$CellContext`\[Omega] Subscript[$CellContext`f1, 0] + 
       4 $CellContext`\[Phi]c $CellContext`\[Omega]^2 
        Subscript[$CellContext`f1, 0] + 
       4 $CellContext`\[Phi]c^2 $CellContext`\[Omega]^2 
        Subscript[$CellContext`h0, 0] - 4 $CellContext`\[Phi]c 
       Subscript[$CellContext`f1, 0] Subscript[$CellContext`Vi, 0] - 
       2 $CellContext`\[Phi]c^2 Subscript[$CellContext`h0, 0] 
       Subscript[$CellContext`Vi, 0] + 
       6 Subscript[$CellContext`h0, 2] Subscript[$CellContext`Vi, 0] + 
       3 Subscript[$CellContext`h2, 0] Subscript[$CellContext`Vi, 0]), 
      Rational[1, 3] 
      Subscript[$CellContext`Vi, 
         0]^(-1) ((-6) $CellContext`\[Sigma] $CellContext`\[Phi]c \
$CellContext`\[Omega] Subscript[$CellContext`f1, 1] + 
       6 $CellContext`\[Phi]c $CellContext`\[Omega]^2 
        Subscript[$CellContext`f1, 1] + 
       4 $CellContext`\[Phi]c^2 $CellContext`\[Omega]^2 
        Subscript[$CellContext`h0, 1] - 6 $CellContext`\[Phi]c 
       Subscript[$CellContext`f1, 1] Subscript[$CellContext`Vi, 0] - 
       2 $CellContext`\[Phi]c^2 Subscript[$CellContext`h0, 1] 
       Subscript[$CellContext`Vi, 0] + 
       9 Subscript[$CellContext`h0, 3] Subscript[$CellContext`Vi, 0] + 
       3 Subscript[$CellContext`h2, 1] Subscript[$CellContext`Vi, 0]), 
      Rational[1, 45] 
      Subscript[$CellContext`Vi, 0]^(-2) (
       15 $CellContext`\[Sigma] $CellContext`\[Phi]c $CellContext`\[Omega]^3 
        Subscript[$CellContext`f1, 0] + 
       60 $CellContext`\[Sigma] $CellContext`\[Phi]c^3 \
$CellContext`\[Omega]^3 Subscript[$CellContext`f1, 0] - 
       20 $CellContext`\[Phi]c^3 $CellContext`\[Omega]^4 
       Subscript[$CellContext`f1, 0] + 
       2 $CellContext`\[Phi]c^2 $CellContext`\[Omega]^4 
        Subscript[$CellContext`h0, 0] - 
       8 $CellContext`\[Phi]c^4 $CellContext`\[Omega]^4 
       Subscript[$CellContext`h0, 0] - 
       15 $CellContext`\[Sigma] $CellContext`\[Phi]c $CellContext`\[Omega] 
       Subscript[$CellContext`f1, 0] Subscript[$CellContext`Vi, 0] - 
       120 $CellContext`\[Sigma] $CellContext`\[Phi]c^3 $CellContext`\[Omega] 
       Subscript[$CellContext`f1, 0] Subscript[$CellContext`Vi, 0] + 
       60 $CellContext`\[Phi]c^3 $CellContext`\[Omega]^2 
        Subscript[$CellContext`f1, 0] Subscript[$CellContext`Vi, 0] - 
       90 $CellContext`\[Sigma] $CellContext`\[Phi]c $CellContext`\[Omega] 
       Subscript[$CellContext`f1, 2] Subscript[$CellContext`Vi, 0] + 
       120 $CellContext`\[Phi]c $CellContext`\[Omega]^2 
        Subscript[$CellContext`f1, 2] Subscript[$CellContext`Vi, 0] + 
       2 $CellContext`\[Phi]c^2 $CellContext`\[Omega]^2 
        Subscript[$CellContext`h0, 0] Subscript[$CellContext`Vi, 0] + 
       44 $CellContext`\[Phi]c^4 $CellContext`\[Omega]^2 
        Subscript[$CellContext`h0, 0] Subscript[$CellContext`Vi, 0] + 
       60 $CellContext`\[Phi]c^2 $CellContext`\[Omega]^2 
        Subscript[$CellContext`h0, 2] Subscript[$CellContext`Vi, 0] - 
       40 $CellContext`\[Phi]c^3 Subscript[$CellContext`f1, 0] 
       Subscript[$CellContext`Vi, 0]^2 - 120 $CellContext`\[Phi]c 
       Subscript[$CellContext`f1, 2] Subscript[$CellContext`Vi, 0]^2 - 
       4 $CellContext`\[Phi]c^2 Subscript[$CellContext`h0, 0] 
       Subscript[$CellContext`Vi, 0]^2 - 20 $CellContext`\[Phi]c^4 
       Subscript[$CellContext`h0, 0] Subscript[$CellContext`Vi, 0]^2 - 
       30 $CellContext`\[Phi]c^2 Subscript[$CellContext`h0, 2] 
       Subscript[$CellContext`Vi, 0]^2 + 
       45 Subscript[$CellContext`h2, 2] Subscript[$CellContext`Vi, 0]^2)}, 0, 
     4, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", "\[Sigma]", " ", "\[Phi]c", " ", 
          "\[Omega]", " ", 
          SubscriptBox["f1", "0"]}], "-", 
         RowBox[{"4", " ", "\[Phi]c", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "0"]}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["h0", "0"]}], "-", 
         RowBox[{"8", " ", "\[Phi]c", " ", 
          SubscriptBox["f1", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"15", " ", 
          SubscriptBox["h2", "0"], " ", 
          SubscriptBox["Vi", "0"]}]}], ")"}], " ", 
       SuperscriptBox["r", "2"]}], 
      RowBox[{"3", " ", 
       SubscriptBox["Vi", "0"]}]], "-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Sigma]", " ", "\[Phi]c", " ", "\[Omega]", " ", 
          SubscriptBox["f1", "1"]}], "+", 
         RowBox[{"\[Phi]c", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "1"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["h0", "1"]}], "+", 
         RowBox[{"5", " ", "\[Phi]c", " ", 
          SubscriptBox["f1", "1"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"9", " ", 
          SubscriptBox["h2", "1"], " ", 
          SubscriptBox["Vi", "0"]}]}], ")"}], " ", 
       SuperscriptBox["r", "3"]}], 
      RowBox[{"3", " ", 
       SubscriptBox["Vi", "0"]}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "r", "]"}], "4"],
      SeriesData[$CellContext`r, 0, {}, 2, 4, 1],
      Editable->False]}],
    SeriesData[$CellContext`r, 0, {
     Rational[1, 3] 
      Subscript[$CellContext`Vi, 
         0]^(-1) ((-6) $CellContext`\[Sigma] $CellContext`\[Phi]c \
$CellContext`\[Omega] Subscript[$CellContext`f1, 0] - 
       4 $CellContext`\[Phi]c $CellContext`\[Omega]^2 
       Subscript[$CellContext`f1, 0] - 
       6 $CellContext`\[Phi]c^2 $CellContext`\[Omega]^2 
       Subscript[$CellContext`h0, 0] - 8 $CellContext`\[Phi]c 
       Subscript[$CellContext`f1, 0] Subscript[$CellContext`Vi, 0] + 
       15 Subscript[$CellContext`h2, 0] Subscript[$CellContext`Vi, 0]), 
      Rational[-2, 3] 
      Subscript[$CellContext`Vi, 0]^(-1) (
       3 $CellContext`\[Sigma] $CellContext`\[Phi]c $CellContext`\[Omega] 
        Subscript[$CellContext`f1, 
          1] + $CellContext`\[Phi]c $CellContext`\[Omega]^2 
        Subscript[$CellContext`f1, 1] + 
       3 $CellContext`\[Phi]c^2 $CellContext`\[Omega]^2 
        Subscript[$CellContext`h0, 1] + 
       5 $CellContext`\[Phi]c Subscript[$CellContext`f1, 1] 
        Subscript[$CellContext`Vi, 0] - 9 Subscript[$CellContext`h2, 1] 
       Subscript[$CellContext`Vi, 0])}, 2, 4, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"4", " ", 
      SubscriptBox["f1", "1"], " ", "r"}], "+", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"6", " ", 
        SubscriptBox["Vi", "0"]}]], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          SuperscriptBox["\[Sigma]", "2"], " ", 
          SubscriptBox["f1", "0"]}], "+", 
         RowBox[{"12", " ", "\[Sigma]", " ", "\[Omega]", " ", 
          SubscriptBox["f1", "0"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "0"]}], "+", 
         RowBox[{"44", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "0"]}], "+", 
         RowBox[{"3", " ", "\[Sigma]", " ", "\[Phi]c", " ", "\[Omega]", " ", 
          SubscriptBox["h0", "0"]}], "+", 
         RowBox[{"7", " ", "\[Phi]c", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["h0", "0"]}], "-", 
         RowBox[{"6", " ", 
          SubscriptBox["f1", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"16", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SubscriptBox["f1", "0"], " ", 
          SubscriptBox["Vi", "0"]}], "+", 
         RowBox[{"60", " ", 
          SubscriptBox["f1", "2"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"\[Phi]c", " ", 
          SubscriptBox["h0", "0"], " ", 
          SubscriptBox["Vi", "0"]}]}], ")"}], " ", 
       SuperscriptBox["r", "2"]}]}], "+", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          SuperscriptBox["\[Sigma]", "2"], " ", 
          SubscriptBox["f1", "1"]}], "+", 
         RowBox[{"12", " ", "\[Sigma]", " ", "\[Omega]", " ", 
          SubscriptBox["f1", "1"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "1"]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["f1", "1"]}], "+", 
         RowBox[{"3", " ", "\[Sigma]", " ", "\[Phi]c", " ", "\[Omega]", " ", 
          SubscriptBox["h0", "1"]}], "+", 
         RowBox[{"7", " ", "\[Phi]c", " ", 
          SuperscriptBox["\[Omega]", "2"], " ", 
          SubscriptBox["h0", "1"]}], "-", 
         RowBox[{"6", " ", 
          SubscriptBox["f1", "1"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"24", " ", 
          SuperscriptBox["\[Phi]c", "2"], " ", 
          SubscriptBox["f1", "1"], " ", 
          SubscriptBox["Vi", "0"]}], "-", 
         RowBox[{"\[Phi]c", " ", 
          SubscriptBox["h0", "1"], " ", 
          SubscriptBox["Vi", "0"]}]}], ")"}], " ", 
       SuperscriptBox["r", "3"]}], 
      RowBox[{"6", " ", 
       SubscriptBox["Vi", "0"]}]], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "r", "]"}], "4"],
      SeriesData[$CellContext`r, 0, {}, 1, 4, 1],
      Editable->False]}],
    SeriesData[$CellContext`r, 0, {
     4 Subscript[$CellContext`f1, 1], Rational[1, 6] 
      Subscript[$CellContext`Vi, 0]^(-1) (
       6 $CellContext`\[Sigma]^2 Subscript[$CellContext`f1, 0] + 
       12 $CellContext`\[Sigma] $CellContext`\[Omega] 
        Subscript[$CellContext`f1, 0] + 
       6 $CellContext`\[Omega]^2 Subscript[$CellContext`f1, 0] + 
       44 $CellContext`\[Phi]c^2 $CellContext`\[Omega]^2 
        Subscript[$CellContext`f1, 0] + 
       3 $CellContext`\[Sigma] $CellContext`\[Phi]c $CellContext`\[Omega] 
        Subscript[$CellContext`h0, 0] + 
       7 $CellContext`\[Phi]c $CellContext`\[Omega]^2 
        Subscript[$CellContext`h0, 0] - 6 Subscript[$CellContext`f1, 0] 
       Subscript[$CellContext`Vi, 0] - 16 $CellContext`\[Phi]c^2 
       Subscript[$CellContext`f1, 0] Subscript[$CellContext`Vi, 0] + 
       60 Subscript[$CellContext`f1, 2] 
        Subscript[$CellContext`Vi, 0] - $CellContext`\[Phi]c 
       Subscript[$CellContext`h0, 0] Subscript[$CellContext`Vi, 0]), 
      Rational[1, 6] 
      Subscript[$CellContext`Vi, 0]^(-1) (
       6 $CellContext`\[Sigma]^2 Subscript[$CellContext`f1, 1] + 
       12 $CellContext`\[Sigma] $CellContext`\[Omega] 
        Subscript[$CellContext`f1, 1] + 
       6 $CellContext`\[Omega]^2 Subscript[$CellContext`f1, 1] + 
       72 $CellContext`\[Phi]c^2 $CellContext`\[Omega]^2 
        Subscript[$CellContext`f1, 1] + 
       3 $CellContext`\[Sigma] $CellContext`\[Phi]c $CellContext`\[Omega] 
        Subscript[$CellContext`h0, 1] + 
       7 $CellContext`\[Phi]c $CellContext`\[Omega]^2 
        Subscript[$CellContext`h0, 1] - 6 Subscript[$CellContext`f1, 1] 
       Subscript[$CellContext`Vi, 0] - 24 $CellContext`\[Phi]c^2 
       Subscript[$CellContext`f1, 1] 
       Subscript[$CellContext`Vi, 0] - $CellContext`\[Phi]c 
       Subscript[$CellContext`h0, 1] Subscript[$CellContext`Vi, 0])}, 1, 4, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.9296103273103895`*^9, {3.9296103635758095`*^9, 3.929610394573797*^9}, 
   3.929611246332514*^9, 3.929616737497755*^9, 3.929619598918354*^9, 
   3.9296315439453173`*^9, 3.92967598308223*^9, 3.929696997576295*^9, 
   3.929761827053615*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"022b751f-c726-49c3-8204-b17797c7c467"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rupertorigin2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"%", "\[Equal]", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["h2", "0"], ",", 
        SubscriptBox["h0", "1"], ",", 
        SubscriptBox["h2", "1"], ",", 
        SubscriptBox["f1", "1"], ",", 
        SubscriptBox["h0", "2"], ",", 
        SubscriptBox["h2", "2"], ",", 
        SubscriptBox["f1", "2"], ",", 
        SubscriptBox["h0", "3"]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.9295417344522657`*^9, 3.929541763950701*^9}, {
   3.9295418453524065`*^9, 3.9295418622167273`*^9}, {3.9295419016587114`*^9, 
   3.929541976150798*^9}, {3.9295422269809914`*^9, 3.929542289375885*^9}, {
   3.929542389433874*^9, 3.929542393461815*^9}, {3.9295425831856422`*^9, 
   3.929542635387864*^9}, {3.9295426746409297`*^9, 3.9295427005905356`*^9}, {
   3.9295430743078103`*^9, 3.9295430754398384`*^9}, {3.929543119927758*^9, 
   3.9295431232197695`*^9}, 3.929548368413004*^9, {3.929548399690729*^9, 
   3.929548399821659*^9}, {3.929610316186268*^9, 3.9296103201682568`*^9}, {
   3.9296103928905306`*^9, 3.9296103930884523`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"543199bb-62c8-49c6-afe4-6c59574133c6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["h2", "0"], "\[Rule]", 
    FractionBox[
     RowBox[{"2", " ", "\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Phi]c", " ", 
         SuperscriptBox["\[Omega]", "2"], " ", 
         SubscriptBox["h0", "0"]}], "+", 
        RowBox[{
         SubscriptBox["f1", "0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Omega]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[Sigma]"}], "+", 
              RowBox[{"2", " ", "\[Omega]"}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            SubscriptBox["Vi", "0"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{"15", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["h0", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["h2", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["f1", "1"], "\[Rule]", "0"}], ",", 
   RowBox[{
    SubscriptBox["h0", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", 
         SubscriptBox["f1", "0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], " ", "\[Omega]"}], 
           "+", 
           SubscriptBox["Vi", "0"]}], ")"}]}], "+", 
        RowBox[{"\[Phi]c", " ", 
         SubscriptBox["h0", "0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "13"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}], "+", 
           RowBox[{"5", " ", 
            SubscriptBox["Vi", "0"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{"15", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["h2", "2"], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"30", " ", 
       SubsuperscriptBox["Vi", "0", "2"]}]], 
     RowBox[{"\[Phi]c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Phi]c", " ", 
         SubscriptBox["h0", "0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["\[Omega]", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", 
               SuperscriptBox["\[Sigma]", "2"]}], "-", 
              RowBox[{"3", " ", "\[Sigma]", " ", "\[Omega]"}], "+", 
              RowBox[{"8", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"5", " ", 
                  SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "-", 
           RowBox[{"3", " ", "\[Omega]", " ", 
            RowBox[{"(", 
             RowBox[{"\[Sigma]", "+", 
              RowBox[{"4", " ", 
               RowBox[{"(", 
                RowBox[{"\[Omega]", "+", 
                 RowBox[{"5", " ", 
                  SuperscriptBox["\[Phi]c", "2"], " ", "\[Omega]"}]}], 
                ")"}]}]}], ")"}], " ", 
            SubscriptBox["Vi", "0"]}], "+", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"5", " ", 
               SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
            SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         SubscriptBox["f1", "0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Omega]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["\[Sigma]", "3"]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Sigma]", "2"], " ", "\[Omega]"}], "+", 
              RowBox[{"58", " ", "\[Sigma]", " ", 
               SuperscriptBox["\[Phi]c", "2"], " ", 
               SuperscriptBox["\[Omega]", "2"]}], "-", 
              RowBox[{"4", " ", 
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"13", " ", 
                  SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
               SuperscriptBox["\[Omega]", "3"]}]}], ")"}]}], "+", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Sigma]", "2"], "-", 
              RowBox[{"14", " ", "\[Sigma]", " ", 
               SuperscriptBox["\[Phi]c", "2"], " ", "\[Omega]"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", 
                 RowBox[{"19", " ", 
                  SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
               SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
            SubscriptBox["Vi", "0"]}], "-", 
           RowBox[{"4", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"7", " ", 
               SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
            SubsuperscriptBox["Vi", "0", "2"]}]}], ")"}]}]}], ")"}]}]}]}], 
   ",", 
   RowBox[{
    SubscriptBox["f1", "2"], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"\[Phi]c", " ", 
       SubscriptBox["h0", "0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Omega]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Sigma]"}], "+", 
            RowBox[{"7", " ", "\[Omega]"}]}], ")"}]}], "+", 
         SubscriptBox["Vi", "0"]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["f1", "0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["\[Sigma]", "2"]}], "+", 
         RowBox[{"6", " ", "\[Sigma]", " ", "\[Omega]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"22", " ", 
             SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
          SuperscriptBox["\[Omega]", "2"]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["\[Phi]c", "2"]}]}], ")"}], " ", 
          SubscriptBox["Vi", "0"]}]}], ")"}]}]}], 
     RowBox[{"60", " ", 
      SubscriptBox["Vi", "0"]}]]}], ",", 
   RowBox[{
    SubscriptBox["h0", "3"], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.929541751554939*^9, 3.929541849367115*^9, {3.9295419020187206`*^9, 
   3.9295419449608097`*^9}, 3.9295419765939765`*^9, {3.9295422414243107`*^9, 
   3.9295423336524343`*^9}, {3.929542364048541*^9, 3.9295423828607864`*^9}, {
   3.929542419613182*^9, 3.929542426643594*^9}, {3.9295425925954313`*^9, 
   3.9295426166457663`*^9}, 3.9295426545580416`*^9, {3.9295426916139355`*^9, 
   3.9295427009929924`*^9}, {3.9295430520746546`*^9, 
   3.9295430816242285`*^9}, {3.929543124001753*^9, 3.9295431386382365`*^9}, 
   3.9295442119217863`*^9, 3.9295443373293734`*^9, {3.9295481443181486`*^9, 
   3.929548156129106*^9}, {3.9295483710217524`*^9, 3.9295484427646646`*^9}, {
   3.92954847596725*^9, 3.9295484797566886`*^9}, 3.929589116053088*^9, 
   3.9295897077842493`*^9, 3.9295939651708794`*^9, 3.9296055520384393`*^9, 
   3.9296055965859404`*^9, 3.92960585918606*^9, {3.929610313208857*^9, 
   3.929610323833785*^9}, {3.9296103724436235`*^9, 3.929610394925604*^9}, 
   3.929611247198616*^9, 3.929616737624874*^9, 3.929619599052287*^9, 
   3.929631544082288*^9, 3.9296759832277875`*^9, 3.929696997710349*^9, 
   3.929761827200861*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"489d3e5f-1a31-4183-a433-beedd4c59a5d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"BOUNOR2", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"H0", "[", "r", "]"}], ",", 
      RowBox[{"H2", "[", "r", "]"}], ",", 
      RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "/.", 
    "rupertorigin2"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.9295430842965994`*^9, 3.929543125273404*^9, {3.92961040078086*^9, 
   3.929610400914248*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"295a2572-6ecf-4238-a83e-d595a94cd4ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2", ",", "H2"}], "]"}], ";"}]], "Input",
 CellLabel->"In[33]:=",ExpressionUUID->"435cf253-1dd7-4a40-8205-ba3084ad7ffa"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finding the boundary conditions at infinity", "Subsubsection",
 CellChangeTimes->{{3.929264466447201*^9, 
  3.929264472267169*^9}},ExpressionUUID->"5b50ea05-fe56-478d-bea8-\
ad176e197605"],

Cell["\<\
At infinity, the boundary conditions are such that we have two scalar \
perturbations+gravitational perturbation in Schwarzschild. Therefore, we can \
use that for our problem.\
\>", "Text",
 CellChangeTimes->{{3.929264522771202*^9, 3.929264566079797*^9}, {
   3.9292646401334925`*^9, 3.929264663234372*^9}, {3.929265109026581*^9, 
   3.929265109913558*^9}, 
   3.929266865005639*^9},ExpressionUUID->"f9e96fae-7db2-4d0a-b3a9-\
995a80b11787"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2", ",", "H2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9295098432222157`*^9, 3.9295098436702147`*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"b5a42ae7-38d1-4879-8021-ab0a9cd2d6f8"],

Cell["\<\
The equations in vacuum can be obtained by considering \[Phi]0->0 and the \
Schwarzschild spacetime with mass Mt.\
\>", "Text",
 CellChangeTimes->{{3.9292651128556232`*^9, 3.929265126269923*^9}, {
  3.9292668898281045`*^9, 
  3.929266905971171*^9}},ExpressionUUID->"d81d3267-c427-4384-bf37-\
4c871c34e5af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQSVAC", "=", 
   RowBox[{"EQHOM", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Phi]0", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"0", "&"}], ")"}]}], ",", 
      RowBox[{"V", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1", "-", 
          RowBox[{"2", 
           FractionBox["Mt", "#"]}]}], "&"}], ")"}]}], ",", 
      RowBox[{"M", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{"Mt", "&"}], ")"}]}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929265128111204*^9, 3.9292651425810957`*^9}, {
   3.929266888490925*^9, 3.9292669295082426`*^9}, 3.929377323320628*^9},
 CellLabel->"In[35]:=",ExpressionUUID->"bd6f9326-b349-4705-bd27-453bba7b10ed"],

Cell["\<\
For the gravitational sector, we can solve it analytically. We have\
\>", "Text",
 CellChangeTimes->{{3.9292651592852583`*^9, 3.9292651716599207`*^9}, {
  3.9293410282923284`*^9, 3.9293410319553633`*^9}, {3.9293411186768703`*^9, 
  3.9293411287010283`*^9}, {3.9295097779092736`*^9, 
  3.929509787299225*^9}},ExpressionUUID->"eda37429-16b1-4241-9f89-\
dbc20c63f55d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQSVAC", "[", 
  RowBox[{"[", 
   RowBox[{"1", ";;", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.9295179228439245`*^9, 3.929517930257368*^9}, {
  3.929610425205044*^9, 3.9296104256557093`*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"f2f3de56-393c-4d73-a839-278b40f05585"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", "Mt"}], "+", "r"}], ")"}], " ", 
       RowBox[{"H0", "[", "r", "]"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "Mt", " ", "r"}], "+", 
       SuperscriptBox["r", "2"]}]]}], "+", 
    FractionBox[
     RowBox[{"H2", "[", "r", "]"}], "r"], "+", 
    RowBox[{
     SuperscriptBox["H0", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         FractionBox[
          RowBox[{"2", " ", "Mt"}], "r"]}], ")"}], " ", 
       RowBox[{"H2", "[", "r", "]"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "Mt"}], "r"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}]}]]}], "+", 
    RowBox[{
     SuperscriptBox["H2", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.9295179256890783`*^9, 3.9295179306902895`*^9}, 
   3.9295204469580383`*^9, 3.929524525120894*^9, 3.929525655037034*^9, 
   3.9295269292592173`*^9, 3.929531718269601*^9, 3.9295318636093826`*^9, 
   3.9295440556754313`*^9, 3.929544341638918*^9, 3.929548498235673*^9, 
   3.929589116909148*^9, 3.929589707884286*^9, {3.9295939653435373`*^9, 
   3.9295939878133965`*^9}, 3.9296056020096264`*^9, 3.9296058593043003`*^9, 
   3.9296104259476404`*^9, 3.9296112757126093`*^9, 3.9296167378887*^9, 
   3.9296195992445507`*^9, 3.929631544167743*^9, 3.929675983395108*^9, 
   3.929696997803257*^9, 3.9297618273614225`*^9},
 CellLabel->"Out[36]=",ExpressionUUID->"b427dda9-ef3c-41a0-ba6b-3a09e3a44bf8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          FractionBox[
           RowBox[{"2", " ", "Mt"}], "r"]}], ")"}], " ", 
        RowBox[{"H2", "[", "r", "]"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", " ", "Mt"}], "r"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}]}]]}], "+", 
     RowBox[{
      SuperscriptBox["H2", "\[Prime]",
       MultilineFunction->None], "[", "r", "]"}]}], "\[Equal]", "0"}], ",", 
   "H2", ",", "r"}], "]"}]], "Input",
 CellChangeTimes->{{3.9295179366282*^9, 3.929517944297445*^9}, 
   3.929610436951552*^9},
 CellLabel->"In[37]:=",ExpressionUUID->"5d010054-d64b-40d8-a19c-969535316c67"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"H2", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "r", "}"}], ",", 
      FractionBox[
       TemplateBox[{"1"},
        "C"], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], "2"]]}], "]"}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.929517939752861*^9, 3.9295179445946894`*^9}, 
   3.929520447025277*^9, 3.929524525200901*^9, 3.9295256551900945`*^9, 
   3.9295269293292756`*^9, 3.9295317183634305`*^9, 3.9295318637234507`*^9, 
   3.9295440557617903`*^9, 3.929544341713986*^9, 3.9295484983151903`*^9, 
   3.929589117007126*^9, 3.929589707932884*^9, {3.9295939654421883`*^9, 
   3.9295939878862305`*^9}, 3.9296056020870843`*^9, 3.929605859386104*^9, 
   3.929610437457722*^9, 3.9296112769008365`*^9, 3.9296167379708824`*^9, 
   3.929619599369056*^9, 3.929631544231267*^9, 3.929675983543223*^9, 
   3.929696997916344*^9, 3.929761827503648*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"d0453d4b-13c9-41d9-b336-02bd2e8852dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", "Mt"}], "+", "r"}], ")"}], " ", 
         RowBox[{"H0", "[", "r", "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "Mt", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}]]}], "+", 
      FractionBox[
       RowBox[{"H2", "[", "r", "]"}], "r"], "+", 
      RowBox[{
       SuperscriptBox["H0", "\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], "\[Equal]", "0"}], "/.", 
    RowBox[{"H2", "\[Rule]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", "r", "}"}], ",", 
       FractionBox[
        TemplateBox[{"1"},
         "C"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], "2"]]}], "]"}]}]}], 
   ",", "H0", ",", "r"}], "]"}]], "Input",
 CellChangeTimes->{{3.929517957069422*^9, 3.929517965322791*^9}, {
  3.9296104429798326`*^9, 3.9296104500145383`*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"f77ea2b0-630a-4f65-8b96-6a924db1490c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"H0", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "r", "}"}], ",", 
      RowBox[{
       FractionBox[
        TemplateBox[{"1"},
         "C"], 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}], "2"]}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["r", "3"], " ", 
         TemplateBox[{"2"},
          "C"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}], "2"]]}]}], 
     "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.929517965557871*^9, 3.9295204470971985`*^9, 3.929524525280839*^9, 
   3.9295256552680216`*^9, 3.9295269294051228`*^9, 3.929531718417061*^9, 
   3.9295318638005233`*^9, 3.9295440558614674`*^9, 3.9295443417903013`*^9, 
   3.929548498400744*^9, 3.929589117073672*^9, 3.9295897079870653`*^9, {
   3.92959396550074*^9, 3.9295939879616566`*^9}, 3.929605602139386*^9, 
   3.9296058594414363`*^9, 3.9296104502297907`*^9, 3.9296112784639273`*^9, 
   3.9296167380528507`*^9, 3.9296195994353223`*^9, 3.9296315442742863`*^9, 
   3.929675983630433*^9, 3.9296969979904823`*^9, 3.9297618275575676`*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"e2f6a77a-3c04-4550-aa37-d47d2c289cca"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"BOUGRAV", "=", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      SubscriptBox["h2i", "0"], 
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}], "2"]}]], ",", 
     FractionBox[
      SubscriptBox["h2i", "0"], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], "2"]]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.929298120437143*^9, 3.929298134628807*^9}, {
   3.929299087987913*^9, 3.9292991265708447`*^9}, {3.9293631491812844`*^9, 
   3.929363172068033*^9}, 3.929509829838138*^9, {3.929509874046542*^9, 
   3.929509897016229*^9}, {3.92951038908949*^9, 3.9295104158734493`*^9}, {
   3.929518013037301*^9, 3.929518018030997*^9}, {3.929610466355954*^9, 
   3.9296105021771326`*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"2e04dcea-b248-421c-b697-fa9ddf1cf4fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9292991877200623`*^9, 3.929299194446289*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"a8711366-7c77-4a8f-8a49-c84c61846fc2"],

Cell["\<\
For the scalar fields, let\[CloseCurlyQuote]s take the scalar perturbation \
for \[Phi]1. The difference between \[Phi]1 and \[Phi]2 can b\
\>", "Text",
 CellChangeTimes->{{3.929299202125712*^9, 3.9292992313238964`*^9}, {
  3.9293001784069977`*^9, 3.9293001921739993`*^9}, {3.9293408707300262`*^9, 
  3.9293408711838408`*^9}},ExpressionUUID->"54f1ea96-474d-4828-839d-\
b5bb4b558ab0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "V", ",", "M", ",", "\[Phi]0", ",", "H0", ",", "H1", ",", "Kp", ",", 
    "\[Phi]1", ",", "\[Phi]2", ",", "H2"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9293001600234337`*^9, 3.929300174525943*^9}, {
  3.9293002532740307`*^9, 3.929300258354559*^9}, {3.9295099002842093`*^9, 
  3.9295099022517605`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"f09364b1-7395-48bc-b6cb-7c0e3167e7c2"],

Cell["Defining the equation for the expansion", "Text",
 CellChangeTimes->{{3.9293017784411545`*^9, 
  3.929301784971286*^9}},ExpressionUUID->"56316e54-5b6e-4b3a-b500-\
627f13f36f87"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rst", "[", "r_", "]"}], ":=", 
  RowBox[{"r", "+", 
   RowBox[{"2", "Mt", " ", 
    RowBox[{"Log", "[", 
     RowBox[{
      FractionBox["r", 
       RowBox[{"2", "Mt"}]], "-", "1"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.9295099130521317`*^9, 3.9295099211612225`*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"85134623-5072-4c86-9b79-004e6d6c5a17"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqgp1", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"2", 
           FractionBox["Mt", "r"]}]}], ")"}], "2"], 
       FractionBox[
        RowBox[{"EQSVAC", "[", 
         RowBox[{"[", "3", "]"}], "]"}], 
        SuperscriptBox["E", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Kappa]p", " ", 
            RowBox[{"rst", "[", "r", "]"}]}], "-", 
           RowBox[{
            FractionBox["Mt", "\[Kappa]p"], " ", 
            RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]]]}], "/.", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "\[Rule]", 
       RowBox[{"1", "-", 
        SuperscriptBox["\[Kappa]p", "2"]}]}]}], "/.", 
     RowBox[{"\[Phi]1", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"g1", "[", "#", "]"}], 
         SuperscriptBox["E", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Kappa]p", " ", 
             RowBox[{"rst", "[", "#", "]"}]}], "-", 
            RowBox[{
             FractionBox["Mt", "\[Kappa]p"], " ", 
             RowBox[{"Log", "[", "#", "]"}]}]}], ")"}]]}], "&"}], ")"}]}]}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"g1", "''"}], "[", "r", "]"}], ",", 
      RowBox[{
       RowBox[{"g1", "'"}], "[", "r", "]"}]}], "}"}], ",", "FullSimplify"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.929301593980744*^9, 3.9293017742423763`*^9}, 
   3.9296112901114235`*^9},
 CellLabel->"In[43]:=",ExpressionUUID->"82c5db82-d48f-48fd-8630-9c4c5afebd66"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Mt", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "Mt"}], "+", "r"}], ")"}], "2"]}], "+", 
      RowBox[{"Mt", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["Mt", "2"]}], "-", 
         RowBox[{"6", " ", "Mt", " ", "r"}], "+", 
         SuperscriptBox["r", "2"]}], ")"}], " ", "\[Kappa]p"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Mt", " ", "r"}], "-", 
         SuperscriptBox["r", "2"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["Mt", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["r", "2"]}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox["\[Kappa]p", "2"]}]}], ")"}], " ", 
    RowBox[{"g1", "[", "r", "]"}]}], 
   RowBox[{
    SuperscriptBox["r", "4"], " ", 
    SuperscriptBox["\[Kappa]p", "2"]}]], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "Mt"}], "-", "r"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["Mt", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox["\[Kappa]p", "2"]}], "+", 
      RowBox[{"Mt", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "r"}], "+", "\[Kappa]p"}], ")"}]}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["g1", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   RowBox[{
    SuperscriptBox["r", "3"], " ", "\[Kappa]p"}]], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "Mt"}], "r"]}], ")"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["g1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.929301597298538*^9, {3.9293017060180464`*^9, 3.929301757085286*^9}, 
   3.9293017896704493`*^9, 3.9293028738142667`*^9, 3.9293321351758037`*^9, 
   3.929339218611923*^9, 3.929340418005526*^9, 3.9293408240422096`*^9, 
   3.929340872751244*^9, 3.9293489113454957`*^9, 3.9293632033177805`*^9, {
   3.92936403220761*^9, 3.9293640588305764`*^9}, 3.929364614807353*^9, 
   3.929377061433199*^9, 3.9293776852673283`*^9, 3.9293778539269247`*^9, 
   3.929377915519204*^9, 3.9293780642205315`*^9, {3.929378121517057*^9, 
   3.9293781330450087`*^9}, 3.9294077585542164`*^9, 3.9295074172686*^9, {
   3.9295099044974756`*^9, 3.9295099228806305`*^9}, 3.9295100952101164`*^9, 
   3.9295104273433447`*^9, 3.9295180325395937`*^9, 3.9295204475103016`*^9, 
   3.9295245256889386`*^9, 3.929529732438772*^9, 3.929530745351022*^9, 
   3.9295312294002485`*^9, 3.9295881773471203`*^9, 3.929589545563878*^9, 
   3.9296112909619904`*^9, 3.929616738658844*^9, 3.929619600165515*^9, 
   3.9296315445531964`*^9, 3.9296759840859623`*^9, 3.929696998329009*^9, 
   3.9297618279994636`*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"04073e35-1832-4645-8975-1f9aac490743"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ORDgINF", "=", "8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g1", "[", "x_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"gi", "[", "i", "]"}], 
      SuperscriptBox["x", "i"]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"ORDgINF", "+", "2"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SEg1", "=", 
   RowBox[{"Series", "[", 
    RowBox[{"eqgp1", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "\[Infinity]", ",", 
       RowBox[{"ORDgINF", "+", "2"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqsg1inf", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"SeriesCoefficient", "[", 
       RowBox[{"SEg1", ",", "i"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", "ORDgINF"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vag1", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"gi", "[", "i", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgp1INF", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"eqsg1inf", ",", "vag1"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgp2INF", "=", 
   RowBox[{"seriesgp1INF", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Kappa]p", "\[Rule]", "\[Kappa]m"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"\[Phi]1", ",", "\[Phi]2", ",", "g1", ",", "g2"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgm1INF", "=", 
   RowBox[{"seriesgp1INF", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Kappa]p", "\[Rule]", 
      RowBox[{"-", "\[Kappa]p"}]}], "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesgm2INF", "=", 
   RowBox[{"seriesgp2INF", "/.", 
    RowBox[{"{", 
     RowBox[{"\[Kappa]m", "\[Rule]", 
      RowBox[{"-", "\[Kappa]m"}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.929301811711835*^9, {3.929377987581792*^9, 3.9293780011737947`*^9}, 
   3.9293781291953344`*^9},
 CellLabel->"In[44]:=",ExpressionUUID->"c54168f8-5bc8-413d-ba0d-20029ee7e626"],

Cell["We have therefore some possible boundary conditions", "Text",
 CellChangeTimes->{{3.929301885467797*^9, 3.929301897014262*^9}, {
  3.9293408737427025`*^9, 3.929340875022051*^9}, {3.929611292779417*^9, 
  3.929611293203514*^9}},ExpressionUUID->"00b8a635-c5a9-4f0f-af3f-\
7dd580430ba2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Phi]1infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Kappa]p", " ", 
          RowBox[{"rst", "[", "r", "]"}]}], "-", 
         RowBox[{
          FractionBox["Mt", "\[Kappa]p"], " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgp1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]1infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Kappa]p", " ", 
             RowBox[{"rst", "[", "r", "]"}]}], "-", 
            RowBox[{
             FractionBox["Mt", "\[Kappa]p"], " ", 
             RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgp1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]2infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Kappa]m", " ", 
          RowBox[{"rst", "[", "r", "]"}]}], "-", 
         RowBox[{
          FractionBox["Mt", "\[Kappa]m"], " ", 
          RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgp2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]2infp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Kappa]m", " ", 
             RowBox[{"rst", "[", "r", "]"}]}], "-", 
            RowBox[{
             FractionBox["Mt", "\[Kappa]m"], " ", 
             RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgp2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]1infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Kappa]p", " ", 
           RowBox[{"rst", "[", "r", "]"}]}], "-", 
          RowBox[{
           FractionBox["Mt", "\[Kappa]p"], " ", 
           RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgm1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]1infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Kappa]p", " ", 
              RowBox[{"rst", "[", "r", "]"}]}], "-", 
             RowBox[{
              FractionBox["Mt", "\[Kappa]p"], " ", 
              RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgm1INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]01"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Phi]2infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["E", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Kappa]m", " ", 
           RowBox[{"rst", "[", "r", "]"}]}], "-", 
          RowBox[{
           FractionBox["Mt", "\[Kappa]m"], " ", 
           RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
      RowBox[{"(", 
       RowBox[{"Sum", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"gi", "[", "i", "]"}], 
          SuperscriptBox["r", "i"]], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", 
           RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}], ")"}]}], "/.", 
     "seriesgm2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"d\[Phi]2infm", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["E", 
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Kappa]m", " ", 
              RowBox[{"rst", "[", "r", "]"}]}], "-", 
             RowBox[{
              FractionBox["Mt", "\[Kappa]m"], " ", 
              RowBox[{"Log", "[", "r", "]"}]}]}], ")"}]}]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"gi", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"ORDgINF", "-", "1"}]}], "}"}]}], "]"}]}], ")"}], ",", 
       "r"}], "]"}], "/.", "seriesgm2INF"}], "/.", 
    RowBox[{
     RowBox[{"gi", "[", "0", "]"}], "\[Rule]", "\[Phi]02"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.549306349150929*^9, 3.549306466408806*^9}, {
   3.549306506116749*^9, 3.5493066062179193`*^9}, 3.549306783897386*^9, {
   3.549306874372128*^9, 3.54930690611703*^9}, {3.549306968185348*^9, 
   3.5493069961053953`*^9}, {3.549307034018713*^9, 3.549307070537508*^9}, {
   3.549307147404871*^9, 3.549307170540349*^9}, {3.549308112051601*^9, 
   3.54930813548073*^9}, {3.5493083977470417`*^9, 3.549308421151948*^9}, {
   3.549465135194933*^9, 3.5494651399318943`*^9}, {3.549465246538871*^9, 
   3.549465249298683*^9}, {3.549564293282992*^9, 3.549564303836585*^9}, {
   3.549566862048184*^9, 3.549566879444447*^9}, {3.549566982238987*^9, 
   3.549567011822197*^9}, {3.557481739284869*^9, 3.557481767696821*^9}, {
   3.557481914705408*^9, 3.557481966296197*^9}, {3.557523476897417*^9, 
   3.557523492212922*^9}, {3.5575687364618893`*^9, 3.55756876197223*^9}, {
   3.559034655725813*^9, 3.5590346984898252`*^9}, {3.55903478495746*^9, 
   3.5590348690719757`*^9}, {3.559035285694399*^9, 3.559035325173521*^9}, {
   3.559036138391244*^9, 3.5590361432442083`*^9}, {3.5590406676256104`*^9, 
   3.5590406725465937`*^9}, {3.559382821023629*^9, 3.55938283847692*^9}, {
   3.55947758200563*^9, 3.559477590333901*^9}, {3.559477650319872*^9, 
   3.559477661262896*^9}, 3.5594880515987587`*^9, {3.8751662786375217`*^9, 
   3.87516631086554*^9}, {3.8751667751010246`*^9, 3.8751667890718665`*^9}, {
   3.875166858284505*^9, 3.875166892297215*^9}, {3.875166944318454*^9, 
   3.8751669497671604`*^9}, {3.897679557335617*^9, 3.8976795791399813`*^9}, {
   3.9293019436666927`*^9, 3.9293019888130674`*^9}, 3.929302039416875*^9, {
   3.9293361836525655`*^9, 3.929336234805143*^9}, {3.9293363478328886`*^9, 
   3.92933637283202*^9}, {3.929339229104553*^9, 3.9293392469115*^9}, {
   3.929339749982477*^9, 3.9293397690903273`*^9}, {3.9293403838404894`*^9, 
   3.9293404117985563`*^9}, {3.929377661727792*^9, 3.9293776804787436`*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"e0460389-5ada-4868-b283-ad54fee139a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"w1", "=", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"]}]]}], ";", 
  RowBox[{"w2", "=", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Sigma]", "-", "\[Omega]"}], ")"}], "2"]}]]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.9293360114424887`*^9, 3.9293360312015777`*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"6b0c3e6b-a6b6-4896-bc7b-15a027826b50"],

Cell["Each of these boundary conditions depend on the frequency", "Text",
 CellChangeTimes->{{3.9293020480135145`*^9, 3.929302052545566*^9}, {
  3.929335988460447*^9, 
  3.9293359977562118`*^9}},ExpressionUUID->"fe10bd0c-eacf-4108-8dd9-\
3103de5854db"]
}, Closed]],

Cell[CellGroupData[{

Cell["Specifying the source terms", "Subsubsection",
 CellChangeTimes->{{3.929302129098925*^9, 3.9293021351277795`*^9}, {
  3.929378146136842*^9, 
  3.929378148047904*^9}},ExpressionUUID->"eaf6ed3a-cd89-45a4-964b-\
3debbf132a88"],

Cell["\<\
Here we show the source terms for a particle in circular motion.\
\>", "Text",
 CellChangeTimes->{{3.9293022422442684`*^9, 3.9293022455866537`*^9}, {
  3.9293023308313518`*^9, 
  3.9293023411541758`*^9}},ExpressionUUID->"f92c49d5-ae87-4de9-80e9-\
7016306fa43f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "Alm1p", ",", "Flmp", ",", "Blm0p", ",", "Blmp", ",", "Almp", ",", "Alm0p",
     ",", "u0", ",", "\[CapitalOmega]0"}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.9293026583471556`*^9, 3.9293026773601675`*^9}, {
  3.9295093589474425`*^9, 3.9295093597694597`*^9}, {3.9295105158190393`*^9, 
  3.9295105181843967`*^9}},
 CellLabel->"In[63]:=",ExpressionUUID->"a97bc482-c471-4ba8-af70-cf3378e7a1e5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Alm1p", "[", "x_", "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Almp", "[", "x_", "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Blmp", "[", "x_", "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Alm0p", "[", "x_", "]"}], ":=", 
   FractionBox[
    RowBox[{"u0", " ", 
     RowBox[{"dir", "[", 
      RowBox[{"x", ",", "rp"}], "]"}], " ", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"2", " ", 
         RowBox[{"M", "[", "x", "]"}]}], "x"]}]], " ", 
     SuperscriptBox[
      RowBox[{"V", "[", "x", "]"}], 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"Yp", "[", "\[Chi]p", "]"}]}], 
    SuperscriptBox["x", "2"]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Blm0p", "[", "x_", "]"}], ":=", 
   FractionBox[
    RowBox[{"u0", " ", "\[CapitalOmega]0", " ", 
     RowBox[{"dir", "[", 
      RowBox[{"x", ",", "rp"}], "]"}], " ", 
     SqrtBox[
      RowBox[{"2", "-", 
       FractionBox[
        RowBox[{"4", " ", 
         RowBox[{"M", "[", "x", "]"}]}], "x"]}]], " ", 
     SqrtBox[
      RowBox[{"V", "[", "x", "]"}]], " ", 
     RowBox[{"Yp", "[", "\[Chi]p", "]"}]}], 
    RowBox[{
     SqrtBox[
      RowBox[{"L", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "L"}], ")"}]}]], " ", "x"}]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.559583366075472*^9, 3.559583383006119*^9}, {
   3.5600202228098917`*^9, 3.5600202229754753`*^9}, 3.8725762990163937`*^9, {
   3.873516249002575*^9, 3.873516296539525*^9}, {3.8735290719085827`*^9, 
   3.8735290729269524`*^9}, {3.929302228065589*^9, 3.9293022402659736`*^9}, {
   3.9293030271233826`*^9, 3.9293030281788883`*^9}, {3.9295093343651295`*^9, 
   3.9295093424621964`*^9}, {3.929510454715167*^9, 3.929510456248176*^9}, {
   3.929510496000614*^9, 3.929510502100645*^9}, 3.9295182175966663`*^9, 
   3.929524547396014*^9},
 CellLabel->"In[64]:=",ExpressionUUID->"ee7ddac8-5e0d-459f-a561-6fca44784295"],

Cell[TextData[{
 "defining the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["u", "0"], TraditionalForm]],ExpressionUUID->
  "dadeec56-8332-4b5e-aebd-bdfd73ff2ea9"],
 " and the rules for spherical harmonics"
}], "Text",
 CellChangeTimes->{{3.929302691755133*^9, 3.9293027139890747`*^9}, 
   3.9293392559691305`*^9, {3.929363210034976*^9, 3.929363212724832*^9}, {
   3.929378019509787*^9, 3.9293780200204196`*^9}, {3.9295104343028297`*^9, 
   3.929510459384275*^9}, {3.929510520786295*^9, 3.929510521414488*^9}, {
   3.9295204473842716`*^9, 3.9295204483411813`*^9}, {3.9296112989737816`*^9, 
   3.929611299453001*^9}},ExpressionUUID->"274fc5b6-309d-4ac0-b5fd-\
9b2923f97934"],

Cell[BoxData[
 RowBox[{
  RowBox[{"u0", "=", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"V", "[", "r", "]"}], "-", 
      RowBox[{
       SuperscriptBox["r", "2"], " ", 
       SuperscriptBox["\[CapitalOmega]0", "2"]}]}], ")"}], 
    RowBox[{
     RowBox[{"-", "1"}], "/", "2"}]]}], ";", 
  RowBox[{"\[CapitalOmega]0", "=", 
   SqrtBox[
    FractionBox[
     RowBox[{
      RowBox[{"V", "'"}], "[", "r", "]"}], 
     RowBox[{"2", "r"}]]]}], ";"}]], "Input",
 CellChangeTimes->{
  3.559583825284994*^9, {3.5595856939332314`*^9, 3.5595857002384853`*^9}, {
   3.9293027603103633`*^9, 3.929302761659951*^9}, {3.9293030544848986`*^9, 
   3.929303063205927*^9}, {3.929303165781002*^9, 3.929303166083785*^9}, {
   3.9293335080975447`*^9, 3.929333508382555*^9}, 3.9293386020217223`*^9, {
   3.929510147021222*^9, 3.929510147737236*^9}, {3.929510607674183*^9, 
   3.9295106290571446`*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"ae368ac1-8e8a-4e0e-8c33-279db5de4456"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rYp", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["Yp", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "\[Chi]p", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"L", 
               RowBox[{"(", 
                RowBox[{"L", "+", "1"}], ")"}]}], "-", 
              RowBox[{
               RowBox[{"m", "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 RowBox[{"\[Chi]p", "^", "2"}]}], ")"}]}]}], ")"}], 
            RowBox[{"Yp", "[", "\[Chi]p", "]"}]}], "-", 
           RowBox[{"2", " ", "\[Chi]p", " ", 
            RowBox[{
             SuperscriptBox["Yp", "\[Prime]",
              MultilineFunction->None], "[", "\[Chi]p", "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["\[Chi]p", "2"]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{"Yp", "[", "\[Chi]p", "]"}], "\[Rule]", 
        RowBox[{"SphericalHarmonicY", "[", 
         RowBox[{"L", ",", "m", ",", 
          RowBox[{"\[Pi]", "/", "2"}], ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Yp", "'"}], "[", "\[Chi]p", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"\[Chi]p", "\[Rule]", "0"}]}], "}"}], "/.", 
     RowBox[{"L", "\[Rule]", "1"}]}], "/.", 
    RowBox[{"m", "\[Rule]", "1"}]}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.8727560914259143`*^9, {3.8730235673299227`*^9, 3.873023581383875*^9}, {
   3.8735161005078697`*^9, 3.8735161046598377`*^9}, 3.873529902197666*^9, {
   3.929303100577754*^9, 3.9293031213426456`*^9}, {3.92934049174562*^9, 
   3.929340493157275*^9}, {3.929510533717362*^9, 3.929510537786005*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"b5e8892f-b99b-4efd-a5da-2f016de06d40"],

Cell["\<\
Finally, we apply for the source terms, simplifying the metric derivatives by \
using the background equations. The source for the first order fundamental \
functions (Kp,H1,\[Phi]1,\[Phi]1\[CloseCurlyQuote],\[Phi]2,\[Phi]2\
\[CloseCurlyQuote]), is given by\
\>", "Text",
 CellChangeTimes->{{3.9293029241318913`*^9, 3.9293029443564186`*^9}, {
  3.929303309770793*^9, 3.9293033113138*^9}, {3.9293405533973427`*^9, 
  3.9293405538612337`*^9}},ExpressionUUID->"04462254-12a0-4387-b3cf-\
7cecdd50db01"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SOURCEN", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"SOURCE", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"SOURCE", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", "0", ",", 
        RowBox[{"SOURCE", "[", 
         RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "//.", "rYp"}], "/.", 
     RowBox[{"L", "\[Rule]", "1"}]}], "/.", 
    RowBox[{"m", "\[Rule]", "1"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.929302896067937*^9, 3.9293028969256296`*^9}, {
   3.929302951241872*^9, 3.9293030185471787`*^9}, {3.929303316071729*^9, 
   3.9293033591637077`*^9}, {3.929338548428838*^9, 3.9293385505790787`*^9}, {
   3.9295101573618584`*^9, 3.9295101579592457`*^9}, {3.9295104424604692`*^9, 
   3.9295104426102457`*^9}, {3.9295105559334927`*^9, 
   3.9295105781821795`*^9}, {3.929530750702075*^9, 3.929530755181819*^9}, 
   3.9295307961689873`*^9, 3.9295308298190484`*^9, 3.9295310722346077`*^9, {
   3.9295895571607285`*^9, 3.929589559253138*^9}, {3.929594402412272*^9, 
   3.9295944024997187`*^9}, {3.9296113034814167`*^9, 3.9296113044282265`*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"fe477ece-3aea-4ce7-a871-afe878b33353"],

Cell["\<\
We then split the tems that depend on the delta and derivative\
\>", "Text",
 CellChangeTimes->{{3.9293034260884905`*^9, 
  3.929303438614642*^9}},ExpressionUUID->"d9d58b3a-b87d-4084-bd88-\
8d887fc19b57"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SOURCED", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"SOURCEN", ",", 
     RowBox[{"dir", "[", 
      RowBox[{"r", ",", "rp"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SOURCEDD", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"SOURCEN", ",", 
     RowBox[{
      SuperscriptBox["dir", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"r", ",", "rp"}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dSOURCEDD", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"SOURCEDD", ",", "r"}], "]"}], "//.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"eq1", ",", "eq2", ",", "eq3"}], "}"}], "\[Equal]", "0"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"V", "'"}], "[", "r", "]"}], ",", 
         RowBox[{
          RowBox[{"M", "'"}], "[", "r", "]"}], ",", 
         RowBox[{
          RowBox[{"\[Phi]0", "''"}], "[", "r", "]"}]}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.9293034571944857`*^9, 3.929303497117684*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"a170f8b1-730d-41f3-af6a-2533479c94d2"],

Cell["\<\
We are now able to integrate the equation. Let us start with the homogeneous \
system.\
\>", "Text",
 CellChangeTimes->{{3.92930318243312*^9, 3.9293032001157656`*^9}, {
  3.9293035037169275`*^9, 
  3.929303504684022*^9}},ExpressionUUID->"247dd1c1-e6f3-408d-9ef0-\
aebb0ad1d76c"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrating the homogeneous system", "Subsubsection",
 CellChangeTimes->{{3.9293032107375164`*^9, 
  3.9293032155647516`*^9}},ExpressionUUID->"f4c5ad7f-8412-488a-99f1-\
2e4451dadd06"],

Cell["\<\
To obtain the homogeneous matrix, we integrate three times from the origin \
and three times from the infinity. First we define the integrations as \
functions of the amplitudes\
\>", "Text",
 CellChangeTimes->{{3.929303217918003*^9, 3.929303248205279*^9}, {
  3.9293035078250914`*^9, 3.9293035084938097`*^9}, {3.929332147099522*^9, 
  3.929332163750059*^9}},ExpressionUUID->"af8c4859-5d86-45ae-84cc-\
ae39b9c53403"],

Cell[BoxData[
 RowBox[{
  RowBox[{"INT", "[", 
   RowBox[{"r01_", ",", "rp0_", ",", "r02_", ",", "rules_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Integrating", " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"paramint2", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"MaxSteps", "\[Rule]", "\[Infinity]"}], ",", 
       RowBox[{"Method", "\[Rule]", "\"\<StiffnessSwitching\>\""}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "20"}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "10"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"paramp", "=", 
     RowBox[{"{", 
      RowBox[{"\[Sigma]", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[CapitalOmega]0", "/.", "rules"}], "/.", 
         RowBox[{"r", "\[Rule]", "rp0"}]}], ")"}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Defining", " ", "the", " ", "equations"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"EQSP", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Thread", "[", 
        RowBox[{"EQHOM", "\[Equal]", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "]"}], "/.", "paramp"}],
       "/.", "rules"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Integrations", " ", "from", " ", "the", " ", "origin"}], "*)"}],
     "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"boundary", " ", "conditions"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"BOU", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"H0", "[", "r", "]"}], ",", 
             RowBox[{"H2", "[", "r", "]"}], ",", 
             RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
             RowBox[{
              RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "\[Equal]", 
           "BOUNOR2"}], "]"}], "/.", 
         RowBox[{
          SubscriptBox["Vi", "0"], "\[Rule]", "scal"}]}], "/.", "paramp"}], "/.", 
       RowBox[{"r", "\[Rule]", "r01"}]}], "/.", "rules"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", "integration", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"SOL1", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{"EQSP", ",", "BOU"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["f1", "0"], "\[Rule]", "1"}], ",", 
           RowBox[{
            SubscriptBox["h0", "0"], "\[Rule]", "0"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"H2", ",", "H0", ",", "\[Phi]1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r01", ",", "rp0"}], "}"}], ",", "paramint2"}], 
       "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"boundary", " ", "conditions"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"BOU4", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"H0", "[", "r", "]"}], ",", 
             RowBox[{"H2", "[", "r", "]"}], ",", 
             RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
             RowBox[{
              RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "\[Equal]", 
           "BOUNOR2"}], "]"}], "/.", 
         RowBox[{
          SubscriptBox["Vi", "0"], "\[Rule]", "scal"}]}], "/.", "paramp"}], "/.", 
       RowBox[{"r", "\[Rule]", "r01"}]}], "/.", "rules"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", "integration", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"SOL4", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{"EQSP", ",", "BOU4"}], "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["f1", "0"], "\[Rule]", "0"}], ",", 
           RowBox[{
            SubscriptBox["h0", "0"], "\[Rule]", "1"}]}], "}"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"H2", ",", "H0", ",", "\[Phi]1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "r01", ",", "rp0"}], "}"}], ",", "paramint2"}], 
       "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Integrations", " ", "from", " ", "infinity"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"To", " ", "improve", " ", "boundary", " ", 
      RowBox[{"conditions", ".", " ", "We"}], " ", "first", " ", "integrate", 
      " ", "from", " ", "the", " ", "vacuum", " ", "region"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"for", " ", "the", " ", "gravitational", " ", 
      RowBox[{"part", ".", " ", "We"}], " ", "left", " ", "the", " ", 
      "scalar", " ", "and", " ", "gravitational", " ", "parts", " ", 
      "separately", " ", "as", " ", "scales", " ", "can", " ", "be", " ", 
      "different"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"for", " ", "the", " ", "scalar", " ", 
       RowBox[{"part", ".", " ", "There"}], " ", "are", " ", "a", " ", 
       "bunch", " ", "of", " ", "Ifs"}], ",", " ", 
      RowBox[{
      "to", " ", "account", " ", "for", " ", "different", " ", "values", " ", 
       "of", " ", "the", " ", "frequency"}]}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"EQSVACS", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"EQSVAC", "[", 
          RowBox[{"[", "3", "]"}], "]"}], "\[Equal]", "0"}], "}"}], "/.", 
       "paramp"}], "/.", "rules"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"1", "-", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"]}], ">", "0"}], 
        "/.", "paramp"}], "/.", "rules"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"BOUSI", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                "\[Phi]1infm"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                "d\[Phi]1infm"}]}], "}"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
               RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
            RowBox[{"r", "->", "rinf"}]}], "/.", "paramp"}], "/.", "rules"}], 
         "/.", 
         RowBox[{"{", 
          RowBox[{"\[Phi]01", "\[Rule]", "1"}], "}"}]}]}], ";"}], 
      "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"BOUSIi", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                "\[Phi]1infp"}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                "d\[Phi]1infp"}]}], "}"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
               RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
            RowBox[{"r", "\[Rule]", "r02"}]}], "/.", "paramp"}], "/.", 
          "rules"}], "/.", 
         RowBox[{"{", 
          RowBox[{"\[Phi]01", "\[Rule]", "1"}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"S\[Phi]1", "=", 
        RowBox[{
         RowBox[{"NDSolve", "[", 
          RowBox[{
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"EQSVACS", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "}"}], ",", "BOUSIi"}], "]"}], 
           ",", "\[Phi]1", ",", 
           RowBox[{"{", 
            RowBox[{"r", ",", "r02", ",", 
             RowBox[{"rinf", "/.", "rules"}]}], "}"}], ",", "paramint2"}], 
          "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"BOUSI", "=", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]1", "[", "r", "]"}], "\[Equal]", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Phi]1", "[", "r", "]"}], "/.", "S\[Phi]1"}], 
                 ")"}]}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "\[Equal]", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}], "/.", 
                  "S\[Phi]1"}], ")"}]}]}], "}"}], "/.", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Kappa]p", "\[Rule]", "w1"}], ",", 
               RowBox[{"\[Kappa]m", "\[Rule]", "w2"}]}], "}"}]}], "/.", 
            RowBox[{"r", "->", "rinf"}]}], "/.", "paramp"}], "/.", "rules"}], 
         "/.", 
         RowBox[{"{", 
          RowBox[{"\[Phi]01", "\[Rule]", "1"}], "}"}]}]}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{
     "Now", " ", "we", " ", "can", " ", "finally", " ", "integrate", " ", 
      "inside", " ", "the", " ", "star", " ", "up", " ", "to", " ", "the", 
      " ", 
      RowBox[{"particle", "'"}], "s", " ", "position"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"BOUINF2", "=", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"H0", "[", 
           RowBox[{"rinf", "/.", "rules"}], "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"H2", "[", 
           RowBox[{"rinf", "/.", "rules"}], "]"}], "\[Equal]", "0"}]}], "}"}],
        ",", "BOUSI"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"SOL2", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"EQSP", ",", "BOUINF2"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"H0", ",", "H2", ",", "\[Phi]1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", 
          RowBox[{"rinf", "/.", "rules"}], ",", "rp0"}], "}"}], ",", 
        "paramint2"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Third", " ", "integration"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"BOUGI", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"H0", "[", "r", "]"}], ",", 
             RowBox[{"H2", "[", "r", "]"}]}], "}"}], "\[Equal]", "BOUGRAV"}], 
          "]"}], "/.", 
         RowBox[{
          SubscriptBox["h2i", "0"], "\[Rule]", "1"}]}], "/.", "paramp"}], "/.", 
       RowBox[{"r", "\[Rule]", "rinf"}]}], "//.", "rules"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"BOUINF3", "=", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"BOUGI", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Phi]1", "[", 
            RowBox[{"rinf", "/.", "rules"}], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Phi]1", "'"}], "[", 
            RowBox[{"rinf", "/.", "rules"}], "]"}], "\[Equal]", "0"}]}], 
         "}"}]}], "]"}], "/.", 
      RowBox[{
       SubscriptBox["h2i", "0"], "\[Rule]", "1"}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"SOL3", "=", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{"EQSP", ",", "BOUINF3"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"H0", ",", "H2", ",", "\[Phi]1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", 
          RowBox[{"rinf", "/.", "rules"}], ",", "rp0"}], "}"}], ",", 
        "paramint2"}], "]"}], "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.9293321735191293`*^9, 3.929332188272459*^9}, {
   3.929332366961613*^9, 3.929332463937969*^9}, {3.929332568985113*^9, 
   3.9293325730069304`*^9}, {3.929333308287141*^9, 3.929333424256067*^9}, {
   3.9293334747519255`*^9, 3.929333536008857*^9}, {3.9293345735165076`*^9, 
   3.929334603357423*^9}, {3.929334633415614*^9, 3.929334663396658*^9}, {
   3.929334698161705*^9, 3.9293347545373325`*^9}, {3.92933485238332*^9, 
   3.9293348533522973`*^9}, {3.929334898322174*^9, 3.9293353863499556`*^9}, {
   3.9293354303153057`*^9, 3.9293357077403345`*^9}, {3.929335862009441*^9, 
   3.9293359571370525`*^9}, {3.9293360451401944`*^9, 
   3.9293361775997562`*^9}, {3.9293362481944113`*^9, 3.929336334255066*^9}, {
   3.929336568245969*^9, 3.929336865128681*^9}, {3.929336952543502*^9, 
   3.929337017284218*^9}, {3.929337053452876*^9, 3.929337163226738*^9}, {
   3.929337201757922*^9, 3.9293372042354155`*^9}, {3.9293372820784197`*^9, 
   3.9293373245631943`*^9}, {3.929337382982788*^9, 3.9293375690242195`*^9}, {
   3.9293376095454226`*^9, 3.9293376113919687`*^9}, {3.929338057621595*^9, 
   3.9293380580381327`*^9}, 3.9293383709663477`*^9, 3.929339296549758*^9, {
   3.92934037017126*^9, 3.929340377016081*^9}, {3.9293634247685213`*^9, 
   3.929363429375661*^9}, {3.9293641069731445`*^9, 3.929364113383202*^9}, {
   3.929364325166173*^9, 3.9293643778943357`*^9}, {3.9293644664064646`*^9, 
   3.929364479157464*^9}, {3.9293645155503902`*^9, 3.9293645212871923`*^9}, {
   3.929368864523243*^9, 3.9293688651211615`*^9}, {3.929377705742117*^9, 
   3.9293777532956767`*^9}, 3.929407751078015*^9, {3.9295107528214045`*^9, 
   3.9295107566536393`*^9}, {3.929511618536357*^9, 3.929511651776209*^9}, {
   3.929511682379183*^9, 3.929511690174424*^9}, {3.929511761103668*^9, 
   3.929511787057203*^9}, {3.9295118246393957`*^9, 3.9295120403958178`*^9}, 
   3.9295174609640045`*^9, 3.9295182364693356`*^9, {3.9295187216756153`*^9, 
   3.9295190486221676`*^9}, {3.929531348492665*^9, 3.929531348658373*^9}, {
   3.9295881890365067`*^9, 3.92958831224059*^9}, 3.929588355774564*^9, {
   3.9295888042893906`*^9, 3.929588808579855*^9}, {3.929589566962397*^9, 
   3.9295895773437605`*^9}, {3.929594429881216*^9, 3.929594431251536*^9}, {
   3.9296113112615004`*^9, 3.929611378310483*^9}},
 CellLabel->"In[76]:=",ExpressionUUID->"1a0da7b8-1818-4ec8-9aca-5f0f6c1aa461"],

Cell["\<\
With the integrator above, we can construct the fundamental matrix\
\>", "Text",
 CellChangeTimes->{{3.9293376291114826`*^9, 
  3.929337640641464*^9}},ExpressionUUID->"7f4123a1-2a48-4634-a1d2-\
0c338394394a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MATRIX", "[", 
   RowBox[{"r01_", ",", "rp0_", ",", "r02_", ",", "rules_"}], "]"}], ":=", 
  RowBox[{"(", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"INT", "[", 
     RowBox[{"r01", ",", "rp0", ",", "r02", ",", "rules"}], "]"}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]1", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], ",", 
        RowBox[{"H2", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL1"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]2", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], ",", 
        RowBox[{"H2", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL2"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]3", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], ",", 
        RowBox[{"H2", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL3"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"\[CapitalPsi]4", "=", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"H0", "[", "r", "]"}], ",", 
        RowBox[{"H2", "[", "r", "]"}], ",", 
        RowBox[{"\[Phi]1", "[", "r", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Phi]1", "'"}], "[", "r", "]"}]}], "}"}], "/.", "SOL4"}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"For", " ", "the", " ", "Matrix"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"XS", "=", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\[CapitalPsi]1", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]2", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]3", "[", 
           RowBox[{"[", "i", "]"}], "]"}], ",", 
          RowBox[{"\[CapitalPsi]4", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "4"}], "}"}]}], "]"}], "/.", 
      RowBox[{"r", "\[Rule]", "rp0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"dXS", "=", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{"XS", ",", "r"}], "]"}], "/.", 
      RowBox[{"r", "\[Rule]", "rp0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"invXS", "=", 
     RowBox[{"Inverse", "[", "XS", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"dinvXS", "=", 
     RowBox[{"-", 
      RowBox[{"invXS", ".", "dXS", ".", "invXS"}]}]}], ";"}], 
   "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.9293376434735155`*^9, 3.9293377283061543`*^9}, {
   3.929337766271801*^9, 3.929337845122262*^9}, {3.929337876111882*^9, 
   3.9293380065407505`*^9}, {3.929338102552593*^9, 3.929338109157919*^9}, {
   3.9295120835751715`*^9, 3.9295121075541706`*^9}, {3.9295165781762156`*^9, 
   3.9295166808422093`*^9}, {3.929518915490575*^9, 3.9295189179405403`*^9}, 
   3.929519067873434*^9, {3.929530770153865*^9, 3.9295308212241917`*^9}, {
   3.929531063164462*^9, 3.9295310654830203`*^9}, 3.9295882296999464`*^9, {
   3.929589592707337*^9, 3.9295896169479446`*^9}, {3.9295944701257744`*^9, 
   3.929594472713127*^9}, {3.9296113873916664`*^9, 3.929611394600012*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"25a99472-5bc3-40ea-9226-f407a3754d00"],

Cell[BoxData[
 RowBox[{"MATRIX", "[", 
  RowBox[{
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]], ",", "1", ",", "200", ",", "rubkg"}], "]"}]], "Input",
 CellChangeTimes->{{3.929516620581891*^9, 3.9295166386381283`*^9}, {
  3.929516672670351*^9, 3.9295166729442186`*^9}},
 CellLabel->"In[79]:=",ExpressionUUID->"e1941701-f70a-4938-959a-ff6554016420"],

Cell["\<\
With the above and the source term we can construct the particular solution \
to find the fluxes\
\>", "Text",
 CellChangeTimes->{{3.9293381629393234`*^9, 3.9293381803307867`*^9}, {
  3.929378156077294*^9, 
  3.9293781568939595`*^9}},ExpressionUUID->"b7fad3bd-0d99-407c-bef5-\
63b6f4af6508"]
}, Closed]],

Cell[CellGroupData[{

Cell["Using the variation of parameters to find the fluxes", "Subsubsection",
 CellChangeTimes->{{3.9293381889079776`*^9, 
  3.9293382007169466`*^9}},ExpressionUUID->"95abf144-d8df-4614-a2b6-\
fcbcd8282194"],

Cell["\<\
The flux can be computed by making the matrix product of the inverse of X \
with the source term and integrating it. Because of the deltas and \
derivatives, what remains is to compute it at the particle position\
\>", "Text",
 CellChangeTimes->{{3.9293670986276536`*^9, 3.92936709981993*^9}, {
  3.929367200381386*^9, 3.9293672048165307`*^9}, {3.929378158481496*^9, 
  3.9293782099901733`*^9}},ExpressionUUID->"6581738c-c1d4-42aa-8450-\
bd904ad4ad34"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FLUXP", "[", 
   RowBox[{"r01_", ",", "rp0_", ",", "r02_", ",", "rules_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MATRIX", "[", 
     RowBox[{"r01", ",", "rp0", ",", "r02", ",", "rules"}], "]"}], ";", 
    "\[IndentingNewLine]", "paramp", ";", "\[IndentingNewLine]", 
    RowBox[{"rulesY", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Yp", "[", "\[Chi]p", "]"}], "\[Rule]", 
        RowBox[{"SphericalHarmonicY", "[", 
         RowBox[{"1", ",", "1", ",", 
          RowBox[{"\[Pi]", "/", "2"}], ",", "0"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Yp", "'"}], "[", "\[Chi]p", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Yp", "''"}], "[", "\[Chi]p", "]"}], "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"SphericalHarmonicY", "[", 
            RowBox[{"1", ",", "1", ",", "\[Theta]", ",", "0"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"\[Theta]", ",", "2"}], "}"}]}], "]"}]}], "/.", 
        RowBox[{"\[Theta]", "\[Rule]", 
         RowBox[{"\[Pi]", "/", "2"}]}]}]}], "}"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"II", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"invXS", ".", "SOURCED"}], ")"}], "/.", 
        RowBox[{"Union", "[", 
         RowBox[{"param", ",", "rulesY", ",", "rules"}], "]"}]}], "/.", 
       RowBox[{"r", "\[Rule]", "rp0"}]}], "/.", 
      RowBox[{"\[Chi]p", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"dII", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"invXS", ".", "dSOURCEDD"}], "+", 
           RowBox[{"dinvXS", ".", "SOURCEDD"}]}], ")"}]}], "/.", 
        RowBox[{"Union", "[", 
         RowBox[{"param", ",", "rulesY", ",", "rules"}], "]"}]}], "/.", 
       RowBox[{"r", "\[Rule]", "rp0"}]}], "/.", 
      RowBox[{"\[Chi]p", "\[Rule]", "0"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"II\[Phi]1", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"II", "+", "dII"}], ")"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"Computing", " ", "the", " ", "fluxes"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"\[Omega]", "+", "\[CapitalOmega]0"}], ")"}], "2"], "/.",
            "paramp"}], "/.", "rules"}], "/.", 
         RowBox[{"r", "\[Rule]", "rp0"}]}], ")"}], "\[GreaterEqual]", "1"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Phi]f1", "=", "II\[Phi]1"}], " ", ";"}], 
      "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Phi]f1", "=", "0"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{"ScalFlux", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", "\[Pi]"}]], "\[Sigma]", 
        SqrtBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Sigma]", "+", "\[Omega]"}], ")"}], "2"], "-", "1"}]], 
        SuperscriptBox[
         RowBox[{"Abs", "[", "II\[Phi]1", "]"}], "2"]}], "/.", "paramp"}], "/.",
       "rules"}]}], ";"}], "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.929338289527746*^9, 3.929338315339635*^9}, {
   3.9293384197855415`*^9, 3.9293384577761526`*^9}, {3.929338611700952*^9, 
   3.9293386138132067`*^9}, {3.9293386669887347`*^9, 3.92933866866003*^9}, {
   3.9293387044652863`*^9, 3.9293387084473004`*^9}, {3.929338895355666*^9, 
   3.9293388955157614`*^9}, 3.9293655945357094`*^9, {3.9293662396862564`*^9, 
   3.929366351772291*^9}, {3.9293678887572613`*^9, 3.9293678902406263`*^9}, {
   3.9293680297342386`*^9, 3.9293680311952095`*^9}, {3.9293686926192536`*^9, 
   3.9293686969912214`*^9}, {3.929516876390246*^9, 3.929516963158777*^9}, {
   3.929517020137187*^9, 3.9295170420232024`*^9}, {3.929517301329174*^9, 
   3.929517301821022*^9}, {3.929517366968548*^9, 3.9295173671033*^9}, {
   3.9295181049129443`*^9, 3.9295181058575573`*^9}, 3.9295183210788364`*^9, {
   3.929519079090405*^9, 3.9295190933332148`*^9}, {3.929523401878318*^9, 
   3.9295234019837775`*^9}, 3.9295246363163185`*^9, {3.929529731306241*^9, 
   3.9295297317774506`*^9}, {3.9296161872540855`*^9, 3.9296161877887464`*^9}},
 CellLabel->"In[80]:=",ExpressionUUID->"c9b92acc-e693-4303-9918-319d1bf4e46a"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 966},
WindowMargins->{{-9, Automatic}, {Automatic, -9}},
Magnification:>1.4 Inherited,
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 197, 3, 40, "Input",ExpressionUUID->"5eabe3ca-11f0-4ce6-8804-d967e41bc368"],
Cell[CellGroupData[{
Cell[780, 27, 325, 6, 135, "Title",ExpressionUUID->"14d7fb90-fe0a-4865-b7df-e69fb8f5009f"],
Cell[1108, 35, 361, 9, 40, "Input",ExpressionUUID->"eae332e9-1963-468e-9c8a-2308583eb3a2"],
Cell[1472, 46, 244, 6, 48, "Text",ExpressionUUID->"5e768322-87f5-49f8-acd1-d8d850091437"],
Cell[CellGroupData[{
Cell[1741, 56, 182, 3, 92, "Section",ExpressionUUID->"f4ea5f2e-aa29-430f-8578-b770ed4148e2"],
Cell[CellGroupData[{
Cell[1948, 63, 215, 4, 62, "Subsubsection",ExpressionUUID->"f6e5c295-8482-44a5-a551-5a2a76549749"],
Cell[2166, 69, 1050, 30, 116, "Text",ExpressionUUID->"8b4750ff-2197-4f67-9c3e-7a89be4400bb"],
Cell[3219, 101, 3406, 102, 201, "Input",ExpressionUUID->"e1880841-24cc-4cae-b8e9-325b9064d94f"],
Cell[6628, 205, 457, 8, 47, "Text",ExpressionUUID->"a0624733-4ecc-4359-b2a6-601f9f46e3d3"],
Cell[7088, 215, 260, 5, 39, "Input",ExpressionUUID->"f6e01616-10d4-46fe-a1c6-54f0fcc29d36"],
Cell[7351, 222, 1562, 44, 109, "Input",ExpressionUUID->"a1c63b01-86f0-4fdb-888c-bf24235333cf"],
Cell[8916, 268, 191, 3, 47, "Text",ExpressionUUID->"d3be96c5-693c-470d-b376-544af8772911"],
Cell[CellGroupData[{
Cell[9132, 275, 1559, 41, 45, "Input",ExpressionUUID->"a43dc386-a53b-4b48-be3c-ef3f91e39b17"],
Cell[10694, 318, 9507, 266, 70, "Output",ExpressionUUID->"e17d01d4-5928-4e07-8866-e4000a456532"]
}, Open  ]],
Cell[20216, 587, 225, 5, 47, "Text",ExpressionUUID->"05300666-11d5-4d92-8823-838f19fcbccb"],
Cell[20444, 594, 493, 13, 39, "Input",ExpressionUUID->"57ffd28c-7a55-443c-8248-3ed515c80611"],
Cell[20940, 609, 274, 5, 39, "Input",ExpressionUUID->"3dc87e96-66ab-4f49-9e4e-413980dc70e7"],
Cell[21217, 616, 221, 3, 47, "Text",ExpressionUUID->"1af02619-a71b-4478-98bf-849ee767fd29"]
}, Closed]],
Cell[CellGroupData[{
Cell[21475, 624, 193, 3, 49, "Subsubsection",ExpressionUUID->"6a305c5a-d0c6-4b1c-9c1f-c3aacc4df08e"],
Cell[21671, 629, 1066, 28, 127, "Text",ExpressionUUID->"dbc38347-e4fc-447e-8b43-906ba1d0ff68"],
Cell[22740, 659, 5749, 147, 898, "Input",ExpressionUUID->"276e9363-6de0-4957-a8a1-d2d14d5733ea"],
Cell[28492, 808, 420, 8, 47, "Text",ExpressionUUID->"d96ffe01-a0c3-43ae-9d7e-f40613916870"]
}, Closed]],
Cell[CellGroupData[{
Cell[28949, 821, 239, 4, 49, "Subsubsection",ExpressionUUID->"6bf26153-0215-45d2-abe5-0667fa1f0a4a"],
Cell[29191, 827, 246, 6, 48, "Text",ExpressionUUID->"5e934734-14e1-4240-ad31-a2aad47b5743"],
Cell[29440, 835, 435, 8, 40, "Input",ExpressionUUID->"d176f7a7-a063-4622-bbf6-ccbe17a362b0"],
Cell[29878, 845, 256, 4, 48, "Text",ExpressionUUID->"ec50739c-c2aa-4b04-902a-64dc73deb85b"],
Cell[CellGroupData[{
Cell[30159, 853, 1008, 18, 69, "Input",ExpressionUUID->"3e41872e-765f-4c4f-beb2-2d911ed40523"],
Cell[31170, 873, 1386, 20, 46, "Output",ExpressionUUID->"818745a3-abfa-4eb5-a08e-ead49fc735f8"],
Cell[32559, 895, 1334, 18, 46, "Output",ExpressionUUID->"e4f72978-51c1-46f5-9724-d64c8a37bda4"]
}, Open  ]],
Cell[33908, 916, 188, 3, 48, "Text",ExpressionUUID->"edd9cfed-2ea1-40be-ac13-4ee2c40a1b5e"],
Cell[CellGroupData[{
Cell[34121, 923, 758, 16, 68, "Input",ExpressionUUID->"fc7d3f4b-d5ca-4a50-be91-a977abdb3d78"],
Cell[34882, 941, 14884, 296, 323, "Output",ExpressionUUID->"19988f73-bc7e-400a-922c-708c63ed4849"]
}, Open  ]],
Cell[49781, 1240, 334, 7, 48, "Text",ExpressionUUID->"724b293e-196d-464a-912e-5cb9949761a4"],
Cell[50118, 1249, 2222, 56, 97, "Input",ExpressionUUID->"71f444f7-014f-4da8-8038-0030508ff14d"],
Cell[52343, 1307, 180, 3, 48, "Text",ExpressionUUID->"498ab69e-9751-4f4f-9f46-3b315e323f04"]
}, Closed]],
Cell[CellGroupData[{
Cell[52560, 1315, 298, 4, 49, "Subsubsection",ExpressionUUID->"ccbde603-85c3-4ed7-a286-6d042a19e157"],
Cell[52861, 1321, 246, 6, 44, "Text",ExpressionUUID->"5c931606-38ff-4a30-872b-1a495c89a165"],
Cell[53110, 1329, 688, 10, 37, "Input",ExpressionUUID->"b57ec35a-a3a2-49d4-8e4a-16feb57183f3"],
Cell[53801, 1341, 256, 4, 44, "Text",ExpressionUUID->"21f81a58-63a8-49fd-b1c9-f9747f4a7a46"],
Cell[CellGroupData[{
Cell[54082, 1349, 1261, 21, 63, "Input",ExpressionUUID->"3ca05f87-f0d0-4d53-9b27-39e2b61985c7"],
Cell[55346, 1372, 1764, 25, 43, "Output",ExpressionUUID->"61d3cbf8-ac71-43c8-b8d2-3789f6104f9b"],
Cell[57113, 1399, 1714, 23, 43, "Output",ExpressionUUID->"8b05f4d0-f504-472c-9966-5528886e8399"]
}, Open  ]],
Cell[58842, 1425, 188, 3, 44, "Text",ExpressionUUID->"bde97fcc-e003-4c87-a4a9-32c543005443"],
Cell[CellGroupData[{
Cell[59055, 1432, 856, 17, 57, "Input",ExpressionUUID->"e2c1baa2-d88f-48dc-bc81-1667586ba7e0"],
Cell[59914, 1451, 9391, 182, 303, "Output",ExpressionUUID->"b8001d49-6b95-444b-a028-7d9983f16411"]
}, Open  ]],
Cell[69320, 1636, 334, 7, 44, "Text",ExpressionUUID->"91b5d5cf-ba05-4c16-b592-68fdc8fbf82e"],
Cell[69657, 1645, 2222, 56, 63, "Input",ExpressionUUID->"15f3121a-d64c-4f6c-a8ca-a4b1e0f90c01"]
}, Closed]],
Cell[CellGroupData[{
Cell[71916, 1706, 363, 6, 49, "Subsubsection",ExpressionUUID->"7b524ab4-c59d-4dc9-8e70-7a831a78f0aa"],
Cell[72282, 1714, 292, 7, 44, "Text",ExpressionUUID->"6c1473b1-8a3d-469f-a528-3c0871e8d781"],
Cell[72577, 1723, 915, 14, 37, "Input",ExpressionUUID->"d13655f6-0f42-443e-a2f1-5c524a55670b"],
Cell[73495, 1739, 210, 4, 44, "Text",ExpressionUUID->"acfbb88a-a8e3-4be3-ace5-4e782133f2ea"],
Cell[CellGroupData[{
Cell[73730, 1747, 1357, 23, 63, "Input",ExpressionUUID->"0ed91164-798a-43fd-88a0-125f1059f539"],
Cell[75090, 1772, 2351, 33, 43, "Output",ExpressionUUID->"acb3f1e7-4186-4052-9ec9-ecab6594333c"],
Cell[77444, 1807, 2299, 31, 43, "Output",ExpressionUUID->"d2e4edf3-cf20-44f4-a632-31d1f27daa3b"]
}, Open  ]],
Cell[79758, 1841, 188, 3, 44, "Text",ExpressionUUID->"b4c81d4f-31b8-4ba3-beae-3e1688815327"],
Cell[CellGroupData[{
Cell[79971, 1848, 890, 18, 57, "Input",ExpressionUUID->"abc4925c-c363-41e2-bdb1-1fbf15ccd861"],
Cell[80864, 1868, 14591, 282, 302, "Output",ExpressionUUID->"fe561659-2761-4c6d-9ad2-6970f5bb9439"]
}, Open  ]],
Cell[95470, 2153, 334, 7, 44, "Text",ExpressionUUID->"4baa6d49-ff90-4d66-8596-a80f34509732"],
Cell[95807, 2162, 1233, 19, 37, "Input",ExpressionUUID->"ae98ff27-cff3-4fe5-8d71-9e2fd106f123"],
Cell[97043, 2183, 1115, 30, 42, "Input",ExpressionUUID->"991d8425-ba17-46ba-b01d-ad89659b97e7"],
Cell[98161, 2215, 3547, 89, 105, "Input",ExpressionUUID->"3ae589e8-e254-4882-894e-01f6d6ad7af3"],
Cell[101711, 2306, 315, 7, 44, "Text",ExpressionUUID->"87a27ed7-d56a-4451-a79e-019f9527e813"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[102075, 2319, 339, 5, 92, "Section",ExpressionUUID->"15a3b179-6f49-451b-838b-7ef3c4b3da1c"],
Cell[CellGroupData[{
Cell[102439, 2328, 179, 3, 62, "Subsubsection",ExpressionUUID->"61da9da6-53ec-4046-9e88-38e1a7d7f592"],
Cell[102621, 2333, 321, 6, 48, "Text",ExpressionUUID->"f3baf43d-edf0-4a6a-a058-ca67af8ef9d3"],
Cell[102945, 2341, 65647, 1633, 1333, "Input",ExpressionUUID->"dca04bf3-e9cf-41db-9343-24452a1b67ec"],
Cell[CellGroupData[{
Cell[168617, 3978, 1305, 35, 69, "Input",ExpressionUUID->"6c03b161-25fc-4a16-92a4-8d882f6ccc80"],
Cell[169925, 4015, 25365, 662, 458, "Output",ExpressionUUID->"42116b41-0e19-46b5-971f-6deec3f803ef"]
}, Open  ]],
Cell[195305, 4680, 204, 3, 48, "Text",ExpressionUUID->"a006cc56-8d6b-4619-8972-1e068e9a049d"],
Cell[195512, 4685, 2181, 63, 69, "Input",ExpressionUUID->"2d75aa07-073b-4efd-bb05-bc65ad75a54d"],
Cell[CellGroupData[{
Cell[197718, 4752, 208, 3, 40, "Input",ExpressionUUID->"2c611093-fd22-4671-b92c-8d12d7e5190d"],
Cell[197929, 4757, 20540, 530, 369, "Output",ExpressionUUID->"4f30ec9a-8a4a-4b30-a6cd-5a929ea215be"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[218518, 5293, 198, 3, 49, "Subsubsection",ExpressionUUID->"27e0e6e7-3352-4504-b1d4-67ecee84ddb7"],
Cell[218719, 5298, 424, 8, 40, "Input",ExpressionUUID->"02f23ecc-1981-4c57-8694-c7bbe43cdc55"],
Cell[219146, 5308, 230, 4, 48, "Text",ExpressionUUID->"763bba11-cf34-48c1-9f61-d4fd9e562ba9"],
Cell[219379, 5314, 2656, 82, 211, "Input",ExpressionUUID->"86b56670-c735-4a05-9eca-0a2fdfe41c9f"],
Cell[CellGroupData[{
Cell[222060, 5400, 1440, 30, 44, "Input",ExpressionUUID->"c59a5dee-45d1-4ab3-8953-0bbc6e38079f"],
Cell[223503, 5432, 18376, 418, 332, "Output",ExpressionUUID->"022b751f-c726-49c3-8204-b17797c7c467"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241916, 5855, 1320, 27, 40, "Input",ExpressionUUID->"543199bb-62c8-49c6-afe4-6c59574133c6"],
Cell[243239, 5884, 7535, 195, 222, "Output",ExpressionUUID->"489d3e5f-1a31-4183-a433-beedd4c59a5d"]
}, Open  ]],
Cell[250789, 6082, 548, 15, 40, "Input",ExpressionUUID->"295a2572-6ecf-4238-a83e-d595a94cd4ed"],
Cell[251340, 6099, 280, 6, 40, "Input",ExpressionUUID->"435cf253-1dd7-4a40-8205-ba3084ad7ffa"]
}, Closed]],
Cell[CellGroupData[{
Cell[251657, 6110, 194, 3, 49, "Subsubsection",ExpressionUUID->"5b50ea05-fe56-478d-bea8-ad176e197605"],
Cell[251854, 6115, 451, 9, 48, "Text",ExpressionUUID->"f9e96fae-7db2-4d0a-b3a9-995a80b11787"],
Cell[252308, 6126, 350, 7, 40, "Input",ExpressionUUID->"b5a42ae7-38d1-4879-8021-ab0a9cd2d6f8"],
Cell[252661, 6135, 316, 7, 48, "Text",ExpressionUUID->"d81d3267-c427-4384-bf37-4c871c34e5af"],
Cell[252980, 6144, 732, 20, 66, "Input",ExpressionUUID->"bd6f9326-b349-4705-bd27-453bba7b10ed"],
Cell[253715, 6166, 375, 7, 48, "Text",ExpressionUUID->"eda37429-16b1-4241-9f89-dbc20c63f55d"],
Cell[CellGroupData[{
Cell[254115, 6177, 305, 6, 40, "Input",ExpressionUUID->"f2f3de56-393c-4d73-a839-278b40f05585"],
Cell[254423, 6185, 1942, 52, 84, "Output",ExpressionUUID->"b427dda9-ef3c-41a0-ba6b-3a09e3a44bf8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[256402, 6242, 954, 29, 95, "Input",ExpressionUUID->"5d010054-d64b-40d8-a19c-969535316c67"],
Cell[257359, 6273, 1088, 24, 67, "Output",ExpressionUUID->"d0453d4b-13c9-41d9-b336-02bd2e8852dc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258484, 6302, 1224, 37, 72, "Input",ExpressionUUID->"f77ea2b0-630a-4f65-8b96-6a924db1490c"],
Cell[259711, 6341, 1446, 37, 75, "Output",ExpressionUUID->"e2f6a77a-3c04-4550-aa37-d47d2c289cca"]
}, Open  ]],
Cell[261172, 6381, 989, 26, 73, "Input",ExpressionUUID->"2e04dcea-b248-421c-b697-fa9ddf1cf4fb"],
Cell[262164, 6409, 337, 7, 40, "Input",ExpressionUUID->"a8711366-7c77-4a8f-8a49-c84c61846fc2"],
Cell[262504, 6418, 393, 7, 48, "Text",ExpressionUUID->"54f1ea96-474d-4828-839d-b5bb4b558ab0"],
Cell[262900, 6427, 452, 9, 40, "Input",ExpressionUUID->"f09364b1-7395-48bc-b6cb-7c0e3167e7c2"],
Cell[263355, 6438, 183, 3, 48, "Text",ExpressionUUID->"56316e54-5b6e-4b3a-b500-627f13f36f87"],
Cell[263541, 6443, 390, 10, 64, "Input",ExpressionUUID->"85134623-5072-4c86-9b79-004e6d6c5a17"],
Cell[CellGroupData[{
Cell[263956, 6457, 1718, 52, 78, "Input",ExpressionUUID->"82c5db82-d48f-48fd-8630-9c4c5afebd66"],
Cell[265677, 6511, 3148, 81, 77, "Output",ExpressionUUID->"04073e35-1832-4645-8975-1f9aac490743"]
}, Open  ]],
Cell[268840, 6595, 2390, 73, 325, "Input",ExpressionUUID->"c54168f8-5bc8-413d-ba0d-20029ee7e626"],
Cell[271233, 6670, 290, 4, 48, "Text",ExpressionUUID->"00b8a635-c5a9-4f0f-af3f-7dd580430ba2"],
Cell[271526, 6676, 8984, 247, 489, "Input",ExpressionUUID->"e0460389-5ada-4868-b283-ad54fee139a7"],
Cell[280513, 6925, 522, 16, 53, "Input",ExpressionUUID->"6b0c3e6b-a6b6-4896-bc7b-15a027826b50"],
Cell[281038, 6943, 252, 4, 48, "Text",ExpressionUUID->"fe10bd0c-eacf-4108-8dd9-3103de5854db"]
}, Closed]],
Cell[CellGroupData[{
Cell[281327, 6952, 229, 4, 49, "Subsubsection",ExpressionUUID->"eaf6ed3a-cd89-45a4-964b-3debbf132a88"],
Cell[281559, 6958, 271, 6, 48, "Text",ExpressionUUID->"f92c49d5-ae87-4de9-80e9-7016306fa43f"],
Cell[281833, 6966, 461, 9, 40, "Input",ExpressionUUID->"a97bc482-c471-4ba8-af70-cf3378e7a1e5"],
Cell[282297, 6977, 2078, 58, 311, "Input",ExpressionUUID->"ee7ddac8-5e0d-459f-a561-6fca44784295"],
Cell[284378, 7037, 675, 14, 48, "Text",ExpressionUUID->"274fc5b6-309d-4ac0-b5fd-9b2923f97934"],
Cell[285056, 7053, 982, 25, 92, "Input",ExpressionUUID->"ae368ac1-8e8a-4e0e-8c33-279db5de4456"],
Cell[286041, 7080, 1981, 50, 44, "Input",ExpressionUUID->"b5e8892f-b99b-4efd-a5da-2f016de06d40"],
Cell[288025, 7132, 508, 9, 48, "Text",ExpressionUUID->"04462254-12a0-4387-b3cf-7cecdd50db01"],
Cell[288536, 7143, 1236, 25, 40, "Input",ExpressionUUID->"fe477ece-3aea-4ce7-a871-afe878b33353"],
Cell[289775, 7170, 214, 5, 48, "Text",ExpressionUUID->"d9d58b3a-b87d-4084-bd88-8d887fc19b57"],
Cell[289992, 7177, 1378, 43, 101, "Input",ExpressionUUID->"a170f8b1-730d-41f3-af6a-2533479c94d2"],
Cell[291373, 7222, 288, 7, 48, "Text",ExpressionUUID->"247dd1c1-e6f3-408d-9ef0-aebb0ad1d76c"]
}, Closed]],
Cell[CellGroupData[{
Cell[291698, 7234, 189, 3, 49, "Subsubsection",ExpressionUUID->"f4c5ad7f-8412-488a-99f1-2e4451dadd06"],
Cell[291890, 7239, 426, 8, 48, "Text",ExpressionUUID->"af8c4859-5d86-45ae-84cc-ae39b9c53403"],
Cell[292319, 7249, 14991, 368, 1005, "Input",ExpressionUUID->"1a0da7b8-1818-4ec8-9aca-5f0f6c1aa461"],
Cell[307313, 7619, 218, 5, 48, "Text",ExpressionUUID->"7f4123a1-2a48-4634-a1d2-0c338394394a"],
Cell[307534, 7626, 3686, 89, 349, "Input",ExpressionUUID->"25a99472-5bc3-40ea-9226-f407a3754d00"],
Cell[311223, 7717, 352, 7, 44, "Input",ExpressionUUID->"e1941701-f70a-4938-959a-ff6554016420"],
Cell[311578, 7726, 301, 7, 48, "Text",ExpressionUUID->"b7fad3bd-0d99-407c-bef5-63b6f4af6508"]
}, Closed]],
Cell[CellGroupData[{
Cell[311916, 7738, 207, 3, 49, "Subsubsection",ExpressionUUID->"95abf144-d8df-4614-a2b6-fcbcd8282194"],
Cell[312126, 7743, 462, 8, 80, "Text",ExpressionUUID->"6581738c-c1d4-42aa-8450-bd904ad4ad34"],
Cell[312591, 7753, 4709, 111, 512, "Input",ExpressionUUID->"c9b92acc-e693-4303-9918-319d1bf4e46a"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

